@@ -42,10 +42,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Supported shells
 //
-#define ISHELL_CL			1
-#define ISHELL_GG			0xFFFFFFFE
-#define ISHELL_QT			2
-//#define ISHELL_FX	4
+#define ISHELL_OS			1
+#define ISHELL_CL			2
+#define ISHELL_GG			0xFFFFFFFC
+#define ISHELL_QT			4
+
+//
+//  Supported scripts
+//
+#define ISCRIPT_PYTHON		1
 
 //
 //  Multiple extensions can be included, they are not exclusive
@@ -57,6 +62,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 #define ISHELL_INCLUDED(_Type_)  ((ISHELL & _Type_) != 0)
 
+//
+//  Multiple scripts can be included, they are not exclusive
+//
+#define ISCRIPT_INCLUDED(_Type_)  ((ISCRIPT & _Type_) != 0)
+
 //
 //  ******************************************************************************
 //
@@ -66,7 +76,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iconfiguresettings.ext.h"
 #else
 #define IEXTENSION	0xFFFFFFFF
-#define ISHELL		0xFFFFFFFF
+#define ISHELL		0xFFFFFFFF 
+#define ISCRIPT		1
 #endif
 //
 //  ******************************************************************************
@@ -77,9 +88,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 !TERMINATE!
 #endif
 
-#if !defined(ISHELL)  || (ISHELL == 0)
+#if !defined(ISHELL) || (ISHELL == 0)
 #error Misconfiguration: shell (ISHELL) is not set.
 !TERMINATE!
 #endif
 
+#if !defined(ISCRIPT)
+#error Misconfiguration: script (ISCRIPT) is not set.
+!TERMINATE!
+#endif
+
 #endif // ICONFIGURE_H
