@@ -35,31 +35,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 
 
-void iEdition::ApplySettings(iObject *obj, const iObjectType &type)
-{
-	if(obj == 0) return;
-
-	iString ws = iEdition::GetObjectSettings(type);
-	if(!ws.IsEmpty())
-	{
-		obj->ReportMissingKeys(false);
-		obj->UnPackCompleteState(ws);
-		obj->ReportMissingKeys(true);
-	}
-}
-
-
 #ifndef I_EDITION
 
-const iString iEdition::GetObjectSettings(const iObjectType &)
+void iEdition::ApplySettings(iObject *obj)
 {
-	return "";
 }
 
 
-const iString iEdition::GetEditionName()
+const iString& iEdition::GetEditionName()
 {
-	return "Standard Edition";
+	static const iString name("Standard Edition");
+	return name;
 }
 
 #endif
