@@ -33,12 +33,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  IFrIT version
 //
-#define IVERSION_BASE			"3.4.2"
-
-#define IVERSION_EXT_ART		"2.4.1"
-#define IVERSION_EXT_MV			"1.2.1"
-#define IVERSION_EXT_VTK		"1.1.0"
-#define IVERSION_EXT_GADGET		"1.1.0"
+#define IVERSION			"4.1.2"
+#define IREVISION			"581"
 
 //
 //  History
@@ -163,10 +159,37 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //			Removed CameraPath Animator mode, fixed title page and logo
 //
 //  121219  Base-3.4.1    ART-2.4.0    MV-1.2.1    VTK-1.1.0     GADGET-1.1.0
-//          Minor bug fix
+//          some bug fixes
 //
 //  130710  Base-3.4.2    ART-2.4.1    MV-1.2.1    VTK-1.1.0     GADGET-1.1.0
-//          Added support for selecting sub-volume of the ART mesh, other minor fixes
+//          some bug fixes
+//
+//  581***********************************************************************
+//          Drop sub-versioning for extensions
+//
+//  140309  4.0.0B1
+//          Full Python integration, initial release
+//
+//  141118  4.0.0B2
+//          Bug fixes, added two new palettes
+//
+//  141225  4.0.0B3
+//          Active instances/etc are controlled by the shell now, small changes in the GUI
+//
+//  141228  4.0.0
+//          Only tiny changes over B3, releasing as 4.0.0
+//
+//  150212  4.0.1
+//          Two small bugs fixed
+//
+//  150216  4.1.0
+//          Port to VTK6, refactored eror reporting (use Monitor), progress observer, output, histogram making, some GUI changes.
+//
+//  150301  4.1.1
+//          Off-screen shell
+//
+//  15....  4.1.2
+//          Bug fixes, Debian portability switch, fixed the bug with render observer not displaying, new ART mode
 //
 
 //
@@ -176,14 +199,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //  2. Multiple images in Composer (do we need this???)
 //
 
-#if ISHELL_INCLUDED(ISHELL_QT)
-#include "iqt.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+#include "iggsubjectfactory.h"
 #endif
 
 
 const iString iVersion::GetVersion()
 { 
-	return IVERSION_BASE;
+	return iString(IVERSION);
+}
+
+
+const iString iVersion::GetRevisionId()
+{ 
+	return iString(IREVISION);
 }
 
 
@@ -191,16 +220,16 @@ const iString iVersion::GetIncludedExtensions()
 { 
 	iString tmp; 
 #if IEXTENSION_INCLUDED(IEXTENSION_ART)
-	tmp += iString("ART extension v") + IVERSION_EXT_ART +";";
+	tmp += "ART extension;";
 #endif
 #if IEXTENSION_INCLUDED(IEXTENSION_MV)
-	tmp += iString("MultiView extension v") + IVERSION_EXT_MV +";";
+	tmp += "MultiView extension;";
 #endif
 #if IEXTENSION_INCLUDED(IEXTENSION_GADGET)
-	tmp += iString("GADGET extension v") + IVERSION_EXT_GADGET +";";
+	tmp += "GADGET extension;";
 #endif
 #if IEXTENSION_INCLUDED(IEXTENSION_VTK)
-	tmp += iString("Native-VTK extension v") + IVERSION_EXT_VTK +";";
+	tmp += "Native-VTK extension;";
 #endif
 	return tmp;
 }
@@ -209,14 +238,14 @@ const iString iVersion::GetIncludedExtensions()
 const iString iVersion::GetIncludedShells()
 { 
 	iString tmp;
+#if ISHELL_INCLUDED(ISHELL_OS)
+	tmp += iString("Off-screen shell") + ";";
+#endif
 #if ISHELL_INCLUDED(ISHELL_CL)
 	tmp += iString("Command-line shell") + ";";
 #endif
-#if ISHELL_INCLUDED(ISHELL_QT)
-	tmp += iString("Qt-based GUI shell (Qt ") + QT_VERSION_STR + ");";
-#endif
-#if ISHELL_INCLUDED(ISHELL_FX)
-	tmp += iString("FOX-based GUI shell") + ";";
+#if ISHELL_INCLUDED(ISHELL_GG)
+	tmp += iggSubjectFactory::GetIncludedShells();
 #endif
 	return tmp;
 }
