@@ -40,16 +40,19 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iarray.h"
+#include "ivtk.h"
 
 class iActor;
-class iArtifactCorrector;
 class iDataLimits;
 class iLookupTable;
+struct iPair;
 class iPalette;
 
-class vtkPlane;
+class vtkAlgorithmOutput;
+class vtkPlaneCollection;
 class vtkPolyData;
 class vtkPolyDataMapper;
+class vtkRandomAttributeGenerator;
 
 
 class iActorSubject
@@ -98,7 +101,7 @@ class iActor: public vtkLODActor
 public:
 	
 	vtkTypeMacro(iActor,vtkLODActor);
-	static iActor* New(bool scaled = false);
+	static iActor* New(vtkPlaneCollection *planes = 0);
 
 	virtual void ReleaseGraphicsResources(vtkWindow *win);
 	virtual void Render(vtkRenderer *ren, vtkMapper *m);
@@ -115,25 +118,27 @@ public:
 	//
 	//  Mapper functionality
 	//
-	void SetInput(vtkPolyData *data);
+	void SetInputData(vtkPolyData *data);
+	void SetInputConnection(vtkAlgorithmOutput *port);
+
 	void SetScalarVisibility(bool s);
 	void SetScalarRange(float min, float max);
+	void SetScalarRange(const iPair &p);
 
-	void SyncWithLimits(iDataLimits *l, int v, float scale = 1.0f);
+	void SyncWithLimits(iDataLimits *l, int v);
 	inline iLookupTable* GetLookupTable() const { return mLookupTable; }
 
 	void AddMapperObserver(unsigned long event, vtkCommand *obs);
 
-	void AddClippingPlane(vtkPlane *plane);
-	void RemoveClippingPlane(vtkPlane *plane);
-
 	void ColorByArrayComponent(int arrayNum, int component);
 
-	void InstallArtifactCorrector(iArtifactCorrector *c);
+#ifdef I_DEBUG
+	static void SetRandomColoring(bool s){ mRandomColoring = s; }
+#endif
 
 protected:
 	
-	iActor(bool scaled = false);
+	iActor(vtkPlaneCollection *planes = 0);
 	virtual ~iActor();
 	
 private:
@@ -142,13 +147,18 @@ private:
 
 	double mBasicScale, mAxisScale[3];
 	bool mScaled;
-	iSearchableArray<iActorSubjectPointer> mSubjects;
+	iLookupArray<iActorSubjectPointer> mSubjects;
 	iActorSubject *mDummySubject, *mCurrentSubject;
 	iActorSubjectPointer mDummySubjectPointer;
 	vtkPolyDataMapper *mDefaultMapper;
 	vtkMapperCollection *mDefaultLODMappers; 
 	iLookupTable *mLookupTable;
-	iArtifactCorrector *mCorrector;
+
+#ifdef I_DEBUG
+	vtkRandomAttributeGenerator *mRandomizer;
+	static bool mRandomColoring;
+	int mSavedInterpolationMode;
+#endif
 };
 
 #endif // IACTOR_H
