@@ -64,7 +64,7 @@ private:
 	
 	iActorCollection();
 
-	iPointerArray<iActor> mActors;
+	iLookupArray<iActor*> mActors;
 };
 
 #endif  // IACTORCOLLECTION_H
