@@ -32,15 +32,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iAppendPolyDataFilter::iAppendPolyDataFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkAppendPolyData>(vo,0,true,false) // avoid setting the number of inputs
+iAppendPolyDataFilter::iAppendPolyDataFilter(iDataConsumer *consumer) : iGenericPolyDataFilter<vtkAppendPolyData>(consumer,1,true) // avoid setting the number of inputs
 {
 }
 	
 
-void iAppendPolyDataFilter::ProduceOutput()
+void iAppendPolyDataFilter::ProvideOutput()
 {
 	this->ExecuteParent();
 }
