@@ -48,15 +48,16 @@ public:
 	inline int Size() const { return this->mNum; }
 	inline int MaxIndex() const { return this->mNum-1; }
 
-	inline T& Last(){ return this->mArr[this->mNum-1]; }
-	inline const T& Last() const { return this->mArr[this->mNum-1]; }
-
 	virtual void Add(const T &val);
 	void Remove(int n);
-	T RemoveLast();  // useful for deleteting all: while(arr.Size() > 0) delete arr.RemoveLast();
 	void Clear();
 	void Resize(int n);
 
+	inline T& Last(){ return this->mArr[this->mNum-1]; }
+    inline const T& Last() const { return this->mArr[this->mNum-1]; }
+	void AddLast();
+	T RemoveLast();  // useful for deleteting all: while(arr.Size() > 0) delete arr.RemoveLast();
+
 	inline const T* Data() const { return this->mArr; }
 
 protected:
@@ -75,71 +76,74 @@ private:
 
 
 //
-//  This version also needs operator ==
+//  iLookupArray class
+//  Needs operator == for type T
 //
 template<class T>
-class iSearchableArray : public iArray<T>
+class iLookupArray : public iArray<T>
 {
 
 public:
 
-	iSearchableArray(int inc = 10);
+	iLookupArray(int inc = 10);
 
 	virtual int Find(const T &val) const;
-	void AddUnique(const T &val);
+	bool AddUnique(const T &val);
 	bool Remove(const T &val);
 
 private:
 
-	iSearchableArray(const iSearchableArray<T>&); // not implemented
-	void operator=(const iSearchableArray<T>&); // not implemented
 };
 
 
 //
-//  This version also needs operator <
+//  iGenericOrderedArray class
+//  Needs operator < for the key type K
 //
-template<class T>
-class iOrderedArray : public iSearchableArray<T>
+template<class T, class K>
+class iGenericOrderedArray : public iLookupArray<T>
 {
 
 public:
 
-	iOrderedArray(int inc = 10);
+	iGenericOrderedArray(const K& (*key)(const T &val), int inc = 10);
 
-	virtual int Find(const T &val) const;
+	//
+	//  In case of duplicate keys, add the new value last
+	//
 	virtual void Add(const T &val);
-	virtual bool Less(const T& v1, const T& v2) const;
+	virtual int Find(const T &val) const;
+	//
+	//  In case of duplicate keys, return the first value
+	//
+	int FindByKey(const K &key) const;
 
 private:
 
+	const K& (*Key)(const T &val);
+
+	iGenericOrderedArray(const iGenericOrderedArray<T,K>&); // not implemented
+	void operator=(const iGenericOrderedArray<T,K>&); // not implemented
+};
+
+
+//
+//  iOrderedArray class (order by its own value)
+//
+template<class T>
+class iOrderedArray : public iGenericOrderedArray<T,T>
+{
+
+public:
+
+	iOrderedArray(int inc = 10) : iGenericOrderedArray<T,T>(Self,inc){}
+
+private:
+
+	static const T& Self(const T &val){ return val; }
+
 	iOrderedArray(const iOrderedArray<T>&); // not implemented
 	void operator=(const iOrderedArray<T>&); // not implemented
 };
 
-	
-template<class T>
-inline bool iOrderedArray<T>::Less(const T& v1, const T& v2) const
-{
-	return v1 < v2;
-}
-
-//
-//  According to C/C++ standard, comparing pointers using < is not portable.
-//  Hence, the pointer array is not ordered.
-//
-template<class T>
-class iPointerArray : public iSearchableArray<T*>
-{
-
-public:
-
-	iPointerArray(int inc = 10) : iSearchableArray<T*>(inc){}
-
-private:
-
-	iPointerArray(const iPointerArray<T>&); // not implemented
-	void operator=(const iPointerArray<T>&); // not implemented
-};
-
 #endif // IARRAY_H
