@@ -39,23 +39,23 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 // iBoundedPlaneSource class
 //
-iBoundedPlaneSource* iBoundedPlaneSource::New(iViewSubject *vo)
+iBoundedPlaneSource* iBoundedPlaneSource::New(iDataConsumer *consumer)
 {
-	IERROR_ASSERT(vo);
-	return new iBoundedPlaneSource(vo);
+	IASSERT(consumer);
+	return new iBoundedPlaneSource(consumer);
 }
 
 
-iBoundedPlaneSource::iBoundedPlaneSource(iViewSubject *vo) : iBoundedPolyDataSource(vo,true,false)
+iBoundedPlaneSource::iBoundedPlaneSource(iDataConsumer *consumer) : iBoundedPolyDataSource(consumer,true,false)
 {
-	mSource = vtkPlaneSource::New(); IERROR_ASSERT(mSource);
+	mSource = vtkPlaneSource::New(); IERROR_CHECK_MEMORY(mSource);
 
 	mSource->SetOrigin(0.0,0.0,0.0);
 	mSource->SetPoint1(7.0,0.0,0.0);
 	mSource->SetPoint2(0.0,7.0,0.0);
 	mSource->SetCenter(0.0,0.0,0.0);
 
-	mFilter->SetInput(mSource->GetOutput());
+	mFilter->SetInputConnection(mSource->GetOutputPort());
 }
 
 
