@@ -42,11 +42,11 @@ class iBoundedPlaneSource : public iBoundedPolyDataSource
 public:
 	
 	vtkTypeMacro(iBoundedPlaneSource,iBoundedPolyDataSource);
-	static iBoundedPlaneSource* New(iViewSubject *vo = 0);
+	static iBoundedPlaneSource* New(iDataConsumer *consumer = 0);
 
 protected:
 	
-	iBoundedPlaneSource(iViewSubject *vo);
+	iBoundedPlaneSource(iDataConsumer *consumer);
 	virtual ~iBoundedPlaneSource();
 
 	virtual void UpdateBoundaryConditions();
