@@ -44,18 +44,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
 //
 // iBoundedPolyDataSource class
 //
-iBoundedPolyDataSource::iBoundedPolyDataSource(iViewSubject *vo, bool normalCanChange, bool radiusCanChange) : iGenericSource<vtkPolyDataSource,vtkPolyData>(vo,true), mNormalCanChange(normalCanChange), mRadiusCanChange(radiusCanChange)
+iBoundedPolyDataSource::iBoundedPolyDataSource(iDataConsumer *consumer, bool normalCanChange, bool radiusCanChange) : iGenericPolyDataFilter<vtkPolyDataAlgorithm>(consumer,0,true), mNormalCanChange(normalCanChange), mRadiusCanChange(radiusCanChange)
 {
-	mTransform = iTransform::New(); IERROR_ASSERT(mTransform);
-	mClipper = vtkClipPolyData::New(); IERROR_ASSERT(mClipper);
-	mClipPlanes = vtkPlanes::New(); IERROR_ASSERT(mClipPlanes);
-	mFilter = vtkTransformPolyDataFilter::New(); IERROR_ASSERT(mFilter);
+	mTransform = iTransform::New(); IERROR_CHECK_MEMORY(mTransform);
+	mClipper = vtkClipPolyData::New(); IERROR_CHECK_MEMORY(mClipper);
+	mClipPlanes = vtkPlanes::New(); IERROR_CHECK_MEMORY(mClipPlanes);
+	mFilter = vtkTransformPolyDataFilter::New(); IERROR_CHECK_MEMORY(mFilter);
 
 	mClipper->SetClipFunction(mClipPlanes);
 	mClipper->InsideOutOn();
@@ -67,7 +67,7 @@ iBoundedPolyDataSource::iBoundedPolyDataSource(iViewSubject *vo, bool normalCanC
 
 	mCenter[0] = mCenter[1] = mCenter[2] = 0.0;
 	mNormal[0] = mNormal[1] = 0.0f; mNormal[2] = 1.0f;
-	mResolution = 6;
+	mResolution = 2;
 
 	mBounds[0] = mBounds[2] = mBounds[4] = -1.0;
 	mBounds[1] = mBounds[3] = mBounds[5] = 1.0;
@@ -75,7 +75,7 @@ iBoundedPolyDataSource::iBoundedPolyDataSource(iViewSubject *vo, bool normalCanC
 
 	mNormalChanged = true;
 
-	mClipper->SetInput(mFilter->GetOutput());
+	mClipper->SetInputConnection(mFilter->GetOutputPort());
 }
 
 
@@ -115,7 +115,7 @@ void iBoundedPolyDataSource::SetCenter(const double x[3])
 }
 
 
-void iBoundedPolyDataSource::SetNormal(const float n[3])
+void iBoundedPolyDataSource::SetNormal(const double n[3])
 {
 	int i;
 	for(i=0; i<3; i++) mNormal[i] = n[i];
@@ -148,10 +148,8 @@ void iBoundedPolyDataSource::SetBounds(double b0, double b1, double b2, double b
 }
 
 
-void iBoundedPolyDataSource::ProduceOutput()
+void iBoundedPolyDataSource::ProvideOutput()
 {
-	vtkPolyData *output = this->GetOutput();
-
 	mTransform->Identity();
 
 	if(vtkMath::Norm(mCenter) > 1.0e-30)
@@ -168,13 +166,13 @@ void iBoundedPolyDataSource::ProduceOutput()
 
 	if(mNormalCanChange && mNormalChanged)
 	{
-		mTransform->SetDirection(mNormal);
+		mTransform->SetDirection(mNormal[0],mNormal[1],mNormal[2]);
 	}
 
 	this->UpdateBoundaryConditions();
 
 	mClipper->Update();
-	output->ShallowCopy(mClipper->GetOutput());
+	this->OutputData()->ShallowCopy(mClipper->GetOutputDataObject(0));
 }
 
 
