@@ -31,23 +31,24 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "igenericfilter.h"
-#include <vtkPolyDataSource.h>
+#include <vtkPolyDataAlgorithm.h>
 
 
 class iLimits;
 class iTransform;
 
 class vtkClipPolyData;
+class vtkCommand;
 class vtkPlanes;
 class vtkTransformPolyDataFilter;
 
 
-class iBoundedPolyDataSource : public iGenericSource<vtkPolyDataSource,vtkPolyData>
+class iBoundedPolyDataSource : public iGenericPolyDataFilter<vtkPolyDataAlgorithm>
 {
 
 public:
 	
-	vtkTypeMacro(iBoundedPolyDataSource,vtkPolyDataSource);
+	vtkTypeMacro(iBoundedPolyDataSource,vtkPolyDataAlgorithm);
 
 	unsigned long AddObserver(unsigned long e, vtkCommand *c, float priority = 0.0);
 	
@@ -63,17 +64,17 @@ public:
 	void SetRadius(double r);
 	inline double GetRadius() const { return mRadius; }
 
-	void SetNormal(const float n[3]);
-	inline const float* GetNormal() const { return mNormal; }
+	void SetNormal(const double n[3]);
+	inline const double* GetNormal() const { return mNormal; }
 
 	float GetMemorySize() const;
 
 protected:
 	
-	iBoundedPolyDataSource(iViewSubject *vo, bool normalCanChange, bool radiusCanChange);
+	iBoundedPolyDataSource(iDataConsumer *consumer, bool normalCanChange, bool radiusCanChange);
 	virtual ~iBoundedPolyDataSource();
 
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 
 	virtual void UpdateBoundaryConditions() = 0;
 	virtual void UpdateSourceResolution() = 0;
@@ -81,9 +82,8 @@ protected:
 	virtual float GetSourceMemorySize() const = 0;
 
 	double mBounds[6];
-	double mCenter[3], mRadius;
+	double mCenter[3], mNormal[3], mRadius;
 	int mResolution;
-	float mNormal[3];
 
 	bool mNormalChanged;
 
