@@ -29,42 +29,41 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iboundedspheresource.h"
 
 
-#include "idatalimits.h"
+#include "idataconsumer.h"
+#include "idatasubject.h"
 #include "ierror.h"
+#include "ispheresource.h"
 #include "iviewmodule.h"
 
 #include <vtkAppendPolyData.h>
 #include <vtkPolyData.h>
-#include <vtkSphereSource.h>
 #include <vtkTransformPolyDataFilter.h>
 
 
 //
 // iBoundedSphereSource class
 //
-iBoundedSphereSource* iBoundedSphereSource::New(iViewSubject *vo)
+iBoundedSphereSource* iBoundedSphereSource::New(iDataConsumer *consumer)
 {
-	IERROR_ASSERT(vo);
-	return new iBoundedSphereSource(vo);
+	IASSERT(consumer);
+	return new iBoundedSphereSource(consumer);
 }
 
 
-iBoundedSphereSource::iBoundedSphereSource(iViewSubject *vo) : iBoundedPolyDataSource(vo,false,true)
+iBoundedSphereSource::iBoundedSphereSource(iDataConsumer *consumer) : iBoundedPolyDataSource(consumer,false,true)
 {
-	mAppend = vtkAppendPolyData::New(); IERROR_ASSERT(mAppend);
+	mAppend = vtkAppendPolyData::New(); IERROR_CHECK_MEMORY(mAppend);
 	for(int i=0; i<8; i++)
 	{
-		mSource[i] = vtkSphereSource::New(); IERROR_ASSERT(mSource[i]);
+		mSource[i] = iSphereSource::New(); IERROR_CHECK_MEMORY(mSource[i]);
 	}
 	mAppend->UserManagedInputsOn();
-	mAppend->SetInputByNumber(0,mSource[0]->GetOutput());
+	mAppend->SetInputConnection(mSource[0]->GetOutputPort());
 
-	mSource[0]->SetCenter(0.0,0.0,0.0);
-	mSource[0]->SetPhiResolution(mResolution);
-	mSource[0]->SetThetaResolution(2*mResolution);
+	mSource[0]->SetResolution(1);
 	mSource[0]->SetRadius(1.0);
 
-	mFilter->SetInput(mSource[0]->GetOutput());
+	mFilter->SetInputConnection(mSource[0]->GetOutputPort());
 }
 
 
@@ -90,8 +89,7 @@ void iBoundedSphereSource::AddObserverToSource(unsigned long e, vtkCommand *c, f
 
 void iBoundedSphereSource::UpdateSourceResolution()
 {
-	mSource[0]->SetPhiResolution(mResolution);
-	mSource[0]->SetThetaResolution(2*mResolution);
+	mSource[0]->SetResolution(mResolution);
 }
 
 
@@ -112,22 +110,13 @@ void iBoundedSphereSource::UpdateBoundaryConditions()
 	int i, j, l, side[3];
 	double cen[3], xb;
 
-	if(this->GetLimits()==0 || !this->GetLimits()->IsBoxPeriodic())
-	{
-		mFilter->SetInput(mSource[0]->GetOutput());
-		return;
-	}
-
-	bool per[3];
-	this->GetLimits()->GetPeriodicities(per);
-
 	//
 	//  Test for out-of-bounds pieces
 	//
 	for(i=0; i<3; i++)
 	{
 		side[i] = 0;
-		if(per[i])
+		if(this->Consumer()->GetSubject()->IsDirectionPeriodic(i))
 		{
 			xb = mCenter[i] - mRadius;
 			if(xb < mBounds[2*i+0]) side[i] = -1;  //  we should only cross one boundary
@@ -141,11 +130,11 @@ void iBoundedSphereSource::UpdateBoundaryConditions()
 		//
 		//  Fully inside
 		//
-		mFilter->SetInput(mSource[0]->GetOutput());
+		mFilter->SetInputConnection(mSource[0]->GetOutputPort());
 		return;
 	}
 
-	mFilter->SetInput(mAppend->GetOutput());
+	mFilter->SetInputConnection(mAppend->GetOutputPort());
 
 	l = 1;
 	for(i=0; i<3; i++)
@@ -156,12 +145,15 @@ void iBoundedSphereSource::UpdateBoundaryConditions()
 			for(j=l; j<2*l; j++)
 			{
 				mSource[j]->SetRadius(1.0);
-				mSource[j]->SetPhiResolution(mResolution);
-				mSource[j]->SetThetaResolution(2*mResolution);
+				mSource[j]->SetResolution(mResolution);
 				mSource[j-l]->GetCenter(cen);
 				cen[i] -= 2.0*side[i]/mRadius;
 				mSource[j]->SetCenter(cen);
+#ifdef IVTK_5
 				mAppend->SetInputByNumber(j,mSource[j]->GetOutput());
+#else
+				mAppend->SetInputConnectionByNumber(j,mSource[j]->GetOutputPort());
+#endif
 			}
 			l *= 2;
 		}
