@@ -43,13 +43,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
-#include "igenericproptemplate.h"
+#include "iarray.tlh"
+#include "igenericprop.tlh"
 
 
 iCameraOrthoActor* iCameraOrthoActor::New(iRenderTool *rt)
 {
-	IERROR_ASSERT(rt);
+	IASSERT(rt);
 	return new iCameraOrthoActor(rt);
 }
 
@@ -59,10 +59,10 @@ iCameraOrthoActor::iCameraOrthoActor(iRenderTool *rt) : iGenericProp<vtkActor2D>
 	int i;
 	for(i=0; i<2; i++)
 	{
-		mLabels[i] = iTextActor::New(rt); IERROR_ASSERT(mLabels[i]);
+		mLabels[i] = iTextActor::New(rt); IERROR_CHECK_MEMORY(mLabels[i]);
 		this->AppendComponent(mLabels[i]);
 		mLabels[i]->SetBold(true);
-		mActors[i] = vtkAxisActor2D::New(); IERROR_ASSERT(mActors[i]);
+		mActors[i] = vtkAxisActor2D::New(); IERROR_CHECK_MEMORY(mActors[i]);
 		this->AppendComponent(mActors[i]);
         mActors[i]->GetPoint1Coordinate()->SetCoordinateSystemToNormalizedViewport(); 
         mActors[i]->GetPoint2Coordinate()->SetCoordinateSystemToNormalizedViewport(); 
