@@ -46,8 +46,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
-#include "igenericproptemplate.h"
+#include "iarray.tlh"
+#include "igenericprop.tlh"
 
 
 bool iCaption::Transparent = true;
@@ -55,7 +55,7 @@ bool iCaption::Transparent = true;
 
 iCaption* iCaption::New(iRenderTool *rt)
 {
-	IERROR_ASSERT(rt);
+	IASSERT(rt);
 	return new iCaption(rt);
 }
 
@@ -67,25 +67,25 @@ iCaption::iCaption(iRenderTool *rt) : iFramedTextActor(rt)
 	//
 	// This is the leader (line) from the attachment point to the caption
 	//
-	mLeaderInput = vtkPolyData::New(); IERROR_ASSERT(mLeaderInput);
+	mLeaderInput = vtkPolyData::New(); IERROR_CHECK_MEMORY(mLeaderInput);
 
-	vtkPoints *pts = vtkPoints::New(VTK_DOUBLE); IERROR_ASSERT(pts);
+	vtkPoints *pts = vtkPoints::New(VTK_DOUBLE); IERROR_CHECK_MEMORY(pts);
 	pts->SetNumberOfPoints(2);
 	mLeaderInput->SetPoints(pts);
 	pts->Delete();
 
-	vtkCellArray *leader = vtkCellArray::New(); IERROR_ASSERT(leader);
+	vtkCellArray *leader = vtkCellArray::New(); IERROR_CHECK_MEMORY(leader);
 	leader->InsertNextCell(2); 
 	leader->InsertCellPoint(0);
 	leader->InsertCellPoint(1); //at the attachment point
 	mLeaderInput->SetLines(leader);
 	leader->Delete();
 	
-	mLeaderActor = iActor::New(); IERROR_ASSERT(mLeaderActor);
+	mLeaderActor = iActor::New(); IERROR_CHECK_MEMORY(mLeaderActor);
 	this->PrependComponent(mLeaderActor);
-	mLeaderActor->SetInput(mLeaderInput);
+	mLeaderActor->SetInputData(mLeaderInput);
 
-	mAttachmentPoint = vtkCoordinate::New(); IERROR_ASSERT(mAttachmentPoint);
+	mAttachmentPoint = vtkCoordinate::New(); IERROR_CHECK_MEMORY(mAttachmentPoint);
 	mAttachmentPoint->SetCoordinateSystemToWorld();
 	mAttachmentPoint->SetValue(0.0,0.0,0.0);
 }
@@ -191,8 +191,8 @@ void iCaption::UpdateGeometry(vtkViewport* vp)
 
 
 #ifdef I_DEBUG
-		iConsole::PrintDebugMessage(iString("Caption: ")+iString::FromNumber(d2min)+" ("+iString::FromNumber(ptmin[0])+","+iString::FromNumber(ptmin[1])+")");
-		iConsole::PrintDebugMessage(iString("         ")+iString::FromNumber(s)+" ("+iString::FromNumber(x[0])+","+iString::FromNumber(x[1])+","+iString::FromNumber(x[2])+","+iString::FromNumber(x[3])+")");
+		iOutput::DisplayDebugMessage(iString("Caption: ")+iString::FromNumber(d2min)+" ("+iString::FromNumber(ptmin[0])+","+iString::FromNumber(ptmin[1])+")");
+		iOutput::DisplayDebugMessage(iString("         ")+iString::FromNumber(s)+" ("+iString::FromNumber(x[0])+","+iString::FromNumber(x[1])+","+iString::FromNumber(x[2])+","+iString::FromNumber(x[3])+")");
 #endif
 
 		vtkPoints *pts = mLeaderInput->GetPoints();
