@@ -31,10 +31,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "icaption.h"
 #include "imarker.h"
-#include "imarkerfamily.h"
 #include "irendertool.h"
 #include "iviewmodule.h"
-#include "iviewobjectfamily.h"
+#include "iviewobject.h"
 
 #include <vtkActor2D.h>
 #include <vtkCamera.h>
@@ -49,26 +48,26 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 iCaptionInteractorStyle* iCaptionInteractorStyle::New(iViewModule *vm)
 {
-	IERROR_ASSERT(vm);
+	IASSERT(vm);
 	return new iCaptionInteractorStyle(vm);
 }
 
 
-iCaptionInteractorStyle::iCaptionInteractorStyle(iViewModule *vm) : mViewModule(vm)
+iCaptionInteractorStyle::iCaptionInteractorStyle(iViewModule *vm) : iViewModuleComponent(vm)
 {
 	mInteractionMarker = 0;
 
 	//
 	//  Experimental: gray screen for moving captions
 	//
-	vtkPolyData *data = vtkPolyData::New(); IERROR_ASSERT(data);
+	vtkPolyData *data = vtkPolyData::New(); IERROR_CHECK_MEMORY(data);
 
-	vtkPoints *pts = vtkPoints::New(VTK_FLOAT); IERROR_ASSERT(pts);
+	vtkPoints *pts = vtkPoints::New(VTK_FLOAT); IERROR_CHECK_MEMORY(pts);
 	pts->SetNumberOfPoints(4);
 	pts->SetPoint(0,0.0,0.0,0.0);
 	pts->SetPoint(1,1.0,0.0,0.0);
@@ -77,7 +76,7 @@ iCaptionInteractorStyle::iCaptionInteractorStyle(iViewModule *vm) : mViewModule(
 	data->SetPoints(pts);
 	pts->Delete();
 
-	vtkCellArray *cells = vtkCellArray::New(); IERROR_ASSERT(cells);
+	vtkCellArray *cells = vtkCellArray::New(); IERROR_CHECK_MEMORY(cells);
 	cells->InsertNextCell(4);
 	cells->InsertCellPoint(0);
 	cells->InsertCellPoint(1);
@@ -86,15 +85,15 @@ iCaptionInteractorStyle::iCaptionInteractorStyle(iViewModule *vm) : mViewModule(
 	data->SetPolys(cells);
 	cells->Delete();
 	
-	vtkPolyDataMapper2D *mapper = vtkPolyDataMapper2D::New(); IERROR_ASSERT(mapper);
-	mapper->SetInput(data);
+	vtkPolyDataMapper2D *mapper = vtkPolyDataMapper2D::New(); IERROR_CHECK_MEMORY(mapper);
+	mapper->SetInputData(data);
 	data->Delete();
-	vtkCoordinate *c = vtkCoordinate::New(); IERROR_ASSERT(c);
+	vtkCoordinate *c = vtkCoordinate::New(); IERROR_CHECK_MEMORY(c);
 	c->SetCoordinateSystemToNormalizedViewport();
 	mapper->SetTransformCoordinate(c);
 	c->Delete();
 
-	mScreen = vtkActor2D::New(); IERROR_ASSERT(mScreen);
+	mScreen = vtkActor2D::New(); IERROR_CHECK_MEMORY(mScreen);
 	mScreen->SetMapper(mapper);
 	mapper->Delete();
 
@@ -133,14 +132,14 @@ void iCaptionInteractorStyle::FindPickedActor(int x, int y)
 
 	if(this->CurrentRenderer == 0) return;
 	
-	for(i=0; i<=this->GetViewModule()->GetMarkerFamily()->GetMaxMemberIndex(); i++) if(this->GetViewModule()->GetMarkerFamily()->GetMember(i)->GetMarkerCaption()->GetVisibility() == 1)
+	for(i=0; i<this->GetViewModule()->GetNumberOfMarkers(); i++) if(this->GetViewModule()->GetMarker(i)->GetMarkerCaption()->GetVisibility() == 1)
 	{
 		int *s = this->CurrentRenderer->GetSize();
 		float b[4];
-		this->GetViewModule()->GetMarkerFamily()->GetMember(i)->GetMarkerCaption()->GetBounds(this->CurrentRenderer,b);
+		this->GetViewModule()->GetMarker(i)->GetMarkerCaption()->GetBounds(this->CurrentRenderer,b);
 		if(x>b[0]*s[0] && y>b[2]*s[1] && x<b[1]*s[0] && y<b[3]*s[1])
 		{
-			mInteractionMarker = this->GetViewModule()->GetMarkerFamily()->GetMember(i);
+			mInteractionMarker = this->GetViewModule()->GetMarker(i);
 			return;
 		}
 	}
@@ -164,8 +163,8 @@ void iCaptionInteractorStyle::Rotate()
 	float dx = rwi->GetEventPosition()[0] - rwi->GetLastEventPosition()[0];
 	float dy = rwi->GetEventPosition()[1] - rwi->GetLastEventPosition()[1];
 	
-	const float *x = mInteractionMarker->GetCaptionPosition();
-	mInteractionMarker->SetCaptionPosition(x[0]+dx/size[0],x[1]+dy/size[1]);
+	const iPair &x(mInteractionMarker->GetCaptionPosition());
+	mInteractionMarker->SetCaptionPosition(iPair(x.X+dx/size[0],x.Y+dy/size[1]));
 	
     rwi->Render();
 }
@@ -200,13 +199,15 @@ void iCaptionInteractorStyle::OnLeftButtonUp()
 	if(mInteractionMarker != 0)
 	{
 		int *size = CurrentRenderer->GetSize();
-		const float *x0 = mInteractionMarker->GetCaptionPosition();
-		float x[2];
-		x[0] = 10.0*floor(0.1*x0[0]*size[0])/size[0];
-		x[1] = 10.0*floor(0.1*x0[1]*size[1])/size[1];
-		mInteractionMarker->SetCaptionPosition(x[0],x[1]);
+		const iPair &x0(mInteractionMarker->GetCaptionPosition());
+		iPair x;
+		x.X = 10.0*floor(0.1*x0.X*size[0])/size[0];
+		x.Y = 10.0*floor(0.1*x0.Y*size[1])/size[1];
+		mInteractionMarker->SetCaptionPosition(x);
 		Interactor->Render();
 	}
+
+	mInteractionMarker = 0;
 }
 
 void iCaptionInteractorStyle::Finish()
