@@ -26,58 +26,57 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 //
-//  A vtkPlane with a glass plane representation
+//  A vtkPlaneCollection with a glass plane representation
 //
 #ifndef ICLIPPLANE_H
 #define ICLIPPLANE_H
 
 
-#include <vtkPlane.h>
+#include <vtkPlaneCollection.h>
+#include "iviewmoduletool.h"
 
 
-#include "ipointermacro.h"
+#include "iarray.h"
 
-#include <vtkSetGet.h>
-
-class iActor;
-class iTransform;
-class iViewModule;
+class iClipPlaneInstance;
+class vtkPlaneCollection;
 
 
-class iClipPlane : public vtkPlane
+class iClipPlane : public iViewModuleTool
 {
-
-	IPOINTER_AS_PART(ViewModule);
-
+	
 public:
 
-	vtkTypeMacro(iClipPlane,vtkPlane);
+	vtkTypeMacro(iClipPlane,iViewModuleTool);
 	static iClipPlane* New(iViewModule *vm = 0);
 
-	void SetDirection(const float *dir);
-	inline void GetDirection(float *dir) const { for(int i=0; i<3; i++) dir[i] = mClipPlaneDirection[i]; }
-	inline const float* GetDirection() const { return mClipPlaneDirection; }
+	iObjectPropertyMacro2V(Position,Vector);
+	iObjectPropertyMacro2V(Direction,Vector);
 
-	void SetDistance(float d);
-	inline float GetDistance() const { return mDistance; }
+	iObjectPropertyMacro2S(Number,Int);
+	iPropertyAction1<iType::Int> Remove;
+	iPropertyAction Create;	
 
-	void SetGlassPlaneVisible(bool s);
-	bool GetGlassPlaneVisible() const;
+	inline vtkPlaneCollection* GetPlanes() const { return mPlanes; }
 
 protected:
 
 	virtual ~iClipPlane();
 
 private:
+	
+	iClipPlane(iViewModule *vm, const iString &fname, const iString &sname);
 
-	iClipPlane(iViewModule *vm);
+	bool CallCreate();
+	bool CallRemove(int i);
+
+	virtual bool ShowBody(bool s);
 
 	//
 	//  Actors displayed by this class
 	//
-	iActor *mClipPlaneActor;
-	iTransform *mTransform;
-	float mDistance, mClipPlaneDirection[3], mClipPlaneActorNormal[3];
+	iArray<iClipPlaneInstance*> mInstances;
+	vtkPlaneCollection* mPlanes;
 };
 
 #endif // ICLIPPLANE_H
