@@ -29,6 +29,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icommondatadistributors.h"
 
 
+#include "iappendimagedatafilter.h"
 #include "iappendpolydatafilter.h"
 #include "ierror.h"
 #include "iparallelmanager.h"
@@ -37,7 +38,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkCellArray.h>
 #include <vtkFloatArray.h>
-#include <vtkImageAppend.h>
 #include <vtkImageData.h>
 #include <vtkPointData.h>
 #include <vtkPolyData.h>
@@ -45,7 +45,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
+#include "igenericfilter.tlh"
 
 
 //
@@ -66,7 +67,7 @@ public:
 template<class Collector, class Type>
 bool iBasicDataDistributorHelper::CollectData(Collector *collector, iArray<vtkDataSet*> &localOutputs, vtkDataSet *globalOutput)
 {
-	IERROR_ASSERT(collector);
+	IASSERT(collector);
 
 	//
 	//  Append the local data
@@ -85,14 +86,14 @@ bool iBasicDataDistributorHelper::CollectData(Collector *collector, iArray<vtkDa
 		{
 			lo = Type::SafeDownCast(localOutputs[i]);
 			if(lo == 0) return false;
-			tmpOutput = Type::New(); IERROR_ASSERT(tmpOutput);
+			tmpOutput = Type::New(); IERROR_CHECK_MEMORY(tmpOutput);
 			tmpOutput->ShallowCopy(lo);
-			collector->AddInput(tmpOutput);
+			collector->AddInputData(tmpOutput);
 			tmpOutput->Delete();
 		}
 		collector->Update();
 		collector->RemoveAllInputs();
-		globalOutput->ShallowCopy(collector->GetOutput());
+		globalOutput->ShallowCopy(collector->OutputData());
 	}
 	return true;
 }
@@ -102,7 +103,7 @@ vtkDataArray* iBasicDataDistributorHelper::SplitArray(vtkDataArray *inArray, vtk
 {
 	if(inArray != 0)
 	{
-		vtkDataArray *outArray = inArray->NewInstance(); IERROR_ASSERT(outArray);
+		vtkDataArray *outArray = inArray->NewInstance(); IERROR_CHECK_MEMORY(outArray);
 		int nc = inArray->GetNumberOfComponents();
 		outArray->SetNumberOfComponents(nc);
 		outArray->SetVoidArray(inArray->GetVoidPointer(nc*offset),nc*size,1);
@@ -158,7 +159,7 @@ bool iImageDataDistributor::DistributeDataBody(vtkDataSet *globalInput, iArray<v
 		//
 		for(i=1; i<nproc; i++)
 		{
-			localInputs[i] = globalInput->NewInstance(); IERROR_ASSERT(localInputs[i]);
+			localInputs[i] = globalInput->NewInstance(); IERROR_CHECK_MEMORY(localInputs[i]);
 		}
 		nproc = 1;
 		mSplitDim = 2;
@@ -171,7 +172,7 @@ bool iImageDataDistributor::DistributeDataBody(vtkDataSet *globalInput, iArray<v
 	{
 		for(i=nproc; i<dims[mSplitDim]; i++) 
 		{
-			localInputs[i] = globalInput->NewInstance(); IERROR_ASSERT(localInputs[i]);
+			localInputs[i] = globalInput->NewInstance(); IERROR_CHECK_MEMORY(localInputs[i]);
 		}
 		nproc = dims[mSplitDim];
 	}
@@ -181,9 +182,8 @@ bool iImageDataDistributor::DistributeDataBody(vtkDataSet *globalInput, iArray<v
 		//
 		//  Nothing to do for 1 proc
 		//
-		localInputs[0] = globalInput->NewInstance(); IERROR_ASSERT(localInputs[0]);
+		localInputs[0] = globalInput->NewInstance(); IERROR_CHECK_MEMORY(localInputs[0]);
 		localInputs[0]->ShallowCopy(input);
-		localInputs[0]->SetUpdateExtentToWholeExtent(); // not set by ShallowCopy in VTK 5
 		return true;
 	}
 
@@ -221,19 +221,13 @@ bool iImageDataDistributor::DistributeDataBody(vtkDataSet *globalInput, iArray<v
 
 		dataSize = (vtkIdType)dimsPiece[0]*(vtkIdType)dimsPiece[1]*(vtkIdType)dimsPiece[2];
 
-		li = vtkImageData::SafeDownCast(globalInput->NewInstance()); IERROR_ASSERT(li);
+		li = vtkImageData::SafeDownCast(globalInput->NewInstance()); IERROR_CHECK_MEMORY(li);
 		localInputs[i] = li;
 
 		li->CopyStructure(input);  // a better way of setting all parameters
 		li->SetDimensions(dimsPiece);
 		li->SetOrigin(orgPiece);
 
-		//
-		//  We also need to set properties that are not set by default
-		//
-		li->SetWholeExtent(li->GetExtent());
-		li->SetUpdateExtentToWholeExtent();
- 
 		array = iBasicDataDistributorHelper::SplitArray(input->GetPointData()->GetScalars(),dataOffset*kbeg,dataSize);
 		if(array != 0)
 		{
@@ -263,7 +257,7 @@ bool iImageDataDistributor::DistributeDataBody(vtkDataSet *globalInput, iArray<v
 //
 iImageDataCollector::iImageDataCollector(iViewSubjectPipelineDataManager *manager) : iViewSubjectPipelineDataCollector(manager,"vtkImageData")
 {
-	mCollector = vtkImageAppend::New(); IERROR_ASSERT(mCollector);
+	mCollector = iAppendImageDataFilter::New(); IERROR_CHECK_MEMORY(mCollector);
 }
 
 
@@ -276,7 +270,7 @@ iImageDataCollector::~iImageDataCollector()
 bool iImageDataCollector::CollectDataBody(iArray<vtkDataSet*> &localOutputs, vtkDataSet *globalOutput)
 {
 	mCollector->SetNumberOfThreads(localOutputs.Size());
-	return iBasicDataDistributorHelper::CollectData<vtkImageAppend,vtkImageData>(mCollector,localOutputs,globalOutput);
+	return iBasicDataDistributorHelper::CollectData<iAppendImageDataFilter,vtkImageData>(mCollector,localOutputs,globalOutput);
 }
 
 
@@ -314,7 +308,7 @@ bool iPolyDataDistributor::DistributeDataBody(vtkDataSet *globalInput, iArray<vt
 		//
 		for(i=0; i<localInputs.Size(); i++)
 		{
-			localInputs[i] = vtkPolyData::New(); IERROR_ASSERT(localInputs[i]);
+			localInputs[i] = vtkPolyData::New(); IERROR_CHECK_MEMORY(localInputs[i]);
 		}
 		localInputs[0]->ShallowCopy(input);
 		return true;
@@ -330,7 +324,7 @@ bool iPolyDataDistributor::DistributeDataBody(vtkDataSet *globalInput, iArray<vt
 		kbeg = kstp*i;
 		if(i == nPieces-1) kstp = nParticles - kbeg;
 		
-		li = vtkPolyData::New(); IERROR_ASSERT(li);
+		li = vtkPolyData::New(); IERROR_CHECK_MEMORY(li);
 		localInputs[i] = li;
 
 		li->Initialize();
@@ -360,7 +354,7 @@ bool iPolyDataDistributor::DistributeDataBody(vtkDataSet *globalInput, iArray<vt
 
 	for(i=nPieces; i<localInputs.Size(); i++)
 	{
-		localInputs[i] = vtkPolyData::New(); IERROR_ASSERT(localInputs[i]);
+		localInputs[i] = vtkPolyData::New(); IERROR_CHECK_MEMORY(localInputs[i]);
 	}
 
 	return true;
@@ -374,7 +368,7 @@ iPolyDataCollector::iPolyDataCollector(iViewSubjectPipelineDataManager *manager,
 {
 	mFixStiches = true;
 	mDistributor = distributor;
-	mCollector = iAppendPolyDataFilter::New(manager->GetViewSubject()); IERROR_ASSERT(mCollector);
+	mCollector = iAppendPolyDataFilter::New(manager->Owner()); IERROR_CHECK_MEMORY(mCollector);
 }
 
 
@@ -401,17 +395,19 @@ bool iPolyDataCollector::CollectDataBody(iArray<vtkDataSet*> &localOutputs, vtkD
 	const iArray<double> &innerEdges(mDistributor->GetEdges());
 	int extDown = 0;
 	int next = 1;
-	if(mManager->GetViewSubject()!=0 && mManager->GetViewSubject()->GetDataReplicated()!=0)
+	if(mManager->Owner()->Owner()->GetDataReplicated() != 0)
 	{
-		extDown = mManager->GetViewSubject()->GetDataReplicated()->GetNumReplicas(2*splitDim);
-		next += mManager->GetViewSubject()->GetDataReplicated()->GetNumReplicas(2*splitDim+1) + extDown;
+		int r[6];
+		mManager->Owner()->Owner()->GetDataReplicated()->GetReplicationFactors(r);
+		extDown = r[2*splitDim];
+		next += r[2*splitDim+1] + extDown;
 	}
 
 	int i, j, numEdges = innerEdges.Size();
 	if(numEdges > 0) 
 	{
 		int ntot = numEdges*next;
-		double *allEdges = new double[ntot]; IERROR_ASSERT(allEdges);
+		double *allEdges = new double[ntot]; IERROR_CHECK_MEMORY(allEdges);
 
 		for(j=0; j<next; j++)
 		{
