@@ -31,16 +31,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "igenericfilter.h"
-#include <vtkDataSetToPolyDataFilter.h>
+#include <vtkDataSetAlgorithm.h>
 
 
 class vtkPolyDataAlgorithm;
 
 
-class iContourFilter : public iGenericFilter<vtkDataSetToPolyDataFilter,vtkDataSet,vtkPolyData>
+class iContourFilter : public iGenericFilter<vtkDataSetAlgorithm,vtkImageData,vtkPolyData>
 {
 	
-	IGENERICFILTER_DECLARE(iContourFilter,vtkDataSetToPolyDataFilter);
+	iGenericFilterTypeMacro(iContourFilter,vtkDataSetAlgorithm);
 
 public:
 
@@ -57,7 +57,7 @@ protected:
 
 	virtual ~iContourFilter();
 
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 
 private:
 
