@@ -35,22 +35,30 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iorthoslicer.h"
 #include "iorthotextureplanefilter.h"
 
-#include <vtkStructuredPoints.h>
+#include <vtkImageData.h>
 
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
-#include "igenericfiltertemplate.h"
-#include "iviewsubjectpipelinetemplate.h"
+#include "iarray.tlh"
+#include "igenericfilter.tlh"
+#include "iviewsubjectpipeline.tlh"
 
 
+iPipelineKeyDefineMacro(iCrossSectionPipeline,Method);
+iPipelineKeyDefineMacro(iCrossSectionPipeline,Location);
+iPipelineKeyDefineMacro(iCrossSectionPipeline,Painting);
+iPipelineKeyDefineMacro(iCrossSectionPipeline,Direction);
+iPipelineKeyDefineMacro(iCrossSectionPipeline,SampleRate);
+iPipelineKeyDefineMacro(iCrossSectionPipeline,InterpolateData);
+
+	
 //
 // Main class
 //
-iCrossSectionPipeline::iCrossSectionPipeline(iCrossSectionViewSubject *s)  : iViewSubjectPipeline(s,1)
+iCrossSectionPipeline::iCrossSectionPipeline(iCrossSectionViewInstance *owner)  : iViewSubjectPipeline(owner,1)
 {
-	mParent = s;
+	mOwner = owner;
 
 	//
 	//  Do VTK stuff
@@ -59,13 +67,13 @@ iCrossSectionPipeline::iCrossSectionPipeline(iCrossSectionViewSubject *s)  : iVi
 	mPolygonConverter = this->CreateFilter<iOrthoPolygonPlaneFilter>();
 	mTextureConverter = this->CreateFilter<iOrthoTexturePlaneFilter>();
 	
-	mSlicer->SetDir(mParent->GetDir());
-	mSlicer->SetCurrentVar(mParent->GetVar());
+	mSlicer->SetDir(mOwner->GetDirection());
+	mSlicer->SetCurrentVar(mOwner->GetPaintVar());
 
-	mPolygonConverter->SetInput(mSlicer->GetOutput());
-	mTextureConverter->SetInput(mSlicer->GetOutput());
+	mPolygonConverter->SetInputConnection(mSlicer->GetOutputPort());
+	mTextureConverter->SetInputConnection(mSlicer->GetOutputPort());
 	
-	this->UpdateContents(_All);
+	this->UpdateContents();
 }
 
 
@@ -74,27 +82,27 @@ iCrossSectionPipeline::~iCrossSectionPipeline()
 }
 
 
-void iCrossSectionPipeline::ProduceOutput()
+void iCrossSectionPipeline::ProvideOutput()
 {
-	vtkPolyData *output = this->GetOutput();
-	vtkImageData *input = vtkImageData::SafeDownCast(this->GetInput());
+	vtkPolyData *output = this->OutputData();
+	vtkImageData *input = vtkImageData::SafeDownCast(this->InputData());
 	if(input == 0)
 	{
-		IERROR_FATAL("iCrossSectionPipeline is configured incorrectly.");
+		IBUG_ERROR("iCrossSectionPipeline is configured incorrectly.");
 		return;
 	}
 
-	if(mSlicer->GetInput() != input)
+	if(mSlicer->InputData() != input)
 	{
-		mSlicer->SetInput(input);
+		mSlicer->SetInputData(input);
 	}
 	
-	switch(mParent->GetActualMethod())
+	switch(mOwner->GetActualMethod())
 	{
 	case 0:
 		{
 			mPolygonConverter->Update();
-			output->ShallowCopy(mPolygonConverter->GetOutput());
+			output->ShallowCopy(mPolygonConverter->OutputData());
 			break;
 		}
 	case 1: 
@@ -104,7 +112,7 @@ void iCrossSectionPipeline::ProduceOutput()
 			//
 			this->SetTextureOffset(input);
 			mTextureConverter->Update(); 
-			output->ShallowCopy(mTextureConverter->GetOutput());
+			output->ShallowCopy(mTextureConverter->OutputData());
 			break;
 		}
 	default: return;
@@ -112,54 +120,51 @@ void iCrossSectionPipeline::ProduceOutput()
 }
 
 
-void iCrossSectionPipeline::SerialPostProcess(int index)
-{
-	if(index==0 && mParent->GetActualMethod()==1)
-	{
-		mTextureConverter->UpdateBoundaryConditions();
-	}
-}
-
-
 void iCrossSectionPipeline::SetTextureOffset(vtkImageData *input)
 {
 	//
 	//  Assign texture offsets
 	//
-	if(mParent->GetMethod() == 1)
+	if(mOwner->GetMethod() == 1)
 	{
 		double org[3], globalOrg[3], spa[3];
 		int dims[3], globalDims[3];
 		int Uidx, Vidx;
-		int Axis = mParent->GetDir();
+		int Axis = mOwner->GetDirection();
 		iOrthoSlicer::GetUV(Axis,Uidx,Vidx);
 
 		input->GetOrigin(org);
 		input->GetSpacing(spa);
 		input->GetDimensions(dims);
 
+		dims[Uidx] /= mOwner->GetSampleRate();
+		dims[Vidx] /= mOwner->GetSampleRate();
+
 		vtkImageData *globalInput = vtkImageData::SafeDownCast(mGlobalInput);
 		if(globalInput == 0)
 		{
-			IERROR_LOW("Incompatible global input.");
+			IBUG_WARN("Incompatible global input.");
 			return;
 		}
 
 		globalInput->GetOrigin(globalOrg);
 		globalInput->GetDimensions(globalDims);
 
+		globalDims[Uidx] /= mOwner->GetSampleRate();
+		globalDims[Vidx] /= mOwner->GetSampleRate();
+
 		if(dims[Axis] != globalDims[Axis])  
 		{
 			//
 			//  Split along Axis
 			//
-			mTextureConverter->SetTexturePiece(mParent->GetTextureData(),0,0,globalOrg,globalDims);
+			mTextureConverter->SetTexturePiece(mOwner->GetTextureData(),0,0,globalOrg,globalDims);
 		}
 		else
 		{
-			int offx = round((org[Uidx]-globalOrg[Uidx])/spa[Uidx]);
-			int offy = round((org[Vidx]-globalOrg[Vidx])/spa[Vidx]);
-			mTextureConverter->SetTexturePiece(mParent->GetTextureData(),offx,offy,globalOrg,globalDims);
+			int offx = iMath::Round2Int((org[Uidx]-globalOrg[Uidx])/spa[Uidx]);
+			int offy = iMath::Round2Int((org[Vidx]-globalOrg[Vidx])/spa[Vidx]);
+			mTextureConverter->SetTexturePiece(mOwner->GetTextureData(),offx,offy,globalOrg,globalDims);
 		}
 	}
 }
@@ -167,7 +172,7 @@ void iCrossSectionPipeline::SetTextureOffset(vtkImageData *input)
 
 void iCrossSectionPipeline::UpdateMethod()
 {
-	switch(mParent->GetActualMethod())
+	switch(mOwner->GetActualMethod())
 	{
 	case 0:
 		{
@@ -185,60 +190,45 @@ void iCrossSectionPipeline::UpdateMethod()
 }
 
 
-void iCrossSectionPipeline::UpdateDir()
+void iCrossSectionPipeline::UpdateDirection()
 { 
-	mSlicer->SetDir(mParent->GetDir());
-	mSlicer->SetPos(mParent->GetLocation());
+	mSlicer->SetDir(mOwner->GetDirection());
+	mSlicer->SetPos(mOwner->GetLocation());
 	this->Modified();
 }
 
 
-void iCrossSectionPipeline::UpdateVar()
+void iCrossSectionPipeline::UpdatePainting()
 { 
-	mSlicer->SetCurrentVar(mParent->GetVar());
+	mSlicer->SetCurrentVar(mOwner->GetPaintVar());
 	this->Modified();
 }
 
 
-void iCrossSectionPipeline::UpdatePos()
+void iCrossSectionPipeline::UpdateLocation()
 { 
-	mSlicer->SetPos(mParent->GetLocation());
+	mSlicer->SetPos(mOwner->GetLocation());
 	this->Modified();
 }
 
 
 void iCrossSectionPipeline::UpdateInterpolateData()
 {
-	mPolygonConverter->SetInterpolation(mParent->GetInterpolateData());
-	mSlicer->SetInterpolation(mParent->GetInterpolateData());
+	mPolygonConverter->SetInterpolation(mOwner->GetInterpolateData());
+	mSlicer->SetInterpolation(mOwner->GetInterpolateData());
 	this->Modified();
 }
 
 
 void iCrossSectionPipeline::UpdateSampleRate()
 {
-	mSlicer->SetSampleRate(mParent->GetSampleRate());
+	mSlicer->SetSampleRate(mOwner->GetSampleRate());
 	this->Modified();
 }
 
 
-float iCrossSectionPipeline::GetContentsMemorySize() const
+void iCrossSectionPipeline::UpdateReplicas()
 {
-	float s = 0.0f;
-	s += mSlicer->GetMemorySize();
-	s += mPolygonConverter->GetMemorySize();
-	s += mTextureConverter->GetMemorySize();
-	return s;
-}
-
-
-void iCrossSectionPipeline::UpdateContents(int n, int)
-{
-	if(n==_All || n==_Dir) this->UpdateDir();
-	if(n==_All || n==_InterpolateData) this->UpdateInterpolateData();
-	if(n==_All || n==_Method) this->UpdateMethod();
-	if(n==_All || n==_Pos) this->UpdatePos();
-	if(n==_All || n==_SampleRate) this->UpdateSampleRate();
-	if(n==_All || n==_Var) this->UpdateVar();
+	// Not replicatable
 }
 
