@@ -33,7 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewsubjectpipeline.h"
 
 
-class iCrossSectionViewSubject;
+class iCrossSectionViewInstance;
 class iOrthoPolygonPlaneFilter;
 class iOrthoSlicer;
 class iOrthoTexturePlaneFilter;
@@ -44,48 +44,30 @@ class vtkImageData;
 class iCrossSectionPipeline : public iViewSubjectPipeline
 {
 
-	friend class iCrossSectionViewSubject;
+	friend class iCrossSectionViewInstance;
 	
 public:
 	
-	enum
-	{
-		_Dir = iViewSubjectPipeline::__Last,
-		_InterpolateData,
-		_Method,
-		_Pos,
-		_SampleRate,
-		_Var,
-		__Last
-	};
-
 	vtkTypeMacro(iCrossSectionPipeline,iViewSubjectPipeline);
 
-	virtual void UpdateContents(int n, int info = 0);
-
-	virtual void SerialPostProcess(int index);
+	iPipelineKeyDeclareMacro(iCrossSectionPipeline,Method);
+	iPipelineKeyDeclareMacro(iCrossSectionPipeline,Location);
+	iPipelineKeyDeclareMacro(iCrossSectionPipeline,Painting);
+	iPipelineKeyDeclareMacro(iCrossSectionPipeline,Direction);
+	iPipelineKeyDeclareMacro(iCrossSectionPipeline,SampleRate);
+	iPipelineKeyDeclareMacro(iCrossSectionPipeline,InterpolateData);
 
 protected:
 	
-	iCrossSectionPipeline(iCrossSectionViewSubject *s);
+	iCrossSectionPipeline(iCrossSectionViewInstance *owner);
 	virtual ~iCrossSectionPipeline();
 
-	virtual void ProduceOutput();
-	virtual float GetContentsMemorySize() const;
-
-	//
-	//  Pipeline operation
-	//
-	virtual void UpdateDir();
-	virtual void UpdateInterpolateData();
-	virtual void UpdateMethod();
-	virtual void UpdatePos();
-	virtual void UpdateSampleRate();
-	virtual void UpdateVar();
+	virtual void ProvideOutput();
+	virtual void UpdateReplicas();
 
 	void SetTextureOffset(vtkImageData *input);
 
-	iCrossSectionViewSubject *mParent;
+	iCrossSectionViewInstance *mOwner;
 
 	//
 	//  VTK stuff
