@@ -32,6 +32,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iaxis.h"
 #include "ierror.h"
 #include "ioverlayhelper.h"
+#include "irendertool.h"
+#include "iviewmodule.h"
 
 #include <vtkAxisActor2D.h>
 #include <vtkProperty2D.h>
@@ -43,13 +45,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
-#include "igenericproptemplate.h"
+#include "iarray.tlh"
+#include "igenericprop.tlh"
 
 
 iCubeAxesActor* iCubeAxesActor::New(iRenderTool *rt)
 {
-	IERROR_ASSERT(rt);
+	IASSERT(rt);
 	return new iCubeAxesActor(rt);
 }
 
@@ -113,6 +115,19 @@ int iCubeAxesActor::RenderOpaqueGeometry(vtkViewport *vp)
 {
  	int mag = mOverlayHelper->GetRenderingMagnification();
 
+	if(strcmp(this->GetXLabel(),"X")==0 && strcmp(this->GetYLabel(),"Y")==0 && strcmp(this->GetZLabel(),"Z")==0)
+	{
+		if(mOverlayHelper->GetRenderTool()->GetViewModule()->InOpenGLCoordinates())
+		{
+			this->SetRanges(-1.0,1.0,-1.0,1.0,-1.0,1.0);
+		}
+		else 
+		{
+			float bs = mOverlayHelper->GetRenderTool()->GetViewModule()->GetBoxSize();
+			this->SetRanges(0.0,bs,0.0,bs,0.0,bs);
+		}
+	}
+
 	if(mag == 1)
 	{
 		return this->vtkCubeAxesActor2D::RenderOpaqueGeometry(vp);
