@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -51,9 +51,9 @@ namespace iData_Private
 		return tmp;
 	}
 
-	iSearchableArray<iString>& Keywords()
+	iLookupArray<iString>& Keywords()
 	{
-		static iSearchableArray<iString> array;
+		static iLookupArray<iString> array;
 		return array;
 	}
 };
@@ -65,17 +65,18 @@ using namespace iData_Private;
 //
 //  DataType class
 //
-iDataType::iDataType(int id, const iString& tname, const iString& sname, int rank, const iString &keywords, const iString &env) : mId(id), mTextName(tname), mShortName(sname), mRank(rank), mKeywords(keywords)
+iDataType::iDataType(int id, const iString& tname, const iString& sname, int rank, const iString &keywords, const iString &env) : mId(id), mTextName(tname), mRank(rank), mKeywords(keywords)
 {
 	int i, n;
 
-	mName = tname.Substitute(" ","");
+	mLongName = tname.Substitute(" ","");
+	mShortName = sname;
 
-	for(i=0; i<AllData().Count(); i++)
+	for(i=0; i<AllData().Size(); i++)
 	{
-		if(mId==AllData().Type(i).GetId() || mName==AllData().Type(i).GetName() || mShortName==AllData().Type(i).GetShortName())
+		if(this->GetId()==AllData().Type(i).GetId() || mLongName==AllData().Type(i).LongName() || mShortName==AllData().Type(i).ShortName())
 		{
-			IERROR_FATAL("Incorrectly configured DataType object.");
+			IBUG_FATAL("Incorrectly configured DataType object.");
 		}
 	}
 
@@ -115,25 +116,7 @@ iDataType::~iDataType()
 
 bool iDataType::MatchesKeyword(const iString &str) const
 {
-#ifdef I_CHECK1
-	if(Keywords().Find(str) == -1)
-	{
-		IERROR_LOW((str+" is not a valid keyword").ToCharPointer());
-	}
-#endif
-
-	//
-	//  Analyse keywords
-	//
-	if(!mKeywords.IsEmpty())
-	{
-		int i, n = mKeywords.Contains(",");
-		for(i=0; i<=n; i++) if(mKeywords.Section(",",i,i) == str)
-		{
-			return true;
-		}
-	}
-	return false;
+	return (mKeywords.Find(str) != -1);
 }
 
 
@@ -141,17 +124,18 @@ void iDataType::FindTypesByKeywords(iDataInfo &info, const iString &str)
 {
 	int i, j, n = str.Contains(",");
 	iString d;
-	info.Erase();
+	info.Clear();
 	for(i=0; i<=n; i++)
 	{
 		d = str.Section(",",i,i);
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 		if(Keywords().Find(d) == -1)
 		{
-			IERROR_LOW((d+" is not a valid keyword").ToCharPointer());
+			IBUG_WARN(d+" is not a valid keyword");
+			continue;
 		}
 #endif
-		for(j=0; j<AllData().Count(); j++)
+		for(j=0; j<AllData().Size(); j++)
 		{
 			if(AllData().Type(j).MatchesKeyword(d)) info += AllData().Type(j);
 		}
@@ -159,10 +143,10 @@ void iDataType::FindTypesByKeywords(iDataInfo &info, const iString &str)
 }
 
 
-const iDataType& iDataType::FindTypeById(int id)
+const iDataType& iDataType::FindTypeById(iDataId id)
 {
 	int i;
-	for(i=0; i<AllData().Count(); i++) if(AllData().Type(i).GetId() == id) return AllData().Type(i);
+	for(i=0; i<AllData().Size(); i++) if(AllData().Type(i).GetId() == id) return AllData().Type(i);
 	return Null();
 }
 
@@ -170,7 +154,7 @@ const iDataType& iDataType::FindTypeById(int id)
 const iDataType& iDataType::FindTypeByName(const iString &name)
 {
 	int i;
-	for(i=0; i<AllData().Count(); i++) if(AllData().Type(i).IsOfType(name)) return AllData().Type(i);
+	for(i=0; i<AllData().Size(); i++) if(AllData().Type(i).IsOfType(name)) return AllData().Type(i);
 	return Null();
 }
 
@@ -205,7 +189,7 @@ iDataInfo::iDataInfo()
 iDataInfo::iDataInfo(const iDataInfo &set)
 {
 	int i;
-	for(i=0; i<set.Count(); i++) mArr.AddUnique(&(set.Type(i)));
+	for(i=0; i<set.Size(); i++) mArr.AddUnique(&(set.Type(i)));
 }
 
 
@@ -220,7 +204,7 @@ iDataInfo::~iDataInfo()
 }
 
 
-void iDataInfo::Erase()
+void iDataInfo::Clear()
 {
 	mArr.Clear();
 }
@@ -231,14 +215,14 @@ iDataInfo& iDataInfo::operator=(const iDataInfo &info)
 	int i;
 
 	mArr.Clear();
-	for(i=0; i<info.Count(); i++) mArr.Add(&(info.Type(i)));
-
+	for(i=0; i<info.Size(); i++) mArr.Add(&(info.Type(i)));
 	return *this;
 }
 
 
-iDataInfo& iDataInfo::operator+=(const iDataType &type)
+iDataInfo& iDataInfo::operator=(const iDataType &type)
 {
+	mArr.Clear();
 	if(!type.IsNull()) mArr.AddUnique(&type);
 	return *this;
 }
@@ -254,6 +238,13 @@ iDataInfo& iDataInfo::operator+=(const iDataInfo &info)
 }
 
 
+iDataInfo& iDataInfo::operator+=(const iDataType &type)
+{
+	if(!type.IsNull()) mArr.AddUnique(&type);
+	return *this;
+}
+
+
 iDataInfo& iDataInfo::operator-=(const iDataType &type)
 {
 	if(!type.IsNull()) mArr.Remove(&type);
