@@ -31,7 +31,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "idata.h"
 #include "idatahandler.h"
+#include "idatalimits.h"
 #include "idatareader.h"
+#include "idatasubject.h"
 #include "ierror.h"
 #include "iviewmodule.h"
 
@@ -39,7 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -49,46 +51,21 @@ int iDataConsumer::mModeGlobal = DataConsumerOptimizationMode::OptimizeForSpeed;
 
 
 //
-//  helper class
+//  Base class for all objects that use data
 //
-iDataSyncRequest::iDataSyncRequest()
+iDataConsumer::iDataConsumer(iViewModule *vm, const iDataType &type) : iViewModuleComponent(vm), mDataType(type), mPrimaryDataInfo(new iDataInfo(type))
 {
-	mDataInfoPointer = new iDataInfo; IERROR_ASSERT(mDataInfoPointer);
-	mVar = -1;
-}
+	IASSERT(vm);
+	IERROR_CHECK_MEMORY(mPrimaryDataInfo);
+	mSecondaryDataInfo = new iDataInfo; IERROR_CHECK_MEMORY(mSecondaryDataInfo);
 
-
-iDataSyncRequest::~iDataSyncRequest()
-{
-	delete mDataInfoPointer;
-}
-
-
-void iDataSyncRequest::Set(int var, const iDataInfo &info)
-{
-	mVar = var;
-	*mDataInfoPointer = info;
-}
-
-
-//
-//  Main class
-//
-iDataConsumer::iDataConsumer(iViewModule *vm, const iDataType &type) : mViewModule(vm), mPrimaryDataInfo(new iDataInfo(type))
-{
-	IERROR_ASSERT(vm);
-	IERROR_ASSERT(mPrimaryDataInfo);
-	mSecondaryDataInfo = new iDataInfo; IERROR_ASSERT(mSecondaryDataInfo);
 	mModeLocal = mModeGlobal;
 	mOverrideGlobal = false;
-	
-	this->GetViewModule()->RegisterDataConsumer(this);
 }
 
 
 iDataConsumer::~iDataConsumer()
 {
-	this->GetViewModule()->UnRegisterDataConsumer(this);
 	delete mPrimaryDataInfo;
 	delete mSecondaryDataInfo;
 
@@ -110,33 +87,21 @@ void iDataConsumer::AddSecondaryDataType(const iDataType &type)
 }
 
 
-bool iDataConsumer::IsUsingData(const iDataInfo &info, bool onlyprimary) const
+float iDataConsumer::GetMemorySize()
 {
 	int i;
-	for(i=0; i<info.Count(); i++)
-	{
-		if(mPrimaryDataInfo->Includes(info.Type(i))) return true;
-		if(!onlyprimary && mSecondaryDataInfo->Includes(info.Type(i))) return true;
-	}
-	return false;
+	float s = 0.0;
+
+	for(i=0; i<mDataHandlers.Size(); i++) s += mDataHandlers[i]->GetMemorySize();
+
+	return s;
 }
 
 
-const iDataType& iDataConsumer::GetDataType() const
+void iDataConsumer::RemoveInternalData()
 {
-	return mPrimaryDataInfo->Type(0);
-}
-
-
-bool iDataConsumer::IsThereData() const
-{
-	return this->GetViewModule()->GetReader()->IsThereData(this->GetDataType());
-}
-
-
-vtkDataSet* iDataConsumer::GetData() const
-{
-	return this->GetViewModule()->GetReader()->GetData(this->GetDataType());
+	int i;
+	for(i=0; i<mDataHandlers.Size(); i++) mDataHandlers[i]->RemoveInternalData();
 }
 
 
@@ -188,38 +153,88 @@ void iDataConsumer::UnRegisterDataHandler(iDataHandler *c)
 }
 
 
-void iDataConsumer::SyncWithData(const iDataSyncRequest &r)
+bool iDataConsumer::IsUsingData(const iDataType &type, bool onlyprimary) const
+{
+	if(mDataType == type) return true;
+
+	return (!onlyprimary && mSecondaryDataInfo->Includes(type));
+}
+
+
+iDataSubject* iDataConsumer::GetSubject() const
+{
+	iDataSubject *subject = this->GetViewModule()->GetReader()->GetSubject(mDataType);
+	IASSERT(subject);
+	return subject;
+}
+
+
+iDataLimits* iDataConsumer::GetLimits() const
+{
+	return this->GetSubject()->GetLimits();
+}
+
+
+bool iDataConsumer::IsThereData() const
+{
+	return this->GetSubject()->IsThereData();
+}
+
+
+bool iDataConsumer::SyncWithLimits(int var, int mode)
 {
 	int i;
-	this->SyncWithDataBody(r);
-	for(i=0; i<mDataHandlers.Size(); i++) mDataHandlers[i]->SyncWithData(r);
+	if(!this->SyncWithLimitsBody(var,mode)) return false;
+	for(i=0; i<mDataHandlers.Size(); i++)
+	{
+		if(!mDataHandlers[i]->SyncWithLimits(var,mode)) return false;
+	}
+	return true;
 }
 
 
-const iDataSyncRequest& iDataConsumer::RequestAll()
+bool iDataConsumer::SyncWithLimitsBody(int var, int mode)
 {
-	mRequest.Set(-1,(*mPrimaryDataInfo)+(*mSecondaryDataInfo));
-	return mRequest;
+	return true;
 }
 
 
-const iDataSyncRequest& iDataConsumer::RequestPrimary()
+//
+//  iSynchRequest class and its specializations
+//
+iSyncRequest::iSyncRequest(const iDataType& type) : mDataType(type)
 {
-	mRequest.Set(-1,*mPrimaryDataInfo);
-	return mRequest;
 }
 
 
-const iDataSyncRequest& iDataConsumer::Request(int ind)
+iSyncRequest::~iSyncRequest()
 {
-	mRequest.Set(ind,(*mPrimaryDataInfo)+(*mSecondaryDataInfo));
-	return mRequest;
 }
 
 
-const iDataSyncRequest& iDataConsumer::Request(const iDataInfo &info, int ind) // for general use
+
+iSyncWithDataRequest::iSyncWithDataRequest(const iDataType& type) : iSyncRequest(type)
 {
-	static iDataSyncRequest req;
-	req.Set(ind,info);
-	return req;
+}
+
+
+void iSyncWithDataRequest::Sync(iDataConsumer *consumer) const
+{
+	IASSERT(consumer);
+
+	consumer->SyncWithData();
+}
+
+
+
+iSyncWithLimitsRequest::iSyncWithLimitsRequest(int var, int mode, const iDataType& type) : iSyncRequest(type), Var(var), Mode(mode)
+{
+}
+
+
+void iSyncWithLimitsRequest::Sync(iDataConsumer *consumer) const
+{
+	IASSERT(consumer);
+
+	consumer->SyncWithLimits(Var,Mode);
 }
