@@ -33,13 +33,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IDATACONSUMER_H
 
 
+#include "iviewmodulecomponent.h"
+
+
 #include "iarray.h"
 #include "istring.h"
 
-#include "ipointermacro.h"
-
+class iDataConsumer;
 class iDataHandler;
 class iDataInfo;
+class iDataLimits;
+class iDataSubject;
 class iDataType;
 class iViewModule;
 
@@ -62,38 +66,64 @@ namespace iParameter
 	};
 };
 
-//
-//  Helper class for providing requests
-//
-class iDataSyncRequest
-{
 
-	friend class iDataConsumer;
+//
+//  Helper class for providing synchronization requests
+//
+class iSyncRequest
+{
 
 public:
 
-	~iDataSyncRequest();
+	virtual ~iSyncRequest();
 
-	int Var() const { return mVar; }
-	const iDataInfo& Data() const { return *mDataInfoPointer; }
+	inline const iDataType& DataType() const { return mDataType; }
+
+	virtual void Sync(iDataConsumer *consumer) const = 0;
+
+protected:
+
+	iSyncRequest(const iDataType& type);
 
 private:
 
-	iDataSyncRequest();
-	void Set(int var, const iDataInfo &info);
-
-	int mVar;
-	iDataInfo* mDataInfoPointer;
+	const iDataType &mDataType;
 };
 
 
-class iDataConsumer
+class iSyncWithDataRequest : public iSyncRequest
+{
+
+public:
+
+	iSyncWithDataRequest(const iDataType& type);
+
+	virtual void Sync(iDataConsumer *consumer) const;
+};
+
+
+class iSyncWithLimitsRequest : public iSyncRequest
+{
+
+public:
+
+	iSyncWithLimitsRequest(int var, int mode, const iDataType& type);
+
+	virtual void Sync(iDataConsumer *consumer) const;
+
+private:
+
+	const int Var, Mode;
+};
+
+
+class iDataConsumer : public iViewModuleComponent
 {
 
 	friend class iDataHandler;
-	friend class iViewModule;
-
-	IPOINTER_AS_PART(ViewModule);
+	friend class iSyncWithDataRequest;
+	friend class iSyncWithLimitsRequest;
+	//friend class iViewModule;
 
 public:
 
@@ -107,46 +137,71 @@ public:
 	inline bool IsOptimizedForMemory() const { return this->GetOptimizationMode() == iParameter::DataConsumerOptimizationMode::OptimizeForMemory; }
 	inline bool IsOptimizedForQuality() const { return this->GetOptimizationMode() == iParameter::DataConsumerOptimizationMode::OptimizeForQuality; }
 
-	virtual const iDataType& GetDataType() const;
+	virtual float GetMemorySize();
+	virtual void RemoveInternalData();
+
+	inline const iDataType& GetDataType() const { return mDataType; }
 	virtual bool IsThereData() const;
-	bool IsUsingData(const iDataInfo &info, bool onlyprimary) const;
 
 	void AddSecondaryDataType(const iDataType &type);
 
 	inline const iDataInfo& GetPrimaryDataInfo() const { return *mPrimaryDataInfo; }
 	inline const iDataInfo& GetSecondaryDataInfo() const { return *mSecondaryDataInfo; }
 
-	virtual void SyncWithData(const iDataSyncRequest &r);
-	const iDataSyncRequest& RequestAll();
-	const iDataSyncRequest& RequestPrimary();
-	const iDataSyncRequest& Request(int var);
-	static const iDataSyncRequest& Request(const iDataInfo &info, int var = -1);
+	iDataLimits* GetLimits() const;
+	iDataSubject* GetSubject() const;
+	virtual bool IsUsingData(const iDataType &type, bool onlyprimary) const;
+
+	bool SyncWithLimits(int var, int mode);
 
 protected:
 
     iDataConsumer(iViewModule *vm, const iDataType &type);
     virtual ~iDataConsumer();
 
-	virtual vtkDataSet* GetData() const;
-
 	void RegisterDataHandler(iDataHandler *c);
 	void UnRegisterDataHandler(iDataHandler *c);
 
-	virtual void SyncWithDataBody(const iDataSyncRequest &r) = 0;
-
-	iDataInfo *mPrimaryDataInfo, *mSecondaryDataInfo;
+	virtual bool SyncWithLimitsBody(int var, int mode); // by default do nothing
+	virtual bool SyncWithData() = 0;
 
 private:
 
-	iDataSyncRequest mRequest;
-
-	iPointerArray<iDataHandler> mDataHandlers;
-
 	static int mModeGlobal;
 	int mModeLocal;
 	bool mOverrideGlobal;
+	iLookupArray<iDataHandler*> mDataHandlers;
+	const iDataType& mDataType;
+	iDataInfo *mPrimaryDataInfo, *mSecondaryDataInfo;
 };
 
 
+#define iDataConsumerTypeMacro(_type_,_parent_) \
+	protected: \
+	virtual bool SyncWithDataBody(); \
+	virtual bool SyncWithData() \
+	{ \
+		if(!this->_type_::SyncWithDataBody()) return false; \
+		return this->_parent_::SyncWithData(); \
+	} \
+	vtkTypeMacro(_type_,_parent_)
+
+#define iDataConsumerTypeMacroPass(_type_,_parent_) \
+	protected: \
+	virtual bool SyncWithData() \
+	{ \
+		return this->_parent_::SyncWithData(); \
+	} \
+	vtkTypeMacro(_type_,_parent_)
+
+#define iDataConsumerTypeMacroBase(_type_,_parent_) \
+	protected: \
+	virtual bool SyncWithDataBody(); \
+	virtual bool SyncWithData() \
+	{ \
+		return this->_type_::SyncWithDataBody(); \
+	} \
+	vtkTypeMacro(_type_,_parent_)
+
 #endif // IDATACONSUMER_H
 
