@@ -37,17 +37,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 iDataFormatter* iDataFormatter::New(iViewModule *vm)
 {
-	IERROR_ASSERT(vm);
+	IASSERT(vm);
 	return new iDataFormatter(vm);
 }
 
 
-iDataFormatter::iDataFormatter(iViewModule *vm) : mViewModule(vm)
+iDataFormatter::iDataFormatter(iViewModule *vm) : iViewModuleComponent(vm)
 {
 	mFormatHelper = "                                                          ";
 }
@@ -103,7 +103,7 @@ void iDataFormatter::FormatScalarData(iDataLimits *lim, int n, float *v, bool us
 
 	for(i=0; i<n; i++) if(!useRank || lim->GetRank(i)==0)
 	{
-		vlog = float(log10(1.0e-30+fabs(v[i])));
+		vlog = float(iMath::Log10(1.0e-30+fabs(v[i])));
 		s2 = iString::FromNumber(v[i],"%.3e");
 		if(s2.Length() < maxLen) s2 += mFormatHelper.Part(0,maxLen-s2.Length());
 		s1 = s2 + " (" + iString::FromNumber(vlog,"% 5.2f") + " dex)";
