@@ -31,22 +31,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkObjectBase.h>
+#include "iviewmodulecomponent.h"
 
 
 #include "iarray.h"
 #include "istring.h"
 
-#include "ipointermacro.h"
-
 class iDataLimits;
-class iViewModule;
 
 
-class iDataFormatter : public vtkObjectBase
+class iDataFormatter : public vtkObjectBase, public iViewModuleComponent
 {
 
-	IPOINTER_AS_PART(ViewModule);
-
 public:
 
 	static iDataFormatter* New(iViewModule *vm = 0);
