@@ -29,44 +29,68 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "idatahandler.h"
 
 
-#include "icontrolmodule.h"
 #include "idataconsumer.h"
+#include "idatasubject.h"
 #include "ierror.h"
 #include "ishell.h"
 #include "iviewmodule.h"
 
 
-iDataHandler::iDataHandler(iDataConsumer *consumer) : mViewModule((consumer==0)?0:consumer->GetViewModule())
+iDataHandler::iDataHandler(iDataConsumer *consumer) : iViewModuleComponent((consumer==0)?0:consumer->GetViewModule())
 {
-	IERROR_ASSERT(consumer);
+	IASSERT(consumer);
 
 	mConsumer = consumer;
 	mConsumer->RegisterDataHandler(this);
 
-	if(mViewModule != 0) mViewModule->GetControlModule()->GetShell()->OnInitAtom();
+	this->GetViewModule()->GetShell()->OnInitAtom();
 }
 
 
 iDataHandler::~iDataHandler()
 {
+	//
+	//  On exit, garbare collector may delete consumer first; 
+	//  then mConsumer would set to 0 by iDataConsumer destructor.
+	//
 	if(mConsumer != 0) mConsumer->UnRegisterDataHandler(this);
 }
 
 
 bool iDataHandler::IsOptimizedForSpeed() const
 {
-	if(mConsumer != 0) return mConsumer->IsOptimizedForSpeed(); else return false;
+	return mConsumer->IsOptimizedForSpeed();
 }
 
 
 bool iDataHandler::IsOptimizedForMemory() const
 {
-	if(mConsumer != 0) return mConsumer->IsOptimizedForMemory(); else return false;
+	return mConsumer->IsOptimizedForMemory();
 }
 
 
 bool iDataHandler::IsOptimizedForQuality() const
 {
-	if(mConsumer != 0) return mConsumer->IsOptimizedForQuality(); else return false;
+	return mConsumer->IsOptimizedForQuality();
+}
+
+
+iDataLimits* iDataHandler::GetLimits() const
+{
+	return mConsumer->GetLimits();
+}
+
+
+void iDataHandler::GetPeriodicities(bool per[3]) const
+{
+	int i;
+
+	for(i=0; i<3; i++) per[i] = mConsumer->GetSubject()->IsDirectionPeriodic(i);
+}
+
+
+bool iDataHandler::SyncWithLimits(int var, int mode)
+{
+	return true;
 }
 
