@@ -26,26 +26,26 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
-#include "iconfigure.h"
 #include "idatareader.h"
 
 
-#include "ibasicdatasubjects.h"
-#include "ibasicparticlesfileloader.h"
 #include "ibuffer.h"
-#include "icommoneventobservers.h"
-#include "icontrolmodule.h"
+#include "icoredatasubjects.h"
+#include "icorefileloaders.h"
 #include "idata.h"
 #include "idatalimits.h"
+#include "idatareaderobserver.h"
 #include "idatasubject.h"
 #include "idirectory.h"
 #include "iedition.h"
 #include "ierror.h"
-#include "ierrorstatus.h"
 #include "ifile.h"
+#include "imonitor.h"
 #include "iobjectfactory.h"
 #include "iparallelmanager.h"
 #include "iparallelworker.h"
+#include "ishell.h"
+#include "ishelleventobservers.h"
 #include "iuniformgriddata.h"
 #include "iuniformgridfileloader.h"
 #include "iviewmodule.h"
@@ -55,37 +55,25 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
+#include "iproperty.tlh"
 
 
 using namespace iParameter;
 
 
-//
-//  Define static members
-//
-IOBJECT_DEFINE_TYPE(iDataReader,DataReader,dr,iObjectType::_Helper);
-
-IOBJECT_DEFINE_KEY(iDataReader,BoundaryConditions,bc,Int,1);
-IOBJECT_DEFINE_KEY(iDataReader,EraseData,e,String,1);
-IOBJECT_DEFINE_KEY(iDataReader,ErrorMessage,em,String,1); 
-IOBJECT_DEFINE_KEY(iDataReader,IsSet,is,Bool,1); 
-IOBJECT_DEFINE_KEY(iDataReader,LoadData,l,String,2); 
-IOBJECT_DEFINE_KEY(iDataReader,ShiftData,s,Double,3);
-IOBJECT_DEFINE_KEY(iDataReader,ScaledDimension,sd,Int,1);
-IOBJECT_DEFINE_KEY(iDataReader,VoxelLocation,vl,Int,1);
-
-IOBJECT_DEFINE_KEY(iDataReader,RecordLength,-l,Int,1);  // hidden key
-
 //
 //  Main class
 //
 iDataReader* iDataReader::New(iViewModule* vm)
 {
+	static iString LongName("DataReader");
+	static iString ShortName("dr");
+
 	int i, j, k;
 
-	IERROR_ASSERT(vm);
-	iDataReader *tmp = new iDataReader(vm); IERROR_ASSERT(tmp);
+	IASSERT(vm);
+	iDataReader *tmp = new iDataReader(vm,LongName,ShortName); IERROR_CHECK_MEMORY(tmp);
 	iObjectFactory::InstallExtensions(tmp);
 
 	iFileLoader *s;
@@ -96,58 +84,74 @@ iDataReader* iDataReader::New(iViewModule* vm)
 		{
 			for(k=0; k<s->NumStreams(); k++)
 			{
-				iEdition::ApplySettings(s->GetStream(k)->Subject,s->GetStream(k)->Subject->GetObjectType());
+				iEdition::ApplySettings(s->GetStream(k)->Subject);
 			}
 			tmp->mLoaders.Add(s);
 		}
 	}
 
-	iEdition::ApplySettings(tmp,iDataReader::Type());
+	iEdition::ApplySettings(tmp);
 
 	return tmp;
 }
 
 
-iDataReader::iDataReader(iViewModule *vm) : iExtendableObject("Data Reader"), mViewModule(vm)
+iDataReader::iDataReader(iViewModule *vm, const iString &fname, const iString &sname) : iExtendableObject(vm,fname,sname), iViewModuleComponent(vm),
+	iObjectConstructPropertyMacroS(Int,iDataReader,BoundaryConditions,bc),
+	iObjectConstructPropertyMacroS(Int,iDataReader,ScaledDimension,sd),
+	iObjectConstructPropertyMacroS(Int,iDataReader,VoxelLocation,vl),
+	iObjectConstructPropertyMacroS(Int,iDataReader,MaxZDimension,mzd),
+	iObjectConstructPropertyMacroV(Double,iDataReader,Shift,s,3),
+	iObjectConstructPropertyMacroA2(DataType,String,iDataReader,Load,l),
+	iObjectConstructPropertyMacroA1(DataType,iDataReader,Erase,e),
+	iObjectConstructPropertyMacroA(iDataReader,Reload,r)
 {
+	mRenderMode = RenderMode::Clones;
+
 	mRecordLength = 4; 
 
 	mTwoCopies = mInExtensionUpdate = false;
 
 	mCellToPointMode = 2;
 	mVoxelLocation = VoxelLocation::Vertex;
-	mBoundaryConditions = BoundaryConditions::Wall;
+	mBoundaryConditions = BoundaryConditions::None;
 
-    mUniformVectorsLoader = new iUniformVectorsFileLoader(this); IERROR_ASSERT(mUniformVectorsLoader);
-    mUniformScalarsLoader = new iUniformScalarsFileLoader(this,mUniformVectorsLoader); IERROR_ASSERT(mUniformScalarsLoader);
-    mUniformTensorsLoader = new iUniformTensorsFileLoader(this); IERROR_ASSERT(mUniformTensorsLoader);
-    mBasicParticlesLoader = new iBasicParticlesFileLoader(this); IERROR_ASSERT(mBasicParticlesLoader);
+	//delete mPropertyStack;
+	//mPropertyStack = new iDataReaderPropertyStack(this); IERROR_CHECK_MEMORY(mPropertyStack);
 
-	iUniformScalarsDataSubject *us = new iUniformScalarsDataSubject(mUniformScalarsLoader); IERROR_ASSERT(us);
-	iUniformVectorsDataSubject *uv = new iUniformVectorsDataSubject(mUniformVectorsLoader); IERROR_ASSERT(uv);
-	iUniformTensorsDataSubject *ut = new iUniformTensorsDataSubject(mUniformTensorsLoader); IERROR_ASSERT(ut);
-	iBasicParticlesDataSubject *bp = new iBasicParticlesDataSubject(mBasicParticlesLoader); IERROR_ASSERT(bp);
+	mVectorLoader = new iCoreData::VectorFileLoader(this); IERROR_CHECK_MEMORY(mVectorLoader);
+    mScalarLoader = new iCoreData::ScalarFileLoader(this,mVectorLoader); IERROR_CHECK_MEMORY(mScalarLoader);
+    mTensorLoader = new iCoreData::TensorFileLoader(this); IERROR_CHECK_MEMORY(mTensorLoader);
+    mParticleLoader = new iCoreData::ParticleFileLoader(this); IERROR_CHECK_MEMORY(mParticleLoader);
 
-	iEdition::ApplySettings(us,us->GetObjectType());
-	iEdition::ApplySettings(uv,uv->GetObjectType());
-	iEdition::ApplySettings(ut,ut->GetObjectType());
-	iEdition::ApplySettings(bp,bp->GetObjectType());
+	iCoreData::ScalarDataSubject *us = new iCoreData::ScalarDataSubject(mScalarLoader); IERROR_CHECK_MEMORY(us);
+	iCoreData::VectorDataSubject *uv = new iCoreData::VectorDataSubject(mVectorLoader); IERROR_CHECK_MEMORY(uv);
+	iCoreData::TensorDataSubject *ut = new iCoreData::TensorDataSubject(mTensorLoader); IERROR_CHECK_MEMORY(ut);
+	iCoreData::ParticleDataSubject *bp = new iCoreData::ParticleDataSubject(mParticleLoader); IERROR_CHECK_MEMORY(bp);
 
-	mLoaders.Add(mUniformScalarsLoader);
-	mLoaders.Add(mUniformVectorsLoader);
-	mLoaders.Add(mUniformTensorsLoader);
-	mLoaders.Add(mBasicParticlesLoader);
+	iEdition::ApplySettings(us);
+	iEdition::ApplySettings(uv);
+	iEdition::ApplySettings(ut);
+	iEdition::ApplySettings(bp);
+
+	mLoaders.Add(mScalarLoader);
+	mLoaders.Add(mVectorLoader);
+	mLoaders.Add(mTensorLoader);
+	mLoaders.Add(mParticleLoader);
 
 	mCurrentRecord = -1;
 	mPeriodicityLeader = 0;
 
-	mDataShift[0] = mDataShift[1] = mDataShift[2] = 0.0f;
+	mShift[0] = mShift[1] = mShift[2] = 0.0f;
 
-	mScaledDim = -1; //max dim
+	mScaledDimension = -1; //max dim
+	mMaxZDimension = 0;
+
+	mDataReloadInfo = new iDataInfo; IERROR_CHECK_MEMORY(mDataReloadInfo);
 
 //	mLastFileName = mLastAttemptedFileName = "";
 
-	mDirectory = new iDirectory; IERROR_ASSERT(mDirectory);
+	mDirectory = new iDirectory; IERROR_CHECK_MEMORY(mDirectory);
 }
 
 
@@ -156,23 +160,12 @@ iDataReader::~iDataReader()
 	int i;
 
 	delete mDirectory;
+	delete mDataReloadInfo;
 
 	for(i=0; i<mLoaders.Size(); i++) mLoaders[i]->Delete();
 }
 
 
-bool iDataReader::IsAborted(const iDataType &type) const
-{
-	int i;
-
-	for(i=0; i<mLoaders.Size(); i++)
-	{
-		if(mLoaders[i]->IsUsingData(type) && mLoaders[i]->IsAborted()) return true;
-	}
-	return false;
-}
-
-
 void iDataReader::EraseData(const iDataType &type)
 {
 	int i;
@@ -181,7 +174,6 @@ void iDataReader::EraseData(const iDataType &type)
 	{
 		if(mLoaders[i]->IsUsingData(type) && mLoaders[i]->IsThereData(type)) mLoaders[i]->EraseData();
 	}
-	this->ClearCache();
 }
 
 
@@ -197,7 +189,6 @@ void iDataReader::SetTwoCopies(bool s)
 		{
 			mLoaders[i]->SetTwoCopies(s);
 		}
-		this->ClearCache();
 	}
 }
 
@@ -206,26 +197,31 @@ void iDataReader::ReloadData(const iDataType &type)
 {
 	int i;
 
-	this->GetErrorStatus()->Clear();
-	for(i=0; this->GetErrorStatus()->NoError() && i<mLoaders.Size(); i++)
+	for(i=0; i<mLoaders.Size(); i++)
 	{
 		if(mLoaders[i]->IsUsingData(type) && mLoaders[i]->IsThereData(type))
 		{
-			this->GetErrorStatus()->Monitor(mLoaders[i]->GetErrorStatus());
-			mLoaders[i]->ReadFile(mLoaders[i]->GetLastFileName());
-			if(mLoaders[i]->GetObserver()->IsAborted()) this->GetErrorStatus()->SetAbort();
+			mLoaders[i]->LoadFile(mLoaders[i]->GetLastFileName(),mShift);
+		}
+	}
+}
 
-			if(this->GetErrorStatus()->NoError()) mLoaders[i]->Finalize();
-			if(mLoaders[i]->GetObserver()->IsAborted()) this->GetErrorStatus()->SetAbort();
 
-			if(this->GetErrorStatus()->NoError()) mLoaders[i]->ShiftData(mDataShift);
-			if(mLoaders[i]->GetObserver()->IsAborted()) this->GetErrorStatus()->SetAbort();
+bool iDataReader::HasDataToReload() const
+{
+	return (mDataReloadInfo->Size()>0 && this->IsThereData(*mDataReloadInfo));
+}
 
-			if(this->GetErrorStatus()->IsError())
-			{
-				mLoaders[i]->EraseData();
-				this->ClearCache();
-			}
+
+void iDataReader::RequestDataReload(const iDataInfo &info)
+{
+	if(this->IsThereData(info))
+	{
+		*mDataReloadInfo += info;
+		
+		if(this->GetShell()->GetDataReaderObserver()->AllowReload())
+		{
+			this->CallReload();
 		}
 	}
 }
@@ -239,7 +235,6 @@ void iDataReader::ResetPipeline()
 	{
 		mLoaders[i]->Reset();
 	}
-	this->ClearCache();
 }
 
 
@@ -247,7 +242,7 @@ bool iDataReader::IsThereData(const iDataInfo &info) const
 {
 	int i;
 
-	for(i=0; i<info.Count(); i++)
+	for(i=0; i<info.Size(); i++)
 	{
 		if(this->IsThereData(info.Type(i))) return true;
 	}
@@ -310,12 +305,10 @@ bool iDataReader::IsSetLeader(const iFileLoader *loader) const
 }
 
 
-void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dryrun, bool savename)
+void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool savename)
 {
 	int i;
 	
-	this->GetErrorStatus()->Clear();
-
 	//
 	//  Find a loader that accepts this type.
 	//
@@ -323,44 +316,44 @@ void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dry
 	{
 		if(mLoaders[i]->IsUsingData(type))
 		{
-			this->LoadFile(mLoaders[i],fname,dryrun,savename);
+			this->LoadFile(mLoaders[i],fname,savename);
 			return;
 		}
 	}
 
-	this->GetErrorStatus()->Set("There is no loader that supports this data type.");
+	//
+	//  We should not use a Monitor here, as it will wrap around DataReaderObserver->StartSet().
+	//
+	this->OutputText(MessageType::Error,"There is no loader that supports the data type <"+type.LongName()+">.");
 }
 
 
-void iDataReader::LoadFile(iFileLoader *loader, const iString &name, bool dryrun, bool savename)
+void iDataReader::LoadFile(iFileLoader *loader, const iString &name, bool savename)
 {
-	int i;
-
-	this->ClearCache();
-
 	if(loader == 0)
 	{
-		this->GetErrorStatus()->Set("Trying to load file by a non-existent loader.");
-		return;
+		IBUG_WARN("Bug: trying to load file by a non-existent loader.");
 	}
 
+	int i;
 	iString fname(name);
 	iDirectory::ExpandFileName(fname);
 
 	mLastAttemptedFileName = fname;
 
-	if(dryrun)
+	this->GetViewModule()->GetParallelManager()->StartCounters();
+	this->GetShell()->GetDataReaderObserver()->StartSet();
+
+	//
+	//  Extension can bring us in again here, so make sure the Monitor goes out of scope before the call to extension
+	//
 	{
-		if(!iFile::IsReadable(fname)) this->GetErrorStatus()->Set("File does not exist.");
-		return;
-	}
-	else
-	{
-		this->GetErrorStatus()->Monitor(loader->GetErrorStatus());
-		loader->ReadFile(fname);
-		if(this->GetErrorStatus()->IsError())
+		iMonitor h(this);
+		loader->LoadFile(fname,mShift);
+		if(h.IsStopped())
 		{
-			if(!mTwoCopies) loader->EraseData(); // mark data as absent if we keep only one copy
+			this->GetShell()->GetDataReaderObserver()->FinishSet(true);
+			this->GetViewModule()->GetParallelManager()->StopCounters();
 			return;
 		}
 	}
@@ -393,6 +386,15 @@ void iDataReader::LoadFile(iFileLoader *loader, const iString &name, bool dryrun
 			}
 			mCurrentRecord = newrec;
 		}
+
+		int m;
+		iString s("File Set: ");
+		for(m=0; m<mSetLoaders.Size(); m++)
+		{
+			if(m > 0) s += " + ";
+			s += mSetLoaders[m]->GetDataType(0).TextName();
+		}
+		this->OutputText(MessageType::Information,s);
 	}
 	else
 	{
@@ -406,8 +408,6 @@ void iDataReader::LoadFile(iFileLoader *loader, const iString &name, bool dryrun
 	if(mPeriodicityLeader==0 || loader->GetPriority()<mPeriodicityLeader->GetPriority()) mPeriodicityLeader = loader;
 	mLastFileName = fname;
 	
-	if(dryrun) return; // we are done in that case
-
 	//
 	//  Do we have a set? If yes, load the rest of it too
 	//
@@ -425,58 +425,29 @@ void iDataReader::LoadFile(iFileLoader *loader, const iString &name, bool dryrun
 			//
 			//  Load the data
 			//
-			for(i=1; this->GetErrorStatus()->NoError() && i<mSetLoaders.Size(); i++) // start at 1 since the leader has been loaded already
+			iMonitor h(this);
+			for(i=1; !h.IsStopped() && i<mSetLoaders.Size(); i++) // start at 1 since the leader has been loaded already
 			{
-				this->GetErrorStatus()->Monitor(mSetLoaders[i]->GetErrorStatus());
-				mSetLoaders[i]->ReadFile(mSetLoaders[i]->GetFileName(newrec));
-				if(this->GetErrorStatus()->IsError() && !mTwoCopies) mSetLoaders[i]->EraseData(); // mark data as absent if we keep only one copy
+				mSetLoaders[i]->LoadFile(mSetLoaders[i]->GetFileName(newrec),mShift);
 			}
 		}
 	}
 
-	this->GetViewModule()->GetParallelManager()->StartCounters();
-
-	//
-	//  Finish updating the data
-	//
-	loader->Finalize();
-	if(loader->GetObserver()->IsAborted()) { loader->EraseData(); this->GetErrorStatus()->SetAbort(); }
-	if(this->IsSetLeader(loader))
-	{
-		for(i=1; this->GetErrorStatus()->NoError() && i<mSetLoaders.Size(); i++) // the leader has been loaded already
-		{
-			mSetLoaders[i]->Finalize();
-			if(mSetLoaders[i]->GetObserver()->IsAborted()) { mSetLoaders[i]->EraseData(); this->GetErrorStatus()->SetAbort(); }
-		}
-	}
-		
-	//
-	//  Shift the data
-	//
-	loader->ShiftData(mDataShift);
-	if(loader->GetObserver()->IsAborted()) { loader->EraseData(); this->GetErrorStatus()->SetAbort(); }
-	if(this->IsSetLeader(loader))
-	{
-		for(i=1; this->GetErrorStatus()->NoError() && i<mSetLoaders.Size(); i++) // the leader has been loaded already
-		{
-			mSetLoaders[i]->ShiftData(mDataShift);
-			if(mSetLoaders[i]->GetObserver()->IsAborted()) { mSetLoaders[i]->EraseData(); this->GetErrorStatus()->SetAbort(); }
-		}
-	}
-
-	this->GetViewModule()->GetParallelManager()->StopCounters();
 	this->GetViewModule()->UpdateAfterFileLoad();
 
 	//
-	//  If this loader has an extension, ask it do to its share of work, but guard against loops if it calls this function
+	//  If this reader has an extension, ask it do to its share of work, but guard against loops if it calls this function
 	//
 	if(loader->GetReaderExtension() != 0)
 	{
 		if(mInExtensionUpdate) return;
 		mInExtensionUpdate = true;
-		loader->GetReaderExtension()->AfterLoadFile(loader,fname,dryrun);
+		loader->GetReaderExtension()->AfterLoadFile(loader,fname);
 		mInExtensionUpdate = false;
 	}
+
+	this->GetShell()->GetDataReaderObserver()->FinishSet(false);
+	this->GetViewModule()->GetParallelManager()->StopCounters();
 }
 
 
@@ -485,36 +456,34 @@ void iDataReader::BreakSet()
 	mCurrentRecord = -1;
 	mSetLoaders.Clear();
 	mDirectory->Close();
-	this->ClearCache();
 }
 
 
-void iDataReader::LoadRecord(int rec, int skip, bool dryrun, bool savename)
+bool iDataReader::LoadRecord(int rec, int skip, bool savename)
 {
+	iMonitor h(this);
+
 	if(rec < 0) rec = mCurrentRecord;
 
-	this->GetErrorStatus()->Clear();
-
-	this->ClearCache();
 	if(mSetLoaders.Size() == 0)
 	{
-		this->GetErrorStatus()->Set("File set has not been established.");
-		return;
+		h.PostError("File set has not been established.");
+		return true;
 	}
 
 	iString fname = mSetLoaders[0]->GetFileName(rec);
 	if(!iFile::IsReadable(fname))
 	{
-		this->GetErrorStatus()->Set("File is not accessible.");
-		return;
+		h.PostError("File is not accessible.");
+		return true;
 	}
 
 	if(skip != 0)
 	{
 		if(!mDirectory->IsOpened() && !mDirectory->Open(fname))
 		{
-			this->GetErrorStatus()->Set("Unable to read the directory.");
-			return;
+			h.PostError("Unable to read the directory.");
+			return true;
 		}
 	
 		while(skip>0 && !fname.IsEmpty())
@@ -528,18 +497,20 @@ void iDataReader::LoadRecord(int rec, int skip, bool dryrun, bool savename)
 		//
 		if(!this->IsAnotherSetLeader(fname))
 		{
-			this->GetErrorStatus()->Set("File does not exist.",10);
-			return;
+			h.PostError("File "+fname+" does not exist.");
+			return false;
 		}
 	}
 
 	if(!fname.IsEmpty())
 	{
-		this->LoadFile(mSetLoaders[0],fname,dryrun,savename);
+		this->LoadFile(mSetLoaders[0],fname,savename);
+		return true;
 	}
 	else
 	{
-		this->GetErrorStatus()->Set("File does not exist.",10);
+		h.PostError("File "+fname+" does not exist.");
+		return false;
 	}
 }
 
@@ -602,18 +573,82 @@ bool iDataReader::IsAnotherSetLeader(const iString &fname) const
 }
 
 
-void iDataReader::SetDataShift(int d, double dx)
+bool iDataReader::CallLoad(const iDataType& type, const iString& name)
 {
-	if(d>=0 && d<=2) mDataShift[d] = dx;
-	this->ClearCache();
+	iMonitor h(this);
+
+	if(type.IsNull())
+	{
+		h.PostError("Invalid data type.");
+		return false;
+	}
+	else
+	{
+		iString fname(name);
+		if(fname[0] == '+')
+		{
+			fname.Replace(0,1,this->GetViewModule()->GetShell()->GetEnvironment(Environment::Data));
+		}
+		this->LoadFile(type,fname);
+		return !h.IsStopped();
+	}
 }
 
 
-void iDataReader::ShiftData(double *dr)
+bool iDataReader::CallErase(const iDataType& type)
+{
+	iMonitor h(this);
+
+	if(type.IsNull())
+	{
+		h.PostError("Invalid data type.");
+		return false;
+	}
+	else
+	{
+		this->EraseData(type);
+		return !h.IsStopped();
+	}
+}
+
+
+bool iDataReader::CallReload()
 {
 	int i;
 
-	if(dr == 0) dr = mDataShift;
+	if(this->HasDataToReload())
+	{
+		iMonitor h(this);
+		this->GetShell()->GetDataReaderObserver()->StartSet();
+		for(i=0; i<mDataReloadInfo->Size(); i++)
+		{
+			this->ReloadData(mDataReloadInfo->Type(i));
+		}
+		this->GetShell()->GetDataReaderObserver()->FinishSet(h.IsStopped());
+		mDataReloadInfo->Clear();
+	}
+
+	return true;
+}
+
+
+bool iDataReader::SetShift(int d, double dx)
+{
+	if(d>=0 && d<=2)
+	{
+		mShift[d] = dx;
+		this->ShiftData();
+		return true;
+	}
+	else return false;
+}
+
+
+void iDataReader::ShiftData(const double *dr)
+{
+	int i;
+
+	if(dr == 0) dr = mShift;
 
 	this->GetViewModule()->GetParallelManager()->StartCounters();
 
@@ -640,132 +675,6 @@ float iDataReader::GetMemorySize() const
 }
 
 
-void iDataReader::ExtendableObjectPackStateBody(iString &s) const
-{
-	this->PackValue(s,KeyScaledDimension(),mScaledDim);
-	this->PackValue(s,KeyVoxelLocation(),mVoxelLocation);
-	this->PackValue(s,KeyBoundaryConditions(),mBoundaryConditions);
-
-	this->PackValue(s,KeyShiftData(),mDataShift,3);
-
-	//
-	//  Hidden key
-	//
-	this->PackValue(s,KeyRecordLength(),mRecordLength);
-
-	//
-	//  Special "query" keys
-	//
-	this->PackValue(s,KeyErrorMessage(),this->GetErrorStatus()->Message());
-	this->PackValue(s,KeyIsSet(),this->IsSet());
-}
-
-
-void iDataReader::ExtendableObjectUnPackStateBody(const iString &s)
-{
-	int i; double ds[3]; iString s1;
-
-	if(this->UnPackValue(s,KeyScaledDimension(),i)) this->SetScaledDimension(i);
-	if(this->UnPackValue(s,KeyVoxelLocation(),i)) this->SetVoxelLocation(i);
-	if(this->UnPackValue(s,KeyBoundaryConditions(),i)) this->SetBoundaryConditions(i);
-
-	for(i=0; i<3; i++) ds[i] = mDataShift[i];
-	if(this->UnPackValue(s,KeyShiftData(),ds,3)) 
-	{
-		for(i=0; i<3; i++) this->SetDataShift(i,ds[i]);
-		this->ShiftData();
-	}
-
-	//
-	//  Hidden key
-	//
-	iObject::ReportMissingKeys(false);
-	if(this->UnPackValue(s,KeyRecordLength(),i))
-	{
-		mRecordLength = i;
-		this->ClearCache();
-	}
-	iObject::ReportMissingKeys(true);
-
-	//
-	//  Special "action" keys
-	//
-	iObject::ReportMissingKeys(false); //action keys are not part of the states
-
-	if(this->UnPackValue(s,KeyEraseData(),s1))
-	{
-		const iDataType &type(iDataType::FindTypeByName(s1));
-		if(!type.IsNull())
-		{
-			this->EraseData(type); 
-		}
-	}
-
-	iString ws[2];
-	if(this->UnPackValue(s,KeyLoadData(),ws,2))
-	{
-		const iDataType &type(iDataType::FindTypeByName(ws[0]));
-		if(type.IsNull())
-		{
-			mUnPackedSomething = false;
-		}
-		else
-		{
-			iDirectory::ExpandFileName(ws[1],type.GetEnvironment(this->GetViewModule()->GetControlModule()->GetShell()));
-			this->LoadFile(type,ws[1]);
-		}
-	}
-
-	iObject::ReportMissingKeys(true);
-}
-
-
-void iDataReader::PackCompleteState(iString &s) const
-{
-	int i, k; iString s1;
-
-	this->PackState(s);
-
-	//
-	//  Pack all subjects for state saving
-	//
-	for(i=0; i<mLoaders.Size(); i++)
-	{
-		for(k=0; k<mLoaders[i]->NumStreams(); k++)
-		{
-			mLoaders[i]->GetSubject(k)->PackCompleteState(s1);
-			s += iObjectKey::SpecialSeparator() + mLoaders[i]->GetSubject(k)->GetDataType().GetName() + iObjectKey::Delimiter() + s1;
-		}
-	}
-}
-
-
-void iDataReader::UnPackCompleteState(const iString &s)
-{
-	int i, j, k, n;
-	iString s1, name;
-
-	this->UnPackState(s);
-
-	//
-	//  UnPack all subjects for state restoring
-	//
-	n = s.Contains(iObjectKey::SpecialSeparator());
-	for(j=0; j<n; j++)
-	{
-		s1 = s.Section(iObjectKey::SpecialSeparator(),j+1,j+1);
-		name = s1.Section(iObjectKey::Delimiter(),0,0);
-		for(i=0; i<mLoaders.Size(); i++)
-		{
-			for(k=0; k<mLoaders[i]->NumStreams(); k++) if(mLoaders[i]->GetSubject(k)->GetDataType().IsOfType(name))
-			{
-				mLoaders[i]->GetSubject(k)->UnPackCompleteState(s1);
-			}
-		}
-	}
-}
-	
-
 void iDataReader::InsertIntoVisitedFilesList(const iFileLoader *loader, const iString &name)
 {
 	VisitedFile v;
@@ -775,19 +684,6 @@ void iDataReader::InsertIntoVisitedFilesList(const iFileLoader *loader, const iS
 }
 
 
-iProgressEventObserver* iDataReader::GetProgressEventObserver(const iDataType &type)
-{
-	int i;
-
-	for(i=0; i<mLoaders.Size(); i++)
-	{
-		if(mLoaders[i]->IsUsingData(type)) return mLoaders[i]->GetObserver();
-	}
-
-	return 0;
-}
-
-
 //
 //  Outputs
 //
@@ -810,7 +706,7 @@ vtkDataSet* iDataReader::GetData(const iDataType &type) const
 //
 //  Decorator functions
 //
-void iDataReader::SetBoundaryConditions(int v)
+bool iDataReader::SetBoundaryConditions(int v)
 {
 	int i;
 
@@ -819,15 +715,16 @@ void iDataReader::SetBoundaryConditions(int v)
 		mBoundaryConditions = v;
 		for(i=0; i<mLoaders.Size(); i++)
 		{
-			mLoaders[i]->SetBoundaryConditions(v);
+			this->RequestDataReload(mLoaders[i]->GetDataInfo());
 		}
-		this->ClearCache();
+		return true;
 	}
+	else return false;
 }
 
 
 //
-void iDataReader::SetScaledDimension(int v)
+bool iDataReader::SetScaledDimension(int v)
 {
 	int i;
 
@@ -838,15 +735,33 @@ void iDataReader::SetScaledDimension(int v)
 		if(ds != 0)
 		{
 			ds->SetScaledDimension(v);
-			mScaledDim = ds->GetScaledDimension();
+			mScaledDimension = ds->GetScaledDimension();
 		}
 	}
-	this->ClearCache();
+	return true;
+}
+
+
+bool iDataReader::SetMaxZDimension(int v)
+{
+	int i;
+
+	iUniformGridFileLoader *ds;
+	for(i=0; i<mLoaders.Size(); i++)
+	{
+		ds = iUniformGridFileLoader::SafeDownCast(mLoaders[i]);
+		if(ds != 0)
+		{
+			ds->SetMaxZDimension(v);
+			mMaxZDimension = ds->GetMaxZDimension();
+		}
+	}
+	return true;
 }
 
 
 //
-void iDataReader::SetVoxelLocation(int v)
+bool iDataReader::SetVoxelLocation(int v)
 {
 	int i;
 
@@ -860,35 +775,34 @@ void iDataReader::SetVoxelLocation(int v)
 			mVoxelLocation = ds->GetVoxelLocation();
 		}
 	}
-	this->ClearCache();
+	return true;
 }
 
 
 //
 //  Extension
 //
-IOBJECTEXTENSION_DEFINE_ABSTRACT(iDataReader);
-
-
-void iDataReaderExtension::Define()
+iObjectExtensionAbstractConstructorBeginMacro(iDataReader)
 {
 }
 
 
-void iDataReaderExtension::AfterLoadFile(iFileLoader *loader, const iString &fname, bool dryrun)
+void iDataReaderExtension::AfterLoadFile(iFileLoader *loader, const iString &fname)
 {
+	iMonitor h(loader);
 	if(loader->GetReaderExtension() !=  this)
 	{
-		IERROR_HIGH("iDataReaderExtension is configured incorrectly.");
+		IBUG_ERROR("iDataReaderExtension is configured incorrectly.");
+		h.PostError("Unable to read the data due to a bug.");
 		return;
 	}
 
 	mLastFileName = fname;
-	this->AfterLoadFileBody(loader,fname,dryrun);
+	this->AfterLoadFileBody(loader,fname);
 }
 
 
-void iDataReaderExtension::AfterLoadFileBody(iFileLoader *, const iString &, bool)
+void iDataReaderExtension::AfterLoadFileBody(iFileLoader *, const iString &)
 {
 	//
 	//  By default do nothing
