@@ -31,11 +31,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iextendableobject.h"
+#include "iviewmodulecomponent.h"
 
 
 #include "iarray.h"
 
-class iBasicParticlesFileLoader;
 class iDataInfo;
 class iDataLimits;
 class iDataReaderHelper;
@@ -44,23 +44,25 @@ class iDataType;
 class iDirectory;
 class iFile;
 class iFileLoader;
-class iProgressEventObserver;
-class iUniformScalarsFileLoader;
-class iUniformVectorsFileLoader;
-class iUniformTensorsFileLoader;
+
+namespace iCoreData
+{
+	class ScalarFileLoader;
+	class VectorFileLoader;
+	class TensorFileLoader;
+	class ParticleFileLoader;
+};
 
 class vtkDataSet;
 class vtkPolyData;
-class vtkStructuredPoints;
+class vtkImageData;
 
 
-class iDataReader : public iExtendableObject
+class iDataReader : public iExtendableObject, public iViewModuleComponent
 {
 
 	friend class iDataReaderHelper;
 
-	IPOINTER_AS_PART(ViewModule);
-
 public:
 
 	struct VisitedFile
@@ -71,46 +73,29 @@ public:
 
 	vtkTypeMacro(iDataReader,iExtendableObject);
 	static iDataReader* New(iViewModule *vm = 0);
-	static const iObjectType& Type();
 	
 	//
 	//  Non-static members
 	//
-	IOBJECT_DECLARE_GETSET(ScaledDimension,mScaledDim,int);
-	//virtual void SetScaledDimension(int v);
-	//inline int GetScaledDimension() const { return mScaledDim; }
+	iObjectPropertyMacro1S(BoundaryConditions,Int);
+	iObjectPropertyMacro1S(ScaledDimension,Int);
+	iObjectPropertyMacro1S(VoxelLocation,Int);
+	iObjectPropertyMacro1S(MaxZDimension,Int);
+	iObjectPropertyMacro1V(Shift,Double,3); 
 
-	IOBJECT_DECLARE_GETSET1(VoxelLocation,int);
-	//virtual void SetVoxelLocation(int s);
-	//inline bool GetVoxelLocation() const { return mVoxelLocation; }
-
-	IOBJECT_DECLARE_GETSET1(BoundaryConditions,int);
-	//virtual void SetBoundaryConditions(int s);
-	//inline int GetBoundaryConditions() const { return mBoundaryConditions; }
-
-	void SetDataShift(int d, double f); 
-	inline double GetDataShift(int d) const { if(d>=0 && d<3) return mDataShift[d]; else return 0.0; }
-	static const iObjectKey& KeyShiftData();
-
-	//
-	//  Special "action" keys
-	//
-	static const iObjectKey& KeyEraseData(); 
-	static const iObjectKey& KeyLoadData(); 
-
-	//
-	//  Special "query" keys 
-	//
-	static const iObjectKey& KeyErrorMessage();
+	iObjectSlotMacroA2(Load,const iDataType&,const iString&);
+	iPropertyAction2<iType::DataType,iType::String> Load;
+	iObjectSlotMacroA1(Erase,const iDataType&);
+	iPropertyAction1<iType::DataType> Erase;
+	iObjectPropertyMacroA(Reload);  // reload requested data
 
 	inline bool IsSet() const { return mSetLoaders.Size() > 0; }
-	static const iObjectKey& KeyIsSet();
 
 	//
 	//  Loading of data
 	//
-	void LoadFile(const iDataType &type, const iString &fname, bool dryrun = false, bool savename = true);
-    void LoadRecord(int rec, int skip = 0, bool dryrun = false, bool savename = false);
+	void LoadFile(const iDataType &type, const iString &fname, bool savename = true);
+    bool LoadRecord(int rec, int skip = 0, bool savename = false);  //  return false if the record is missing, true otherwise (even in case of an error)
 
 	//
 	//  Operation on data
@@ -120,6 +105,8 @@ public:
 
 	void EraseData(const iDataType &type);
 	void ReloadData(const iDataType &type);
+	void RequestDataReload(const iDataInfo &info);
+	bool HasDataToReload() const;
 
 	void SetTwoCopies(bool s);
 
@@ -136,7 +123,7 @@ public:
 	inline bool IsFileAnimatable() const { return (mCurrentRecord >= 0); }
 	inline int GetRecordNumber() const { return mCurrentRecord; }
 
-	virtual void ShiftData(double *dx = 0);
+	virtual void ShiftData(const double *dx = 0);
 
 	virtual float GetMemorySize() const;
 	
@@ -155,53 +142,38 @@ public:
 	inline const iString& GetLastAttemptedFileName() const { return mLastAttemptedFileName; }
 
 	inline const iArray<VisitedFile>& GetVisitedFilesList() const { return mVisitedFilesList; }
-
-	virtual iProgressEventObserver* GetProgressEventObserver(const iDataType &type);
-
-	virtual void PackCompleteState(iString &s) const;
-	virtual void UnPackCompleteState(const iString &s);
-
-	//
-	//  Hidden (undocumented) keys
-	//
-	static const iObjectKey& KeyRecordLength(); 
 	inline int GetRecordLength() const { return mRecordLength; }
 
 protected:
 
 	virtual ~iDataReader();
 
-	virtual void ExtendableObjectPackStateBody(iString &s) const;
-	virtual void ExtendableObjectUnPackStateBody(const iString &s);
-
 private:
 	
-	iDataReader(iViewModule *vm);
+	iDataReader(iViewModule *vm, const iString &fname, const iString &sname);
 
-	void LoadFile(iFileLoader *loader, const iString &fname, bool dryrun, bool savename);
+	void LoadFile(iFileLoader *loader, const iString &fname, bool savename);
 
 	void InsertIntoVisitedFilesList(const iFileLoader *loader, const iString &name);
 	void BreakSet();
-	bool IsAborted(const iDataType &type) const;
 	bool IsSetLeader(const iFileLoader *loader) const;
 
 	bool mTwoCopies, mInExtensionUpdate;
 	int mCellToPointMode;
-
-	double mDataShift[3];
 	iString mMode;
-	int mScaledDim, mVoxelLocation, mBoundaryConditions;
 
 	iFileLoader *mPeriodicityLeader;
-	iSearchableArray<iFileLoader*> mSetLoaders;
+	iLookupArray<iFileLoader*> mSetLoaders;
 	iArray<iFileLoader*> mLoaders;
-	iUniformScalarsFileLoader *mUniformScalarsLoader;
-	iUniformVectorsFileLoader *mUniformVectorsLoader;
-	iUniformTensorsFileLoader *mUniformTensorsLoader;
-	iBasicParticlesFileLoader *mBasicParticlesLoader;
+	iCoreData::ScalarFileLoader *mScalarLoader;
+	iCoreData::VectorFileLoader *mVectorLoader;
+	iCoreData::TensorFileLoader *mTensorLoader;
+	iCoreData::ParticleFileLoader *mParticleLoader;
 
 	int mCurrentRecord, mRecordLength;
 
+	iDataInfo *mDataReloadInfo;
+
 	iString mLastFileName, mLastAttemptedFileName;
 	iArray<VisitedFile> mVisitedFilesList;
 	iDirectory *mDirectory;
@@ -211,7 +183,7 @@ private:
 class iDataReaderExtension : public iObjectExtension
 {
 
-	IOBJECTEXTENSION_DECLARE_ABSTRACT(iDataReader);
+	iObjectExtensionDeclareAbstractMacro(iDataReader);
 
 public:
 
@@ -224,11 +196,11 @@ public:
 	//
 	inline const iString& GetLastFileName() const { return mLastFileName; }
 
-	void AfterLoadFile(iFileLoader *loader, const iString &fname, bool dryrun);
+	void AfterLoadFile(iFileLoader *loader, const iString &fname);
 
 protected:
 
-	virtual void AfterLoadFileBody(iFileLoader *loader, const iString &fname, bool dryrun);
+	virtual void AfterLoadFileBody(iFileLoader *loader, const iString &fname);
 
 	iString mLastFileName;
 };
