@@ -33,17 +33,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IERROR_H
 
 
-#include "iconsole.h"
+#include "ioutput.h"
 
 
-#define IERROR_LOW(_m_)			{ iConsole::Display(iConsole::_LowError,_m_,__FILE__,__LINE__); }
-#define IERROR_HIGH(_m_)		{ iConsole::Display(iConsole::_HighError,_m_,__FILE__,__LINE__); }
-#define IERROR_FATAL(_m_)		{ iConsole::Display(iConsole::_FatalError,_m_,__FILE__,__LINE__); }
-#define IERROR_ASSERT(_p_)		{ if((_p_) == 0) iConsole::Display(iConsole::_FatalError,"Invalid use of a null pointer.",__FILE__,__LINE__); }
-
-#if defined(I_CHECK1) || defined(I_CHECK2)
-#define IERROR_REPORT_BUG		{ iConsole::Display(iConsole::_HighError,"Bug detected.",__FILE__,__LINE__); }
-#endif
+#define IBUG_WARN(_m_)				{ iOutput::ReportBug(_m_,__FILE__,__LINE__,2); }
+#define IBUG_ERROR(_m_)				{ iOutput::ReportBug(_m_,__FILE__,__LINE__,1); }
+#define IBUG_FATAL(_m_)				{ iOutput::ReportBug(_m_,__FILE__,__LINE__,0); }
+#define IASSERT(_p_)				{ if((_p_) == 0) IBUG_FATAL("Invalid use of a null pointer."); }
+#define IERROR_CHECK_MEMORY(_p_)	{ if((_p_) == 0) iOutput::ReportBug("There is not enough memory to proceed.",__FILE__,__LINE__,-1); }
 
 //
 //  error-reporting dynamic_cast - make it a global function to reduce de-referencing
@@ -54,7 +51,7 @@ inline O* iDynamicCast(int line, const char *file, I* p)
 {
 	if(p == 0) return 0;
 	O* tmp = dynamic_cast<O*>(p);
-	if(tmp == 0) iConsole::Display(iConsole::_FatalError,"Invalid cast.",file,line);
+	if(tmp == 0) iOutput::ReportBug("Invalid cast.",file,line,0);
 	return tmp;
 }
 
@@ -67,7 +64,7 @@ inline O* iRequiredCast(int line, const char *file, vtkObjectBase *p)
 {
 	if(p == 0) return 0;
 	O* tmp = O::SafeDownCast(p);
-	if(tmp == 0) iConsole::Display(iConsole::_FatalError,"Invalid cast.",file,line);
+	if(tmp == 0) iOutput::ReportBug("Invalid cast.",file,line,0);
 	return tmp;
 }
 
