@@ -32,31 +32,21 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "ivtk.h"
 
-#include <vtkCriticalSection.h>
-
 
 bool iEventObserver::mAllAreBlocked = false;
 
 //
 //  Parent class for all event observers
 //
-iEventObserver::iEventObserver(iShell *s) : mShell(s)
+iEventObserver::iEventObserver()
 {
 	mIsBlocked = mLockedExecute = false;
-
-#ifndef IVTK_PRE52
 	this->PassiveObserverOn(); // O-ho-ho, VTK guys - how I wish you messed less with the basic interface...
-#endif
-	//
-	//  Use this mutex to support multi-threaded execution
-	//
-	mMutex = vtkCriticalSection::New(); IERROR_ASSERT(mMutex);
 }
 
 
 iEventObserver::~iEventObserver()
 {
-	mMutex->Delete();
 }
 
 
@@ -64,8 +54,6 @@ void iEventObserver::Execute(vtkObject *caller, unsigned long event, void *data)
 {
 	if(mAllAreBlocked || mIsBlocked) return;
 
-	if(mLockedExecute) mMutex->Lock();
 	this->ExecuteBody(caller,event,data);
-	if(mLockedExecute) mMutex->Unlock();
 }
 
