@@ -36,20 +36,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkCommand.h>
 
 
-#include "ipointermacro.h"
-
 #include <vtkSetGet.h>
 
-class iShell;
-
-class vtkCriticalSection;
-
 
 class iEventObserver : public vtkCommand
 {
 
-	IPOINTER_AS_PART(Shell);
-
 public:
 
 	vtkTypeMacro(iEventObserver,vtkCommand);
@@ -62,7 +54,7 @@ public:
 
 protected:
 
-	iEventObserver(iShell *s);
+	iEventObserver();
 	virtual ~iEventObserver();
 
 	void SetLockedExecute(bool s){ mLockedExecute = s; }
@@ -72,7 +64,6 @@ private:
 
 	static bool mAllAreBlocked;
 	bool mIsBlocked, mLockedExecute;
-	vtkCriticalSection *mMutex;
 };
 
 #endif // IEVENTOBSERVER_H
