@@ -30,45 +30,35 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "idata.h"
-#include "iextensionfactory.h"
 
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
+#include "iproperty.tlh"
 
 
 //
 //  Helper class
 //
-iObjectExtension::iObjectExtension(iExtendableObject *owner, const iString &name) : iObject(name), mName(name)
+iObjectExtension::iObjectExtension(iExtendableObject *owner, const iString &fname, const iString &sname) : iObject(owner,fname,sname)
 {
-	mOwner = owner; IERROR_ASSERT(owner);
+	IASSERT(owner);
+
+	mOwner = owner;
+	mRenderMode = owner->GetRenderMode();
 }
 
 
-void iObjectExtension::ClearCache()
+iObjectExtension::~iObjectExtension()
 {
-	this->iObject::ClearCache();
-	mOwner->ClearCache();
-}
-
-
-void iObjectExtension::PackStateBody(iString &) const
-{
-}
-
-
-void iObjectExtension::UnPackStateBody(const iString &)
-{
-	mUnPackedSomething = true;
 }
 
 
 //
 //  Main class
 //
-iExtendableObject::iExtendableObject(const iString &name) : iObject(name)
+iExtendableObject::iExtendableObject(iObject *parent, const iString &fname, const iString &sname) : iObject(parent,fname,sname)
 {
 }
 
@@ -82,7 +72,7 @@ iExtendableObject::~iExtendableObject()
 iObjectExtension* iExtendableObject::GetExtensionByName(const iString &name) const
 {
 	int i;
-	for(i=0; i<mExtensions.Size(); i++) if(mExtensions[i]->Name() == name) return mExtensions[i];
+	for(i=0; i<mExtensions.Size(); i++) if(mExtensions[i]->LongName() == name) return mExtensions[i];
 	return 0;
 }
 
@@ -97,57 +87,24 @@ iObjectExtension* iExtendableObject::GetExtensionByClassName(const iString &name
 
 void iExtendableObject::InstallExtension(iObjectExtension *object)
 {
-	IERROR_ASSERT(object);
+	IASSERT(object);
 	mExtensions.AddUnique(object);
-}
 
+	//
+	//  We don't treat extensions as children
+	//
+	mChildren.Remove(object);
 
-void iExtendableObject::PackCompleteState(iString &s) const
-{
-	int i;
-	iString s1;
-
-	this->iObject::PackCompleteState(s);
-
-	for(i=0; i<mExtensions.Size(); i++)
+	//
+	//  Register extension properties
+	//
+	int j;
+	for(j=0; j<object->mVariableProperties.Size(); j++)
 	{
-		mExtensions[i]->PackCompleteState(s1);
-		s += s1;
+		mVariableProperties.Add(object->mVariableProperties[j]);
+	}
+	for(j=0; j<object->mFunctionProperties.Size(); j++)
+	{
+		mFunctionProperties.Add(object->mFunctionProperties[j]);
 	}
 }
-
-
-void iExtendableObject::UnPackCompleteState(const iString &s)
-{
-	int i;
-
-	this->iObject::UnPackCompleteState(s);
-
-	for(i=0; i<mExtensions.Size(); i++) mExtensions[i]->UnPackCompleteState(s);
-}
-
-
-void iExtendableObject::PackStateBody(iString &s) const
-{
-	int i;
-	iString s1;
-
-	this->ExtendableObjectPackStateBody(s);
-
-	for(i=0; i<mExtensions.Size(); i++)
-	{
-		mExtensions[i]->PackState(s1);
-		s += s1;
-	}
-}
-
-
-void iExtendableObject::UnPackStateBody(const iString &s)
-{
-	int i;
-
-	this->ExtendableObjectUnPackStateBody(s);
-
-	for(i=0; i<mExtensions.Size(); i++) mExtensions[i]->UnPackState(s);
-}
-
