@@ -45,27 +45,22 @@ class iExtendableObject;
 class iObjectExtension : public iObject
 {
 
+	friend class iExtendableObject;
+
 public:
 
 	vtkTypeMacro(iObjectExtension,iObject);
 
-	const iString& Name() const { return mName; }
-
-	virtual void ClearCache();
-
 protected:
 
-	iObjectExtension(iExtendableObject *owner, const iString &name);
+	iObjectExtension(iExtendableObject *owner, const iString &fname, const iString &sname);
+	virtual ~iObjectExtension();
 
 	iExtendableObject* Owner() const { return mOwner; }
 
-	virtual void PackStateBody(iString &) const;
-	virtual void UnPackStateBody(const iString &);
-
 private:
 
 	iExtendableObject* mOwner;
-	const iString mName;
 };
 
 
@@ -78,22 +73,16 @@ public:
 
 	vtkTypeMacro(iExtendableObject,iObject);
 
-	virtual void PackCompleteState(iString &s) const;
-	virtual void UnPackCompleteState(const iString &s);
-
 	inline iObjectExtension* GetExtension(int n) const { return mExtensions[n]; } // will return 0 if out of bounds
 	iObjectExtension* GetExtensionByName(const iString &name) const; // will return 0 if none has this name; if more than one has the same name, the first one will be returned
 	iObjectExtension* GetExtensionByClassName(const iString &name) const; // will return 0 if none has this name; if more than one has the same name, the first one will be returned
 
 protected:
 
-	iExtendableObject(const iString &name);
+	iExtendableObject(iObject *parent, const iString &fname, const iString &sname);
 	virtual ~iExtendableObject();
 
-	virtual void ExtendableObjectPackStateBody(iString &s) const = 0;
-	virtual void ExtendableObjectUnPackStateBody(const iString &s) = 0;
-
-	iSearchableArray<iObjectExtension*> mExtensions;
+	iLookupArray<iObjectExtension*> mExtensions;
 
 private:
 
@@ -101,46 +90,44 @@ private:
 	//  Constructor helpers accessible to iExtensionFactory only
 	//
 	void InstallExtension(iObjectExtension *object);
-
-	virtual void PackStateBody(iString &s) const;
-	virtual void UnPackStateBody(const iString &s);
 };
 
 
 //
 //  Useful macros
 //
-#define IOBJECTEXTENSION_DECLARE_COMMON(_owner_,_self_) \
+#define iObjectExtensionDeclareCommonMacro(_owner_,_self_) \
 	public: \
 	static _self_* Self(_owner_ *owner)
 
-#define IOBJECTEXTENSION_DECLARE_ABSTRACT(_owner_) \
-	IOBJECTEXTENSION_DECLARE_COMMON(_owner_,_owner_##Extension); \
+#define iObjectExtensionDeclareAbstractMacro(_owner_) \
+	iObjectExtensionDeclareCommonMacro(_owner_,_owner_##Extension); \
 	vtkTypeMacro(_owner_##Extension,iObjectExtension); \
 	protected: \
-	_owner_##Extension(_owner_ *owner, const iString &name) : iObjectExtension(owner,name) { mRealOwner = owner; this->Define(); } \
-	void Define(); \
-	_owner_ *mRealOwner
+	_owner_ *mRealOwner; \
+	_owner_##Extension(_owner_ *owner, const iString &fname, const iString &sname)
 
-#define IOBJECTEXTENSION_DECLARE_SPECIFIC(_owner_,_self_) \
-	IOBJECTEXTENSION_DECLARE_COMMON(_owner_,_self_); \
+#define iObjectExtensionDeclareSpecificMacro(_owner_,_self_) \
+	iObjectExtensionDeclareCommonMacro(_owner_,_self_); \
 	vtkTypeMacro(_self_,_owner_##Extension); \
 	protected: \
-	_self_(_owner_ *owner, const iString &name) : _owner_##Extension(owner,name) { this->Define(); } \
-	void Define()
+	_self_(_owner_ *owner)
 
 
-#define IOBJECTEXTENSION_DEFINE_COMMON(_owner_,_self_) \
+#define iObjectExtensionDefineCommonMacro(_owner_,_self_) \
 	_self_* _self_::Self(_owner_ *owner) \
 	{ \
 		return iRequiredCast<_self_>(INFO,owner->GetExtensionByClassName(#_self_)); \
 	}
 
-#define IOBJECTEXTENSION_DEFINE_ABSTRACT(_owner_) \
-	IOBJECTEXTENSION_DEFINE_COMMON(_owner_,_owner_##Extension)
+#define iObjectExtensionAbstractConstructorBeginMacro(_owner_) \
+	iObjectExtensionDefineCommonMacro(_owner_,_owner_##Extension) \
+	_owner_##Extension::_owner_##Extension(_owner_ *owner, const iString &fname, const iString &sname) : iObjectExtension(owner,fname,sname), mRealOwner(owner)
 
-#define IOBJECTEXTENSION_DEFINE_SPECIFIC(_owner_,_self_) \
-	IOBJECTEXTENSION_DEFINE_COMMON(_owner_,_self_)
+
+#define iObjectExtensionSpecificConstructorBeginMacro(_owner_,_self_) \
+	iObjectExtensionDefineCommonMacro(_owner_,_self_) \
+	_self_::_self_(_owner_ *owner) : _owner_##Extension(owner,owner->LongName(),owner->ShortName())
 
 #endif
 
