@@ -65,7 +65,7 @@ struct iFilePosition
 iFile::iFile(const iString &n)
 {
 	mName = n;
-	mStream = new fstream(); IERROR_ASSERT(mStream);
+	mStream = new fstream(); IERROR_CHECK_MEMORY(mStream);
 	mMaxMarker = 0;
 	mNumMarker = 0;
 	mMarker = 0;
@@ -178,6 +178,10 @@ bool iFile::ReadBlock(void *p, size_t length)
 {
 	mStream->clear();
 	mStream->read((char *)p,length);
+#ifdef I_DEBUG
+	bool f = (mStream->fail() == 0);
+	bool e = (mStream->eof() == 0);
+#endif
 	return (mStream->fail()==0 && mStream->eof()==0);
 }
 
@@ -231,7 +235,7 @@ int iFile::SetMarker()
 	if(mNumMarker == mMaxMarker)
 	{
 		mMaxMarker += 100;
-		iFilePosition *tmp = new iFilePosition[mMaxMarker]; IERROR_ASSERT(tmp);
+		iFilePosition *tmp = new iFilePosition[mMaxMarker]; IERROR_CHECK_MEMORY(tmp);
 		if(mMarker != 0)
 		{
 			for(int i=0; i<mNumMarker; i++) tmp[i] = mMarker[i];
