@@ -29,25 +29,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ifileloader.h"
 
 
-#include "icommoneventobservers.h"
 #include "idata.h"
-#include "idatahelper.h"
+#include "idataconsumer.h"
 #include "idatalimits.h"
 #include "idatareader.h"
+#include "idatareaderobserver.h"
 #include "idatasubject.h"
 #include "ierror.h"
-#include "ierrorstatus.h"
 #include "ifile.h"
-#include "ishellfactory.h"
+#include "ihistogrammaker.h"
+#include "imonitor.h"
+#include "iparallelmanager.h"
+#include "ishell.h"
+#include "ishelleventobservers.h"
 #include "isystem.h"
 #include "iviewmodule.h"
+#include "ivtktype.h"
 
 #include <vtkDataSet.h>
 
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 #define	IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(_type_) \
@@ -61,9 +65,9 @@ void iFileLoader::SwapBytesRange(_type_ *p, vtkIdType count) \
 }
 
 #define	IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(_type_) \
-bool iFileLoader::ReadBlock(iFile& F, _type_ *p, vtkIdType len, float updateStart, float updateDuration) \
+bool iFileLoader::ReadBlock(iFile& F, _type_ *p, vtkIdType len, double updateStart, double updateDuration) \
 { \
-	return iFileLoader_Private::ReadBlockToArray(F,p,len,updateStart,updateDuration,mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver); \
+	return iFileLoader_Private::ReadBlockToArray(F,p,len,updateStart,updateDuration,mIsBigEndian!=iSystem::IsBigEndianMachine(),this->GetShell()->GetExecutionEventObserver()); \
 } \
 iFileLoader::ReadingBuffer iFileLoader::Buffer(_type_ &d) const \
 { \
@@ -143,7 +147,7 @@ namespace iFileLoader_Private
 			}
 		default:
 			{
-				IERROR_FATAL("IFrIT was not ported to that platform.");
+				IBUG_FATAL("IFrIT was not ported to that platform.");
 			}
 		}
 	}
@@ -166,7 +170,7 @@ namespace iFileLoader_Private
 			}
 		default:
 			{
-				IERROR_FATAL("IFrIT was not ported to that platform.");
+				IBUG_FATAL("IFrIT was not ported to that platform.");
 			}
 		}
 	}
@@ -199,18 +203,18 @@ namespace iFileLoader_Private
 	//  Read blocks of data from a file
 	//
 	template<class T>
-	bool ReadBlockToArray(iFile& F, T *p, vtkIdType len, float updateStart, float updateDuration, bool swapbytes, iProgressEventObserver *observer)
+	bool ReadBlockToArray(iFile& F, T *p, vtkIdType len, double updateStart, double updateDuration, bool swapbytes, iExecutionEventObserver *observer)
 	{
 		const vtkIdType nline = 16384L;
 		vtkIdType nread, l, nstep = (len+nline-1)/nline;
-		float ustep = updateDuration/nstep;
+		double ustep = updateDuration/nstep;
 
 		for(l=0; l<nstep; l++) 
 		{
 			if(observer->IsAborted()) return true;
 			if(l < nstep-1) nread = nline; else nread  = len - nline*l;
 			if(!F.ReadBlock(p+l*nline,nread*sizeof(T))) return false;
-			observer->SetProgress(updateStart+ustep*l);
+			if(ustep > 0.0) observer->SetProgress(updateStart+ustep*l);
 		}
 
 		if(swapbytes) 
@@ -228,7 +232,7 @@ namespace iFileLoader_Private
 	}
 
 
-	bool ReadBlockToBuffer(iFile& F, const iFileLoader::ReadingBuffer &b, float updateStart, float updateDuration, bool swapbytes, iProgressEventObserver *observer)
+	bool ReadBlockToBuffer(iFile& F, const iFileLoader::ReadingBuffer &b, double updateStart, double updateDuration, bool swapbytes, iExecutionEventObserver *observer)
 	{
 		switch(b.Type)
 		{
@@ -298,13 +302,13 @@ using namespace iFileLoader_Private;
 using namespace iParameter;
 
 
-iFileLoader::iFileLoader(iDataReader *r, int priority) : mViewModule(r?r->GetViewModule():0), mErrorStatus("Data Subject"), mReader(r), mReaderExtension(0), mPriority(priority)
+iFileLoader::iFileLoader(iDataReader *r, int priority) : iViewModuleComponent(r?r->GetViewModule():0), mReader(r), mReaderExtension(0), mPriority(priority)
 {
 	this->Define();
 }
 
 
-iFileLoader::iFileLoader(iDataReaderExtension *ext, int priority) : mViewModule(ext?ext->GetReader()->GetViewModule():0), mErrorStatus("Data Subject"), mReader(ext->GetReader()), mReaderExtension(ext), mPriority(priority)
+iFileLoader::iFileLoader(iDataReaderExtension *ext, int priority) : iViewModuleComponent(ext?ext->GetReader()->GetViewModule():0), mReader(ext->GetReader()), mReaderExtension(ext), mPriority(priority)
 {
 	this->Define();
 }
@@ -312,31 +316,24 @@ iFileLoader::iFileLoader(iDataReaderExtension *ext, int priority) : mViewModule(
 
 void iFileLoader::Define()
 {
-	IERROR_ASSERT(mReader);
+	IASSERT(mReader);
 
 	mFortranHeaderFooterLength = -1;
 
 	// mFileRoot = mFileSuffix = mLastFileName = "";
-	mUpdated = true;
 	mIsBigEndian = true;
 	mTwoCopies = false;
 	mRecord = -1;
 	mShift[0] = mShift[1] = mShift[2] = 0.0f;
-
 	mPeriodic[0] = mPeriodic[1] = mPeriodic[2] = false;
-	mBoundaryConditions = BoundaryConditions::Wall;
 
-	//
-	//  Event observers are driven directly (otherwise we would have to create at least 16 new events, which is
-	//  cumbersome), so adding with AddObserver is not necessarily
-	//
-	mObserver = dynamic_cast<iProgressEventObserver *>(iShellFactory::CreateEventObserver("Progress",mReader->GetViewModule())); IERROR_ASSERT(mObserver);
+	mInfo = new iDataInfo; IERROR_CHECK_MEMORY(mInfo);
 }
 
 
 iFileLoader::~iFileLoader()
 {
-	mObserver->Delete();
+	delete mInfo;
 	while(mStreams.Size() > 0) delete mStreams.RemoveLast();
 }
 
@@ -352,6 +349,18 @@ bool iFileLoader::IsUsingData(const iDataType &type) const
 }
 
 
+const iDataInfo& iFileLoader::GetDataInfo() const
+{
+	if(mInfo->Size() != mStreams.Size())
+	{
+		mInfo->Clear();
+		int i;
+		for(i=0; i<mStreams.Size(); i++) *mInfo += mStreams[i]->Subject->GetDataType();
+	}
+	return *mInfo;
+}
+
+
 const iDataType& iFileLoader::GetDataType(int n) const
 {
 	if(n>=0 && n<mStreams.Size()) return mStreams[n]->Subject->GetDataType(); else return iDataType::Null();
@@ -375,9 +384,9 @@ vtkDataSet* iFileLoader::GetData(const iDataType &type) const
 }
 
 
-iDataSubject* iFileLoader::GetSubject(int n) const
+iDataLimits* iFileLoader::GetLimits(int n) const
 {
-	if(n>=0 && n<mStreams.Size()) return mStreams[n]->Subject; else return 0;
+	if(n>=0 && n<mStreams.Size()) return mStreams[n]->Subject->GetLimits(); else return 0;
 }
 
 
@@ -392,12 +401,19 @@ iDataSubject* iFileLoader::GetSubject(const iDataType &type) const
 }
 
 
-void iFileLoader::SetBoundaryConditions(int s)
+int iFileLoader::GetBoundaryConditions() const
 {
-	if(BoundaryConditions::IsValid(s))
+	return mReader->GetBoundaryConditions();
+}
+
+
+bool iFileLoader::IsDirectionPeriodic(int d) const
+{
+	if(d>=0 && d<3)
 	{
-		mBoundaryConditions = s;
+		return (this->GetBoundaryConditions()==iParameter::BoundaryConditions::Periodic && mPeriodic[d]);
 	}
+	else return false;
 }
 
 
@@ -410,17 +426,29 @@ void iFileLoader::SetDirectionPeriodic(int d, bool s)
 }
 
 
-void iFileLoader::ReadFile(const iString &fname)
+void iFileLoader::LoadFile(const iString &fname)
 {
 	int i;
+	double shift[3];
+
+	for(i=0; i<3; i++) shift[i] = mReader->GetShift(i);
+
+	this->LoadFile(fname,shift);
+}
+
+
+void iFileLoader::LoadFile(const iString &fname, const double *shift)
+{
+	int i;
+	iMonitor h(this,"Loading file",0.8);
 
-	this->GetErrorStatus()->Clear();
-	mOverflow = false;
 	mFortranHeaderFooterLength = -1; // must be set by a child class
 
 	iString root, suffix;
 	int record = this->DissectFileName(fname,root,suffix);
 
+	this->GetShell()->GetDataReaderObserver()->StartFile(fname,this->GetDataType(0));
+
 	for(i=0; i<mStreams.Size(); i++)
 	{
 		mStreams[i]->Subject->GetLimits()->BlockNotifications(true);
@@ -435,63 +463,117 @@ void iFileLoader::ReadFile(const iString &fname)
 			mStreams[i]->ReleasedData = 0;
 		}
 	}
-	this->ReadFileBody(suffix,fname);
+
+	this->LoadFileBody(suffix,fname);
+	
 	for(i=0; i<mStreams.Size(); i++)
 	{
 		mStreams[i]->Subject->GetLimits()->BlockNotifications(false);
 	}
 
-	if(this->GetErrorStatus()->NoError())
+	if(h.IsStopped())
 	{
-		mLastFileName = fname;
-		mFileSuffix = suffix;
-		mFileRoot = root;
-		mUpdated = false;
-		mRecord = record;
-		mShift[0] = mShift[1] = mShift[2] = 0.0f;
+		if(!mTwoCopies) this->EraseData();
+		return;
 	}
-}
-
-
-void iFileLoader::Finalize()
-{
-	int i;
 
+	//
+	//  Check that we are properly configured
+	//
 	for(i=0; i<mStreams.Size(); i++)
 	{
-		mStreams[i]->Subject->GetLimits()->BlockNotifications(true);
-	}
-
-	this->FinalizeBody();
-
-	for(i=0; i<mStreams.Size(); i++)
-	{
-		mStreams[i]->Subject->GetLimits()->BlockNotifications(false);
-	}
-
-	if(!mUpdated)
-	{
-		mUpdated = true;
-
-		if(this->GetErrorStatus()->NoError() && mOverflow)
+		if(mStreams[i]->ReleasedData == 0)
 		{
-			this->GetErrorStatus()->Set("The data are read correctly, but some values in the file were outside of range ("+iString::FromNumber(-iMath::_LargeFloat)+","+iString::FromNumber(iMath::_LargeFloat)+").\n These values were clamped to be within the required range.",-1);
+			IBUG_ERROR("Stream #"+iString::FromNumber(i)+" was not assigned data. This is a bug, the file has not been read properly.");
+			if(!mTwoCopies) this->EraseData();
+			return;	
 		}
 	}
 
-	this->NotifyDependencies();
-}
+	h.SetInterval("Shifting",0.8,0.1);
 
+	mShift[0] = mShift[1] = mShift[2] = 0.0f;
+	this->ShiftData(shift);
+	if(h.IsStopped())
+	{
+		if(!mTwoCopies) this->EraseData();
+		return;
+	}
 
-void iFileLoader::NotifyDependencies()
-{
-	int i;
+	mLastFileName = fname;
+	mFileSuffix = suffix;
+	mFileRoot = root;
+	mRecord = record;
 
+	h.SetProgress(1.0);
+	h.SetInterval("Computing",0.9,0.1);
+
+	//
+	//  Configure limits
+	//
+	bool overflow = false;
+	iMonitor h1(this);
 	for(i=0; i<mStreams.Size(); i++)
 	{
-		mStreams[i]->Subject->NotifyDependencies();
-		mStreams[i]->Subject->ClearCache();
+		h1.SetInterval(double(i)/mStreams.Size(),1.0/mStreams.Size());
+
+		if(mStreams[i]->Subject->IsThereData())
+		{
+			int var, nvars = mStreams[i]->Subject->GetHistogramMaker()->GetNumberOfComponents();
+			if(nvars < 0)
+			{
+				IBUG_ERROR("Stream #"+iString::FromNumber(i)+" has invalid data. This is a bug, the file has not been read properly.");
+				if(!mTwoCopies) this->EraseData();
+				return;
+			}
+			mStreams[i]->Subject->GetLimits()->BlockNotifications(true);
+
+			//
+			//  Try to set the requested number of variables. DataLimits will either expand to accommodate 
+			//  all of them or limit the allowed number to the number of listed records.
+			//
+			if(!mStreams[i]->Subject->GetLimits()->Activate(nvars) || nvars!=mStreams[i]->Subject->GetLimits()->GetNumVars())
+			{
+				IBUG_ERROR("Stream #"+iString::FromNumber(i)+" is unable to accommodate "+iString::FromNumber(nvars)+" fields - associated iDataLimits class has been configured incorrectly. This is a bug, the file has not been read properly.");
+				if(!mTwoCopies) this->EraseData();
+				return;
+			}
+
+			iMonitor h2(this);
+			for(var=0; var<nvars; var++)
+			{
+				h2.SetInterval(double(var)/nvars,1.0/nvars);
+
+				float range[2];
+				mStreams[i]->Subject->GetHistogramMaker()->GetRange(var,range);
+				if(mStreams[i]->Subject->GetHistogramMaker()->HasOverflow(var)) overflow = true;
+			}
+
+			if(mStreams[i]->Subject->GetResetOnLoad())
+			{
+				for(var=0; var<nvars; var++)
+				{
+					mStreams[i]->Subject->GetLimits()->SetRange(var,mStreams[i]->Subject->GetHistogramMaker()->GetRange(var));
+				}
+			}
+			mStreams[i]->Subject->GetLimits()->BlockNotifications(false);
+
+			iSyncWithDataRequest req(mStreams[i]->Subject->GetDataType());
+			this->GetViewModule()->SyncWithData(req);
+		}
+
+		h1.SetProgress(1.0);
 	}
+
+	if(overflow)
+	{
+		this->OutputText(MessageType::Warning,"The data are read correctly, but some values in the file were outside of range ("+iString::FromNumber(-iMath::_LargeFloat)+","+iString::FromNumber(iMath::_LargeFloat)+").\n These values were clamped to be within the required range.");
+	}
+
+	this->OutputDataDescription();
+
+	h.SetProgress(1.0);
+	this->GetShell()->GetDataReaderObserver()->FinishFile(fname,this->GetDataInfo());
 }
 
 
@@ -501,7 +583,7 @@ void iFileLoader::AttachDataToStream(int i, vtkDataSet *ds)
 	{
 		if(ds == 0)
 		{
-			IERROR_FATAL("Cannot attach a null data set.");
+			IBUG_FATAL("Cannot attach a null data set.");
 		}
 		else
 		{
@@ -509,7 +591,7 @@ void iFileLoader::AttachDataToStream(int i, vtkDataSet *ds)
 			{
 				mStreams[i]->ReleasedData->Delete();
 			}
-			mStreams[i]->ReleasedData = ds->NewInstance(); IERROR_ASSERT(mStreams[i]->ReleasedData);
+			mStreams[i]->ReleasedData = ds->NewInstance(); IERROR_CHECK_MEMORY(mStreams[i]->ReleasedData);
 			if(mTwoCopies)
 			{
 				mStreams[i]->ReleasedData->DeepCopy(ds);
@@ -524,22 +606,43 @@ void iFileLoader::AttachDataToStream(int i, vtkDataSet *ds)
 }
 
 
-bool iFileLoader::IsAborted() const
-{
-	return mObserver->IsAborted();
-}
-
-
 bool iFileLoader::IsThereData(int n) const
 {
 	if(n>=0 && n<mStreams.Size())
 	{
-		iDataHelper h(this->GetData(n));
-		return h.IsThereData();
+		return (this->GetData(n)!=0 && this->GetData(n)->GetNumberOfPoints()>0);
 	}
 	else return false;
 }
 
+bool iFileLoader::IsThereScalarData(int n) const
+{
+	if(n>=0 && n<mStreams.Size())
+	{
+		return ivtkType::IsThereScalarData(this->GetData(n));
+	}
+	else return false;
+}
+
+
+bool iFileLoader::IsThereVectorData(int n) const
+{
+	if(n>=0 && n<mStreams.Size())
+	{
+		return ivtkType::IsThereVectorData(this->GetData(n));
+	}
+	else return false;
+}
+
+
+bool iFileLoader::IsThereTensorData(int n) const
+{
+	if(n>=0 && n<mStreams.Size())
+	{
+		return ivtkType::IsThereTensorData(this->GetData(n));
+	}
+	else return false;
+}
 
 bool iFileLoader::IsThereData() const
 {
@@ -566,22 +669,29 @@ bool iFileLoader::IsThereData(const iDataType &type) const
 void iFileLoader::EraseData()
 {
 	int i;
-	for(i=0; i<mStreams.Size(); i++) if(mStreams[i]->ReleasedData != 0)
+	for(i=0; i<mStreams.Size(); i++)
 	{
-		mStreams[i]->ReleasedData->Initialize();
+		if(mStreams[i]->ReleasedData != 0)
+		{
+			mStreams[i]->ReleasedData->Initialize();
+			mStreams[i]->ReleasedData = 0;
+			mStreams[i]->Subject->GetLimits()->Activate(-1);
+		}
+
+		//
+		//  EraseData can be called by a loader if a file load failed; in that case the data
+		//  may be in an invalid state, so send the request anyway, even if the data were not released
+		//
+		iSyncWithDataRequest req(mStreams[i]->Subject->GetDataType());
+		this->GetViewModule()->SyncWithData(req);
 	}
 
 	mRecord = -1;
 	mShift[0] = mShift[1] = mShift[2] = 0.0f;
-
-	for(i=0; i<mStreams.Size(); i++)
-	{
-		mStreams[i]->Subject->GetLimits()->AssignVars(); // if no data, use all vars
-		mStreams[i]->Subject->ClearCache();
-	}
 }
 
 
+
 void iFileLoader::SetTwoCopies(bool s)
 {
 	if(mTwoCopies != s)
@@ -597,29 +707,28 @@ void iFileLoader::Reset()
 	for(i=0; i<mStreams.Size(); i++) if(mStreams[i]->ReleasedData != 0)
 	{
 		mStreams[i]->ReleasedData->Modified();
-		this->GetViewModule()->NotifyDataConsumers(mStreams[i]->Subject->Request());
+
+		iSyncWithDataRequest req(mStreams[i]->Subject->GetDataType());
+		this->GetViewModule()->SyncWithData(req);
 	}
 }
 
 
-void iFileLoader::ShiftData(double dr[3])
+void iFileLoader::ShiftData(const double *shift)
 {
 	int i;
 	double dx[3];
 
-	mObserver->Started(iProgressEventObserver::_Shifting);
-	mObserver->SetProgress(0.0);
-
-	for(i=0; i<3; i++) dx[i] = dr[i] - mShift[i];
+	for(i=0; i<3; i++) dx[i] = shift[i] - mShift[i];
 
+	iMonitor h(this);
 	for(i=0; i<this->NumStreams(); i++) if(mStreams[i]->ReleasedData != 0)
 	{
+		h.SetInterval("Shifting",double(i)/this->NumStreams(),1.0/this->NumStreams());
 		this->ShiftDataBody(mStreams[i]->ReleasedData,dx);
 	}
 
-	for(i=0; i<3; i++) mShift[i] = dr[i];
-
-	mObserver->Finished();
+	for(i=0; i<3; i++) mShift[i] = shift[i];
 }
 
 
@@ -659,23 +768,29 @@ bool iFileLoader::SkipFortranRecord(iFile& F, vtkIdType len)
 }
 
 
-bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b, float updateStart, float updateDuration, bool autoswap)
+bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b, double updateStart, double updateDuration, bool autoswap, bool full)
 {
 	vtkIdType lrec1, lrec2;
 
 	if(!this->ReadFortranHeaderFooter(F,lrec1)) return false;
+	if(full && lrec1!=b.Length*b.Size) return false;
 
-	if(!ReadBlockToBuffer(F,b,updateStart,updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver)) return false;
-	if(mObserver->IsAborted()) return true;
+	if(!ReadBlockToBuffer(F,b,updateStart,updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),this->GetShell()->GetExecutionEventObserver())) return false;
+	if(this->GetShell()->GetExecutionEventObserver()->IsAborted()) return true;
+
+	if(!full && b.Length*b.Size<lrec1)
+	{
+		if(!F.SkipBlock(lrec1-b.Length*b.Size)) return false;
+	}
 
 	if(!this->ReadFortranHeaderFooter(F,lrec2)) return false;
-	if(lrec1!=lrec2 || lrec1!=b.Length*b.Size) return false;
+	if(lrec1 != lrec2) return false;
 
 	return true;
 }
 
 
-bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, float updateStart, float updateDuration, bool autoswap)
+bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, double updateStart, double updateDuration, bool autoswap)
 {
 	vtkIdType lrec1, lrec2;
 	vtkIdType len = b1.Length*b1.Size + b2.Length*b2.Size;
@@ -683,20 +798,21 @@ bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const Rea
 	float f2 = float(b2.Length*b2.Size)/len;
 
 	if(!this->ReadFortranHeaderFooter(F,lrec1)) return false;
+	if(lrec1 != len) return false;
 
-	if(!ReadBlockToBuffer(F,b1,updateStart,f1*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver)) return false;
-	if(mObserver->IsAborted()) return true;
-	if(!ReadBlockToBuffer(F,b2,updateStart+f1*updateDuration,f2*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver)) return false;
-	if(mObserver->IsAborted()) return true;
+	if(!ReadBlockToBuffer(F,b1,updateStart,f1*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),this->GetShell()->GetExecutionEventObserver())) return false;
+	if(this->GetShell()->GetExecutionEventObserver()->IsAborted()) return true;
+	if(!ReadBlockToBuffer(F,b2,updateStart+f1*updateDuration,f2*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),this->GetShell()->GetExecutionEventObserver())) return false;
+	if(this->GetShell()->GetExecutionEventObserver()->IsAborted()) return true;
 
 	if(!this->ReadFortranHeaderFooter(F,lrec2)) return false;
-	if(lrec1!=lrec2 || lrec1!=len) return false;
+	if(lrec1 != lrec2) return false;
 
 	return true;
 }
 
 
-bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, const ReadingBuffer &b3, float updateStart, float updateDuration, bool autoswap)
+bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, const ReadingBuffer &b3, double updateStart, double updateDuration, bool autoswap)
 {
 	vtkIdType lrec1, lrec2;
 	vtkIdType len = b1.Length*b1.Size + b2.Length*b2.Size + b3.Length*b3.Size;
@@ -705,34 +821,37 @@ bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const Rea
 	float f3 = float(b3.Length*b3.Size)/len;
 
 	if(!this->ReadFortranHeaderFooter(F,lrec1)) return false;
+	if(lrec1 != len) return false;
 
-	if(!ReadBlockToBuffer(F,b1,updateStart,f1*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver)) return false;
-	if(mObserver->IsAborted()) return true;
-	if(!ReadBlockToBuffer(F,b2,updateStart+f1*updateDuration,f2*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver)) return false;
-	if(mObserver->IsAborted()) return true;
-	if(!ReadBlockToBuffer(F,b3,updateStart+(f1+f2)*updateDuration,f3*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver)) return false;
-	if(mObserver->IsAborted()) return true;
+	if(!ReadBlockToBuffer(F,b1,updateStart,f1*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),this->GetShell()->GetExecutionEventObserver())) return false;
+	if(this->GetShell()->GetExecutionEventObserver()->IsAborted()) return true;
+	if(!ReadBlockToBuffer(F,b2,updateStart+f1*updateDuration,f2*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),this->GetShell()->GetExecutionEventObserver())) return false;
+	if(this->GetShell()->GetExecutionEventObserver()->IsAborted()) return true;
+	if(!ReadBlockToBuffer(F,b3,updateStart+(f1+f2)*updateDuration,f3*updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),this->GetShell()->GetExecutionEventObserver())) return false;
+	if(this->GetShell()->GetExecutionEventObserver()->IsAborted()) return true;
 
 	if(!this->ReadFortranHeaderFooter(F,lrec2)) return false;
-	if(lrec1!=lrec2 || lrec1!=len) return false;
+	if(lrec1 != lrec2) return false;
 
 	return true;
 }
 
 	
-bool iFileLoader::ReadFortranRecord(iFile& F, int nbufs, const ReadingBuffer *b, float updateStart, float updateDuration, bool autoswap) // read any number of buffers
+bool iFileLoader::ReadFortranRecord(iFile& F, int nbufs, const ReadingBuffer *b, double updateStart, double updateDuration, bool autoswap) // read any number of buffers
 {
 	vtkIdType lrec1, lrec2;
 
 	if(b==0 || nbufs<=0 || !this->ReadFortranHeaderFooter(F,lrec1)) return false;
 
+	updateDuration /= nbufs;
+
 	int i;
 	vtkIdType len = 0L;
 	for(i=0; i<nbufs; i++)
 	{
 		len += b[i].Length*b[i].Size;
-		if(!ReadBlockToBuffer(F,b[i],updateStart+i*updateDuration,updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver)) return false;
-		if(mObserver->IsAborted()) return true;
+		if(!ReadBlockToBuffer(F,b[i],updateStart+i*updateDuration,updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),this->GetShell()->GetExecutionEventObserver())) return false;
+		if(this->GetShell()->GetExecutionEventObserver()->IsAborted()) return true;
 	}
 
 	if(!this->ReadFortranHeaderFooter(F,lrec2)) return false;
@@ -755,10 +874,10 @@ bool iFileLoader::ReadFortranHeaderFooter(iFile& F, vtkIdType &lrec)
 			if(mIsBigEndian != iSystem::IsBigEndianMachine()) this->SwapBytes(ltmp);
 			if(sizeof(vtkIdType) < 8)
 			{
-				IERROR_LOW("VTK is compiled with 32-bit Ids. The record length of this file is 64-bits, it cannot be read with this VTK installation. To be able to read this file you will have to recompile VTK with the advanced option VTK_USE_64BIT_IDS set to ON and then recompile IFrIT.");
+				IBUG_WARN("VTK is compiled with 32-bit Ids. The record length of this file is 64-bits, it cannot be read with this VTK installation. To be able to read this file you will have to recompile VTK with the advanced option VTK_USE_64BIT_IDS set to ON and then recompile IFrIT.");
 				return false;
 			}
-			lrec = ltmp;
+			lrec = (vtkTypeUInt64)ltmp;
 		}
 	}
 	else if(mFortranHeaderFooterLength == 4)
@@ -768,12 +887,12 @@ bool iFileLoader::ReadFortranHeaderFooter(iFile& F, vtkIdType &lrec)
 		if(ret)
 		{
 			if(mIsBigEndian != iSystem::IsBigEndianMachine()) this->SwapBytes(ltmp);
-			lrec = ltmp;
+			lrec = (vtkTypeUInt32)ltmp;
 		}
 	}
 	else
 	{
-		IERROR_LOW("Invalid Fortran header/footer length.");
+		IBUG_WARN("Invalid Fortran header/footer length.");
 	}
 
 	return ret;
@@ -862,6 +981,14 @@ bool iFileLoader::IsSeriesFileName(const iString &fname) const
 }
 
 
+//
+//  Optional final touch
+//
+void iFileLoader::Polish(vtkDataSet *data)
+{
+}
+
+
 //
 //  Overloads
 //
@@ -883,6 +1010,7 @@ iFileLoader::Stream::Stream()
 {
 	Subject = 0;
 	ReleasedData = 0;
+	Periodic[0] = Periodic[1] = Periodic[2] = false;
 }
 
 
@@ -892,3 +1020,72 @@ iFileLoader::Stream::~Stream()
 	if(Subject != 0) Subject->Delete();
 }
 
+
+#include <vtkDataSet.h>
+#include <vtkImageData.h>
+#include <vtkPointData.h>
+#include <vtkPolyData.h>
+
+
+void iFileLoader::OutputDataDescription() const
+{
+	int j;
+
+	this->OutputText(MessageType::Information,"File: "+mLastFileName);
+
+	for(j=0; j<this->NumStreams(); j++)
+	{
+		const iDataType &type(mStreams[j]->Subject->GetDataType());
+		vtkDataSet *data = mStreams[j]->ReleasedData;
+		if(data == 0) continue;
+
+		//
+		//  DataType and VTK class names
+		//
+		this->OutputText(MessageType::Information,"\tStream: "+type.TextName()+" ( VTK class name: "+data->GetClassName()+")");
+
+		if(mStreams[j]->Periodic[0] || mStreams[j]->Periodic[1] || mStreams[j]->Periodic[2])
+		{
+			this->OutputText(MessageType::Information,iString("\t\tPeriodic directions: ")+(mStreams[j]->Periodic[0]?"X ":"")+(mStreams[j]->Periodic[0]?"Y ":"")+(mStreams[j]->Periodic[2]?"Z":""));
+		}
+
+		//
+		//  Are we ImageData?
+		//
+		vtkImageData *im = vtkImageData::SafeDownCast(data);
+		if(im != 0)
+		{
+			int dims[3];
+			im->GetDimensions(dims);
+			this->OutputText(MessageType::Information,"\t\tDimensions = "+iString::FromNumber(dims[0])+" x "+iString::FromNumber(dims[1])+" x "+iString::FromNumber(dims[2]));
+		}
+
+		vtkPolyData *pl = vtkPolyData::SafeDownCast(data);
+		if(pl != 0)
+		{
+			this->OutputText(MessageType::Information,"    Number of particles = "+iString::FromNumber(pl->GetNumberOfPoints()));
+		}
+
+		vtkPointData *pd = data->GetPointData();
+		if(pd!=0 && pd->GetScalars() != 0)
+		{
+			this->OutputText(MessageType::Information,"    Number of scalar components = "+iString::FromNumber(pd->GetScalars()->GetNumberOfComponents()));
+		}
+		if(pd!=0 && pd->GetVectors() != 0)
+		{
+			this->OutputText(MessageType::Information,"    Number of vector components = "+iString::FromNumber(pd->GetVectors()->GetNumberOfComponents()));
+		}
+		if(pd!=0 && pd->GetTensors() != 0)
+		{
+			this->OutputText(MessageType::Information,"    Number of tensor components = "+iString::FromNumber(pd->GetTensors()->GetNumberOfComponents()));
+		}
+
+		int i;
+		for(i=0; i<mStreams[j]->Subject->GetLimits()->GetNumVars(); i++)
+		{
+			float range[2];
+			mStreams[j]->Subject->GetHistogramMaker()->GetRange(i,range);
+			this->OutputText(MessageType::Information,"    "+mStreams[j]->Subject->GetLimits()->GetName(i)+" from "+iString::FromNumber(range[0])+" ("+iString::FromNumber(iMath::Log10(1.0e-30+fabs(range[0])))+" dex) to "+iString::FromNumber(range[1])+" ("+iString::FromNumber(iMath::Log10(1.0e-30+fabs(range[1])))+" dex)");
+		}
+	}
+}
