@@ -34,22 +34,21 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkObjectBase.h>
+#include "iviewmodulecomponent.h"
 
 
 #include "iarray.h"
-#include "ipointermacro.h"
 #include "istring.h"
 
 #include <vtkSetGet.h>
 
+class iDataLimits;
 class iDataReader;
 class iDataReaderExtension;
 class iDataSubject;
+class iDataInfo;
 class iDataType;
-class iErrorStatus;
 class iFile;
-class iProgressEventObserver;
-class iViewModule;
 
 class vtkDataSet;
 
@@ -61,8 +60,8 @@ namespace iParameter
 	//
 	namespace BoundaryConditions
 	{
-		const int Periodic = 0;
-		const int Wall = 1;
+		const int None =	 0;
+		const int Periodic = 1;
 
 		inline bool IsValid(int m){ return m>=0 && m<=1; }
 	};
@@ -77,21 +76,16 @@ namespace iParameter
 	static void SwapBytesRange(_type_ *data, vtkIdType count)
 
 #define	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(_type_) \
-	bool ReadBlock(iFile& F, _type_ *p, vtkIdType len, float updateStart, float updateDuration); \
+	bool ReadBlock(iFile& F, _type_ *p, vtkIdType len, double updateStart = 0.0, double updateDuration = 0.0); \
 	ReadingBuffer Buffer(_type_ &d) const; \
 	ReadingBuffer Buffer(_type_ *d, vtkIdType l) const
 
 
-class iFileLoader : public vtkObjectBase
+class iFileLoader : public vtkObjectBase, public iViewModuleComponent
 {
 
-	IPOINTER_AS_PART(ViewModule);
-	IPOINTER_AS_USER(ErrorStatus);
-
 	friend class iDataReader;
 	friend class iDataSubject;
-	friend class iFieldFileLoader;
-	friend class iParticleFileLoader;
 
 public:
 
@@ -105,16 +99,15 @@ public:
 	//
 	//  Operation on data
 	//
-	void ReadFile(const iString &fname);
-	void Finalize();
+	void LoadFile(const iString &fname);
+	void LoadFile(const iString &fname, const double *shift);
 	void EraseData();
 	void Reset();
-	void ShiftData(double dr[3]);
+	void ShiftData(const double *shift);
 
 	inline bool IsTwoCopies() const { return mTwoCopies; }
 	void SetTwoCopies(bool s);
 
-	virtual bool IsAborted() const;
 	inline bool IsAnimatable() const { return (mRecord >= 0); }
 
 	inline const iString& GetLastFileName() const { return mLastFileName; }
@@ -128,11 +121,8 @@ public:
 	//
 	//  Boundary conditions
 	//
-	void SetBoundaryConditions(int s);
-	void SetDirectionPeriodic(int d, bool s);
-	inline int GetBoundaryConditions() const {	return mBoundaryConditions; }
-	inline bool IsBoxPeriodic() const {	return (mBoundaryConditions == iParameter::BoundaryConditions::Periodic); }
-	inline bool IsDirectionPeriodic(int d) const { if(d>=0 && d<3) return this->IsBoxPeriodic() && mPeriodic[d]; else return false; }
+	int GetBoundaryConditions() const;
+	bool IsDirectionPeriodic(int d) const;
 
 	//
 	//  Access to components
@@ -141,19 +131,26 @@ public:
 	inline iDataReaderExtension* GetReaderExtension() const { return mReaderExtension; }
 	bool IsThereData() const;
 	virtual bool IsThereData(int n) const;
-	virtual iDataSubject* GetSubject(int n) const;
+	virtual bool IsThereScalarData(int n) const;
+	virtual bool IsThereVectorData(int n) const;
+	virtual bool IsThereTensorData(int n) const;
 	virtual vtkDataSet* GetData(int n) const;
-	inline iProgressEventObserver* GetObserver() const { return mObserver; }
 
 	bool IsUsingData(const iDataType &type) const;
 	const iDataType& GetDataType(int n) const;
+	const iDataInfo& GetDataInfo() const;
 	virtual int DissectFileName(const iString &fname, iString &root, iString &suffix) const;
 	inline int NumStreams() const { return mStreams.Size(); }
 
 	bool IsThereData(const iDataType &type) const;
-	iDataSubject* GetSubject(const iDataType &type) const;
 	vtkDataSet* GetData(const iDataType &type) const;
 
+	//
+	//  Some of children and collaborating loaders may need access to subject limits,
+	//  but they should not use subjects directly.
+	//
+	virtual iDataLimits* GetLimits(int n) const;
+
 	inline int GetPriority() const { return mPriority; }
 
 	//
@@ -175,13 +172,18 @@ public:
 
 protected:
 
+	iFileLoader(iDataReader *r, int priority);
 	iFileLoader(iDataReaderExtension *ext, int priority);
 	virtual ~iFileLoader();
 
-	virtual void ReadFileBody(const iString &suffix, const iString &fname) = 0;
-	virtual void FinalizeBody() = 0;
-	virtual void ShiftDataBody(vtkDataSet *data, double dx[3]) = 0;
-	virtual void Polish(vtkDataSet * ){} // optional post-finalize
+	virtual void LoadFileBody(const iString &suffix, const iString &fname) = 0;
+	virtual void ShiftDataBody(vtkDataSet *data, const double *dx) = 0;
+	virtual void Polish(vtkDataSet *data); // optional final touch
+
+	//
+	//  Output information about the data.
+	//
+	virtual void OutputDataDescription() const;
 
 	//
 	//  File reading helpers
@@ -195,10 +197,13 @@ protected:
 	bool ReadFortranHeaderFooter(iFile& F, vtkIdType &lrec);
 
 	bool SkipFortranRecord(iFile& F, vtkIdType len);
-	bool ReadFortranRecord(iFile& F, const ReadingBuffer &b, float updateStart, float updateDuration, bool autoswap = true);
-	bool ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, float updateStart, float updateDuration, bool autoswap = true);
-	bool ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, const ReadingBuffer &b3, float updateStart, float updateDuration, bool autoswap = true);
-	bool ReadFortranRecord(iFile& F, int nbufs, const ReadingBuffer *b, float updateStart, float updateDuration, bool autoswap = true); // read any number of buffers
+
+	bool ReadFortranRecord(iFile& F, const ReadingBuffer &b, double updateStart = 0.0, double updateDuration = 0.0, bool autoswap = true, bool full = true);
+	bool ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, double updateStart = 0.0, double updateDuration = 0.0, bool autoswap = true);
+	bool ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, const ReadingBuffer &b3, double updateStart = 0.0, double updateDuration = 0.0, bool autoswap = true);
+	bool ReadFortranRecord(iFile& F, int nbufs, const ReadingBuffer *b, double updateStart = 0.0, double updateDuration = 0.0, bool autoswap = true); // read any number of buffers
+
+	void SetDirectionPeriodic(int d, bool s);
 
 	//
 	//  Data management
@@ -207,6 +212,7 @@ protected:
 	{
 		iDataSubject *Subject;
 		vtkDataSet *ReleasedData;
+		bool Periodic[3];
 
 		Stream();
 		virtual ~Stream();
@@ -216,33 +222,31 @@ protected:
 	inline Stream* GetStream(int i) const { return mStreams[i]; } // no bound checking for speed
 	void AttachDataToStream(int i, vtkDataSet *ds);
 
-	void NotifyDependencies();
-
 	//
 	//  Components
 	//
-	int mBoundaryConditions;
 	bool mPeriodic[3];
-
-	iString mFileRoot, mFileSuffix, mLastFileName;
-	bool mTwoCopies, mIsBigEndian, mOverflow;
-	iProgressEventObserver *mObserver;
-	double mShift[3];
+	bool mTwoCopies, mIsBigEndian;
 	int mRecord, mFortranHeaderFooterLength;
 
+private:
+
+	void Define();
+
+	double mShift[3];
+	const int mPriority;
+	iString mFileRoot, mFileSuffix, mLastFileName;
+
 	iDataReader *mReader;
 	iDataReaderExtension *mReaderExtension;
 
-private:
-
-	iFileLoader(iDataReader *r, int priority);
-
-	void Define();
-
+	mutable iDataInfo *mInfo;
 	iArray<Stream*> mStreams;
 
-	const int mPriority;
-	bool mUpdated; // should not be used by children
+	//
+	//  Loaders should not be really accessing subjects, that may create cyclic dependency
+	//
+	iDataSubject* GetSubject(const iDataType &type) const;
 };
 
 #endif  // IFILELOADER_H
