@@ -32,15 +32,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iFlipNormalsFilter::iFlipNormalsFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkReverseSense>(vo,1,true,false)
+iFlipNormalsFilter::iFlipNormalsFilter(iDataConsumer *consumer) : iGenericPolyDataFilter<vtkReverseSense>(consumer,1,true)
 {
 }
 	
 
-void iFlipNormalsFilter::ProduceOutput()
+void iFlipNormalsFilter::ProvideOutput()
 {
 	this->ExecuteParent();
 }
