@@ -34,14 +34,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkReverseSense.h>
 
 
-class iFlipNormalsFilter : public iGenericPolyDataToPolyDataFilter<vtkReverseSense>
+class iFlipNormalsFilter : public iGenericPolyDataFilter<vtkReverseSense>
 {
 	
-	IGENERICFILTER_DECLARE(iFlipNormalsFilter,vtkReverseSense);
+	iGenericFilterTypeMacro(iFlipNormalsFilter,vtkReverseSense);
 	
 protected:
 
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 };
 
 #endif // IFLIPNORMALSFILTER_H
