@@ -33,17 +33,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "igenericfilter.h"
-#include <vtkDataSetToDataSetFilter.h>
+#include <vtkPassThroughFilter.h>
 
 
-class iIdentityFilter : public iGenericFilter<vtkDataSetToDataSetFilter,vtkDataSet,vtkDataSet>
+class vtkDataSet;
+
+
+class iIdentityFilter : public iGenericFilter<vtkPassThroughFilter,vtkDataSet,vtkDataSet>
 {
 	
-	IGENERICFILTER_DECLARE(iIdentityFilter,vtkDataSetToDataSetFilter);
+	iGenericFilterTypeMacro(iIdentityFilter,vtkPassThroughFilter);
 	
 protected:
 
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 };
 
 #endif // IIDENTITYFILTER_H
