@@ -31,6 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icolor.h"
 #include "ierror.h"
 #include "imath.h"
+#include "ivtk.h"
 
 #include <vtkBMPReader.h>
 #include <vtkImageBlend.h>
@@ -49,7 +50,7 @@ iImage::iImage(int depth)
 {
 	if(depth<1 || depth>4)
 	{
-		IERROR_LOW("Incorrect number of image components");
+		IBUG_WARN("Incorrect number of image components");
 		depth = 3;
 	}
 	mData = 0;
@@ -82,31 +83,32 @@ iImage::~iImage()
 }
 
 
-vtkImageData* iImage::CreateData(int depth)
+vtkImageData* iImage::CreateData(int w, int h, int d)
 {
 	vtkImageData *tmp;
 
-	if(depth<1 || depth>4)
-	{
-		IERROR_LOW("Incorrect number of image components");
-		depth = 3;
-	}
-	tmp = vtkImageData::New(); IERROR_ASSERT(tmp);
-	tmp->SetScalarTypeToUnsignedChar();
-	tmp->SetNumberOfScalarComponents(depth);
+	tmp = vtkImageData::New(); IERROR_CHECK_MEMORY(tmp);
 	tmp->SetOrigin(0.0,0.0,0.0);
 	tmp->SetSpacing(1.0,1.0,1.0);
-	return tmp;
-}
+	tmp->SetDimensions(w,h,1);
 
-
-void iImage::Allocate(vtkImageData *d, int w, int h)
-{
 	if(d != 0)
 	{
-		d->SetDimensions(w,h,1);
-		d->AllocateScalars();
+		if(d < 1 || d>4)
+		{
+			IBUG_WARN("Incorrect number of image components");
+			d = 3;
+		}
+#ifdef IVTK_5
+		tmp->SetScalarType(VTK_UNSIGNED_CHAR);
+		tmp->SetNumberOfScalarComponents(d);
+		tmp->AllocateScalars();
+#else
+		tmp->AllocateScalars(VTK_UNSIGNED_CHAR,d);
+#endif
 	}
+
+	return tmp;
 }
 
 
@@ -118,21 +120,20 @@ unsigned char* iImage::DataPointer() const
 
 void iImage::SetDataPointer(unsigned char* array, int w, int h, int d)
 {
-	if(w>0 && h>0)
+	if(array!=0 && w>0 && h>0 && d>0 && d<5)
 	{
 		if(mData != 0) mData->Delete();
-		mData = CreateData(d);
-		mData->SetDimensions(w,h,1);
-		mDepth = mData->GetNumberOfScalarComponents();
+		mData = CreateData(w,h,0); // do not allocate
 		vtkUnsignedCharArray *a;
 		if(mData->GetPointData()->GetScalars()==0 || (a = vtkUnsignedCharArray::SafeDownCast(mData->GetPointData()->GetScalars()))==0)
 		{
-			a = vtkUnsignedCharArray::New(); IERROR_ASSERT(a);
+			a = vtkUnsignedCharArray::New(); IERROR_CHECK_MEMORY(a);
 			mData->GetPointData()->SetScalars(a);
 			a->Delete();
 		}
-		a->SetNumberOfComponents(mDepth);
-		a->SetArray(array,mDepth*w*h,1);
+		a->SetNumberOfComponents(d);
+		a->SetArray(array,d*w*h,1);
+		mDepth = d;
 		mWidth = w;
 		mHeight = h;
 	}
@@ -165,27 +166,27 @@ bool iImage::LoadFromFile(const iString &filename, iImage &image)
 
 	if(suf=="jpg" || suf=="jpeg")
 	{
-		ir = vtkJPEGReader::New(); IERROR_ASSERT(ir);
+		ir = vtkJPEGReader::New(); IERROR_CHECK_MEMORY(ir);
 	}
 	
 	if(suf == "pnm")
 	{
-		ir = vtkPNMReader::New(); IERROR_ASSERT(ir);
+		ir = vtkPNMReader::New(); IERROR_CHECK_MEMORY(ir);
 	}
 	
 	if(suf == "bmp")
 	{
-		ir = vtkBMPReader::New(); IERROR_ASSERT(ir);
+		ir = vtkBMPReader::New(); IERROR_CHECK_MEMORY(ir);
 	}
 	
 	if(suf=="tif" || suf=="tiff")
 	{
-		ir = vtkTIFFReader::New(); IERROR_ASSERT(ir);
+		ir = vtkTIFFReader::New(); IERROR_CHECK_MEMORY(ir);
 	}
 	
 	if(suf == "png")
 	{
-		ir = vtkPNGReader::New(); IERROR_ASSERT(ir);
+		ir = vtkPNGReader::New(); IERROR_CHECK_MEMORY(ir);
 	}
 	
 	if(ir!=0 && ir->CanReadFile(filename.ToCharPointer())==3)
@@ -218,8 +219,8 @@ void iImage::Blend(const iImage& im, float op)
 	if(op > 1.0) op = 1.0;
 
 	iblend = vtkImageBlend::New(); if(iblend == 0) return;
-	iblend->SetInput(0,im.mData);
-	iblend->SetInput(1,mData);
+	iblend->SetInputData(0,im.mData);
+	iblend->SetInputData(1,mData);
 	iblend->SetOpacity(1,(double)op);	
 	iblend->Update();
 	mData->Delete();
@@ -247,7 +248,7 @@ void iImage::ReplaceData(vtkImageData *newdata)
 	//  We need to actually copy the data, not just link it here, since if the data object
 	//  changes, we would have no way of knowing it.
 	//
-	if(mData == 0) mData = CreateData(newdata->GetNumberOfScalarComponents()); 
+	if(mData == 0) mData = CreateData(mWidth,mHeight); 
 	mData->DeepCopy(newdata);
 }
 
@@ -314,7 +315,7 @@ void iImage::Overlay(int x, int y, const iImage& ovr, float opacity, bool maskin
 						{
 							for(k=0; k<mDepth; k++) // this is not because I am lazy, it is the fastest way
 							{
-								iPtr[lImage+k] = (unsigned char)round(wI*iPtr[lImage+k]+wO*oPtr[lOvlay+k]);
+								iPtr[lImage+k] = (unsigned char)iMath::Round2Int(wI*iPtr[lImage+k]+wO*oPtr[lOvlay+k]);
 							}
 						}
 					}
@@ -387,8 +388,7 @@ void iImage::Scale(int w, int h, ScaleMode m, ScaleFilter f)
 	{
 		mWidth = w;
 		mHeight = h;
-		mData = CreateData(mDepth);
-		Allocate(mData,w,h);
+		mData = CreateData(w,h,mDepth);
 		memset(mData->GetScalarPointer(),0,mDepth*w*h);
 		return;
 	}
@@ -397,30 +397,30 @@ void iImage::Scale(int w, int h, ScaleMode m, ScaleFilter f)
 	{
 	case _Fit:
 		{
-			fx = (float)w/mWidth;
-			fy = (float)h/mHeight;
+			fx = float(w)/mWidth;
+			fy = float(h)/mHeight;
 			if(fx < fy) fy = fx;
-			w = round(fy*mWidth);
-			h = round(fy*mHeight);
+			w = iMath::Round2Int(fy*mWidth);
+			h = iMath::Round2Int(fy*mHeight);
 			break;
 		}
 	case _Include:
 		{
-			fx = (float)w/mWidth;
-			fy = (float)h/mHeight;
+			fx = float(w)/mWidth;
+			fy = float(h)/mHeight;
 			if(fx < fy) fx = fy;
-			w = round(fx*mWidth);
-			h = round(fx*mHeight);
+			w = iMath::Round2Int(fx*mWidth);
+			h = iMath::Round2Int(fx*mHeight);
 			break;
 		}
 	case _FitMin:
 		{
-			fx = (float)w/mWidth;
-			fy = (float)h/mHeight;
+			fx = float(w)/mWidth;
+			fy = float(h)/mHeight;
 			if(fx < fy) fy = fx;
 			if(fy > 1.0) fy = 1.0;
-			w = round(fy*mWidth);
-			h = round(fy*mHeight);
+			w = iMath::Round2Int(fy*mWidth);
+			h = iMath::Round2Int(fy*mHeight);
 			break;
 		}
 	case _Both:
@@ -432,24 +432,23 @@ void iImage::Scale(int w, int h, ScaleMode m, ScaleFilter f)
 	//
 	//  w and h are now proper size. Scale linearly first.
 	//
-	vtkImageData *tmp = CreateData(mDepth);
-	Allocate(tmp,w,h);
+	vtkImageData *tmp = CreateData(w,h,mDepth);
 
 	unsigned char *sPtr = (unsigned char *)mData->GetScalarPointer();
 	unsigned char *dPtr = (unsigned char *)tmp->GetScalarPointer();
 
-	fx = (float)mWidth/w;
-	fy = (float)mHeight/h;
+	fx = float(mWidth)/w;
+	fy = float(mHeight)/h;
 
-	int *i0l = new int[w]; IERROR_ASSERT(i0l);
-	int *i0s = new int[w]; IERROR_ASSERT(i0s);
-	float *x0l = new float[w]; IERROR_ASSERT(x0l);
-	float *x0s = new float[w]; IERROR_ASSERT(x0s);
+	int *i0l = new int[w]; IERROR_CHECK_MEMORY(i0l);
+	int *i0s = new int[w]; IERROR_CHECK_MEMORY(i0s);
+	float *x0l = new float[w]; IERROR_CHECK_MEMORY(x0l);
+	float *x0s = new float[w]; IERROR_CHECK_MEMORY(x0s);
 
-	int *j0l = new int[h]; IERROR_ASSERT(j0l);
-	int *j0s = new int[h]; IERROR_ASSERT(j0s);
-	float *y0l = new float[h]; IERROR_ASSERT(y0l);
-	float *y0s = new float[h]; IERROR_ASSERT(y0s);
+	int *j0l = new int[h]; IERROR_CHECK_MEMORY(j0l);
+	int *j0s = new int[h]; IERROR_CHECK_MEMORY(j0s);
+	float *y0l = new float[h]; IERROR_CHECK_MEMORY(y0l);
+	float *y0s = new float[h]; IERROR_CHECK_MEMORY(y0s);
 
 	int i, j, k;
 	float v, x0, y0, x1, y1, dx, dy;
@@ -458,10 +457,10 @@ void iImage::Scale(int w, int h, ScaleMode m, ScaleFilter f)
 	{
 		y1 = j + 0.5;
 		y0 = y1*fy;
-		j0l[j] = round(y0-0.5);
+		j0l[j] = iMath::Round2Int(y0-0.5);
 		if(j0l[j]<0 || j0l[j]>=mHeight)
 		{
-			IERROR_LOW("Corrupted image.");
+			IBUG_WARN("Corrupted image.");
 			return;
 		}
 		dy = y0 - 0.5 - j0l[j]; 
@@ -485,10 +484,10 @@ void iImage::Scale(int w, int h, ScaleMode m, ScaleFilter f)
 	{
 		x1 = i + 0.5;
 		x0 = x1*fx;
-		i0l[i] = round(x0-0.5);
+		i0l[i] = iMath::Round2Int(x0-0.5);
 		if(i0l[i]<0 || i0l[i]>=mWidth)
 		{
-			IERROR_LOW("Corrupted image.");
+			IBUG_WARN("Corrupted image.");
 			return;
 		}
 		dx = x0 - 0.5 - i0l[i]; 
@@ -521,7 +520,7 @@ void iImage::Scale(int w, int h, ScaleMode m, ScaleFilter f)
 					x0s[i]*y0s[j]*sPtr[k+mDepth*(i0s[i]+mWidth*j0s[j])];
 				if(v < 0.0) v = 0.0;
 				if(v > 255.0) v = 255.0;
-				dPtr[k+mDepth*(i+w*j)] = (unsigned char)round(v);
+				dPtr[k+mDepth*(i+w*j)] = (unsigned char)iMath::Round2Int(v);
 			}
 		}
 	}
@@ -552,7 +551,7 @@ void iImage::Smooth(float dx, float dy)
 	filter->SetDimensionality(3);
 	filter->SetStandardDeviations(dx,dy,0.0);
 	filter->SetRadiusFactors(1.0*dx,1.0*dy,1.0); // exp(-0.5*3.3^2) = 1/255
-	filter->SetInput(mData);
+	filter->SetInputData(mData);
 	filter->Update();
 	if(mData != 0) mData->Delete();
 	mData = filter->GetOutput();
@@ -614,8 +613,7 @@ bool iImage::CombineInPseudoColor(const iImage &imRed, const iImage &imGreen, co
 	mWidth = w;
 	mHeight = h;
 	mDepth = d;
-	mData = CreateData(d);
-	Allocate(mData,w,h);
+	mData = CreateData(w,h,d);
 
 	unsigned char *dPtr1, *dPtr2, *dPtr = this->DataPointer(); 
 	unsigned char *rPtr1, *rPtr2, *rPtr = imRed.DataPointer();
@@ -679,9 +677,7 @@ void iImage::Crop(int x, int y, int w, int h)
 	//
 	if(x==0 && y==0 && w==mWidth && h==mHeight) return;
 
-	vtkImageData *tmp = this->CreateData(mDepth);
-	tmp->SetDimensions(w,h,1);
-	tmp->AllocateScalars();
+	vtkImageData *tmp = this->CreateData(w,h,mDepth);
 
 	int j;
 	vtkIdType line = mDepth*w;
