@@ -110,10 +110,9 @@ public:
 private:
 
 	//
-	//  Helper functions
+	//  Helper function: if depth is set to 0, then the data are not actually allocated
 	//
-	static vtkImageData* CreateData(int depth);
-	static void Allocate(vtkImageData *d, int w, int h);
+	vtkImageData* CreateData(int w, int h, int depth = 0);
 
 	vtkImageData *mData;
 	int mDepth, mWidth, mHeight;
