@@ -31,51 +31,69 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iobject.h"
+#include "ishellcomponent.h"
 
 
 #include "iarray.h"
 
-class iControlModule;
 class iImageComposerWindow;
 class iImageComposerBackgroundWindow;
 class iImageComposerForegroundWindow;
 class iStereoImageArray;
 class iViewModule;
 
+#define iImageComposerPropertyMacro(_name_,_id_) \
+	iObjectSlotMacro2V(_name_,iType::Traits<iType::_id_>::Type); \
+	iPropertyVector<iType::_id_> _name_
 
-class iImageComposer : public iObject
+class iImageComposer : public iObject, public iShellComponent
 {
 
-	IPOINTER_AS_PART(ControlModule);
-
 public:
 
 	vtkTypeMacro(iImageComposer,iObject);
-	static iImageComposer* New(iControlModule *cm = 0);
-	static const iObjectType& Type();
+	static iImageComposer* New(iShell *s = 0);
 
-	IOBJECT_DECLARE_GETSET1(ScaleBackground,bool);
-	IOBJECT_DECLARE_GETSET1(InnerBorder,bool);
-	IOBJECT_DECLARE_GETSET1(BorderColor,const iColor&);
-	IOBJECT_DECLARE_GETSET1(BorderWidth,int);
+	iObjectPropertyMacro1V(NumTiles,Int,2);
+	iObjectPropertyMacro2S(NumForegroundWindows,Int);
 
-	IOBJECT_DECLARE_GET(ImageWidth,mFullWidth,int);
-	IOBJECT_DECLARE_GET(ImageHeight,mFullHeight,int);
+	iObjectPropertyMacro1S(ScaleBackground,Bool);
+	iObjectPropertyMacro1S(InnerBorder,Bool);
+	iObjectPropertyMacro1S(BorderColor,Color);
+	iObjectPropertyMacro1S(BorderWidth,Int);
+
+	iImageComposerPropertyMacro(BackgroundWindowIndex,Int);
+	iImageComposerPropertyMacro(BackgroundWindowIndex2,Int);
+	iImageComposerPropertyMacro(BackgroundWindowIndex3,Int);
+	iImageComposerPropertyMacro(BackgroundWindowWallpaperFile,String);
+
+	iImageComposerPropertyMacro(ForegroundWindowIndex,Int);
+	iImageComposerPropertyMacro(ForegroundWindowIndex2,Int);
+	iImageComposerPropertyMacro(ForegroundWindowIndex3,Int);
+	iImageComposerPropertyMacro(ForegroundWindowBorderColor,Color);
+	iImageComposerPropertyMacro(ForegroundWindowScale,Float);
+	iImageComposerPropertyMacro(ForegroundWindowBorderWidth,Int);
+	iImageComposerPropertyMacro(ForegroundWindowPositionX,Int);
+	iImageComposerPropertyMacro(ForegroundWindowPositionY,Int);
+	iImageComposerPropertyMacro(ForegroundWindowZoomSource,Int);
+	iImageComposerPropertyMacro(ForegroundWindowZoom4Line,Bool);
+	iImageComposerPropertyMacro(ForegroundWindowZoomFactor,Float);
+	iImageComposerPropertyMacro(ForegroundWindowZoomX,Float);
+	iImageComposerPropertyMacro(ForegroundWindowZoomY,Float);
+
+	iObjectPropertyMacro2Q(ImageWidth,Int);
+	iObjectPropertyMacro2Q(ImageHeight,Int);
 	int GetTileWidth() const { return mTileWidth; }
 	int GetTileHeight() const { return mTileHeight; }
-
-	void SetNumTiles(int nx, int ny);
-	int GetNumTilesX() const { return mNumTilesX; }
-	int GetNumTilesY() const { return mNumTilesY; }
-	static const iObjectKey& KeyNumTiles();
+	int GetNumTilesX() const { return mNumTiles[0]; }
+	int GetNumTilesY() const { return mNumTiles[1]; }
 
 	int GetNumberOfBackgroundWindows() const { return mBackgroundWindows.Size(); }
 	int GetNumberOfForegroundWindows() const { return mForegroundWindows.Size(); }
-	static const iObjectKey& KeyNumForegroundWindows();
 
 	inline iImageComposerBackgroundWindow* GetBackgroundWindow(int i, int j) const
 	{
-		return this->GetBackgroundWindow(i+mNumTilesX*j);
+		return this->GetBackgroundWindow(i+mNumTiles[0]*j);
 	}
 
 	iImageComposerBackgroundWindow* GetBackgroundWindow(int i) const;
@@ -83,36 +101,12 @@ public:
 
 	void AddForegroundWindow(iViewModule *v);
 	void RemoveForegroundWindow(int n);
-	void MoveToBack(int n);
-
-	//
-	//  Useful keys for command-line interface 
-	//
-	static const iObjectKey& KeyBackgroundWindowViewModule();
-	static const iObjectKey& KeyBackgroundWindowViewModule2();
-	static const iObjectKey& KeyBackgroundWindowViewModule3();
-	static const iObjectKey& KeyBackgroundWindowWallpaperFile();
-
-	static const iObjectKey& KeyForegroundWindowViewModule();
-	static const iObjectKey& KeyForegroundWindowViewModule2();
-	static const iObjectKey& KeyForegroundWindowViewModule3();
-	static const iObjectKey& KeyForegroundWindowPositionX();
-	static const iObjectKey& KeyForegroundWindowPositionY();
-	static const iObjectKey& KeyForegroundWindowScale();
-	static const iObjectKey& KeyForegroundWindowBorderWidth();
-	static const iObjectKey& KeyForegroundWindowBorderColor();
-
-	static const iObjectKey& KeyForegroundWindowZoomSource();
-	static const iObjectKey& KeyForegroundWindowZoom4Line();
-	static const iObjectKey& KeyForegroundWindowZoomFactor();
-	static const iObjectKey& KeyForegroundWindowZoomX();
-	static const iObjectKey& KeyForegroundWindowZoomY();
 
 	//
 	//  Other functions
 	//
 	inline bool InComposing() const { return mInComposing; }
-	void Compose(iViewModule *vm, iStereoImageArray &images);
+	bool Compose(iViewModule *vm, iStereoImageArray &images);
 	bool IsActive();
 
 	void Update();  // update all
@@ -125,20 +119,11 @@ protected:
 
 private:
 
-	iImageComposer(iControlModule *cm);
-
-	virtual void PackStateBody(iString &s) const;
-	virtual void UnPackStateBody(const iString &s);
-
-	void UnPackingHelper(int n, int j, iImageComposerWindow **win, int *itmp, const iObjectKey &key, const iString &s);
+	iImageComposer(iShell *s, const iString &fname, const iString &sname);
 
 	bool mBlockUpdate, mInComposing;
-	bool mInnerBorder, mScaleBackground;
-	iColor mBorderColor;
-	int mBorderWidth;
 	int mFullWidth, mFullHeight;
 	int mTileWidth, mTileHeight;
-	int mNumTilesX, mNumTilesY;
 
 	iArray<iImageComposerBackgroundWindow*> mBackgroundWindows;
 	iArray<iImageComposerForegroundWindow*> mForegroundWindows;
