@@ -29,12 +29,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iimagecomposerwindows.h"
 
 
-#include "icontrolmodule.h"
 #include "ierror.h"
-#include "ierrorstatus.h"
 #include "iimagecomposer.h"
 #include "imath.h"
-#include "ishellfactory.h"
+#include "imonitor.h"
+#include "ishell.h"
 #include "istereoimagearray.h"
 #include "iviewmodule.h"
 
@@ -44,7 +43,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 iColor iImageComposerBackgroundWindow::mEmptyBackground = iColor::White();
@@ -76,7 +75,7 @@ namespace iImageComposerWindow_Private
 			ptr = image.Eye(eye).DataPointer() + d*(x+w*y);
 			for(k=0; k<d; k++)
 			{
-				ptr[k] = (unsigned char)round(f*rgb[k]+(1.0f-f)*ptr[k]);
+				ptr[k] = (unsigned char)iMath::Round2Int(f*rgb[k]+(1.0f-f)*ptr[k]);
 			}
 		}
 	}
@@ -222,8 +221,8 @@ namespace iImageComposerWindow_Private
 		float x = x1 + 0.5*(w-1), y = y1 + 0.5*(w-1), xmax = x2 + 0.5*(w-1) + 1.0e-2;
 		while(x < xmax)
 		{
-			x0 = round(x);
-			y0 = round(y);
+			x0 = iMath::Round2Int(x);
+			y0 = iMath::Round2Int(y);
 			for(k=-kmax; k<=kmax; k++)
 			{
 				f = 0.0f;
@@ -269,7 +268,7 @@ iImageComposerWindow::~iImageComposerWindow()
 {
 	while(mZoomTargets.Size() > 0)
 	{
-		mZoomTargets.Last()->SetZoomSource(0);
+		mZoomTargets[mZoomTargets.MaxIndex()]->SetZoomSource(0);
 	}
 }
 
@@ -285,7 +284,6 @@ void iImageComposerWindow::SetViewModule(iViewModule *vm, int win)
 		mViewModules[0] = vm;
 		if(vm == 0) mViewModules[1] = mViewModules[2] = 0;
 	}
-	mComposer->ClearCache();
 }
 
 
@@ -293,14 +291,14 @@ void iImageComposerWindow::UpdateWindow()
 {
 	int j, k;
 	bool present;
-	iControlModule *cm = this->GetImageComposer()->GetControlModule();
+	iShell *s = this->GetImageComposer()->GetShell();
 
 	for(j=0; j<3; j++) if(mViewModules[j] != 0)
 	{
 		present = false;
-		for(k=0; !present && k<cm->GetNumberOfViewModules(); k++)
+		for(k=0; !present && k<s->GetNumberOfViewModules(); k++)
 		{
-			if(mViewModules[j] == cm->GetViewModule(k)) present = true;
+			if(mViewModules[j] == s->GetViewModule(k)) present = true;
 		}
 		if(!present) this->SetViewModule(0,j);
 	}
@@ -314,28 +312,28 @@ int iImageComposerWindow::GetWindowNumber(int win) const
 }
 
 	
-void iImageComposerWindow::RenderStereoImage(iStereoImage &im) const
+bool iImageComposerWindow::RenderStereoImage(iStereoImage &im) const
 {
+	iMonitor h(this->GetImageComposer());
+
 	if(mViewModules[0] == 0)
 	{
-		mComposer->GetErrorStatus()->Set("Unable to render image: ViewModule is not set.");
-		return;
+		h.PostError("Unable to render image: ViewModule is not set.");
+		return false;
 	}
 
 	if(mViewModules[1]!=0 || mViewModules[2]!=0)
 	{
 		iStereoImage imRed, imGreen, imBlue;
-		mComposer->GetErrorStatus()->Monitor(mViewModules[0]->GetErrorStatus(),true);
 		mViewModules[0]->RenderStereoImage(imRed);
-		if(mComposer->GetErrorStatus()->IsError()) return;
+		if(h.IsStopped()) return false;
 
 		im.SetStereo(imRed.IsStereo());
 
 		if(mViewModules[1] != 0)
 		{
-			mComposer->GetErrorStatus()->Monitor(mViewModules[1]->GetErrorStatus(),true);
 			mViewModules[1]->RenderStereoImage(imGreen);
-			if(mComposer->GetErrorStatus()->IsError()) return;
+			if(h.IsStopped()) return false;
 			if(imRed.Width()!=imGreen.Width() || imRed.Height()!=imGreen.Height())
 			{
 				imGreen.SetStereo(imRed.IsStereo());
@@ -344,9 +342,8 @@ void iImageComposerWindow::RenderStereoImage(iStereoImage &im) const
 		}
 		if(mViewModules[2] != 0)
 		{
-			mComposer->GetErrorStatus()->Monitor(mViewModules[2]->GetErrorStatus(),true);
 			mViewModules[2]->RenderStereoImage(imBlue);
-			if(mComposer->GetErrorStatus()->IsError()) return;
+			if(h.IsStopped()) return false;
 			if(imRed.Width()!=imBlue.Width() || imRed.Height()!=imBlue.Height())
 			{
 				imBlue.SetStereo(imRed.IsStereo());
@@ -355,13 +352,15 @@ void iImageComposerWindow::RenderStereoImage(iStereoImage &im) const
 		}
 		if(!im.CombineInPseudoColor(imRed,imGreen,imBlue))
 		{
-			mComposer->GetErrorStatus()->Set("Unable to render image: error in pseudo-color composting."); 
+			h.PostError("Unable to render image: error in pseudo-color composting.");
+			return false;
 		}
+		else return true;
 	}
 	else
 	{
-		mComposer->GetErrorStatus()->Monitor(mViewModules[0]->GetErrorStatus());
 		mViewModules[0]->RenderStereoImage(im);
+		return !h.IsStopped();
 	}
 }
 
@@ -512,7 +511,7 @@ int iImageComposerBackgroundWindow::GetId() const
 	}
 	else
 	{
-		IERROR_LOW("Invalid id for a background window.");
+		IBUG_WARN("Invalid id for a background window.");
 		return 0;
 	}
 }
@@ -600,9 +599,7 @@ void iImageComposerBackgroundWindow::Draw(iStereoImage &outIm) const
 		//
 		//  Render the image
 		//
-		this->RenderStereoImage(winIm);
-		if(mComposer->GetErrorStatus()->IsError()) return;
-		this->OverlayImage(outIm,winIm,mEmptyBackground);
+		if(this->RenderStereoImage(winIm)) this->OverlayImage(outIm,winIm,mEmptyBackground);
 	}
 	else
 	{
@@ -621,7 +618,6 @@ bool iImageComposerBackgroundWindow::LoadWallpaperImage(const iString &s)
 			mWallpaperImage.Clear();
 			mWallpaperFile.Clear();
 			mComposer->UpdateSize();
-			mComposer->ClearCache();
 			return true;
 		}
 		else
@@ -631,7 +627,6 @@ bool iImageComposerBackgroundWindow::LoadWallpaperImage(const iString &s)
 			{
 				mWallpaperFile = s;
 				mComposer->UpdateSize();
-				mComposer->ClearCache();
 			}
 			return ret;
 		}
@@ -681,7 +676,7 @@ int iImageComposerForegroundWindow::GetId() const
 	}
 	else
 	{
-		IERROR_LOW("Invalid id for a foreground window.");
+		IBUG_WARN("Invalid id for a foreground window.");
 		return 0;
 	}
 }
@@ -725,13 +720,13 @@ int iImageComposerForegroundWindow::GetContentsY() const
 
 int iImageComposerForegroundWindow::GetContentsWidth() const
 {
-	return round(mScale*this->GetWindowWidth());
+	return iMath::Round2Int(mScale*this->GetWindowWidth());
 }
 
 
 int iImageComposerForegroundWindow::GetContentsHeight() const
 {
-	return round(mScale*this->GetWindowHeight());
+	return iMath::Round2Int(mScale*this->GetWindowHeight());
 }
 
 
@@ -764,9 +759,11 @@ void iImageComposerForegroundWindow::Draw(iStereoImage &outIm) const
 {
 	if(this->GetViewModule() != 0)
 	{
+		iMonitor h(this->GetImageComposer());
 		iStereoImage winIm;
+
 		this->RenderStereoImage(winIm);
-		if(mComposer->GetErrorStatus()->IsError()) return;
+		if(h.IsStopped()) return;
 		//
 		// Draw zoom first
 		//
@@ -775,10 +772,10 @@ void iImageComposerForegroundWindow::Draw(iStereoImage &outIm) const
 			int bw = this->GetBorderWidth();
 			iColor bc(this->GetBorderColor());
 
-			int zx1 = round(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()-0.5*this->GetZoomWidth()));
-			int zy1 = round(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()-0.5*this->GetZoomHeight()));
-			int zx2 = round(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()+0.5*this->GetZoomWidth()));
-			int zy2 = round(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()+0.5*this->GetZoomHeight()));
+			int zx1 = iMath::Round2Int(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()-0.5*this->GetZoomWidth()));
+			int zy1 = iMath::Round2Int(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()-0.5*this->GetZoomHeight()));
+			int zx2 = iMath::Round2Int(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()+0.5*this->GetZoomWidth()));
+			int zy2 = iMath::Round2Int(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()+0.5*this->GetZoomHeight()));
 
 			int i;
 			for(i=0; i<bw; i++)
@@ -813,7 +810,6 @@ void iImageComposerForegroundWindow::SetScale(float s)
 	{
 		mScale = s;
 		this->CorrectPosition();
-		mComposer->ClearCache();
 	}
 }
 
@@ -828,7 +824,6 @@ void iImageComposerForegroundWindow::SetPosition(int x, int y)
 		if(x+this->GetImageWidth() < mComposer->GetImageWidth()) mPosX = mPosQuantum*(x/mPosQuantum); else mPosX = x;
 		if(y+this->GetImageHeight() < mComposer->GetImageHeight()) mPosY = mPosQuantum*(y/mPosQuantum); else mPosY = y;
 		this->CorrectPosition();
-		mComposer->ClearCache();
 	}
 }
 
@@ -839,7 +834,6 @@ void iImageComposerForegroundWindow::SetBorderWidth(int w)
 	{
 		mBorderWidth = w;
 		this->CorrectPosition();
-		mComposer->ClearCache();
 	}
 }
 
@@ -849,7 +843,6 @@ void iImageComposerForegroundWindow::SetBorderColor(const iColor& c)
 	if(c != mBorderColor)
 	{
 		mBorderColor = c;
-		mComposer->ClearCache();
 	}
 }
 
@@ -868,13 +861,13 @@ void iImageComposerForegroundWindow::CorrectPosition()
 	if(this->GetImageWidth() > mComposer->GetImageWidth())
 	{
 		mPosX = 0;
-		mScale = (float)(mComposer->GetImageWidth()-2*mBorderWidth)/this->GetWindowWidth();
+		mScale = float(mComposer->GetImageWidth()-2*mBorderWidth)/this->GetWindowWidth();
 	}
 		
 	if(this->GetImageHeight() > mComposer->GetImageHeight()) 
 	{
 		mPosY = 0;
-		mScale = (float)(mComposer->GetImageHeight()-2*mBorderWidth)/this->GetWindowHeight();
+		mScale = float(mComposer->GetImageHeight()-2*mBorderWidth)/this->GetWindowHeight();
 	}		
 	//
 	//  Now we are guaranteed to fit into the image. But are we fully inside?
@@ -895,7 +888,6 @@ void iImageComposerForegroundWindow::SetZoomSource(iImageComposerWindow *source)
 		if(source != 0) source->RegisterZoomTarget(this);
 		this->UpdateZoomPosition();
 		this->UpdateZoomFlag();
-		mComposer->ClearCache();
 	}
 }
 
@@ -906,7 +898,6 @@ void iImageComposerForegroundWindow::SetZoomPosition(float x, float y)
 	{
 		mZoomX = x;
 		mZoomY = y;
-		mComposer->ClearCache();
 		if(mZoomSource != 0) this->UpdateZoomPosition();
 	}
 }
@@ -917,7 +908,6 @@ void iImageComposerForegroundWindow::SetZoomFactor(float factor)
 	if(factor>0.0f && factor<1.0f && fabs(factor-mZoomFactor)>1.0e-5)
 	{
 		mZoomFactor = factor;
-		mComposer->ClearCache();
 		if(mZoomSource != 0) this->UpdateZoomPosition();
 	}
 }
@@ -984,10 +974,10 @@ void iImageComposerForegroundWindow::UpdateZoomFlag()
 	bool ok;
 	int i, j, s, d, pz[4][2], pw[4][2], n[2];
 
-	pz[0][0] = pz[2][0] = round(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()-0.5*this->GetZoomWidth()));
-	pz[1][0] = pz[3][0] = round(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()+0.5*this->GetZoomWidth()));
-	pz[0][1] = pz[1][1] = round(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()-0.5*this->GetZoomHeight()));
-	pz[2][1] = pz[3][1] = round(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()+0.5*this->GetZoomHeight()));
+	pz[0][0] = pz[2][0] = iMath::Round2Int(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()-0.5*this->GetZoomWidth()));
+	pz[1][0] = pz[3][0] = iMath::Round2Int(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()+0.5*this->GetZoomWidth()));
+	pz[0][1] = pz[1][1] = iMath::Round2Int(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()-0.5*this->GetZoomHeight()));
+	pz[2][1] = pz[3][1] = iMath::Round2Int(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()+0.5*this->GetZoomHeight()));
 
 	pw[0][0] = pw[2][0] = mPosX;
 	pw[1][0] = pw[3][0] = mPosX + this->GetImageWidth() - 1;
