@@ -89,14 +89,14 @@ protected:
 	//
 	//  Helper functions
 	//
-	void RenderStereoImage(iStereoImage &winIm) const;
+	bool RenderStereoImage(iStereoImage &winIm) const;
 	void OverlayImage(iStereoImage &outIm, const iStereoImage &winIm, const iColor &bg) const;
 
 	iViewModule *mViewModules[3];
 	iImageComposer *mComposer;
 	iImageComposerWindowType mType;
 
-	iSearchableArray<iImageComposerForegroundWindow*> mZoomTargets;
+	iLookupArray<iImageComposerForegroundWindow*> mZoomTargets;
 };
 
 
@@ -183,7 +183,7 @@ public:
 	inline int GetPositionX() const { return mPosX; }
 	inline int GetPositionY() const { return mPosY; }
 	inline int GetBorderWidth() const { return mBorderWidth; }
-	inline iColor GetBorderColor() const { return mBorderColor; }
+	inline const iColor& GetBorderColor() const { return mBorderColor; }
 	
 	void SetScale(float s);
 	void SetPosition(int x, int y);
