@@ -42,13 +42,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
-#include "igenericproptemplate.h"
+#include "iarray.tlh"
+#include "igenericprop.tlh"
 
 
 iLegend* iLegend::New(iRenderTool *rv)
 {
-	IERROR_ASSERT(rv);
+	IASSERT(rv);
 	return new iLegend(rv);
 }
 
