@@ -32,15 +32,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iLineToBandFilter::iLineToBandFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkRuledSurfaceFilter>(vo,1,true,false)
+iLineToBandFilter::iLineToBandFilter(iDataConsumer *consumer) : iGenericPolyDataFilter<vtkRuledSurfaceFilter>(consumer,1,true)
 {
 }
 	
 
-void iLineToBandFilter::ProduceOutput()
+void iLineToBandFilter::ProvideOutput()
 {
 	this->ExecuteParent();
 }
