@@ -34,14 +34,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkRuledSurfaceFilter.h>
 
 
-class iLineToBandFilter : public iGenericPolyDataToPolyDataFilter<vtkRuledSurfaceFilter>
+class iLineToBandFilter : public iGenericPolyDataFilter<vtkRuledSurfaceFilter>
 {
 	
-	IGENERICFILTER_DECLARE(iLineToBandFilter,vtkRuledSurfaceFilter);
+	iGenericFilterTypeMacro(iLineToBandFilter,vtkRuledSurfaceFilter);
 	
 protected:
 
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 };
 
 #endif // ILINETOBANDFILTER_H
