@@ -39,18 +39,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iLineToTubeFilter::iLineToTubeFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkTubeFilter>(vo,1,true,false)
+iLineToTubeFilter::iLineToTubeFilter(iDataConsumer *consumer) : iGenericPolyDataFilter<vtkTubeFilter>(consumer,1,true)
 {
 }
 	
 
-void iLineToTubeFilter::ProduceOutput()
+void iLineToTubeFilter::ProvideOutput()
 {
-	vtkPolyData *input = vtkPolyData::SafeDownCast(this->GetInput());
-	vtkPolyData *output = this->GetOutput();
+	vtkPolyData *input = this->InputData();
+	vtkPolyData *output = this->OutputData();
 
 	//
 	//  The code between === lines is copied from vtkTubeFilter.cxx file with minor modifications, as marked behind /// comments
@@ -205,7 +205,9 @@ void iLineToTubeFilter::ProduceOutput()
 
 		if (npts < 2)
 		{
-			vtkWarningMacro(<< "Less than two points in line!");
+			/// ------ Removed ------------------------------------------
+			/// vtkWarningMacro(<< "Less than two points in line!");
+			/// ---------------------------------------------------------
 			continue; //skip tubing this polyline
 		}
 
