@@ -32,7 +32,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "imath.h"
 #include "ipalette.h"
-#include "ipaletteset.h"
+#include "ipalettecollection.h"
+#include "istretch.h"
 
 #include <vtkMath.h>
 
@@ -98,11 +99,11 @@ void iLookupTable::SetColor(const iColor &c)
 }
 
 
-void iLookupTable::OnStretchChanged()
+void iLookupTable::SetStretchId(int s)
 {
-	switch(this->GetStretch())
+	switch(s)
 	{
-	case iDataStretch::Log:
+	case iStretch::Log:
 		{
 			if(this->TableRange[0] < 1*iMath::_DoubleRes) this->TableRange[0] = 1*iMath::_DoubleRes;
 			if(this->TableRange[1] < 2*iMath::_DoubleRes) this->TableRange[1] = 2*iMath::_DoubleRes;
@@ -120,7 +121,7 @@ void iLookupTable::OnStretchChanged()
 
 void iLookupTable::ForceBuild()
 {
-	vtkLookupTable *lut = iPaletteSet::Default()->GetLookupTable(mPaletteId);
+	vtkLookupTable *lut = iPaletteCollection::Global()->GetLookupTable(mPaletteId);
 
 	if(lut != 0)
 	{
@@ -136,6 +137,18 @@ void iLookupTable::ForceBuild()
 }
 
 
+unsigned long iLookupTable::GetMTime()
+{
+	vtkLookupTable *lut = iPaletteCollection::Global()->GetLookupTable(mPaletteId);
+	if(lut != 0)
+	{
+		if(lut->GetMTime() > this->vtkObject::GetMTime()) this->Modified();
+	}
+
+	return this->vtkObject::GetMTime();
+}
+
+
 void iLookupTable::MapScalarsThroughTable2(void *input, unsigned char *output, int inputDataType, int numberOfValues, int inputIncrement, int outputFormat)
 {
 	//
