@@ -31,25 +31,26 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkLookupTable.h>
-#include "idatastretch.h"
 
 
 class iColor;
 
 
-class iLookupTable : public vtkLookupTable, public iDataStretchUser
+class iLookupTable : public vtkLookupTable
 {
 
 public:
 
 	static iLookupTable* New();
 
+	void SetStretchId(int s);
 	void SetPaletteId(int n);
 	void SetReversed(bool s);
 	void SetColor(const iColor &c);
-	
+
 	virtual void ForceBuild();
 
+	virtual unsigned long GetMTime(); 
 	virtual void MapScalarsThroughTable2(void *input, unsigned char *output, int inputDataType, int numberOfValues, int inputIncrement, int outputFormat);
 
 protected:
@@ -60,8 +61,6 @@ private:
 
 	iLookupTable();
 
-	virtual void OnStretchChanged();
-
 	int mPaletteId;
 };
 
