@@ -31,6 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ierror.h"
 #include "itransform.h"
+#include "ivtk.h"
 
 #include <vtkCamera.h>
 #include <vtkImageData.h>
@@ -64,7 +65,7 @@ int iMagnifier::ProcessRequest(vtkInformation* request, vtkInformationVector** i
 	// generate the data
 	if(request->Has(vtkDemandDrivenPipeline::REQUEST_DATA()))
 	{
-		this->RequestMyData(request, inputVector, outputVector);
+		this->RequestData(request, inputVector, outputVector);
 		return 1;
 	}
 
@@ -78,12 +79,18 @@ int iMagnifier::ProcessRequest(vtkInformation* request, vtkInformationVector** i
 	return this->Superclass::ProcessRequest(request, inputVector, outputVector);
 }
 
-void iMagnifier::RequestMyData(vtkInformation *, vtkInformationVector **, vtkInformationVector* outputVector)
+
+void iMagnifier::RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector* outputVector)
 {
 	vtkInformation *outInfo = outputVector->GetInformationObject(0);
 	vtkImageData *data = vtkImageData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 	data->SetExtent(outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT()));
+
+#ifdef IVTK_5
 	data->AllocateScalars();
+#else
+	data->AllocateScalars(outInfo);
+#endif
 
 	this->Render(data);
 }
@@ -129,7 +136,7 @@ void iMagnifier::Render(vtkImageData *data)
 	}
 
 	// Get the requested extents.
-	this->GetOutput()->GetUpdateExtent(inExtent);
+	this->GetOutput()->GetExtent(inExtent);
 
 	// get and transform the increments
 	data->GetIncrements(inIncr);
