@@ -49,7 +49,7 @@ public:
 
 protected:
 
-	void RequestMyData(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
+	void RequestData(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
 
 	virtual ~iMagnifier();
 
