@@ -32,15 +32,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "igenericprop.h"
 #include "iactor.h"
+#include "iviewmoduletool.h"
 
 
-#include "ipointermacro.h"
-
 #include <vtkProperty.h>
 
 class iColor;
+class iMeasuringBox;
 class iTextActor;
-class iViewModule;
 
 class vtkCommand;
 class vtkCubeSource;
@@ -48,15 +47,14 @@ class vtkInteractorStyle;
 class vtkPolyDataMapper;
 
 
-class iMeasuringBox : public iGenericProp<iActor>
+class iMeasuringBoxActor : public iGenericProp<iActor>, public iViewModuleComponent
 {
 	
-	IPOINTER_AS_PART(ViewModule);
+	friend class iMeasuringBox;
 
 public:
 	
-	vtkTypeMacro(iMeasuringBox,iActor);
-	static iMeasuringBox* New(iViewModule *vm = 0);
+	vtkTypeMacro(iMeasuringBoxActor,iActor);
 	
 	void AttachToInteractorStyle(vtkInteractorStyle *s);
 
@@ -72,13 +70,13 @@ public:
 
 protected:
 	
-	virtual ~iMeasuringBox();
+	virtual ~iMeasuringBoxActor();
 	
 	virtual void UpdateGeometry(vtkViewport *vp);
 
 private:
 
-	iMeasuringBox(iViewModule *vm);
+	iMeasuringBoxActor(iViewModule *vm);
 
 	iTextActor *mText;
 	iActor *mFrameActor, *mBoxActor, *mWorkerActor;
@@ -91,4 +89,31 @@ private:
 
 };
 
+
+class iMeasuringBox : public iViewModuleTool
+{
+	
+public:
+
+	vtkTypeMacro(iMeasuringBox,iViewModuleTool);
+	static iMeasuringBox* New(iViewModule *vm = 0);
+		
+	inline iMeasuringBoxActor* GetActor() const { return mActor; }
+
+protected:
+
+	virtual ~iMeasuringBox();
+
+private:
+	
+	iMeasuringBox(iViewModule *vm, const iString &fname, const iString &sname);
+
+	virtual bool ShowBody(bool s);
+
+	//
+	//  Actors displayed by this class
+	//
+	iMeasuringBoxActor *mActor;
+};
+
 #endif // IMEASURINGBOX_H
