@@ -43,24 +43,32 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iMergeDataFilter::iMergeDataFilter(iViewSubject *vo) : iGenericFilter<vtkDataSetToDataSetFilter,vtkDataSet,vtkDataSet>(vo,1,false,false)
+iMergeDataFilter::iMergeDataFilter(iDataConsumer *consumer) : iGenericFilter<vtkDataSetAlgorithm,vtkDataSet,vtkDataSet>(consumer,2,false)
 {
-	mDataRank = 0;
-	mDataInput = 0;
+	mRank = 0;
 }
 
 
-void iMergeDataFilter::SetDataInput(int rank, vtkDataSet *input)
+int iMergeDataFilter::FillInputPortInformation(int port, vtkInformation* info)
 {
-	if(rank>=0 && rank<3 && input!=0)
+	if(port == 1)
 	{
-		mDataRank = rank;
-		mDataInput = input;
-		this->SetNumberOfInputPorts(2);
-	    this->SetInputConnection(1,input->GetProducerPort());
+		info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(),"vtkDataSet");
+		info->Set(vtkAlgorithm::INPUT_IS_OPTIONAL(),1);
+		return 1;
+	}
+	else return this->iGenericFilter<vtkDataSetAlgorithm,vtkDataSet,vtkDataSet>::FillInputPortInformation(port,info);
+}
+
+
+void iMergeDataFilter::SetRank(int rank)
+{
+	if(rank>=0 && rank<3)
+	{
+		mRank = rank;
 	}
 }
 
@@ -70,39 +78,41 @@ bool iMergeDataFilter::HasData(int rank)
 	if(rank>=0 && rank<3)
 	{
 		this->Update();
+
+		IASSERT(this->OutputData()); 
+		vtkPointData *pd = this->OutputData()->GetPointData();
+		if(pd == 0) return false;
 		switch(rank)
 		{
-		case 0:	return (this->GetOutput()->GetPointData()->GetScalars()!=0 && this->GetOutput()->GetPointData()->GetScalars()->GetNumberOfTuples()>0);
-		case 1: return (this->GetOutput()->GetPointData()->GetVectors()!=0 && this->GetOutput()->GetPointData()->GetVectors()->GetNumberOfTuples()>0);
-		case 2: return (this->GetOutput()->GetPointData()->GetTensors()!=0 && this->GetOutput()->GetPointData()->GetTensors()->GetNumberOfTuples()>0);
+		case 0:	return (pd->GetScalars()!=0 && pd->GetScalars()->GetNumberOfTuples()>0);
+		case 1: return (pd->GetVectors()!=0 && pd->GetVectors()->GetNumberOfTuples()>0);
+		case 2: return (pd->GetTensors()!=0 && pd->GetTensors()->GetNumberOfTuples()>0);
 		}
 	}
 	return false;
 }
 
 
-void iMergeDataFilter::InitExecution()
+void iMergeDataFilter::ProvideInfo()
 {
-	vtkDataSet *input = this->GetInput();
-	vtkDataSet *output = this->GetOutput();
+	vtkInformation* inInfo = wCache.InputVector[0]->GetInformationObject(0);
+	vtkInformation* outInfo = wCache.OutputVector->GetInformationObject(0);
 
-	output->SetWholeExtent(input->GetWholeExtent());  // God only knows why these two are needed,
-	output->SetUpdateExtent(input->GetUpdateExtent()); // but it took me a lot of debugging to find out they must be here
-	if(mDataInput != 0) mDataInput->SetUpdateExtentToWholeExtent();
+	outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()),6);
+	//outInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(),inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT()),6);
 
-    if(mSavedOutputVector != 0)
+	inInfo = wCache.InputVector[1]->GetInformationObject(0);
+	if(inInfo != 0)
 	{
-		vtkInformation* outInfo = mSavedOutputVector->GetInformationObject(0);
-		outInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(),1);
-		outInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(),0);
+		//inInfo->Set(vtkStreamingDemandDrivenPipeline::EXACT_EXTENT(),1);
 	}
 }
 
 
-void iMergeDataFilter::ProduceOutput()
+void iMergeDataFilter::ProvideOutput()
 {
-	vtkDataSet *input = this->GetInput();
-	vtkDataSet *output = this->GetOutput();
+	vtkDataSet *input = this->InputData();
+	vtkDataSet *output = this->OutputData();
 
 	vtkPointData *pd = input->GetPointData();
 	if(pd == 0)
@@ -113,29 +123,29 @@ void iMergeDataFilter::ProduceOutput()
 
 	output->ShallowCopy(input);
 
-	switch(mDataRank)
+	switch(mRank)
 	{
 	case 0:
 		{
-			if(this->AreDataSetsCompatible(input,this->GetDataInput()) && this->GetDataInput()->GetPointData()->GetScalars()!=0)
+			if(this->AreDataSetsCompatible(input,this->InputData(1)) && this->InputData(1)->GetPointData()->GetScalars()!=0)
 			{
-				output->GetPointData()->SetScalars(this->GetDataInput()->GetPointData()->GetScalars());
+				output->GetPointData()->SetScalars(this->InputData(1)->GetPointData()->GetScalars());
 			}
 			break;
 		}
 	case 1:
 		{
-			if(this->AreDataSetsCompatible(input,this->GetDataInput()) && this->GetDataInput()->GetPointData()->GetVectors()!=0)
+			if(this->AreDataSetsCompatible(input,this->InputData(1)) && this->InputData(1)->GetPointData()->GetVectors()!=0)
 			{
-				output->GetPointData()->SetVectors(this->GetDataInput()->GetPointData()->GetVectors());
+				output->GetPointData()->SetVectors(this->InputData(1)->GetPointData()->GetVectors());
 			}
 			break;
 		}
 	case 2:
 		{
-			if(this->AreDataSetsCompatible(input,this->GetDataInput()) && this->GetDataInput()->GetPointData()->GetTensors()!=0)
+			if(this->AreDataSetsCompatible(input,this->InputData(1)) && this->InputData(1)->GetPointData()->GetTensors()!=0)
 			{
-				output->GetPointData()->SetTensors(this->GetDataInput()->GetPointData()->GetTensors());
+				output->GetPointData()->SetTensors(this->InputData(1)->GetPointData()->GetTensors());
 			}
 			break;
 		}
