@@ -31,31 +31,35 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "igenericfilter.h"
-#include <vtkDataSetToDataSetFilter.h>
+#include <vtkDataSetAlgorithm.h>
 
 
-class iMergeDataFilter : public iGenericFilter<vtkDataSetToDataSetFilter,vtkDataSet,vtkDataSet>
+class vtkDataSet;
+
+
+class iMergeDataFilter : public iGenericFilter<vtkDataSetAlgorithm,vtkDataSet,vtkDataSet>
 {
 
-	IGENERICFILTER_DECLARE(iMergeDataFilter,vtkDataSetToDataSetFilter);
+	iGenericFilterTypeMacro(iMergeDataFilter,vtkDataSetAlgorithm);
 	
 public:
 
-	inline vtkDataSet* GetDataInput(){ return mDataInput; }
-	void SetDataInput(int rank, vtkDataSet *input);
+	inline int GetRank() const { return mRank; }
+	void SetRank(int rank);
 	bool HasData(int rank);
 
 protected:
 	
-	virtual void InitExecution();
-	virtual void ProduceOutput();
+	int FillInputPortInformation(int port, vtkInformation* info);
+
+	virtual void ProvideInfo();
+	virtual void ProvideOutput();
 
 private:
 
 	bool AreDataSetsCompatible(vtkDataSet *ds1, vtkDataSet *ds2) const;
 
-	int mDataRank;
-	vtkDataSet *mDataInput;
+	int mRank;
 };
 
 #endif
