@@ -32,16 +32,30 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iOptimizePolyDataFilter::iOptimizePolyDataFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkStripper>(vo,1,true,false)
+iOptimizePolyDataFilter::iOptimizePolyDataFilter(iDataConsumer *consumer) : iGenericPolyDataFilter<vtkStripper>(consumer,1,true)
 {
+	mEnabled = true;
 }
 	
 
-void iOptimizePolyDataFilter::ProduceOutput()
+void iOptimizePolyDataFilter::SetEnabled(bool s)
 {
-	this->ExecuteParent();
+	mEnabled = s;
+}
+
+
+void iOptimizePolyDataFilter::ProvideOutput()
+{
+	if(mEnabled)
+	{
+		this->ExecuteParent();
+	}
+	else
+	{
+		this->OutputData()->ShallowCopy(this->InputData());
+	}
 }
 
