@@ -34,14 +34,21 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkStripper.h>
 
 
-class iOptimizePolyDataFilter : public iGenericPolyDataToPolyDataFilter<vtkStripper>
+class iOptimizePolyDataFilter : public iGenericPolyDataFilter<vtkStripper>
 {
 	
-	IGENERICFILTER_DECLARE(iOptimizePolyDataFilter,vtkStripper);
+	iGenericFilterTypeMacro(iOptimizePolyDataFilter,vtkStripper);
 	
+public:
+
+	void SetEnabled(bool s);
+	inline bool GetEnabled() const { return mEnabled; }
+
 protected:
 	
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
+
+	bool mEnabled;
 };
 
 #endif // IOPTIMIZEPOLYDATAFILTER_H
