@@ -36,14 +36,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkCellArray.h>
 #include <vtkCellData.h>
 #include <vtkFloatArray.h>
+#include <vtkImageData.h>
 #include <vtkPointData.h>
 #include <vtkPolyData.h>
-#include <vtkStructuredPoints.h>
 
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
 #ifndef IVTK_QUAD_ORDER
@@ -52,7 +52,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 
 
-iOrthoPolygonPlaneFilter::iOrthoPolygonPlaneFilter(iViewSubject *vo) : iGenericFilter<vtkStructuredPointsToPolyDataFilter,vtkImageData,vtkPolyData>(vo,1,true,false)
+iOrthoPolygonPlaneFilter::iOrthoPolygonPlaneFilter(iDataConsumer *consumer) : iGenericFilter<vtkDataSetAlgorithm,vtkImageData,vtkPolyData>(consumer,1,true)
 {
 	mInterpolate = true;
 
@@ -61,7 +61,7 @@ iOrthoPolygonPlaneFilter::iOrthoPolygonPlaneFilter(iViewSubject *vo) : iGenericF
 	//
 	//  Keep our quds so that we do not have to re-create them unless something changes
 	//
-	mNewQuads = vtkCellArray::New(); IERROR_ASSERT(mNewQuads);
+	mNewQuads = vtkCellArray::New(); IERROR_CHECK_MEMORY(mNewQuads);
 }
 
 
@@ -78,13 +78,13 @@ void iOrthoPolygonPlaneFilter::SetInterpolation(bool s)
 }
 
 
-void iOrthoPolygonPlaneFilter::ProduceOutput()
+void iOrthoPolygonPlaneFilter::ProvideOutput()
 {
 	int dims[3];
 	double org[3], spa[3];
 
-	vtkImageData *input = this->GetInput();
-	vtkPolyData *output = this->GetOutput();
+	vtkImageData *input = this->InputData();
+	vtkPolyData *output = this->OutputData();
 
 	output->Initialize();
 
@@ -143,7 +143,7 @@ void iOrthoPolygonPlaneFilter::ProduceOutput()
 	}
 
 	vtkIdType numPts = (vtkIdType)dimU*dimV;
-    vtkPoints *newPts = vtkPoints::New(VTK_FLOAT); IERROR_ASSERT(newPts);
+    vtkPoints *newPts = vtkPoints::New(VTK_FLOAT); IERROR_CHECK_MEMORY(newPts);
     newPts->SetNumberOfPoints(numPts);
     
 	float xyz[3];
@@ -165,7 +165,7 @@ void iOrthoPolygonPlaneFilter::ProduceOutput()
 	if(dimU!=mOldDimU || dimV!=mOldDimV) 
 	{
 		mNewQuads->Delete();
-		mNewQuads = vtkCellArray::New(); IERROR_ASSERT(mNewQuads);
+		mNewQuads = vtkCellArray::New(); IERROR_CHECK_MEMORY(mNewQuads);
 		mNewQuads->Allocate(mNewQuads->EstimateSize((dimV-1)*(dimU-1),4));
 		vtkIdType l[4];
 		for(j=0; j<dimV-1; j++)
@@ -209,25 +209,30 @@ void iOrthoPolygonPlaneFilter::ProduceOutput()
 			//
 			//  Correct for flat shading
 			//
-			if(!this->ScalarsInit(input->GetPointData())) return;
+			if(!wArray.Init(input->GetPointData()->GetScalars()))
+			{
+				this->SetAbortExecute(1);
+				return;
+			}
 
 			float *pl, *ql;
 			for(j=0; j<dimV-1; j++)
 			{
-				pl = wScalarPtrIn + wScalarDimIn*j*dimU;
-				ql = wScalarPtrOut + wScalarDimOut*j*dimU;
+				pl = wArray.PtrIn + wArray.DimIn*j*dimU;
+				ql = wArray.PtrOut + wArray.DimOut*j*dimU;
 				for(i=0; i<dimU-1; i++)
 				{
-					for(k=0; k<wScalarDimIn; k++)
+					for(k=0; k<wArray.DimIn; k++)
 					{
-						ql[k] = 0.25*(pl[k]+pl[wScalarDimIn+k]+pl[wScalarDimIn*dimU+k]+pl[wScalarDimIn*(dimU+1)+k]);
+						ql[k] = 0.25*(pl[k]+pl[wArray.DimIn+k]+pl[wArray.DimIn*dimU+k]+pl[wArray.DimIn*(dimU+1)+k]);
 					}
-					pl += wScalarDimIn;
-					ql += wScalarDimOut;
+					pl += wArray.DimIn;
+					ql += wArray.DimOut;
 				}
 			}
 
-			this->ScalarsDone(output->GetPointData());
+			output->GetPointData()->SetScalars(wArray.ArrOut);
+			wArray.ArrOut->Delete();
 		}
 		else
 		{
@@ -236,7 +241,11 @@ void iOrthoPolygonPlaneFilter::ProduceOutput()
 	}
 	else
 	{
-		if(!this->ScalarsInit(input->GetCellData(),numPts)) return;
+		if(!wArray.Init(input->GetCellData()->GetScalars(),numPts))
+		{
+			this->SetAbortExecute(1);
+			return;
+		}
 
 		int du = dimU - 1;
 
@@ -250,18 +259,18 @@ void iOrthoPolygonPlaneFilter::ProduceOutput()
 				if(j1 == dimV-1) j1 = dimV - 2;
 				j2 = j - 1;
 				if(j2 < 0) j2 = 0;
-				ql = wScalarPtrOut + wScalarDimOut*j*dimU;
+				ql = wArray.PtrOut + wArray.DimOut*j*dimU;
 				for(i=0; i<dimU; i++)
 				{
 					i1 = i;
 					if(i1 == du) i1 = du - 1;
 					i2 = i - 1;
 					if(i2 < 0) i2 = 0;
-					for(k=0; k<wScalarDimIn; k++)
+					for(k=0; k<wArray.DimIn; k++)
 					{
-						ql[k] = 0.25f*(wScalarPtrIn[k+wScalarDimIn*(i1+j1*du)]+wScalarPtrIn[k+wScalarDimIn*(i2+j1*du)]+wScalarPtrIn[k+wScalarDimIn*(i1+j2*du)]+wScalarPtrIn[k+wScalarDimIn*(i2+j2*du)]);
+						ql[k] = 0.25f*(wArray.PtrIn[k+wArray.DimIn*(i1+j1*du)]+wArray.PtrIn[k+wArray.DimIn*(i2+j1*du)]+wArray.PtrIn[k+wArray.DimIn*(i1+j2*du)]+wArray.PtrIn[k+wArray.DimIn*(i2+j2*du)]);
 					}
-					ql += wScalarDimOut;
+					ql += wArray.DimOut;
 				}
 			}
 		}
@@ -270,21 +279,22 @@ void iOrthoPolygonPlaneFilter::ProduceOutput()
 			float *pl, *ql;
 			for(j=0; j<dimV-1; j++)
 			{
-				pl = wScalarPtrIn + wScalarDimIn*j*du;
-				ql = wScalarPtrOut + wScalarDimOut*j*dimU;
+				pl = wArray.PtrIn + wArray.DimIn*j*du;
+				ql = wArray.PtrOut + wArray.DimOut*j*dimU;
 				for(i=0; i<du; i++)
 				{
-					for(k=0; k<wScalarDimIn; k++)
+					for(k=0; k<wArray.DimIn; k++)
 					{
 						ql[k] = pl[k];
 					}
-					pl += wScalarDimIn;
-					ql += wScalarDimOut;
+					pl += wArray.DimIn;
+					ql += wArray.DimOut;
 				}
 			}
 		}
 
-		this->ScalarsDone(output->GetPointData());
+		output->GetPointData()->SetScalars(wArray.ArrOut);
+		wArray.ArrOut->Delete();
 	}
 }
 
