@@ -43,10 +43,10 @@ using namespace iParameter;
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iOrthoSlicer::iOrthoSlicer(iViewSubject *vo) : iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>(vo,1,true,false)
+iOrthoSlicer::iOrthoSlicer(iDataConsumer *consumer) : iGenericImageDataFilter<vtkImageAlgorithm>(consumer,1,true)
 {
 	mCurVar = 0;
 
@@ -99,7 +99,7 @@ void iOrthoSlicer::SetDir(int d)
 }
 
 
-void iOrthoSlicer::ProduceOutput()
+void iOrthoSlicer::ProvideOutput()
 {
     int numCellsIn[3], dimsIn[3], dimsOut[3];
     double orgIn[3], spaIn[3];
@@ -108,8 +108,8 @@ void iOrthoSlicer::ProduceOutput()
 
 	iOrthoSlicer::GetUV(mDir,u,v);
 
-	iUniformGridData *input = iUniformGridData::SafeDownCast(this->GetInput());
-	vtkImageData *output = this->GetOutput();
+	iUniformGridData *input = iUniformGridData::SafeDownCast(this->InputData());
+	vtkImageData *output = this->OutputData();
 
 	output->Initialize();
 
@@ -195,10 +195,10 @@ void iOrthoSlicer::ProduceOutput()
     ijk1[mDir] = ijk2[mDir] = int(ht); //Grid Point below
 	if(ijk2[mDir] < dimsIn[mDir]-1) ijk2[mDir]++;
 
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 	if(ijk1[mDir]<0 || ijk2[mDir]>=dimsIn[mDir])
 	{
-		IERROR_REPORT_BUG;
+		IBUG_WARN("Internal check failed.");
 	}
 #endif
 
@@ -213,14 +213,18 @@ void iOrthoSlicer::ProduceOutput()
 	//  Prepare output scalars
 	//
     vtkIdType numPts = dimsOut[u]*dimsOut[v];
-	if(!this->ScalarsInit(input->GetPointData(),numPts,1)) return;
+	if(!wArray.Init(input->GetPointData()->GetScalars(),numPts,1))
+	{
+		this->SetAbortExecute(1);
+		return;
+	}
 
-	wScalarPtrIn += mCurVar;
+	wArray.PtrIn += mCurVar;
 
 	vtkIdType loffOut, loffIn1, loffIn2;
 	for(ijk[v]=0; ijk[v]<dimsOut[v]; ijk[v]++)
 	{
-		this->UpdateProgress((float)ijk[v]/dimsOut[v]);
+		this->UpdateProgress(double(ijk[v])/dimsOut[v]);
 		if(this->GetAbortExecute()) break;
 
 		for(ijk[u]=0; ijk[u]<dimsOut[u]; ijk[u]++)
@@ -232,15 +236,15 @@ void iOrthoSlicer::ProduceOutput()
 			{
 				ijk1[u] = ijk[u]*step + step/2;
 				ijk1[v] = ijk[v]*step + step/2;
-				loffIn1 = wScalarDimIn*(ijk1[0]+(vtkIdType)dimsIn[0]*(ijk1[1]+(vtkIdType)dimsIn[1]*ijk1[2]));
+				loffIn1 = wArray.DimIn*(ijk1[0]+(vtkIdType)dimsIn[0]*(ijk1[1]+(vtkIdType)dimsIn[1]*ijk1[2]));
 				ijk2[u] = ijk1[u];
 				ijk2[v] = ijk1[v];
-				loffIn2 = wScalarDimIn*(ijk2[0]+(vtkIdType)dimsIn[0]*(ijk2[1]+(vtkIdType)dimsIn[1]*ijk2[2]));
+				loffIn2 = wArray.DimIn*(ijk2[0]+(vtkIdType)dimsIn[0]*(ijk2[1]+(vtkIdType)dimsIn[1]*ijk2[2]));
 //				for(j=0; j<wScalarDimOut; j++)
 //				{
 //					wScalarPtrOut[loffOut+j] = ss1*wScalarPtrIn[loffIn1+j] + ss2*wScalarPtrIn[loffIn2+j];
 //				}
-				wScalarPtrOut[loffOut] = ss1*wScalarPtrIn[loffIn1] + ss2*wScalarPtrIn[loffIn2];  //  wScalarDimOut = 1
+				wArray.PtrOut[loffOut] = ss1*wArray.PtrIn[loffIn1] + ss2*wArray.PtrIn[loffIn2];  //  wScalarDimOut = 1
 			}
 			else
 			{
@@ -248,30 +252,32 @@ void iOrthoSlicer::ProduceOutput()
 				{
 					ijk1[u] = ijk[u]*step + step/2;
 					ijk1[v] = ijk[v]*step + step/2;
-					loffIn1 = wScalarDimIn*(ijk1[0]+(vtkIdType)dimsIn[0]*(ijk1[1]+(vtkIdType)dimsIn[1]*ijk1[2]));
+					loffIn1 = wArray.DimIn*(ijk1[0]+(vtkIdType)dimsIn[0]*(ijk1[1]+(vtkIdType)dimsIn[1]*ijk1[2]));
 				}
 				else
 				{
 					ijk2[u] = ijk[u]*step + step/2;
 					ijk2[v] = ijk[v]*step + step/2;
-					loffIn1 = wScalarDimIn*(ijk2[0]+(vtkIdType)dimsIn[0]*(ijk2[1]+(vtkIdType)dimsIn[1]*ijk2[2]));
+					loffIn1 = wArray.DimIn*(ijk2[0]+(vtkIdType)dimsIn[0]*(ijk2[1]+(vtkIdType)dimsIn[1]*ijk2[2]));
 				}
 //				for(j=0; j<wScalarDimOut; j++)
 //				{
 //					wScalarPtrOut[loffOut+j] = wScalarPtrIn[loffIn1+j];
 //				}
-				wScalarPtrOut[loffOut] = wScalarPtrIn[loffIn1];  //  wScalarDimOut = 1
+				wArray.PtrOut[loffOut] = wArray.PtrIn[loffIn1];  //  wScalarDimOut = 1
 			}
 		}
     }
     
 	if(input->GetVoxelLocation() == VoxelLocation::Vertex)
 	{
-	    this->ScalarsDone(output->GetPointData());
+		output->GetPointData()->SetScalars(wArray.ArrOut);
+		wArray.ArrOut->Delete();
 	}
 	else
 	{
-	    this->ScalarsDone(output->GetCellData());
+		output->GetCellData()->SetScalars(wArray.ArrOut);
+		wArray.ArrOut->Delete();
 	}
 }
 
