@@ -30,63 +30,60 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IPALETTE_H
 
 
+#include "iobject.h"
+
+
 #include "icolor.h"
+#include "ipair.h"
 #include "istring.h"
 
 class iImage;
-class iPaletteSet;
+class iPaletteCollection;
 class iPiecewiseFunction;
 
 class vtkColorTransferFunction;
 class vtkLookupTable;
 
 
-class iPalette 
+class iPalette : public iObject
 {
 	
-	friend class iPaletteSet;
+	friend class iPaletteCollection;
 
 public:
 	
-	iPalette();
-	~iPalette();
-	
-	inline const iString& GetName() const { return mName; }
-	void SetName(const iString &n) { mName = n; }
+	vtkTypeMacro(iPalette,iObject);
+
+	iObjectPropertyMacro1S(Name,String);
+	iPropertyPiecewiseFunction Red, Green, Blue;
+
+	virtual bool CopyState(const iObject *p);
 
 	iColor GetColor(int n) const;
-	inline const iPiecewiseFunction* GetRedComponent() const { return mFun[0]; } 
-	inline const iPiecewiseFunction* GetGreenComponent() const { return mFun[1]; } 
-	inline const iPiecewiseFunction* GetBlueComponent() const { return mFun[2]; } 
-
-	void SetComponents(const iPiecewiseFunction *r, const iPiecewiseFunction *g, const iPiecewiseFunction *b);
-
-	void Copy(iPalette *p);
-
-	const iImage* GetImage();
-
-	//
-	//  For direct editing - use with care as this function requires an explicit call to Update();
-	//
-	inline iPiecewiseFunction** GetComponents() { return mFun; }
-	inline iPiecewiseFunction* GetComponent(int n) { return (n>=0 && n<3) ? mFun[n] : 0; }
-	inline const iPiecewiseFunction* const * GetComponents() const { return mFun; }
-
-	void Update();
-
-private:
+	const iImage* GetImage(int shape = 0);
 	
+	void SetComponents(const iPiecewiseFunction *r, const iPiecewiseFunction *g, const iPiecewiseFunction *b);
+	iPiecewiseFunction* GetComponent(int n) const;
+
 	inline vtkLookupTable* GetLookupTable(bool reverse) const { return mLT[reverse?1:0]; }
 	inline vtkColorTransferFunction* GetColorTransferFunction(bool reverse) const { return mCTF[reverse?1:0]; }
 
-	iString mName;
-	iPiecewiseFunction *mFun[3];
+	void Update();
+
+protected:
+	
+	iPalette(iObject *parent, const iString &fname, const iString &sname);
+	virtual ~iPalette();
+
+private:
+
+	iPiecewiseFunction *mRed, *mGreen, *mBlue;
 	vtkColorTransferFunction *mCTF[2];
 	vtkLookupTable *mLT[2];
 
 	int mImageWidth, mImageHeight;
 	bool mImageNeedsUpdate;
-	iImage *mImage;
+	iImage *mImage[3];
 };
 
 #endif // IPALETTE_H
