@@ -36,25 +36,22 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparallelworker.h"
 #include "iviewmodule.h"
 
-#include <vtkToolkits.h>
-#ifdef VTK_USE_PARALLEL
 #include <vtkMultiThreader.h>
-#endif
 #include <vtkTimerLog.h>
 
 
 #if defined(I_DEBUG)
-#include "icontrolmodule.h"
 #include "ishell.h"
 #endif
 
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParallel;
+using namespace iParameter;
 
 
 #ifdef I_DEBUG
@@ -72,7 +69,7 @@ public:
 
 	iParallelTimer()
 	{
-		mClock = vtkTimerLog::New(); IERROR_ASSERT(mClock);
+		mClock = vtkTimerLog::New(); IERROR_CHECK_MEMORY(mClock);
 		mValue = 0.0;
 	}
 
@@ -129,12 +126,12 @@ public:
 	{
 		this->GetMinMax(minnp,maxnp);
 
-		mWallTimer = new iParallelTimer; IERROR_ASSERT(mWallTimer);
+		mWallTimer = new iParallelTimer; IERROR_CHECK_MEMORY(mWallTimer);
 
 		iParallelTimer *tmp;
 		while(mProcTimers.Size() < maxnp)
 		{
-			tmp = new iParallelTimer; IERROR_ASSERT(tmp);
+			tmp = new iParallelTimer; IERROR_CHECK_MEMORY(tmp);
 			mProcTimers.Add(tmp);
 		}
 	}
@@ -146,7 +143,7 @@ public:
 		iParallelTimer *tmp;
 		while(mProcTimers.Size() < n)
 		{
-			tmp = new iParallelTimer; IERROR_ASSERT(tmp);
+			tmp = new iParallelTimer; IERROR_CHECK_MEMORY(tmp);
 			mProcTimers.Add(tmp);
 		}
 		while(mProcTimers.Size() > n) delete mProcTimers.RemoveLast();
@@ -208,8 +205,6 @@ protected:
 //
 namespace iParallelManager_Private
 {
-#ifdef VTK_USE_PARALLEL
-	
 	class SharedMemoryHelper : public iParallelHelper
 	{
 
@@ -217,7 +212,7 @@ namespace iParallelManager_Private
 
 		SharedMemoryHelper()
 		{
-			mExec = vtkMultiThreader::New(); IERROR_ASSERT(mExec);
+			mExec = vtkMultiThreader::New(); IERROR_CHECK_MEMORY(mExec);
 		}
 
 		virtual ~SharedMemoryHelper()
@@ -282,128 +277,153 @@ namespace iParallelManager_Private
 
 		vtkMultiThreader *mExec;
 	};
-#endif
+
+
+	class SharedMemoryManager : public iParallelManager
+	{
+
+	public:
+
+		SharedMemoryManager(iShell *s) : iParallelManager(s)
+		{
+		}
+
+	protected:
+
+		virtual iParallelHelper* CreateHelper() const
+		{
+			return new SharedMemoryHelper;
+		}
+	};
 };
 
 
 using namespace iParallelManager_Private;
 
 
-iParallelManager* iParallelManager::New(iControlModule *cm)
+iParallelManager* iParallelManager::New(iShell *s)
 {
-	return new iParallelManager(cm);
+	iParallelManager *ret =  new SharedMemoryManager(s);
+	ret->Define();
+	return ret;
 }
 
 
-iParallelManager::iParallelManager(iControlModule *cm) : mControlModule(cm)
+iParallelManager::iParallelManager(iShell *s) : iShellComponent(s)
 {
-#ifdef VTK_USE_PARALLEL
+}
 
-	mHelper = new SharedMemoryHelper(); IERROR_ASSERT(mHelper);
-	mHelper->Initialize(mMinNumProcs,mMaxNumProcs);
-	this->SetNumberOfProcessors(1);
 
-#if defined(I_DEBUG)
-	iConsole::PrintDebugMessage("Max # of procs: "+iString::FromNumber(mMaxNumProcs));
+void iParallelManager::Define()
+{
+	mHelper = this->CreateHelper();
+	if(mHelper != 0)
+	{
+		mHelper->Initialize(mMinNumProcs,mMaxNumProcs);
+		this->SetNumberOfProcessors(1);
+
+#ifdef I_DEBUG
+		iOutput::DisplayDebugMessage("Max # of procs: "+iString::FromNumber(mMaxNumProcs)+", using "+iString::FromNumber(this->GetNumberOfProcessors()));
 #endif
 
-	mCount = 0;
-#else
-	mNumProcs = mMinNumProcs = mMaxNumProcs = 1;
-#endif
+		mCount = 0;
+	}
+	else
+	{
+		mCount = -1;
+		mNumProcs = mMinNumProcs = mMaxNumProcs = 1;
+	}
 }
 
 
 iParallelManager::~iParallelManager()
 {
-#ifdef VTK_USE_PARALLEL
-	delete mHelper;
-#endif
+	if(mHelper != 0) delete mHelper;
 }
 
 
 int iParallelManager::ExecuteWorker(iParallelWorker *worker)
 {
 	int ret;
-#ifdef VTK_USE_PARALLEL
+
 	bool single = (mCount == 0);
 
 	if(single) this->StartCounters();
 
-	if(mNumProcs > 1)
+	if(mHelper!=0 && mNumProcs>1)
 	{
 		ret = mHelper->ExecuteWorker(worker);
 	}
 	else
 	{
-#endif
 		ProcessorInfo p;
 		if(worker != 0) ret = worker->ExecuteInternal(p); else ret = 1;
-#ifdef VTK_USE_PARALLEL
 	}
 
 	if(single) this->StopCounters();
-#endif
 	return ret;
 }
 
 
 void iParallelManager::SetNumberOfProcessors(int n)
 { 
-#ifdef VTK_USE_PARALLEL
-	if(n == 0) n = mMaxNumProcs; // auto-set to max available number
-	if(n>0 && n<=mMaxNumProcs)
+	if(mHelper != 0)
 	{
-		mNumProcs = n;
-		mHelper->SetNumProcs(mNumProcs); 
+		if(n == 0) n = mMaxNumProcs; // auto-set to max available number
+		if(n>0 && n<=mMaxNumProcs)
+		{
+			mNumProcs = n;
+			mHelper->SetNumProcs(mNumProcs); 
+		}
 	}
-#endif
 }
 
 
 double iParallelManager::GetProcessorExecutionTime(int n) const
 {
-#ifdef VTK_USE_PARALLEL
-	return mHelper->GetProcessorExecutionTime(n);
-#else
-	return 0.0;
-#endif
+	if(mHelper != 0)
+	{
+		return mHelper->GetProcessorExecutionTime(n);
+	}
+	else return 0.0;
 }
 
 
 double iParallelManager::GetWallClockExecutionTime() const
 {
-#ifdef VTK_USE_PARALLEL
-	return mHelper->GetWallClockExecutionTime();
-#else
-	return 0.0;
-#endif
+	if(mHelper != 0)
+	{
+		return mHelper->GetWallClockExecutionTime();
+	}
+	else return 0.0;
 }
 
 
 void iParallelManager::StartCounters()
 {
-#ifdef VTK_USE_PARALLEL
-	if(mCount == 0)
+	if(mHelper != 0)
 	{
-		mHelper->StartTimers();
+		if(mCount == 0)
+		{
+			mHelper->StartTimers();
+		}
+		mCount++;
 	}
-	mCount++;
-#endif
 }
 
 
 void iParallelManager::StopCounters()
 {
-#ifdef VTK_USE_PARALLEL
-	mCount--;
-	if(mCount == 0)
+	if(mHelper != 0)
 	{
-		if(mHelper->StopTimers()) this->InvokeEvent(InformationEvent,0);
+		mCount--;
+		if(mCount == 0)
+		{
+			if(mHelper->StopTimers()) this->InvokeEvent(InformationEvent,0);
+		}
+#ifndef I_NO_CHECK
+		if(mCount < 0) IBUG_WARN("Imbalanced start/stop counters.");
+#endif
 	}
-#ifdef I_CHECK1
-	if(mCount < 0) IERROR_LOW("Imbalanced start/stop counters.");
-#endif
-#endif
 }
 
