@@ -31,24 +31,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkObject.h>
+#include "ishellcomponent.h"
 
 
-#include "ipointermacro.h"
-
-class iControlModule;
 class iParallelHelper;
 class iParallelUpdateEventObserver;
 class iParallelWorker;
 
 
-class iParallelManager : public vtkObject
+class iParallelManager : public vtkObject, public iShellComponent
 {
 
-	IPOINTER_AS_PART(ControlModule);
-
 public:
 
-	static iParallelManager* New(iControlModule *cm);
+	static iParallelManager* New(iShell *s);
 
 	int ExecuteWorker(iParallelWorker *worker); 
 
@@ -70,11 +66,14 @@ public:
 
 protected:
 
+	iParallelManager(iShell *s);
 	virtual ~iParallelManager();
 
+	virtual iParallelHelper* CreateHelper() const = 0;
+
 private:
 
-	iParallelManager(iControlModule *cm);
+	void Define();
 
 	int mNumProcs, mMinNumProcs, mMaxNumProcs;
 	int mCount;
