@@ -29,14 +29,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparticledataconverter.h"
 
 
-#include "idatalimits.h"
-#include "idatastretch.h"
+//#include "idatalimits.h"
 #include "ierror.h"
-#include "ifunctionmapping.h"
 #include "imath.h"
-#include "iparticlegroup.h"
+#include "iparticleviewsubject.h"
 #include "ipiecewisefunction.h"
 #include "ipointglyph.h"
+#include "istretch.h"
 #include "iviewmodule.h"
 
 #include <vtkCellArray.h>
@@ -51,16 +50,25 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
-#include "igenericfiltertemplate.h"
+#include "iarray.tlh"
+#include "igenericfilter.tlh"
 
 using namespace iParameter;
 
 
-iParticleDataConverter::iParticleDataConverter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>(vo,1,true,true)
+iParticleDataConverter* iParticleDataConverter::New(iViewInstance *owner)
 {
+	IASSERT(owner);
+	return new iParticleDataConverter(owner);
+}
+
+
+iParticleDataConverter::iParticleDataConverter(iViewInstance *owner) : iGenericPolyDataFilter<vtkPolyDataAlgorithm>(owner,1,true)
+{
+	mOwner = iRequiredCast<iParticleViewInstance>(INFO,owner);
+
 	mSize = 0.005;
-	mPoint = iPointGlyph::New(vo); IERROR_ASSERT(mPoint);
+	mPoint = iPointGlyph::New(); IERROR_CHECK_MEMORY(mPoint);
 	this->SetType(PointGlyphType::Point);
 }
 
@@ -94,15 +102,15 @@ void iParticleDataConverter::SetSize(float s)
 }
 
 
-void iParticleDataConverter::ProduceOutput()
+void iParticleDataConverter::ProvideOutput()
 {
 	int i, j;
 	vtkIdType lp, lv;
 	vtkIdType nCell1, *pCell1, pCell2[999];
 	double x0[3], x1[3], x2[3];
 	
-	vtkPolyData *input = this->GetInput();
-	vtkPolyData *output = this->GetOutput();
+	vtkPolyData *input = this->InputData();
+	vtkPolyData *output = this->OutputData();
 
 	output->ShallowCopy(input);
 
@@ -143,7 +151,7 @@ void iParticleDataConverter::ProduceOutput()
 	//
 	mPoint->Update();
 
-	vtkPoints *srcPnts = mPoint->GetOutput()->GetPoints();
+	vtkPoints *srcPnts = mPoint->GetData()->GetPoints();
 	if(srcPnts->GetDataType() != VTK_FLOAT)
 	{
 		vtkErrorMacro("Source points are not floats.");
@@ -152,10 +160,10 @@ void iParticleDataConverter::ProduceOutput()
 	float *srcPntsArr = (float *)srcPnts->GetVoidPointer(0);
 
 	bool srcCellPoly = true;
-	vtkCellArray *srcClls = mPoint->GetOutput()->GetPolys();
+	vtkCellArray *srcClls = mPoint->GetData()->GetPolys();
 	if(srcClls==0 || srcClls->GetNumberOfCells()==0)
 	{
-		srcClls = mPoint->GetOutput()->GetVerts();
+		srcClls = mPoint->GetData()->GetVerts();
 		srcCellPoly = false;
 	}
 	if(srcClls==0 || srcClls->GetNumberOfCells()==0)
@@ -166,14 +174,14 @@ void iParticleDataConverter::ProduceOutput()
 	
 	int sSrcNmls = 0;
 	vtkFloatArray *srcNmls = 0;
-	if(mPoint->GetOutput()->GetPointData()->GetNormals() != 0) 
+	if(mPoint->GetData()->GetPointData()->GetNormals() != 0) 
 	{
-		srcNmls = iRequiredCast<vtkFloatArray>(INFO,mPoint->GetOutput()->GetPointData()->GetNormals());
+		srcNmls = iRequiredCast<vtkFloatArray>(INFO,mPoint->GetData()->GetPointData()->GetNormals());
 		sSrcNmls = 1;
 	}
-	else if(mPoint->GetOutput()->GetCellData()->GetNormals() != 0) 
+	else if(mPoint->GetData()->GetCellData()->GetNormals() != 0) 
 	{
-		srcNmls = iRequiredCast<vtkFloatArray>(INFO,mPoint->GetOutput()->GetCellData()->GetNormals());
+		srcNmls = iRequiredCast<vtkFloatArray>(INFO,mPoint->GetData()->GetCellData()->GetNormals());
 		sSrcNmls = -1;
 	}
 	float *srcNmlsArr = 0;
@@ -206,16 +214,17 @@ void iParticleDataConverter::ProduceOutput()
 			if(inpPntsDir == 0)
 			{
 				vtkErrorMacro("There is not enough memory to convert the particle set data");
+				this->SetAbortExecute(1);
 				return;
 			}
 			memset(inpPntsDir,0,3*nInpPnts*sizeof(float));
 			inpLins->InitTraversal();
 			while(inpLins->GetNextCell(nCell1,pCell1) != 0)
 			{
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 				if(nCell1 != 2)
 				{
-					IERROR_LOW("Line contains more than 2 points!");
+					IBUG_WARN("Line contains more than 2 points!");
 					break;
 				}
 #endif
@@ -244,8 +253,8 @@ void iParticleDataConverter::ProduceOutput()
 	//
 	vtkIdType nOutPnts = nInpVrts*nSrcPnts + nOutPntsOff;
 	vtkIdType nOutClls = nInpVrts*nSrcClls;
-	vtkPoints *outPnts = vtkPoints::New(inpPnts->GetDataType()); IERROR_ASSERT(outPnts);
-	vtkCellArray *outClls = vtkCellArray::New(); IERROR_ASSERT(outClls);
+	vtkPoints *outPnts = vtkPoints::New(inpPnts->GetDataType()); IERROR_CHECK_MEMORY(outPnts);
+	vtkCellArray *outClls = vtkCellArray::New(); IERROR_CHECK_MEMORY(outClls);
 
 	//	
 	// Allocates and Sets MaxId
@@ -261,13 +270,14 @@ void iParticleDataConverter::ProduceOutput()
 		outPnts->Delete();
 		outClls->Delete();
 		vtkErrorMacro("There is not enough memory to convert the particle set data");
+		this->SetAbortExecute(1);
 		return;
 	}
 	
 	//
 	//  Output normals
 	//
-	vtkFloatArray *outNmls = vtkFloatArray::New(); IERROR_ASSERT(outNmls);
+	vtkFloatArray *outNmls = vtkFloatArray::New(); IERROR_CHECK_MEMORY(outNmls);
 	outNmls->SetNumberOfComponents(3);
 	float *outNmlsArr = 0;
 	if(sSrcNmls > 0) 
@@ -289,31 +299,24 @@ void iParticleDataConverter::ProduceOutput()
 		outClls->Delete();
 		outNmls->Delete();
 		vtkErrorMacro("There is not enough memory to convert the particle set data");
+		this->SetAbortExecute(1);
 		return;
 	}
 
-	if(!this->ScalarsInit(input->GetPointData(),nOutPnts))
+	bool hasScalars = (input->GetPointData()->GetScalars() != 0);
+	if(hasScalars && !wArray.Init(input->GetPointData()->GetScalars(),nOutPnts))
 	{
 		outPnts->Delete();
 		outClls->Delete();
 		outNmls->Delete();
+		this->SetAbortExecute(1);
 		return;
 	}
 
 	//
-	//  Attributes for scaling
+	//  Variable for scaling
 	//
-	int catt;
-	float cattLo = 0.0, cattHi = 0.0;
-	int cattSt = 0;
-	catt = iRequiredCast<iParticleGroup>(INFO,this->GetViewSubject())->GetAttributeToSize();
-	if(catt>=0 && this->GetLimits()->GetNumVars())
-	{
-		iParticleGroup *pg = iRequiredCast<iParticleGroup>(INFO,this->GetViewSubject());
-		cattSt = pg->GetStretchToSize();
-		cattLo = iDataStretch::ApplyStretch(pg->GetLowerLimitToSize(),cattSt,false);
-		cattHi = iDataStretch::ApplyStretch(pg->GetUpperLimitToSize(),cattSt,true);
-	}
+	int cvar = mOwner->GetScaleVar();
 	
 	//
 	//  Set fixed seed to make sure particles do not jump in an animation
@@ -326,7 +329,7 @@ void iParticleDataConverter::ProduceOutput()
 	if(nOutPntsOff > 0) 
 	{
 		memcpy(outPnts->GetVoidPointer(0),inpPnts->GetVoidPointer(0),nInpPnts*3*sop);
-		if(wScalarDimIn > 0) memcpy(wScalarPtrOut,wScalarPtrIn,nInpPnts*wScalarDimIn*sizeof(float));
+		if(hasScalars) memcpy(wArray.PtrOut,wArray.PtrIn,nInpPnts*wArray.DimIn*sizeof(float));
 		if(sSrcNmls != 0) 
 		{
 			memset(outNmlsArr,0,nInpPnts*3*sizeof(float));
@@ -336,21 +339,18 @@ void iParticleDataConverter::ProduceOutput()
 //			}
 		}
 	}
-	//
-	//  Prepare for direct scaling
-	//
-	iParticleGroup *myParticles = iRequiredCast<iParticleGroup>(INFO,this->GetViewSubject());
-	iPiecewiseFunction *pFun = myParticles->GetSizeFunction()->GetFunction();
 
-	bool doDirect = myParticles->GetAttributeSizeDirect();
-	float scale = 2.0*myParticles->GetAttributeSizeExtraFactor();
+	//
+	//  Prepare for scaling
+	//
+	float scale = 2.0*mOwner->GetScaleFactor();
 
 	//
 	//  Main loop
 	//
 	double mat[3][3];
 	double en, e[4];  // Euler quaternion
-	float *s0 = 0, latt;
+	float *s0 = 0;
 	double s, ct, st, cp, sp;
 	vtkIdType llPnts = nOutPntsOff, llClls = 0;
 
@@ -360,15 +360,15 @@ void iParticleDataConverter::ProduceOutput()
 	{
 		if(lv%1000 == 0)
 		{
-			this->UpdateProgress((float)lv/nInpVrts);
+			this->UpdateProgress(double(lv)/nInpVrts);
 			if(this->GetAbortExecute()) break;
 		}
 
 		inpVrts->GetNextCell(nCell1,pCell1);
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 		if(nCell1 != 1)
 		{
-			IERROR_LOW("Vert contains more than 1 point!");
+			IBUG_WARN("Vert contains more than 1 point!");
 			break;
 		}
 #endif
@@ -376,24 +376,12 @@ void iParticleDataConverter::ProduceOutput()
 
 		inpPnts->GetPoint(lp,x0);
 		s = mSize;
-		if(wScalarDimIn > 0)
+		if(hasScalars)
 		{
-			s0 = wScalarPtrIn + wScalarDimIn*lp;
-			if(catt >= 0)
+			s0 = wArray.PtrIn + wArray.DimIn*lp;
+			if(cvar >= 0)
 			{
-				if(doDirect)
-				{
-					//
-					//  use the attribute as the precise value of the size scaled by scale
-					//
-					s = scale*s0[catt];
-				}
-				else
-				{
-					latt = iDataStretch::ApplyStretch(s0[catt],cattSt,false);
-					latt = (latt-cattLo)/(cattHi-cattLo);
-					s *= pFun->GetValue(latt);
-				}
+				s = scale*s0[cvar];
 			}
 		}
 		
@@ -456,9 +444,9 @@ void iParticleDataConverter::ProduceOutput()
 			}
 			for(j=0; j<3; j++) x1[j] = s*x1[j] + x0[j];
 			outPnts->SetPoint(llPnts,x1);
-			if(wScalarDimIn > 0) 
+			if(hasScalars) 
 			{
-				for(j=0; j<wScalarDimIn; j++) wScalarPtrOut[wScalarDimOut*llPnts+j] = s0[j];
+				for(j=0; j<wArray.DimIn; j++) wArray.PtrOut[wArray.DimOut*llPnts+j] = s0[j];
 			}
 			if(sSrcNmls > 0) // point normals 
 			{
@@ -488,8 +476,12 @@ void iParticleDataConverter::ProduceOutput()
 	}
 	outClls->Delete();
 	
-	this->ScalarsDone(output->GetPointData());
-	
+	if(hasScalars)
+	{
+		output->GetPointData()->SetScalars(wArray.ArrOut);
+		wArray.ArrOut->Delete();
+	}
+
 	if(sSrcNmls > 0) 
 	{
 		output->GetPointData()->SetNormals(outNmls);
@@ -509,6 +501,6 @@ void iParticleDataConverter::ProduceOutput()
 
 float iParticleDataConverter::GetMemorySize()
 {
-	if(this->GetType() == PointGlyphType::Point) return 0.0; else return this->iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>::GetMemorySize();
+	if(this->GetType() == PointGlyphType::Point) return 0.0; else return this->iGenericPolyDataFilter<vtkPolyDataAlgorithm>::GetMemorySize();
 }
 
