@@ -46,7 +46,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 iParticleDensityEstimator* iParticleDensityEstimator::New(iParticleFileLoader *loader)
 {
-	IERROR_ASSERT(loader);
+	IASSERT(loader);
 	return new iParticleDensityEstimator(loader);
 }
 
@@ -54,8 +54,8 @@ iParticleDensityEstimator* iParticleDensityEstimator::New(iParticleFileLoader *l
 iParticleDensityEstimator::iParticleDensityEstimator(iParticleFileLoader *loader) : iParallelWorker(loader->GetViewModule()->GetParallelManager())
 {
 	mNumNeighbors = 16;
-	mLocator = vtkPointLocator::New(); IERROR_ASSERT(mLocator);
-	mData = vtkPolyData::New(); IERROR_ASSERT(mData);
+	mLocator = vtkPointLocator::New(); IERROR_CHECK_MEMORY(mLocator);
+	mData = vtkPolyData::New(); IERROR_CHECK_MEMORY(mData);
 
 	mLocator->SetDataSet(mData);
 }
@@ -78,12 +78,12 @@ void iParticleDensityEstimator::SetNumNeighbors(int num)
 
 
 
-void iParticleDensityEstimator::ComputeDensity(vtkPoints *points, vtkFloatArray *scalars, int attIn, int attOut)
+void iParticleDensityEstimator::ComputeDensity(vtkPoints *points, vtkFloatArray *scalars, int varIn, int varOut)
 {
-	if(points==0 || scalars==0 || scalars->GetDataType()!=VTK_FLOAT || attIn<-1 || attIn>=scalars->GetNumberOfComponents() || attOut<0 || attOut>=scalars->GetNumberOfComponents()) return;
+	if(points==0 || scalars==0 || scalars->GetDataType()!=VTK_FLOAT || varIn<-1 || varIn>=scalars->GetNumberOfComponents() || varOut<0 || varOut>=scalars->GetNumberOfComponents()) return;
 
-	wAttrIn = attIn;
-	wAttrOut = attOut;
+	wVarIn = varIn;
+	wVarOut = varOut;
 
 	mData->SetPoints(points);
 	mData->GetPointData()->SetScalars(scalars);
@@ -119,16 +119,13 @@ int iParticleDensityEstimator::ExecuteStep(int step, iParallel::ProcessorInfo &p
 	if(result == 0) return 1;
 
 	float v;
-	float *ptrIn = (float *)mData->GetPointData()->GetScalars()->GetVoidPointer(0) + wAttrIn;
-	float *ptrOut = (float *)mData->GetPointData()->GetScalars()->GetVoidPointer(0) + wAttrOut;
+	float *ptrIn = (float *)mData->GetPointData()->GetScalars()->GetVoidPointer(0) + wVarIn;
+	float *ptrOut = (float *)mData->GetPointData()->GetScalars()->GetVoidPointer(0) + wVarOut;
 	for(l=kbeg; l<kend; l++)
 	{
 		if(l%1000 == 0)
 		{
-			if(this->IsMaster(p))
-			{
-				this->UpdateProgress(float(l-kbeg)/(kend-kbeg));
-			}
+			if(p.IsMaster()) this->UpdateProgress(double(l-kbeg)/(kend-kbeg));
 			if(this->GetAbortExecute()) break;
 		}
 
@@ -142,7 +139,7 @@ int iParticleDensityEstimator::ExecuteStep(int step, iParallel::ProcessorInfo &p
 			id = result->GetId(i);
 			points->GetPoint(id,x1);
 			r2 = vtkMath::Distance2BetweenPoints(x,x1);
-			v = (wAttrIn == -1) ? 1.0 : ptrIn[nc*id];
+			v = (wVarIn == -1) ? 1.0 : ptrIn[nc*id];
 			sr0 += v;
 			sr2 += v*r2;
 			if(r2 > r2max) r2max = r2;
@@ -154,7 +151,7 @@ int iParticleDensityEstimator::ExecuteStep(int step, iParallel::ProcessorInfo &p
 		}
 		else
 		{
-			ptrOut[nc*l] = (wAttrIn == -1) ? 1.0 : ptrIn[nc*l];
+			ptrOut[nc*l] = (wVarIn == -1) ? 1.0 : ptrIn[nc*l];
 		}
 	}
 
