@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 //
@@ -97,7 +97,7 @@ vtkIdType iParticleDownsampleIterator::CreateOneMask(int i, vtkIdType ntot, int
 {
 	if(i < 0)
 	{
-		IERROR_HIGH("Mask id should be non-negative.")
+		IBUG_ERROR("Mask id should be non-negative.")
 		return 0;
 	}
 
@@ -110,7 +110,7 @@ vtkIdType iParticleDownsampleIterator::CreateOneMask(int i, vtkIdType ntot, int
 	{
 		if(i != mMaskId+1)
 		{
-			IERROR_HIGH("iParticleDownsampleIterator::PrepareMask should be called sequentially.");
+			IBUG_ERROR("iParticleDownsampleIterator::PrepareMask should be called sequentially.");
 			return 0;
 		}
 		mMaskId++;
@@ -215,7 +215,7 @@ void iParticleDownsampleIterator::Start(int m)
 
 void iParticleDownsampleIterator::Stop(int m)
 {
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 	wIdTot++;
 	wIdGlob++;
 	if(m==-1 && wIdTot==wMask->OffsetTotal+wMask->NumTotal)
@@ -225,7 +225,7 @@ void iParticleDownsampleIterator::Stop(int m)
 	if(m<0 || m>mMasks.MaxIndex()) m = mMasks.MaxIndex();
 	if(wMask!=&mMasks[m] || wIdGlob!=wMask->NumSelected+wMask->OffsetSelected || wIdTot!=wMask->NumTotal+wMask->OffsetTotal)
 	{
-		IERROR_REPORT_BUG;
+		IBUG_WARN("Internal check failed.");
 	}
 #endif
 	wIdTot = -1L;
@@ -239,7 +239,7 @@ void iParticleDownsampleIterator::AdvanceCurrentMask()
 	//
 	//  Do nothing if requested to advance the last mask
 	//
-	if(wMask == &mMasks.Last()) return; 
+	if(wMask == &mMasks[mMasks.MaxIndex()]) return; 
 
 	wMask++;
 	while(wMask->Skip || wMask->NumTotal==0)
@@ -247,16 +247,16 @@ void iParticleDownsampleIterator::AdvanceCurrentMask()
 		wIdTot += wMask->NumTotal;
 		wIdGlob += wMask->NumSelected;
 		wIdLoc = 0;
-		if(wMask != &mMasks.Last()) wMask++; else break;
+		if(wMask != &mMasks[mMasks.MaxIndex()]) wMask++; else break;
 	}
 }
 
 
-#ifdef I_CHECK2
+#ifdef I_CHECK
 
 void iParticleDownsampleIterator::ReportBug()
 {
-	IERROR_REPORT_BUG;
+	IBUG_WARN("Internal check failed.");
 }
 
 #endif
