@@ -30,15 +30,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ibuffer.h"
-#include "icommoneventobservers.h"
+#include "idata.h"
 #include "idatalimits.h"
+#include "idatareader.h"
 #include "idatasubject.h"
 #include "ierror.h"
-#include "ierrorstatus.h"
+#include "imonitor.h"
 #include "iparallel.h"
 #include "iparallelmanager.h"
 #include "iparallelworker.h"
 #include "iparticledensityestimator.h"
+#include "ishell.h"
+#include "ishelleventobservers.h"
 #include "iviewmodule.h"
 
 #include <vtkCellArray.h>
@@ -52,8 +55,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
-#include "ibuffertemplate.h"
+#include "iarray.tlh"
+#include "ibuffer.tlh"
 
 
 //
@@ -66,12 +69,11 @@ public:
 
 	iParticleHelper(iParticleFileLoader *loader);
 
-	void ShiftData(bool paf, int dim, vtkIdType n, bool per[3], float dr, float *pf, double *pd);
-	void FindRange(int dim, vtkIdType n, float *pf, float *amin, float *amax);
-	void AddIndexAsAttribute(int att, int nc, vtkIdType n, float *pf);
+	void ShiftData(bool paf, int dim, vtkIdType n, bool per[3], double dr, float *pf, double *pd);
+	void AddOrderAsVar(int var, int nc, vtkIdType n, float *pf);
 
 	template<class T, class D>
-	bool ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int inNum, int outOffset, float updateStart, float updateDuration, T *scale, T *offset);
+	bool ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int inNum, int outOffset, double updateStart, double updateDuration, T *scale, T *offset);
 
 	template<class T>
 	void AutoScalePositions();
@@ -82,8 +84,6 @@ protected:
 
 	iParticleFileLoader *mLoader;
 
-	iBuffer<float> mMin, mMax;
-
 	bool *mPeriodic;
 	float *mFarr;
 	double *mDarr;
@@ -91,7 +91,7 @@ protected:
 	int mDim, mCom, mNumProcs;
 	bool mPaf;
 	vtkIdType mTot;
-	float mDr;
+	double mDr;
 };
 
 
@@ -114,22 +114,16 @@ void iParticleFileLoader::Define()
 {
 	mHaveNormals = false;
 
-	mHelper = new iParticleHelper(this); IERROR_ASSERT(mHelper);
-	mDensityEstimator = iParticleDensityEstimator::New(this); IERROR_ASSERT(mDensityEstimator);
-	mDensityEstimator->AddObserver(vtkCommand::StartEvent,this->GetObserver());
-	mDensityEstimator->AddObserver(vtkCommand::ProgressEvent,this->GetObserver());
-	mDensityEstimator->AddObserver(vtkCommand::EndEvent,this->GetObserver());
+	mHelper = new iParticleHelper(this); IERROR_CHECK_MEMORY(mHelper);
+	mDensityEstimator = iParticleDensityEstimator::New(this); IERROR_CHECK_MEMORY(mDensityEstimator);
+	mDensityEstimator->AddObserver(vtkCommand::StartEvent,this->GetShell()->GetExecutionEventObserver());
+	mDensityEstimator->AddObserver(vtkCommand::ProgressEvent,this->GetShell()->GetExecutionEventObserver());
+	mDensityEstimator->AddObserver(vtkCommand::EndEvent,this->GetShell()->GetExecutionEventObserver());
 }
 
 
 iParticleFileLoader::~iParticleFileLoader()
 {
-	int i;
-	for(i=0; i<this->NumStreams(); i++)
-	{
-		if(this->GetStream(i)->Data != 0) this->GetStream(i)->Data->Delete();
-	}
-
 	delete mHelper;
 	mDensityEstimator->Delete();
 }
@@ -138,6 +132,7 @@ iParticleFileLoader::~iParticleFileLoader()
 void iParticleFileLoader::SetDownsampleMode(int v)
 {
 	mIterator.SetDownsampleMode(v);
+	this->GetReader()->RequestDataReload(this->GetDataInfo());
 }
 
 
@@ -150,6 +145,7 @@ int iParticleFileLoader::GetDownsampleMode() const
 void iParticleFileLoader::SetNumNeighbors(int num)
 {
 	mDensityEstimator->SetNumNeighbors(num);
+	this->GetReader()->RequestDataReload(this->GetDataInfo());
 }
 
 
@@ -164,6 +160,7 @@ void iParticleFileLoader::SetTypeIncluded(int type, bool s)
 	if(type>=0 && type<this->NumStreams())
 	{
 		this->GetStream(type)->Included = s;
+		this->GetReader()->RequestDataReload(this->GetDataType(type));
 	}
 }
 
@@ -181,140 +178,81 @@ void iParticleFileLoader::SetDownsampleFactor(int type, int value)
 			int i;
 			for(i=0; i<this->NumStreams(); i++) this->GetStream(i)->DownsampleFactor = value;
 		}
+		this->GetReader()->RequestDataReload(this->GetDataInfo());
 	}
 }
 
 
-void iParticleFileLoader::SetDensityAttribute(int type, int attr)
+void iParticleFileLoader::SetDensityVariable(int type, int var)
 {
 	if(mUseExtras && type>=0 && type<this->NumStreams())
 	{
-		this->GetStream(type)->Extras.DensityAttribute = (attr > -2) ? attr : -2;
+		this->GetStream(type)->Extras.DensityVariable = (var > -2) ? var : -2;
+		this->GetReader()->RequestDataReload(this->GetDataInfo());
 	}
 }
 
 
-void iParticleFileLoader::SetOrderIsAttribute(int type, bool s)
+void iParticleFileLoader::SetAddOrderAsVariable(int type, bool s)
 {
 	if(mUseExtras && type>=0 && type<this->NumStreams())
 	{
-		this->GetStream(type)->Extras.OrderIsAttribute = s;
+		this->GetStream(type)->Extras.AddOrderAsVariable = s;
+		this->GetReader()->RequestDataReload(this->GetDataInfo());
 	}
 }
 
 
 void iParticleFileLoader::AddExtras(ParticleStream *stream)
 {
-	int natt = stream->NumAttributesInFile;
+	int nvar = stream->NumVariablesInFile;
 
 	//
-	//  If we save the order in file as an attribute, fill it in.
+	//  If we save the order in file as a variable, fill it in.
 	//
-	if(stream->Extras.OrderIsAttribute && natt<stream->NumAttributesInData)
+	if(stream->Extras.AddOrderAsVariable && nvar<stream->NumVariablesInData)
 	{
-		mHelper->AddIndexAsAttribute(natt,stream->Scalars->GetNumberOfComponents(),stream->Scalars->GetNumberOfTuples(),stream->Scalars->GetPointer(0));
-		natt++;
+		mHelper->AddOrderAsVar(nvar,stream->Scalars()->GetNumberOfComponents(),stream->Scalars()->GetNumberOfTuples(),stream->Scalars()->GetPointer(0));
+		nvar++;
 	}
 
 	//
 	//  Check if we need to add density
 	//
-	if(stream->Extras.DensityAttribute>-2 && natt<stream->NumAttributesInData && stream->Extras.DensityAttribute<natt)
+	iMonitor h(this,"Operating",1.0);
+	if(stream->Extras.DensityVariable>-2 && nvar<stream->NumVariablesInData && stream->Extras.DensityVariable<nvar)
 	{
-		this->GetObserver()->SetMode(iProgressEventObserver::_Operating);
-		mDensityEstimator->ComputeDensity(stream->Points,stream->Scalars,stream->Extras.DensityAttribute,natt);
-		natt++;
+
+		mDensityEstimator->ComputeDensity(stream->Points(),stream->Scalars(),stream->Extras.DensityVariable,nvar);
+		nvar++;
 	}
 
 	//
 	//  Final check
 	//
-	if(natt != stream->NumAttributesInData)
+	if(nvar != stream->NumVariablesInData)
 	{
-		IERROR_HIGH("iParticleFileLoader is configured icorrectly: unfilled  attributes remained.");
-		this->GetErrorStatus()->Set("Unable to read the data due to a bug.");
+		IBUG_ERROR("iParticleFileLoader is configured icorrectly: unfilled variables remained.");
+		h.PostError("Unable to read the data due to a bug.");
 	}
 }
 
 
-void iParticleFileLoader::FinalizeBody()
+void iParticleFileLoader::WrapPositions(vtkPoints *points)
 {
 	int i;
-
-	//
-	//  Apply extras
-	//
-	for(i=0; i<this->NumStreams(); i++) this->AddExtras(this->GetStream(i));
-		
-
-	for(i=0; i<this->NumStreams(); i++)
-	{
-		this->GetStream(i)->Data->SetPoints(this->GetStream(i)->Points);
-		this->GetStream(i)->Data->SetVerts(this->GetStream(i)->Verts);
-		this->GetStream(i)->Data->GetPointData()->SetScalars(this->GetStream(i)->Scalars);
-		this->AttachDataToStream(i,this->GetStream(i)->Data);
-	}
-
-	this->ReleaseStreams();
-
-	//
-	//  Attribute limits.
-	//
-	for(i=0; i<this->NumStreams(); i++)	if(!this->GetStream(i)->Subject->GetFixedLimits())
-	{
-		vtkFloatArray *att = iRequiredCast<vtkFloatArray>(INFO,this->GetStream(i)->Data->GetPointData()->GetScalars());
-
-		if(att!=0 && att->GetNumberOfComponents()>0  && att->GetNumberOfTuples()>0 && att->GetNumberOfComponents()==this->GetStream(i)->Subject->GetLimits()->GetNumVars()) // just in case
-		{
-			iBuffer<float> aMin, aMax;
-			aMin.Extend(att->GetNumberOfComponents());
-			aMax.Extend(att->GetNumberOfComponents());
-
-			mHelper->FindRange(att->GetNumberOfComponents(),att->GetNumberOfTuples(),att->GetPointer(0),aMin,aMax);
-
-			int j;
-			for(j=0; j<att->GetNumberOfComponents(); j++)
-			{
-				this->GetStream(i)->Subject->GetLimits()->SetMin(j,aMin[j]);
-				this->GetStream(i)->Subject->GetLimits()->SetMax(j,aMax[j]);
-			}
-		}
-	}
-
-	for(i=0; i<this->NumStreams(); i++)
-	{
-		this->FinalizePolyData(this->GetStream(i)->Data);
-	}
-}
-
-
-void iParticleFileLoader::ShiftDataBody(vtkDataSet *data, double dx[3])
-{
-	int i;
-	for(i=0; i<3; i++) if(fabs(dx[i]) > 1.0e-100)
-	{
-		this->ShiftPolyData(iRequiredCast<vtkPolyData>(INFO,data),i,dx[i]);
-	}
-}
-
-
-void iParticleFileLoader::FinalizePolyData(vtkPolyData *data)
-{
-	if(data==0 || data->GetPoints()==0) return;
-
-	int i;
-	vtkIdType l, loff, ntot = data->GetNumberOfPoints();
+	vtkIdType l, loff, ntot = points->GetNumberOfPoints();
 
 	//
 	//  Boundary condition
 	//
-	for(i=0; i<3; i++) this->SetDirectionPeriodic(i,this->IsBoxPeriodic());
+	for(i=0; i<3; i++) this->SetDirectionPeriodic(i,true);
 
-	if(this->IsBoxPeriodic())
+	if(this->GetBoundaryConditions() == iParameter::BoundaryConditions::Periodic)
 	{
-		if(data->GetPoints()->GetDataType() == VTK_FLOAT)
+		if(points->GetDataType() == VTK_FLOAT)
 		{
-			float *xptrF = (float *)data->GetPoints()->GetVoidPointer(0);
+			float *xptrF = (float *)points->GetVoidPointer(0);
 			for(i=0; i<3; i++) if(this->IsDirectionPeriodic(i))
 			{
 				for(l=0; l<ntot; l++)
@@ -324,9 +262,9 @@ void iParticleFileLoader::FinalizePolyData(vtkPolyData *data)
 				}
 			}
 		}
-		else if(data->GetPoints()->GetDataType() == VTK_DOUBLE)
+		else if(points->GetDataType() == VTK_DOUBLE)
 		{
-			double *xptrD = (double *)data->GetPoints()->GetVoidPointer(0);
+			double *xptrD = (double *)points->GetVoidPointer(0);
 			for(i=0; i<3; i++) if(this->IsDirectionPeriodic(i))
 			{
 				for(l=0; l<ntot; l++)
@@ -338,14 +276,70 @@ void iParticleFileLoader::FinalizePolyData(vtkPolyData *data)
 		}
 		else
 		{
-			this->GetErrorStatus()->Set("Internal bug: ivalid points data type.");
+			IBUG_ERROR("Internal bug: ivalid points data type.");
 		}
 	}
+}
+
+
+void iParticleFileLoader::LoadFileBody(const iString &suffix, const iString &fname)
+{
+	int i;
+
+	iMonitor h(this);
+	h.SetInterval(0.0,0.8);
+
+	this->LoadParticleFileBody(suffix,fname);
+	if(h.IsStopped()) return;
+
+	h.SetInterval(0.8,0.2);
+
+	//
+	//  Apply extras
+	//
+	for(i=0; i<this->NumStreams(); i++)
+	{
+		this->WrapPositions(this->GetStream(i)->Points());
+		this->AddExtras(this->GetStream(i));
+	}
+		
+	for(i=0; i<this->NumStreams(); i++)
+	{
+		this->AttachDataToStream(i,this->GetStream(i)->Data);
+	}
+
+	for(i=0; i<this->NumStreams(); i++)
+	{
+		this->FinalizePolyData(this->GetStream(i)->Data);
+	}
+}
+
+
+void iParticleFileLoader::ShiftDataBody(vtkDataSet *data, const double *dx)
+{
+	int i;
+	iMonitor h(this,"Shifting",1.0);
+	for(i=0; i<3; i++) 
+	{
+		h.SetInterval(i/3.0,1.0/3.0);
+		if(fabs(dx[i]) > 1.0e-100)
+		{
+			this->ShiftPolyData(iRequiredCast<vtkPolyData>(INFO,data),i,dx[i]);
+		}
+	}
+}
+
+
+void iParticleFileLoader::FinalizePolyData(vtkPolyData *data)
+{
+	if(data==0 || data->GetPoints()==0) return;
+
+	vtkIdType l, ntot = data->GetNumberOfPoints();
 
 	if(mHaveNormals)
 	{
 		vtkFloatArray *newNormals;
-		newNormals = vtkFloatArray::New(); IERROR_ASSERT(newNormals);
+		newNormals = vtkFloatArray::New(); IERROR_CHECK_MEMORY(newNormals);
 		newNormals->SetNumberOfComponents(3);
 		// Allocates and Sets MaxId
 		newNormals->SetNumberOfTuples(ntot);
@@ -361,34 +355,6 @@ void iParticleFileLoader::FinalizePolyData(vtkPolyData *data)
 		}
 		newNormals->Delete();
 	}
-
-	//
-	//  Check for overflow
-	//
-	if(data->GetPointData()->GetScalars() != 0)
-	{
-		float *p = (float *)data->GetPointData()->GetScalars()->GetVoidPointer(0);
-		int natt = data->GetPointData()->GetScalars()->GetNumberOfComponents();
-		if(p != 0)
-		{
-			for(l=0; l<ntot; l++)
-			{
-				for(i=0; i<natt; i++)
-				{
-					if(p[natt*l+i] < -iMath::_LargeFloat)
-					{
-						p[natt*l+i] = -iMath::_LargeFloat;
-						mOverflow = true;
-					}
-					if(p[natt*l+i] >  iMath::_LargeFloat)
-					{
-						p[natt*l+i] =  iMath::_LargeFloat;
-						mOverflow = true;
-					}
-				}
-			}
-		}
-	}
 }
 
 
@@ -408,31 +374,31 @@ void iParticleFileLoader::ShiftPolyData(vtkPolyData *data, int d, double dx)
 }
 
 
-bool iParticleFileLoader::ReadPositions(iFile &F, int inNum, int outOffset, float updateStart, float updateDuration, float *scale, float *offset)
+bool iParticleFileLoader::ReadPositions(iFile &F, int inNum, int outOffset, double updateStart, double updateDuration, float *scale, float *offset)
 {
 	return mHelper->ReadFortranRecordWithMaskTemplate<float,float>(F,0,inNum,outOffset,updateStart,updateDuration,scale,offset);
 }
 
 
-bool iParticleFileLoader::ReadPositions(iFile &F, int inNum, int outOffset, float updateStart, float updateDuration, double *scale, double *offset)
+bool iParticleFileLoader::ReadPositions(iFile &F, int inNum, int outOffset, double updateStart, double updateDuration, double *scale, double *offset)
 {
 	return mHelper->ReadFortranRecordWithMaskTemplate<double,double>(F,0,inNum,outOffset,updateStart,updateDuration,scale,offset);
 }
 
 
-bool iParticleFileLoader::ReadAttributes(iFile &F, int inNum, int outOffset, float updateStart, float updateDuration, float *scale)
+bool iParticleFileLoader::ReadVariables(iFile &F, int inNum, int outOffset, double updateStart, double updateDuration, float *scale)
 {
 	return mHelper->ReadFortranRecordWithMaskTemplate<float,float>(F,1,inNum,outOffset,updateStart,updateDuration,scale,(float *)0);
 }
 
 
-bool iParticleFileLoader::ReadIntAttributes(iFile &F, int inNum, int outOffset, float updateStart, float updateDuration)
+bool iParticleFileLoader::ReadIntVariables(iFile &F, int inNum, int outOffset, double updateStart, double updateDuration)
 {
 	return mHelper->ReadFortranRecordWithMaskTemplate<float,int>(F,1,inNum,outOffset,updateStart,updateDuration,(float *)0,(float *)0);
 }
 
 
-void iParticleFileLoader::ConfigureStreams(vtkIdType *ntot, int *natt, bool paf)
+void iParticleFileLoader::ConfigureStreams(vtkIdType *ntot, int *nvar, bool paf)
 {
 	int n;
 	ParticleStream *stream;
@@ -443,31 +409,24 @@ void iParticleFileLoader::ConfigureStreams(vtkIdType *ntot, int *natt, bool paf)
 
 		if(stream->Data == 0)
 		{
-			stream->Data = vtkPolyData::New(); IERROR_ASSERT(stream->Data);
+			stream->Data = vtkPolyData::New(); IERROR_CHECK_MEMORY(stream->Data);
 		}
 
 		vtkIdType nsel = mIterator.CreateOneMask(n,ntot[n],stream->Included?stream->DownsampleFactor:0);
 		//
-		//  Determine how many extra (derived) attributes we need.
+		//  Determine how many extra (derived) variables we need.
 		//
-		int nattIn = natt[n];
-		if(stream->Extras.DensityAttribute>-2 && stream->Extras.DensityAttribute<natt[n]) natt[n]++;
-		if(stream->Extras.OrderIsAttribute) natt[n]++;
-		//
-		//  Try to set the requested number of attributes. DataLimits will either expand to accommodate 
-		//  all of them or limit the allowed number to the number of listed records.
-		//
-		stream->Subject->GetLimits()->AssignVars(natt[n]);
-		natt[n] = stream->Subject->GetLimits()->GetNumVars();
-		if(nattIn > natt[n]) nattIn = natt[n];
+		int nvarIn = nvar[n];
+		if(stream->Extras.DensityVariable>-2 && stream->Extras.DensityVariable<nvar[n]) nvar[n]++;
+		if(stream->Extras.AddOrderAsVariable) nvar[n]++;
 
 		//
 		//  Fill in stream info
 		//
 		stream->NumTotal = ntot[n];
 		stream->NumSelected = nsel;
-		stream->NumAttributesInFile = nattIn;
-		stream->NumAttributesInData = natt[n];
+		stream->NumVariablesInFile = nvarIn;
+		stream->NumVariablesInData = nvar[n];
 		stream->InFile = true;
 
 		//
@@ -480,81 +439,46 @@ void iParticleFileLoader::ConfigureStreams(vtkIdType *ntot, int *natt, bool paf)
 		int type = paf ? VTK_FLOAT : VTK_DOUBLE;
 		if(oldPoints==0 || oldPoints->GetNumberOfPoints()!=nsel || oldPoints->GetDataType()!=type)
 		{
-			stream->Data->SetPoints(0);
-			stream->Points = vtkPoints::New(type); IERROR_ASSERT(stream->Points);
+			stream->Data->SetPoints(0); // delete the old data first
+			vtkPoints *points = vtkPoints::New(type); IERROR_CHECK_MEMORY(points);
 			// Allocates and Sets MaxId
-			stream->Points->SetNumberOfPoints(nsel);
-		}
-		else
-		{
-			stream->Points = oldPoints;
-			stream->Points->Register(0);
+			points->SetNumberOfPoints(nsel);
+			stream->Data->SetPoints(points);
+			points->Delete();
 		}
 
 		if(oldVerts==0 || oldVerts->GetNumberOfCells()!=nsel)
 		{
-			stream->Data->SetVerts(0);
-			stream->Verts = vtkCellArray::New(); IERROR_ASSERT(stream->Verts);
+			stream->Data->SetVerts(0); // delete the old data first
+			vtkCellArray *verts = vtkCellArray::New(); IERROR_CHECK_MEMORY(verts);
 			// This allocates but does not Set Max Id
-			stream->Verts->Allocate(stream->Verts->EstimateSize(nsel,1));
+			verts->Allocate(verts->EstimateSize(nsel,1));
 			vtkIdType l;
 			for(l=0; l<nsel; l++)
 			{
-				stream->Verts->InsertNextCell(1);
-				stream->Verts->InsertCellPoint(l);
+				verts->InsertNextCell(1);
+				verts->InsertCellPoint(l);
 			}
-		}
-		else
-		{
-			stream->Verts = oldVerts;
-			stream->Verts->Register(0);
+			stream->Data->SetVerts(verts);
+			verts->Delete();
 		}
 
-		if(oldScalars==0 || oldScalars->GetNumberOfTuples()!=nsel || oldScalars->GetNumberOfComponents()!=natt[n])
+		if(oldScalars==0 || oldScalars->GetNumberOfTuples()!=nsel || oldScalars->GetNumberOfComponents()!=nvar[n])
 		{
-			stream->Data->GetPointData()->SetScalars(0);
-			if(natt[n] > 0)
+			stream->Data->GetPointData()->SetScalars(0); // delete the old data first
+			if(nvar[n] > 0)
 			{
-				stream->Scalars = vtkFloatArray::New(); IERROR_ASSERT(stream->Scalars);
-				stream->Scalars->SetNumberOfComponents(natt[n]);
-				stream->Scalars->SetNumberOfTuples(nsel);
+				vtkFloatArray *scalars = vtkFloatArray::New(); IERROR_CHECK_MEMORY(scalars);
+				scalars->SetNumberOfComponents(nvar[n]);
+				scalars->SetNumberOfTuples(nsel);
+				stream->Data->GetPointData()->SetScalars(scalars);
+				scalars->Delete();
 			}
-			else stream->Scalars = 0;
-		}
-		else
-		{
-			stream->Scalars = oldScalars;
-			stream->Scalars->Register(0);
 		}
 	}
 }
 
 
-void iParticleFileLoader::ReleaseStreams()
-{
-	int n;
-	for(n=0; n<this->NumStreams(); n++)
-	{
-		this->GetStream(n)->Points->Delete();
-		this->GetStream(n)->Points = 0;
-		this->GetStream(n)->Verts->Delete();
-		this->GetStream(n)->Verts = 0;
-		if(this->GetStream(n)->Scalars != 0)
-		{
-			this->GetStream(n)->Scalars->Delete();
-			this->GetStream(n)->Scalars = 0;
-		}
-	}
-}
-
-
-void iParticleFileLoader::SetErrorMessage(const iString &filename)
-{
-	this->GetErrorStatus()->Set(filename);
-	mObserver->Finished();
-}
-
-
 void iParticleFileLoader::AutoScalePositions()
 {
 	//
@@ -562,7 +486,13 @@ void iParticleFileLoader::AutoScalePositions()
 	//
 	vtkPoints *p = 0;
 	int i;
-	for(i=0; p==0 && i<this->NumStreams(); i++) p = this->GetStream(i)->Points;
+	for(i=0; p==0 && i<this->NumStreams(); i++)
+	{
+		if(this->GetStream(i)->Data->GetNumberOfPoints() > 0)
+		{
+			p = this->GetStream(i)->Points();
+		}
+	}
 	if(p == 0) return;
 
 	switch(p->GetDataType())
@@ -586,11 +516,11 @@ void iParticleFileLoader::AutoScalePositions()
 //
 iParticleHelper::iParticleHelper(iParticleFileLoader *loader) : iParallelWorker(loader->GetViewModule()->GetParallelManager())
 {
-	mLoader = loader;
+	mLoader = loader; IASSERT(loader);
 }
 
 
-void iParticleHelper::ShiftData(bool paf, int dim, vtkIdType n, bool per[3], float dr, float *pf, double *pd)
+void iParticleHelper::ShiftData(bool paf, int dim, vtkIdType n, bool per[3], double dr, float *pf, double *pd)
 {
 	mPaf = paf;
 	mDim = dim;
@@ -600,44 +530,20 @@ void iParticleHelper::ShiftData(bool paf, int dim, vtkIdType n, bool per[3], flo
 	mDarr = pd;
 	mPeriodic = per;
 
+	iMonitor h(mLoader,"Shifting",1.0);
 	this->ParallelExecute(1);
 }
 
 
-void iParticleHelper::FindRange(int dim, vtkIdType tot, float *pf, float *fMin, float *fMax)
-{
-	mDim = dim;
-	mTot = tot;
-	mFarr = pf;
-
-	mNumProcs = this->GetManager()->GetNumberOfProcessors();
-	mMin.Extend(mDim*mNumProcs);
-	mMax.Extend(mDim*mNumProcs);
-	
-	this->ParallelExecute(2);
-
-	int i, n;
-	for(n=0; n<dim; n++)
-	{
-		fMin[n] = mMin[n];
-		fMax[n] = mMax[n];
-		for(i=1; i<mNumProcs; i++)
-		{
-			if(fMin[n] > mMin[n+dim*i]) fMin[n] = mMin[n+dim*i];
-			if(fMax[n] < mMax[n+dim*i]) fMax[n] = mMax[n+dim*i];
-		}
-	}
-}
-
-
-void iParticleHelper::AddIndexAsAttribute(int dim, int com, vtkIdType tot, float *pf)
+void iParticleHelper::AddOrderAsVar(int dim, int com, vtkIdType tot, float *pf)
 {
 	mDim = dim;
 	mCom = com;
 	mTot = tot;
 	mFarr = pf;
 
-	this->ParallelExecute(3);
+	iMonitor h(mLoader,"Formatting",1.0);
+	this->ParallelExecute(2);
 }
 
 
@@ -662,8 +568,8 @@ int iParticleHelper::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 				{
 					if(l%1000 == 0)
 					{
-						if(this->IsMaster(p)) mLoader->GetObserver()->SetProgress((d+(float)(l-kbeg)/(kend-kbeg))/3.0);
-						if(mLoader->GetObserver()->IsAborted()) return 2;
+						if(p.IsMaster()) mLoader->GetShell()->GetExecutionEventObserver()->SetProgress(double(l-kbeg)/(kend-kbeg));
+						if(mLoader->GetShell()->GetExecutionEventObserver()->IsAborted()) return 2;
 					}
 					x[d] += 2.0*dr;
 					if(mPeriodic[d])
@@ -681,8 +587,8 @@ int iParticleHelper::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 				{
 					if(l%1000 == 0)
 					{
-						if(this->IsMaster(p)) mLoader->GetObserver()->SetProgress((float)(l-kbeg)/(kend-kbeg));
-						if(mLoader->GetObserver()->IsAborted()) return 2;
+						if(p.IsMaster()) mLoader->GetShell()->GetExecutionEventObserver()->SetProgress(double(l-kbeg)/(kend-kbeg));
+						if(mLoader->GetShell()->GetExecutionEventObserver()->IsAborted()) return 2;
 					}
 					x[d] += 2.0*dr;
 					if(mPeriodic[d])
@@ -696,30 +602,14 @@ int iParticleHelper::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 			return 0;
 		}
 	case 2:
-		{
-			int j;
-			float *f = mFarr + d*kbeg, *fmin = mMin + d*p.ThisProc, *fmax = mMax + d*p.ThisProc;
-			for(j=0; j<d; j++) fmin[j] = fmax[j] = f[j];
-			for(l=kbeg+1; l<kend; l++)
-			{
-				f += d;
-				for(j=0; j<d; j++)
-				{
-					if(fmin[j] > f[j]) fmin[j] = f[j];
-					if(fmax[j] < f[j]) fmax[j] = f[j];
-				}
-			}
-			return 0;
-		}
-	case 3:
 		{
 			float *f = mFarr + mDim;
 			for(l=kbeg; l<kend; l++)
 			{
 				if(l%1000 == 0)
 				{
-					if(this->IsMaster(p)) mLoader->GetObserver()->SetProgress((float)(l-kbeg)/(kend-kbeg));
-					if(mLoader->GetObserver()->IsAborted()) return 2;
+					if(p.IsMaster()) mLoader->GetShell()->GetExecutionEventObserver()->SetProgress(double(l-kbeg)/(kend-kbeg));
+					if(mLoader->GetShell()->GetExecutionEventObserver()->IsAborted()) return 2;
 				}
 				f[nc*l] = l;
 			}
@@ -734,19 +624,22 @@ int iParticleHelper::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 
 
 template<class T, class D>
-bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int inNum, int outOffset, float updateStart, float updateDuration, T *scale, T *offset)
+bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int inNum, int outOffset, double updateStart, double updateDuration, T *scale, T *offset)
 {
 	iParticleDownsampleIterator &it(this->mLoader->mIterator);
 
+	iMonitor h(this->mLoader);
 	if(this->mLoader->NumStreams() == 0)
 	{
-		IERROR_HIGH("Streams must be configured prior to a call to iParticleFileLoader::ReadFortranRecordWithMask.");
+		IBUG_ERROR("Streams must be configured prior to a call to iParticleFileLoader::ReadFortranRecordWithMask.");
+		h.PostError("Unable to read the data due to a bug.");
 		return false;
 	}
 
 	if(this->mLoader->NumStreams() != it.GetNumMasks())
 	{
-		IERROR_HIGH("Masks must be created prior to a call to iParticleFileLoader::ReadFortranRecordWithMask.");
+		IBUG_ERROR("Masks must be created prior to a call to iParticleFileLoader::ReadFortranRecordWithMask.");
+		h.PostError("Unable to read the data due to a bug.");
 		return false;
 	}
 
@@ -755,7 +648,8 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 	//
 	if(inNum<1 || outOffset<0)
 	{
-		IERROR_HIGH("Invalid call to iParticleFileLoader::ReadFortranRecordWithMask.");
+		IBUG_ERROR("Invalid call to iParticleFileLoader::ReadFortranRecordWithMask.");
+		h.PostError("Unable to read the data due to a bug.");
 		return false;
 	}
 
@@ -769,12 +663,12 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 			{
 			case 0:
 				{
-					arr = this->mLoader->GetStream(j)->Points->GetData();
+					arr = this->mLoader->GetStream(j)->Points()->GetData();
 					break;
 				}
 			case 1:
 				{
-					arr = this->mLoader->GetStream(j)->Scalars;
+					arr = this->mLoader->GetStream(j)->Scalars();
 					break;
 				}
 			default:
@@ -784,7 +678,7 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 			}
 			if((arr==0 && it.GetNumSelected(j)>0) || !it.AttachBuffer(j,arr,outOffset))
 			{
-				IERROR_HIGH("Invalid call to iParticleFileLoader::ReadFortranRecordWithMask.");
+				IBUG_ERROR("Invalid call to iParticleFileLoader::ReadFortranRecordWithMask.");
 				return false;
 			}
 			it.SkipMask(j,false);
@@ -798,7 +692,7 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 	vtkIdType lrec1, lrec2;
 	if(!this->mLoader->ReadFortranHeaderFooter(F,lrec1))
 	{
-		this->mLoader->GetErrorStatus()->Set("Corrupted data.");
+		h.PostError("Corrupted data.");
 		return false;
 	}
 
@@ -808,7 +702,7 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 	int nCompRec = lrec1/((vtkIdType)sizeof(T)*it.GetNumGlobalTotal());
 	if(lrec1 != nCompRec*sizeof(T)*it.GetNumGlobalTotal())
 	{
-		this->mLoader->GetErrorStatus()->Set("Corrupted data.");
+		h.PostError("Corrupted data.");
 		return false;
 	}
 
@@ -826,7 +720,7 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 	D *d = new D[lpiece*nCompRec];
 	if(d == 0) 
 	{ 
-		this->mLoader->GetErrorStatus()->Set("Not enough memory to create the data.");
+		h.PostError("Not enough memory to create the data.");
 		return false;
 	}
 
@@ -855,13 +749,12 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 		}
 		if(!this->mLoader->ReadBlock(F,d,inNum*lpiece1,updateStart+j*updateDuration,updateDuration))
 		{
-			this->mLoader->GetErrorStatus()->Set("Corrupted data.");
+			h.PostError("Corrupted data.");
 			delete [] d;
 			return false;
 		}
-		if(this->mLoader->GetObserver()->IsAborted())
+		if(h.IsAborted())
 		{
-			this->mLoader->GetErrorStatus()->SetAbort();
 			delete [] d;
 			return false;
 		}
@@ -886,7 +779,7 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 	//
 	if(!this->mLoader->ReadFortranHeaderFooter(F,lrec2) || lrec1!=lrec2)
 	{
-		this->mLoader->GetErrorStatus()->Set("Corrupted data.");
+		h.PostError("Corrupted data.");
 		return false;
 	}
 
@@ -939,9 +832,8 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 		}
 	}
 
-	if(this->mLoader->GetObserver()->IsAborted())
+	if(h.IsAborted())
 	{
-		this->mLoader->GetErrorStatus()->SetAbort();
 		return false;
 	}
 
@@ -958,17 +850,19 @@ void iParticleHelper::AutoScalePositions()
 	int i, j;
 	vtkIdType l, np;
 	T min[3], max[3], r = 0.0, *ptr; 
+	bool start = true;
 
 	//
 	//  Find min/max
 	//
-	for(j=0; j<this->mLoader->NumStreams(); j++) if(this->mLoader->GetStream(j)->Points != 0)
+	for(j=0; j<this->mLoader->NumStreams(); j++) if(this->mLoader->GetStream(j)->Data->GetNumberOfPoints() > 0)
 	{
-		ptr = (T *)this->mLoader->GetStream(j)->Points->GetVoidPointer(0);
+		ptr = (T *)this->mLoader->GetStream(j)->Points()->GetVoidPointer(0);
 		if(ptr == 0) continue;
 
-		if(j == 0)
+		if(start)
 		{
+			start = false;
 			for(i=0; i<3; i++)
 			{
 				min[i] = ptr[i];
@@ -976,7 +870,7 @@ void iParticleHelper::AutoScalePositions()
 			}
 		}
 
-		np = this->mLoader->GetStream(j)->Points->GetNumberOfPoints();
+		np = this->mLoader->GetStream(j)->Points()->GetNumberOfPoints();
 		for(l=0; l<np; l++)
 		{
 			for(i=0; i<3; i++)
@@ -996,12 +890,12 @@ void iParticleHelper::AutoScalePositions()
 
 	r = 2.0/r;
 
-	for(j=0; j<this->mLoader->NumStreams(); j++) if(this->mLoader->GetStream(j)->Points != 0)
+	for(j=0; j<this->mLoader->NumStreams(); j++) if(this->mLoader->GetStream(j)->Data->GetNumberOfPoints() > 0)
 	{
-		ptr = (T *)this->mLoader->GetStream(j)->Points->GetVoidPointer(0);
+		ptr = (T *)this->mLoader->GetStream(j)->Points()->GetVoidPointer(0);
 		if(ptr == 0) continue;
 
-		np = this->mLoader->GetStream(j)->Points->GetNumberOfPoints();
+		np = this->mLoader->GetStream(j)->Points()->GetNumberOfPoints();
 		for(l=0; l<np; l++)
 		{
 			for(i=0; i<3; i++)
@@ -1020,12 +914,39 @@ iParticleFileLoader::ParticleStream::ParticleStream()
 {
 	Included = InFile = true;
 	DownsampleFactor = 1;
-	NumAttributesInFile = NumAttributesInData = 0;
+	NumVariablesInFile = NumVariablesInData = 0;
 	NumSelected = 0;
 	Data = 0;
-	Points = 0;
-	Verts = 0;
-	Scalars = 0;
+}
+
+
+iParticleFileLoader::ParticleStream::~ParticleStream()
+{
+	if(Data != 0) Data->Delete();
+}
+
+
+vtkPoints* iParticleFileLoader::ParticleStream::Points() const
+{
+	IASSERT(Data);
+	vtkPoints *p = Data->GetPoints(); IASSERT(p);
+	return p;
+}
+
+
+vtkCellArray* iParticleFileLoader::ParticleStream::Verts() const
+{
+	IASSERT(Data);
+	vtkCellArray *c = Data->GetVerts(); IASSERT(c);
+	return c;
+}
+
+
+vtkFloatArray* iParticleFileLoader::ParticleStream::Scalars() const
+{
+	IASSERT(Data);
+	IASSERT(Data->GetPointData());
+	return vtkFloatArray::SafeDownCast(Data->GetPointData()->GetScalars());
 }
 
 
@@ -1037,6 +958,6 @@ iParticleFileLoader::Stream* iParticleFileLoader::CreateNewStream() const
 
 iParticleFileLoader::ParticleStreamExtras::ParticleStreamExtras()
 {
-	DensityAttribute = -2;
-	OrderIsAttribute = false;
+	DensityVariable = -2;
+	AddOrderAsVariable = false;
 }
