@@ -51,7 +51,6 @@ class vtkPolyData;
 class iParticleFileLoader : public iFileLoader
 {
 
-	friend class iBasicParticlesFileLoader;
 	friend class iParticleHelper;
 
 public:
@@ -67,11 +66,11 @@ public:
 	void SetDownsampleFactor(int type, int value);
 	int GetDownsampleFactor(int type) const;
 
-	void SetDensityAttribute(int type, int attr);
-	int GetDensityAttribute(int type) const;
+	void SetDensityVariable(int type, int var);
+	int GetDensityVariable(int type) const;
 
-	void SetOrderIsAttribute(int type, bool s);
-	bool GetOrderIsAttribute(int type) const;
+	void SetAddOrderAsVariable(int type, bool s);
+	bool GetAddOrderAsVariable(int type) const;
 
 	void SetNumNeighbors(int num);
 	int GetNumNeighbors() const;
@@ -80,13 +79,14 @@ public:
 
 protected:
 
+	iParticleFileLoader(iDataReader *r, int priority = 300, bool useExtras = true);
 	iParticleFileLoader(iDataReaderExtension *ext, int priority = 300, bool useExtras = true);
 	virtual ~iParticleFileLoader();
 
 	struct ParticleStreamExtras
 	{
-		int DensityAttribute;
-		bool OrderIsAttribute;
+		int DensityVariable;
+		bool AddOrderAsVariable;
 
 		ParticleStreamExtras();
 	};
@@ -95,49 +95,49 @@ protected:
 	{
 		bool Included, InFile;
 		int DownsampleFactor;
-		int NumAttributesInFile, NumAttributesInData;
+		int NumVariablesInFile, NumVariablesInData;
 		vtkIdType NumTotal;
 		vtkIdType NumSelected;
-		vtkPolyData *Data;
-		vtkPoints *Points;
-		vtkCellArray *Verts;
-		vtkFloatArray *Scalars;
 		ParticleStreamExtras Extras;
+		vtkPolyData *Data;
 
 		ParticleStream();
+		virtual ~ParticleStream();
+		vtkPoints* Points() const;
+		vtkCellArray* Verts() const;
+		vtkFloatArray* Scalars() const;
 	};
 	virtual Stream* CreateNewStream() const;
 	inline ParticleStream* GetStream(int i) const { return static_cast<ParticleStream*>(iFileLoader::GetStream(i)); } // no bound checking for speed
 
-	virtual void FinalizeBody();
-	virtual void ShiftDataBody(vtkDataSet *data, double dx[3]);
+	virtual void LoadFileBody(const iString &suffix, const iString &fname);
+	virtual void ShiftDataBody(vtkDataSet *data, const double *dx);
+
+	virtual void LoadParticleFileBody(const iString &suffix, const iString &fname) = 0;
 
 	virtual void AddExtras(ParticleStream *stream);
 
 	//
 	//  helper functions
 	//
+	void WrapPositions(vtkPoints *points);
 	void FinalizePolyData(vtkPolyData *data);
 	void ShiftPolyData(vtkPolyData *data, int d, double dx);
 
-	bool ReadPositions(iFile &F, int inNum, int outOffset, float updateStart, float updateDuration, float *scale, float *offset);
-	bool ReadPositions(iFile &F, int inNum, int outOffset, float updateStart, float updateDuration, double *scale, double *offset);
-	bool ReadAttributes(iFile &F, int inNum, int outOffset, float updateStart, float updateDuration, float *scale = 0);
-	bool ReadIntAttributes(iFile &F, int inNum, int outOffset, float updateStart, float updateDuration);
+	bool ReadPositions(iFile &F, int inNum, int outOffset, double updateStart, double updateDuration, float *scale, float *offset);
+	bool ReadPositions(iFile &F, int inNum, int outOffset, double updateStart, double updateDuration, double *scale, double *offset);
+	bool ReadVariables(iFile &F, int inNum, int outOffset, double updateStart, double updateDuration, float *scale = 0);
+	bool ReadIntVariables(iFile &F, int inNum, int outOffset, double updateStart, double updateDuration);
 
 	void AutoScalePositions();
 
-	void ConfigureStreams(vtkIdType *ntot, int *natt, bool paf = true);
-	void ReleaseStreams();
-	void SetErrorMessage(const iString &message);
+	void ConfigureStreams(vtkIdType *ntot, int *nvar, bool paf = true);
 
 	iParticleDownsampleIterator mIterator; // value, not the pointer, for efficiency (to remove one level of indirection in loops)
 	iParticleDensityEstimator *mDensityEstimator;
 
 private:
 
-	iParticleFileLoader(iDataReader *r, int priority = 300, bool useExtras = true);
-
 	void Define();
 
 	//
@@ -169,21 +169,21 @@ inline int iParticleFileLoader::GetDownsampleFactor(int type) const
 }
 
 
-inline int iParticleFileLoader::GetDensityAttribute(int type) const
+inline int iParticleFileLoader::GetDensityVariable(int type) const
 {
 	if(type>=0 && type<this->NumStreams())
 	{
-		return this->GetStream(type)->Extras.DensityAttribute;
+		return this->GetStream(type)->Extras.DensityVariable;
 	}
 	else return 1;
 }
 
 
-inline bool iParticleFileLoader::GetOrderIsAttribute(int type) const
+inline bool iParticleFileLoader::GetAddOrderAsVariable(int type) const
 {
 	if(type>=0 && type<this->NumStreams())
 	{
-		return this->GetStream(type)->Extras.OrderIsAttribute;
+		return this->GetStream(type)->Extras.AddOrderAsVariable;
 	}
 	else return false;
 }
