@@ -38,31 +38,31 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iParticleProbeFilter::iParticleProbeFilter(iViewSubject *vo) : iProbeFilter(vo)
+iParticleProbeFilter::iParticleProbeFilter(iDataConsumer *consumer) : iProbeFilter(consumer)
 {
 }
 
 
-void iParticleProbeFilter::ProduceOutput()
+void iParticleProbeFilter::ProvideOutput()
 {
-	vtkDataObject *input = this->GetInput();
-	vtkDataSet *output = this->GetOutput();
-	vtkDataObject *source = this->GetSource();
+	vtkDataSet *input = this->InputData();
+	vtkDataSet *output = this->OutputData();
+	vtkDataSet *source = this->SourceData();
 
 	output->ShallowCopy(input);
 
-	if(source->IsA("vtkDataSet") && input->IsA("vtkPointSet") && output->IsA("vtkPointSet"))
+	if(input->IsA("vtkPointSet") && output->IsA("vtkPointSet"))
 	{
 		vtkDataArray *atts = vtkDataSet::SafeDownCast(source)->GetPointData()->GetScalars();
 		if(atts!=0 && atts->GetSize()>0)
 		{
-			vtkFloatArray *outScalars = vtkFloatArray::New(); IERROR_ASSERT(outScalars);
+			vtkFloatArray *outScalars = vtkFloatArray::New(); IERROR_CHECK_MEMORY(outScalars);
 			outScalars->SetNumberOfComponents(atts->GetNumberOfComponents());
 			
-			vtkPointLocator *locator = vtkPointLocator::New(); IERROR_ASSERT(locator);
+			vtkPointLocator *locator = vtkPointLocator::New(); IERROR_CHECK_MEMORY(locator);
 			locator->SetDataSet(vtkDataSet::SafeDownCast(source));
 			locator->BuildLocator();
 
