@@ -31,12 +31,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "igenericfilter.h"
-#include <vtkPolyDataToPolyDataFilter.h>
+#include <vtkPolyDataAlgorithm.h>
 
 
-class iHistogramMaker;
-class iRangeCollection;
-class iRangeMapping;
+#include "iarray.h"
+#include "ipair.h"
+
+class iParticleViewSubject;
 
 class vtkPoints;
 class vtkCellArray;
@@ -44,67 +45,48 @@ class vtkFloatArray;
 class vtkFloatArray;
 
 
-class iParticleSplitter : public iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>
+class iParticleSplitter : public iGenericPolyDataFilter<vtkPolyDataAlgorithm>
 {
 	
-	IGENERICFILTER_DECLARE(iParticleSplitter,vtkPolyDataToPolyDataFilter);
+	friend class iParticleViewSubject;
+	iGenericFilterTypeMacro(iParticleSplitter,vtkPolyDataAlgorithm);
 
 public:
 	
-	int GetNumberOfPieces() const;
+	inline int GetNumberOfPieces() const { return mRanges.Size(); }
 
-	void SetAttributeToSplit(int a);
-	inline int GetAttributeToSplit() const { return mAtt; }
+	void SetSplitVariable(int v);
+	inline int GetSplitVariable() const { return mSplitVariable; }
 	
-	void SetSplitRangesStretch(int s);
-	int GetSplitRangesStretch() const;
-	
-	void SetSplitRangesTiled(bool s);
-	bool GetSplitRangesTiled() const;
-	
-	void SetSplitRangesMinMax(float amin, float amax);
-	void GetSplitRangesMinMax(float &amin, float &amax) const;
+	void SetSorterMode(bool s);
+	inline bool GetSorterMode() const { return mSorterMode; }
 
-	void SetSplitRangeLimits(int n, float amin, float amax);
-	void GetSplitRangeLimits(int n, float &amin, float &amax) const;
+	const iPair& GetPieceRange(int n) const { return mRanges[n]; }
+	void SetPieceRange(int n, const iPair &p);
 
-	void ResetRange(){ mRangeSet = false; }
-
-	bool CreateGroup();
-	bool DeleteGroup(int n);
-
-	iRangeMapping* GetSplitRanges(); // for direct access
+	bool CreatePiece(const iPair &p);
+	bool DeletePiece(int n);
 
 	void TakeOverData(bool);
-
 	float GetMemorySize() const;
 
 protected:
 	
 	virtual ~iParticleSplitter();
 
-	virtual void SyncWithData(const iDataSyncRequest &r);
-
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 	
 private:
 
-	void UpdateRange();
+	int mSplitVariable;
+	bool mOwnsData, mSorted, mSorterMode;
 
-	bool mRangeSet, mOwnsData;
-
-	int mAtt;
-	static float mAttRange;
-	bool mSorted;
-
-	iRangeCollection *mRanges;
-	iRangeMapping *mMapping;
-	iHistogramMaker *mHistogramMaker;
+	iArray<iPair> mRanges;
 
 	vtkPoints *mSavedPoints;
 	vtkCellArray *mSavedVerts;
 	vtkFloatArray *mSavedNorms;
-	vtkFloatArray *mSavedAtts;
+	vtkFloatArray *mSavedVars;
 
 	unsigned long mSortingMTime;
 };
