@@ -30,10 +30,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iactor.h"
-#include "icommoneventobservers.h"
 #include "idata.h"
 #include "idataformatter.h"
-#include "idatahelper.h"
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "idatasubject.h"
@@ -41,12 +39,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iobjectfactory.h"
 #include "iprobefilter.h"
 #include "iviewmodule.h"
+#include "iviewmoduleeventobservers.h"
 #include "iviewsubject.h"
 #include "iviewsubjectobserver.h"
 
 #include <vtkCellArray.h>
 #include <vtkCellPicker.h>
 #include <vtkFloatArray.h>
+#include <vtkImageData.h>
 #include <vtkPointData.h>
 #include <vtkPointLocator.h>
 #include <vtkPointPicker.h>
@@ -56,22 +56,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkProperty.h>
 #include <vtkPropPicker.h>
 #include <vtkSphereSource.h>
-#include <vtkStructuredPoints.h>
 
 //
 //  templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
+#include "iproperty.tlh"
 
 
 //
 //  Picker must be an object so that it can be created by the ObjectFactory
 //
-IOBJECT_DEFINE_TYPE(iPicker,Picker,pi,iObjectType::_Helper);  // helper type
-
-IOBJECT_DEFINE_KEY(iPicker,Accuracy,a,Float,1);
-IOBJECT_DEFINE_KEY(iPicker,PickMethod,m,Int,1);
-IOBJECT_DEFINE_KEY(iPicker,PointSize,ps,Float,1);
 
 
 namespace iPicker_Private
@@ -180,25 +175,26 @@ namespace iPicker_Private
 
 		PickHandler(iPicker *parent)
 		{
-			mParent = parent; IERROR_ASSERT(parent);
+			IASSERT(parent);
+			mParent = parent;
 
 			//
 			//  Pickers
 			//
-			mDevices[0] = CellPicker::New(); IERROR_ASSERT(mDevices[0]);
-			mDevices[1] = PointPicker::New(); IERROR_ASSERT(mDevices[1]);
-			mDevices[2] = ObjectPicker::New(); IERROR_ASSERT(mDevices[2]);
+			mDevices[0] = CellPicker::New(); IERROR_CHECK_MEMORY(mDevices[0]);
+			mDevices[1] = PointPicker::New(); IERROR_CHECK_MEMORY(mDevices[1]);
+			mDevices[2] = ObjectPicker::New(); IERROR_CHECK_MEMORY(mDevices[2]);
 
 			//
 			//  Observer
 			//
-			mObserver = iPickEventObserver::New(mParent->GetViewModule()); IERROR_ASSERT(mObserver);
+			mObserver = iPickEventObserver::New(mParent->GetViewModule()); IERROR_CHECK_MEMORY(mObserver);
 			this->AddObserver(vtkCommand::StartPickEvent,mObserver);
 			this->AddObserver(vtkCommand::EndPickEvent,mObserver);
 			int i;
 			for(i=0; i<NumPickMethods; i++)
 			{
-				mDevices[i]->AddObserver(vtkCommand::AbortCheckEvent,mParent->GetViewModule()->GetAbortRenderEventObserver());
+				mDevices[i]->AddObserver(vtkCommand::AbortCheckEvent,mParent->GetViewModule()->GetRenderEventObserver());
 			}
 		}
 
@@ -222,32 +218,40 @@ using namespace iPicker_Private;
 	
 iPicker* iPicker::New(iViewModule *vm)
 {
-	IERROR_ASSERT(vm);
-	iPicker *tmp = new iPicker(vm); IERROR_ASSERT(tmp);
+	static iString LongName("Picker");
+	static iString ShortName("pi");
+
+	IASSERT(vm);
+	iPicker *tmp = new iPicker(vm,LongName,ShortName); IERROR_CHECK_MEMORY(tmp);
 	iObjectFactory::InstallExtensions(tmp);
 	return tmp;
 }
 
 
-iPicker::iPicker(iViewModule *vm) : iExtendableObject("Picker"), mViewModule(vm), mDataFormatter(vm), mPos(vm)
+iPicker::iPicker(iViewModule *vm, const iString &fname, const iString &sname) : iExtendableObject(vm,fname,sname), iViewModuleComponent(vm), mDataFormatter(vm), mPosition(vm),
+	Position(iObject::Self(),static_cast<iPropertyQuery<iType::Vector>::GetterType>(&iPicker::GetBoxPosition),"Position","x"),
+	iObjectConstructPropertyMacroS(Float,iPicker,Accuracy,a),
+	iObjectConstructPropertyMacroS(Int,iPicker,PickMethod,m),
+	iObjectConstructPropertyMacroS(Float,iPicker,PointSize,ps)
 {
+	mRenderMode = RenderMode::Self;
+
 	mSubjectName = "";
-	mSubjectId = ViewSubject::Id::Undefined;
 	mDataTypePointer = 0;
-	mPickMethod = PickMethod::Object;
+	mPickMethod = PickMethod::Point;
 
 	//
 	//  Handler
 	//
-	mHandler = PickHandler::New(this); IERROR_ASSERT(mHandler);
-
-	this->SetAccuracy(0.02f);
+	mHandler = PickHandler::New(this); IERROR_CHECK_MEMORY(mHandler);
+	mAccuracy = 0.02;
+	this->SetAccuracy(mAccuracy);
 
 	//
 	//  Graphical representation
 	//
-	mPointActor = iActor::New(); IERROR_ASSERT(mPointActor);
-	mPointSource = vtkSphereSource::New(); IERROR_ASSERT(mPointSource);
+	mPointActor = iActor::New(); IERROR_CHECK_MEMORY(mPointActor);
+	mPointSource = vtkSphereSource::New(); IERROR_CHECK_MEMORY(mPointSource);
 
 	mPointSize = 0.1;
 	this->SetPointSize(mPointSize);
@@ -261,13 +265,13 @@ iPicker::iPicker(iViewModule *vm) : iExtendableObject("Picker"), mViewModule(vm)
 	//
 	//  PolyData inout for a probe filter
 	//
-	mProbeInput = vtkPolyData::New(); IERROR_ASSERT(mProbeInput);
-	vtkCellArray *v = vtkCellArray::New(); IERROR_ASSERT(v);
+	mProbeInput = vtkPolyData::New(); IERROR_CHECK_MEMORY(mProbeInput);
+	vtkCellArray *v = vtkCellArray::New(); IERROR_CHECK_MEMORY(v);
 	v->InsertNextCell(1);
 	v->InsertCellPoint(0);
 	mProbeInput->SetVerts(v);
 	v->Delete();
-	vtkPoints *p = vtkPoints::New(VTK_DOUBLE); IERROR_ASSERT(p);
+	vtkPoints *p = vtkPoints::New(VTK_DOUBLE); IERROR_CHECK_MEMORY(p);
 	p->SetNumberOfPoints(1);
 	p->SetPoint(0,0.0,0.0,0.0);
 	mProbeInput->SetPoints(p);
@@ -288,24 +292,23 @@ iPicker::~iPicker()
 void iPicker::Modified()
 {
 	mHandler->Modified();
-	this->ClearCache();
 }
 
 
 void iPicker::UpdateReport()
 {
 	mSubjectName = "Unknown";
-	mPos = mHandler->GetPickPosition();
+	mPosition = mHandler->GetPickPosition();
 
 	this->SetPointSize(mPointSize);
-	mPointActor->SetPosition(mPos);
+	mPointActor->SetPosition(mPosition);
 
 	mDataFormatter->ClearReport();
 	this->UpdateReportBody(); // this can replace mPointObject via its extensions
 
-	mPointActor->SetInput(mPointSource->GetOutput());
+	mPointActor->SetInputConnection(mPointSource->GetOutputPort());
 	mPointActor->SetScaled(true);
-	mPointActor->SetPosition(mPos);
+	mPointActor->SetPosition(mPosition);
 
 	//
 	//  Check if extensions want to modify the point actor
@@ -325,7 +328,6 @@ void iPicker::UpdateReport()
 
 void iPicker::UpdateReportBody()
 {
-	int j;
 	iString s1, s2;
 
 	//
@@ -342,13 +344,11 @@ void iPicker::UpdateReportBody()
 
 	if(obs != 0)
 	{
-		mSubjectId = obs->GetSubjectId();
 		mSubjectName = obs->GetSubjectName();
-		mDataTypePointer = &obs->GetDataType();
+		mDataTypePointer = &obs->GetSubjectDataType();
 	}
 	else
 	{
-		mSubjectId = ViewSubject::Id::Undefined;
 		mSubjectName = "Unknown";
 		mDataTypePointer = 0;
 	}
@@ -364,16 +364,16 @@ void iPicker::UpdateReportBody()
 	//
 	//  Use the ProbeFilter to find attribute values
 	//
-	mProbeInput->GetPoints()->SetPoint(0,mPos);
+	mProbeInput->GetPoints()->SetPoint(0,mPosition);
 	iProbeFilter *probe = subject->CreateProbeFilter(obs->GetSubject());
-	probe->SetInput(mProbeInput);
-	probe->SetSource(subject->GetData());
+	probe->SetInputData(mProbeInput);
+	probe->SetSourceData(subject->GetData());
 	probe->Update();
 	vtkPolyData *out = probe->GetPolyDataOutput();
 
 	if(out==0 || out->GetPointData()==0)
 	{
-		IERROR_LOW("Unable to probe data for the picked object");
+		IBUG_WARN("Unable to probe data for the picked object");
 		return;
 	}
 
@@ -386,50 +386,41 @@ void iPicker::UpdateReportBody()
 		iRequiredCast<iPickerExtension>(INFO,mExtensions[i])->AddInfo(*mDataTypePointer);
 	}
 
-	iDataHelper h(out);
 	vtkDataArray *d = 0;
 	int nvar = 0;
-	if(h.IsThereScalarData())
+	if(subject->IsThereScalarData())
 	{
 		d = out->GetPointData()->GetScalars();
 		nvar = lim->GetNumVars();
 		if(d==0 || nvar<1 || d->GetNumberOfComponents()!=nvar || !d->IsA("vtkFloatArray"))
 		{
-			IERROR_LOW("Unable to probe data for the picked object");
+			IBUG_WARN("Unable to probe data for the picked object");
 			return;
 		}
 		float *v = (float *)d->GetVoidPointer(0);
-		//
-		//  Make the correction for the surface
-		//
-		if(mSubjectId == ViewSubject::Id::Surface)
-		{
-			j = obs->GetIsoSurfaceData().Var;
-			if(j>=0 && j<nvar) v[j] = obs->GetIsoSurfaceData().Level;
-		}
 		mDataFormatter->FormatScalarData(lim,nvar,v);
 	}
 
-	if(h.IsThereVectorData())
+	if(subject->IsThereVectorData())
 	{
 		d = out->GetPointData()->GetVectors();
 		nvar = 3;
 		if(d==0 || nvar<1 || d->GetNumberOfComponents()!=nvar || !d->IsA("vtkFloatArray"))
 		{
-			IERROR_LOW("Unable to probe data for the picked object");
+			IBUG_WARN("Unable to probe data for the picked object");
 			return;
 		}
 		float *v = (float *)d->GetVoidPointer(0);
 		mDataFormatter->FormatVectorData(lim,-1,v);
 	}
 
-	if(h.IsThereTensorData())
+	if(subject->IsThereTensorData())
 	{
 		d = out->GetPointData()->GetTensors();
 		nvar = 9;
 		if(d==0 || nvar<1 || d->GetNumberOfComponents()!=nvar || !d->IsA("vtkFloatArray"))
 		{
-			IERROR_LOW("Unable to probe data for the picked object");
+			IBUG_WARN("Unable to probe data for the picked object");
 			return;
 		}
 		float *v = (float *)d->GetVoidPointer(0);
@@ -440,7 +431,7 @@ void iPicker::UpdateReportBody()
 }
 
 
-void iPicker::SetPointSize(float s)
+bool iPicker::SetPointSize(float s)
 {
 	if(s > 0.0)
 	{
@@ -448,7 +439,9 @@ void iPicker::SetPointSize(float s)
 		mPointActor->SetScaled(true);
 		mPointActor->SetBasicScale(mPointSize);
 		this->Modified();
+		return true;
 	}
+	else return false;
 }
 
 
@@ -462,57 +455,36 @@ void iPicker::ShowPickedPoint(bool s)
 	{
 		mPointActor->VisibilityOff();
 	}
-	this->GetViewModule()->Render();
+	this->RequestRender();
 }
 
 
-//
-//  Two functions used in saving/restoring the state and in creating new instances with
-//
-void iPicker::ExtendableObjectPackStateBody(iString &s) const
-{
-	this->PackValue(s,KeyPickMethod(),mPickMethod);
-	this->PackValue(s,KeyPointSize(),mPointSize);
-	this->PackValue(s,KeyAccuracy(),float(mHandler->GetTolerance()));
-}
-
-
-void iPicker::ExtendableObjectUnPackStateBody(const iString &s)
-{
-	int i; float f;
-
-	if(this->UnPackValue(s,KeyPickMethod(),i)) this->SetPickMethod(i);
-	if(this->UnPackValue(s,KeyPointSize(),f)) this->SetPointSize(f);
-	if(this->UnPackValue(s,KeyAccuracy(),f)) this->SetAccuracy(f);
-}
-
-
-void iPicker::SetPickMethod(int s)
+bool iPicker::SetPickMethod(int s)
 {
 	if(s>=0 && s<NumPickMethods)
 	{
 		mPickMethod = s;
-		this->ClearCache();
+		return true;
 	}
+	else return false;
 }
 
 
-void iPicker::SetAccuracy(float s)
+bool iPicker::SetAccuracy(float s)
 {
 	if(s > 0.0f)
 	{
 		mHandler->SetTolerance(s);
-		this->ClearCache();
+		return true;
 	}
+	else return false;
 }
 
 
 //
 //  Extension class
 //
-IOBJECTEXTENSION_DEFINE_ABSTRACT(iPicker);
-
-void iPickerExtension::Define()
+iObjectExtensionAbstractConstructorBeginMacro(iPicker)
 {
 }
 
