@@ -31,6 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iextendableobject.h"
+#include "iviewmodulecomponent.h"
 
 
 #include "iposition.h"
@@ -58,23 +59,23 @@ namespace iParameter
 };
 
 
-class iPicker : public iExtendableObject
+class iPicker : public iExtendableObject, public iViewModuleComponent
 {
 
-	IPOINTER_AS_PART(ViewModule);
 	IPOINTER_AS_USER(DataFormatter);
 
 public:
 
 	vtkTypeMacro(iPicker,iExtendableObject);
 	static iPicker* New(iViewModule *vm = 0);
-	static const iObjectType& Type();
 
-	IOBJECT_DECLARE_GETSET2(Accuracy,float);
-	IOBJECT_DECLARE_GETSET1(PickMethod,int);
-	IOBJECT_DECLARE_GETSET1(PointSize,float);
+	iObjectPropertyMacro1S(Accuracy,Float);
+	iObjectPropertyMacro1S(PickMethod,Int);
+	iObjectPropertyMacro1S(PointSize,Float);
+	iPropertyQuery<iType::Vector> Position;
 
-	inline const iPosition& GetPosition() const { return mPos; }
+	inline const iPosition& GetPosition() const { return mPosition; }
+	inline const iVector3D& GetBoxPosition() const { return mPosition.BoxValue(); }
 	inline const iString& GetObjectName() const { return mSubjectName; }
 
 	void ShowPickedPoint(bool s);
@@ -86,19 +87,15 @@ public:
 
 protected:
 
-	iPicker(iViewModule *vm);
+	iPicker(iViewModule *vm, const iString &fname, const iString &sname);
 	virtual ~iPicker();
 
-	virtual void ExtendableObjectPackStateBody(iString &) const;
-	virtual void ExtendableObjectUnPackStateBody(const iString &);
-
 	virtual void UpdateReportBody();
 
 private:
 
-	iPosition mPos;
+	iPosition mPosition;
 	iString mSubjectName;
-	int mSubjectId, mPickMethod;
 	const iDataType *mDataTypePointer;
 	vtkPolyData *mProbeInput;
 
@@ -112,14 +109,13 @@ private:
 	//
 	iActor *mPointActor;
 	vtkSphereSource *mPointSource;
-	float mPointSize, mAccuracy;
 };
 
 
 class iPickerExtension : public iObjectExtension
 {
 
-	IOBJECTEXTENSION_DECLARE_ABSTRACT(iPicker);
+	iObjectExtensionDeclareAbstractMacro(iPicker);
 
 public:
 
