@@ -36,7 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 class iPiecewiseFunctionHelper : public vtkPiecewiseFunction
@@ -54,14 +54,12 @@ public:
 		int i;
 
 		this->RemoveAllPoints();
-		for(i=0; i<mParent->mArr.Size(); i++) this->AddPoint(255*mParent->mArr[i].X,mParent->mArr[i].Y);
-
-		vtkPiecewiseFunction::Update();
+		for(i=0; i<mParent->mArray.Size(); i++) this->AddPoint(255*mParent->mArray[i].X,mParent->mArray[i].Y);
 	}
 
 	void ParentChanged()
 	{
-		this->Update(); // Very inefficient, but needed to work around a VTK 5.0.0 bug
+		this->Update();
 		mParent->Modified();
 	}
 
@@ -76,18 +74,19 @@ private:
 //
 iPiecewiseFunction* iPiecewiseFunction::New(float ymin, float ymax)
 {
-	return new iPiecewiseFunction(ymin,ymax,10);
+	iPiecewiseFunction *tmp = new iPiecewiseFunction(ymin,ymax,10); IERROR_CHECK_MEMORY(tmp);
+	return tmp;
 }
 
 
-iPiecewiseFunction::iPiecewiseFunction(float ymin, float ymax, int inc) : mArr(inc)
+iPiecewiseFunction::iPiecewiseFunction(float ymin, float ymax, int inc) : mArray(inc)
 {
 	mYmin = ymin;
 	mYmax = ymax;
-	mArr.Add(Point(0.0,ymin));
-	mArr.Add(Point(1.0,ymax));
+	mArray.Add(iPair(0.0,ymin));
+	mArray.Add(iPair(1.0,ymax));
 	
-	mHelper = new iPiecewiseFunctionHelper(this); IERROR_ASSERT(mHelper);
+	mHelper = new iPiecewiseFunctionHelper(this); IERROR_CHECK_MEMORY(mHelper);
 	mHelper->ParentChanged();
 }
 
@@ -108,11 +107,14 @@ void iPiecewiseFunction::Copy(const iPiecewiseFunction *f)
 {
 	if(this==f || f==0) return;
 
+	mArray.Clear();
 	int i;
-	for(i=0; i<mArr.Size() && i<f->mArr.Size(); i++) mArr[i] = f->mArr[i];
-
-	while(mArr.Size() < f->mArr.Size()) mArr.Add(f->mArr[mArr.Size()]);
-	while(mArr.Size() > f->mArr.Size()) mArr.RemoveLast();
+	for(i=0; i<f->N(); i++)
+	{
+		mArray.Add(f->mArray[i]);
+	}
+	mYmin = f->mYmin;
+	mYmax = f->mYmax;
 
 	mHelper->ParentChanged();
 }
@@ -122,10 +124,10 @@ void iPiecewiseFunction::SetMinMax(float ymin, float ymax)
 {
 	mYmin = ymin;
 	mYmax = ymax;
-	for(int i=0; i<mArr.Size(); i++) 
+	for(int i=0; i<mArray.Size(); i++) 
 	{
-		mArr[i].Y = (mArr[i].Y > mYmax) ? mYmax : mArr[i].Y;
-		mArr[i].Y = (mArr[i].Y < mYmin) ? mYmin : mArr[i].Y;
+		mArray[i].Y = (mArray[i].Y > mYmax) ? mYmax : mArray[i].Y;
+		mArray[i].Y = (mArray[i].Y < mYmin) ? mYmin : mArray[i].Y;
 	}
 
 	mHelper->ParentChanged();
@@ -136,67 +138,71 @@ void iPiecewiseFunction::AddPoint(int n)
 {
 	n++;
 	if(n < 1) n = 1;
-	if(n > mArr.MaxIndex()) n = mArr.MaxIndex();
+	if(n > mArray.MaxIndex()) n = mArray.MaxIndex();
 
-	mArr.Add(Point(0.5*(mArr[n-1].X+mArr[n].X),0.5*(mArr[n-1].Y+mArr[n].Y)));
+	mArray.Add(iPair(0.5*(mArray[n-1].X+mArray[n].X),0.5*(mArray[n-1].Y+mArray[n].Y)));
 	mHelper->ParentChanged();
 }
 
 
-void iPiecewiseFunction::AddPoint(float x, float y) 
+void iPiecewiseFunction::AddPoint(const iPair &p) 
 {
-	if(x>mArr[0].X && x<mArr.Last().X) 
-	{
-		mArr.Add(Point(x,y));
-		mHelper->ParentChanged();
-	}
+	float x = p.X;
+	if(x < 0.0) x = 0.0;
+	if(x > 1.0) x = 1.0;
+	float y = p.Y;
+	if(y < mYmin) y = mYmin;
+	if(y > mYmax) y = mYmax;
+	mArray.Add(iPair(x,y));
+	mHelper->ParentChanged();
 }
 
 
 void iPiecewiseFunction::RemovePoint(int n) 
 {
-	if(n>0 && n<mArr.MaxIndex() && mArr.Size()>2) 
+	if(n>0 && n<mArray.MaxIndex() && mArray.Size()>2) 
 	{
-		mArr.iArray<Point>::Remove(n);
+		mArray.iArray<iOrderedPair>::Remove(n);
 		mHelper->ParentChanged();
 	}
 }
 
 
-void iPiecewiseFunction::MovePoint(int n, float x, float y) 
+void iPiecewiseFunction::MovePoint(int n, const iPair &p) 
 {
-	if(n>0 && n<mArr.MaxIndex()) 
+	if(n>0 && n<mArray.MaxIndex()) 
 	{
-		float xl = mArr[n-1].X;
-		float xr = mArr[n+1].X;
-		x = (x < xl) ? xl : x;
-		x = (x > xr) ? xr : x;
-		y = (y < mYmin) ? mYmin : y;
-		y = (y > mYmax) ? mYmax : y;
-		mArr[n] = Point(x,y);
+		float x = p.X;
+		if(x < mArray[n-1].X) x = mArray[n-1].X;
+		if(x > mArray[n+1].X) x = mArray[n+1].X;
+		float y = p.Y;
+		if(y < mYmin) y = mYmin;
+		if(y > mYmax) y = mYmax;
+		mArray[n] = iPair(x,y);
 	} 
-	else if(n==0 || n==mArr.MaxIndex()) 
+	else if(n==0 || n==mArray.MaxIndex()) 
 	{
-		y = (y < mYmin) ? mYmin : y;
-		y = (y > mYmax) ? mYmax : y;
-		mArr[n].Y = y;
+		float y = p.Y;
+		if(y < mYmin) y = mYmin;
+		if(y > mYmax) y = mYmax;
+		mArray[n].Y = y;
 	}
 
 	mHelper->ParentChanged();
 }
 
 
-int iPiecewiseFunction::FindPoint(float x, float y, float &dmin) const
+int iPiecewiseFunction::FindPoint(const iPair &p, float &dmin) const
 {
 	int i, imin;
 	float d, dx, dy;
 	
 	dmin = iMath::_LargeFloat;
 	imin = -1;
-	for(i=0; i<mArr.Size(); i++) 
+	for(i=0; i<mArray.Size(); i++) 
 	{
-		dx = x - mArr[i].X;
-		dy = y - mArr[i].Y;
+		dx = p.X - mArray[i].X;
+		dy = p.Y - mArray[i].Y;
 		d = dx*dx + dy*dy;
 		if(d < dmin) 
 		{
@@ -214,19 +220,19 @@ float iPiecewiseFunction::GetValue(float x) const
 {
 	int i;
 	
-	if(x < mArr[0].X) return mArr[0].Y;
-	if(x > mArr.Last().X) return mArr.Last().Y;
+	if(x < mArray[0].X) return mArray[0].Y;
+	if(x > mArray[mArray.MaxIndex()].X) return mArray[mArray.MaxIndex()].Y;
 
-	for(i=1; i<mArr.MaxIndex() && mArr[i].X<x; i++);
-	return mArr[i].Y + (mArr[i].Y-mArr[i-1].Y)/(mArr[i].X-mArr[i-1].X+1.0e-30)*(x-mArr[i].X);
+	for(i=1; i<mArray.MaxIndex() && mArray[i].X<x; i++);
+	return mArray[i].Y + (mArray[i].Y-mArray[i-1].Y)/(mArray[i].X-mArray[i-1].X+1.0e-30)*(x-mArray[i].X);
 }
 
 
 void iPiecewiseFunction::Reset()
 {
-	while(mArr.Size() > 2) mArr.RemoveLast();
-	mArr[0] = Point(0.0,mYmin);
-	mArr[1] = Point(1.0,mYmax);
+	mArray.Clear();
+	mArray.Add(iPair(0.0,mYmin));
+	mArray.Add(iPair(1.0,mYmax));
 
 	mHelper->ParentChanged();
 }
