@@ -30,10 +30,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IPIECEWISEFUNCTION_H
 
 
-#include <vtkObject.h>
+#include "vtkObject.h"
 
 
 #include "iarray.h"
+#include "ipair.h"
 
 class iPiecewiseFunctionHelper;
 class iPiecewiseFunctionUser;
@@ -45,6 +46,7 @@ class vtkPiecewiseFunction;
 class iPiecewiseFunction : public vtkObject
 {
 	
+	friend class iPropertyPiecewiseFunction;
 	friend class iPiecewiseFunctionHelper;
 
 public:
@@ -52,20 +54,24 @@ public:
 	vtkTypeMacro(iPiecewiseFunction,vtkObject);
 	static iPiecewiseFunction* New(float ymin = 0.0f, float ymax = 1.0f);
 	
-	inline int N() const { return mArr.Size(); }
-	inline float X(int i) const { return mArr[i].X; }
-	inline float Y(int i) const { return mArr[i].Y; }
+	inline int N() const { return mArray.Size(); }
+	inline const iPair& P(int i) const { return mArray[i]; }
+	inline float X(int i) const { return mArray[i].X; }
+	inline float Y(int i) const { return mArray[i].Y; }
 	inline float Min() const { return mYmin; }
 	inline float Max() const { return mYmax; }
 
 	void SetMinMax(float ymin, float ymax);
 	void AddPoint(int n);
-	void AddPoint(float x, float y);
+	void AddPoint(const iPair &p);
 	void RemovePoint(int n);
-	void MovePoint(int n, float x, float y);
-	int FindPoint(float x, float y, float &d) const;
+	void MovePoint(int n, const iPair &p);
+	int FindPoint(const iPair &p, float &d) const;
 	float GetValue(float x) const;
 
+	inline void AddPoint(float x, float y){ this->AddPoint(iPair(x,y)); }
+	inline void MovePoint(int n, float x, float y){ this->MovePoint(n,iPair(x,y)); }
+
 	void Copy(const iPiecewiseFunction *f);
 	void Reset();
 	
@@ -76,17 +82,7 @@ protected:
 	iPiecewiseFunction(float ymin, float ymax, int inc);
 	virtual ~iPiecewiseFunction();
 
-	struct Point
-	{
-		float X;
-		float Y;
-		Point(){ X = Y = 0.0; }
-		Point(float x, float y){ X = x; Y = y; }
-		bool operator==(const Point &p) const { return (X == p.X); }
-		bool operator<(const Point &p) const { return (X < p.X); }
-	};
-
-	iOrderedArray<Point> mArr;
+	iOrderedArray<iOrderedPair> mArray;
 	float mYmin, mYmax;
 	iPiecewiseFunctionHelper *mHelper;
 };
