@@ -39,7 +39,7 @@ namespace iPointer
 	//
 	void Validate(void *ptr)
 	{
-		IERROR_ASSERT(ptr);
+		IASSERT(ptr);
 	}
 };
 
