@@ -30,11 +30,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
+#include "ispheresource.h"
 
 #include <vtkArrowSource.h>
 #include <vtkCellData.h>
 #include <vtkConeSource.h>
 #include <vtkCylinderSource.h>
+#include <vtkDecimatePro.h>
 #include <vtkFloatArray.h>
 #include <vtkMath.h>
 #include <vtkPlatonicSolidSource.h>
@@ -46,11 +48,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkReverseSense.h>
 #include <vtkSphereSource.h>
 
-//
-//  Templates
-//
-#include "igenericfiltertemplate.h"
-
 
 namespace iPointGlyph_Private
 {
@@ -58,7 +55,7 @@ namespace iPointGlyph_Private
 	{
 		int Type;  // for consistency checking
 		bool IsOriented;
-		char *Name;
+		const char *Name;
 	};
 
 	const PointType type[] = {
@@ -81,13 +78,13 @@ using namespace iParameter;
 using namespace iPointGlyph_Private;
 
 
-iPointGlyph* iPointGlyph::New(iViewSubject *vo)
+iPointGlyph* iPointGlyph::New()
 {
-	return new iPointGlyph(vo);
+	return new iPointGlyph();
 }
 
 
-iPointGlyph::iPointGlyph(iViewSubject *vo) : iGenericSource<vtkPolyDataSource,vtkPolyData>(vo,false)
+iPointGlyph::iPointGlyph()
 {
 	int i;
 
@@ -96,9 +93,11 @@ iPointGlyph::iPointGlyph(iViewSubject *vo) : iGenericSource<vtkPolyDataSource,vt
 	for(i=0; i<PointGlyphType::SIZE; i++) 
 	{
 		if(type[i].Type != i) vtkErrorMacro("Incorrectly configured object.");
-		mData[i] = vtkPolyData::New(); IERROR_ASSERT(mData[i]);
+		mData[i] = vtkPolyData::New(); IERROR_CHECK_MEMORY(mData[i]);
 	}
 
+	this->SetNumberOfInputPorts(0);
+
 	this->CreateData(3);
 }
 
@@ -129,14 +128,40 @@ void iPointGlyph::CreateData(int res)
 	if(res < 1) res = 1;
 	if(res > 100) res = 100;
 
+	vtkPolyDataNormals *pn = vtkPolyDataNormals::New(); IERROR_CHECK_MEMORY(pn);
+	pn->AutoOrientNormalsOn();
+	pn->ConsistencyOn();
+
 	//
 	//  Sphere
 	//
-	vtkSphereSource *ss = vtkSphereSource::New(); IERROR_ASSERT(ss);
+	/*
+	vtkSphereSource *ss = vtkSphereSource::New(); IERROR_CHECK_MEMORY(ss);
+	vtkDecimatePro *sf = vtkDecimatePro::New(); IERROR_CHECK_MEMORY(sf);
 	ss->SetThetaResolution(12*res);
 	ss->SetPhiResolution(6*res);
 	ss->SetRadius(0.5);
-	ss->LatLongTessellationOn();
+	ss->LatLongTessellationOff();
+	ss->Update();
+	ss->GetOutput()->GetPointData()->SetNormals(0);
+
+	sf->SetTargetReduction(0.5);
+	sf->PreserveTopologyOn();
+	sf->SetInputConnection(ss->GetOutputPort());
+
+	pn->ComputePointNormalsOn();
+	pn->SetInputConnection(sf->GetOutputPort());
+
+	pn->SetOutput(mData[PointGlyphType::Sphere]);
+	pn->Update();
+	sf->Delete();
+	ss->Delete();
+	done[PointGlyphType::Sphere] = true;
+	*/
+
+	iSphereSource *ss = iSphereSource::New(); IERROR_CHECK_MEMORY(ss);
+	ss->SetResolution(3*res);
+	ss->SetRadius(0.5);
 	ss->SetOutput(mData[PointGlyphType::Sphere]);
 	ss->Update();
 	ss->Delete();
@@ -145,12 +170,9 @@ void iPointGlyph::CreateData(int res)
 	//
 	//  Platonic solids
 	//
-	vtkPlatonicSolidSource *ps = vtkPlatonicSolidSource::New(); IERROR_ASSERT(ps);
-	vtkPolyDataNormals *pn = vtkPolyDataNormals::New(); IERROR_ASSERT(pn);
-	pn->AutoOrientNormalsOn();
-	pn->ConsistencyOn();
+	vtkPlatonicSolidSource *ps = vtkPlatonicSolidSource::New(); IERROR_CHECK_MEMORY(ps);
 	pn->ComputePointNormalsOff();
-	pn->SetInput(ps->GetOutput());
+	pn->SetInputConnection(ps->GetOutputPort());
 
 	pn->SetOutput(mData[PointGlyphType::Tetrahydron]);
 	pn->ComputeCellNormalsOn();
@@ -203,7 +225,7 @@ void iPointGlyph::CreateData(int res)
 	//
 	//  Cone
 	//
-	vtkConeSource *cs = vtkConeSource::New(); IERROR_ASSERT(cs);
+	vtkConeSource *cs = vtkConeSource::New(); IERROR_CHECK_MEMORY(cs);
 	cs->SetResolution(6*res);
 	cs->SetOutput(mData[PointGlyphType::Cone]);
 	cs->Update();
@@ -216,7 +238,7 @@ void iPointGlyph::CreateData(int res)
 	//
 	//  Cylinder
 	//
-	vtkCylinderSource *ts = vtkCylinderSource::New(); IERROR_ASSERT(ts);
+	vtkCylinderSource *ts = vtkCylinderSource::New(); IERROR_CHECK_MEMORY(ts);
 	ts->SetResolution(6*res);
 	ts->SetOutput(mData[PointGlyphType::Cylinder]);
 	ts->Update();
@@ -228,7 +250,7 @@ void iPointGlyph::CreateData(int res)
 	//
 	//  Arrow
 	//
-	vtkArrowSource *as = vtkArrowSource::New(); IERROR_ASSERT(as);
+	vtkArrowSource *as = vtkArrowSource::New(); IERROR_CHECK_MEMORY(as);
 	as->SetTipResolution(6*res);
 	as->SetShaftResolution(6*res);
 	as->SetTipRadius(0.5);
@@ -245,7 +267,7 @@ void iPointGlyph::CreateData(int res)
 	//  Point
 	//
 	vtkPointSource *cc;
-	cc = vtkPointSource::New(); IERROR_ASSERT(cc);
+	cc = vtkPointSource::New(); IERROR_CHECK_MEMORY(cc);
 	cc->SetNumberOfPoints(1);
 	cc->SetCenter(0.0,0.0,0.0);
 	cc->SetRadius(1.0);
@@ -259,7 +281,7 @@ void iPointGlyph::CreateData(int res)
 	//
 	//  Cluster
 	//
-	cc = vtkPointSource::New(); IERROR_ASSERT(cc);
+	cc = vtkPointSource::New(); IERROR_CHECK_MEMORY(cc);
 	cc->SetNumberOfPoints(30*res);
 	cc->SetCenter(0.0,0.0,0.0);
 	cc->SetRadius(1.0);
@@ -286,7 +308,7 @@ void iPointGlyph::CreateData(int res)
 	//
 	//  Galaxy
 	//
-	cc = vtkPointSource::New(); IERROR_ASSERT(cc);
+	cc = vtkPointSource::New(); IERROR_CHECK_MEMORY(cc);
 	cc->SetNumberOfPoints(30*res);
 	cc->SetCenter(0.0,0.0,0.0);
 	cc->SetRadius(1.0);
@@ -510,8 +532,15 @@ void iPointGlyph::SetType(int t)
 }
 
 
-void iPointGlyph::ProduceOutput()
+vtkPolyData* iPointGlyph::GetData()
 {
-	this->GetOutput()->ShallowCopy(mData[mType]);
+	return this->vtkPolyDataAlgorithm::GetOutput();
+}
+
+
+int iPointGlyph::RequestData(vtkInformation *request, vtkInformationVector **inputVector, vtkInformationVector *outputVector)
+{
+	this->GetData()->ShallowCopy(mData[mType]);
+	return 1;
 }
 
