@@ -33,8 +33,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IPOINTGLYPH_H
 
 
-#include "igenericfilter.h"
-#include <vtkPolyDataSource.h>
+#include <vtkPolyDataAlgorithm.h>
+
+
+class iDataConsumer;
 
 
 namespace iParameter
@@ -59,12 +61,13 @@ namespace iParameter
 };
 
 
-class iPointGlyph: public iGenericSource<vtkPolyDataSource,vtkPolyData>
+class iPointGlyph: public vtkPolyDataAlgorithm
 {
 
 public:
 
-	static iPointGlyph* New(iViewSubject *vo);
+	vtkTypeMacro(iPointGlyph,vtkPolyDataAlgorithm);
+	static iPointGlyph* New();
 	
 	inline int GetType() const { return mType; }
 	void SetType(int m);
@@ -75,13 +78,15 @@ public:
 	static bool GetOriented(int t);
 	static const char* GetName(int t);
 
+	vtkPolyData* GetData();
+
 protected:
 	
-	iPointGlyph(iViewSubject *vo);
+	iPointGlyph();
 	virtual ~iPointGlyph();
 	
-	virtual void ProduceOutput();
-	
+	virtual int	RequestData(vtkInformation *request, vtkInformationVector **inputVector, vtkInformationVector *outputVector);
+
 private:
 
 	void CreateData(int res);
@@ -91,6 +96,12 @@ private:
 
 	int mType;
 	vtkPolyData *mData[iParameter::PointGlyphType::SIZE];
+
+	//
+	//  Block for better control
+	//
+	void GetOutput();
+	void OutputData();
 };
 
 #endif // IPOINTGLYPH_H
