@@ -28,9 +28,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ipostscriptwriter.h"
 
+
 #include <vtkImageData.h>
 #include <vtkPointData.h>
 
+
 #define VTK_MARGIN 0.95
 
 
@@ -87,7 +89,7 @@ void iPostScriptWriter::WriteFileHeader(ofstream *file, vtkImageData *cache)
 	int pagehgt = (int)(mPaper[mFormat].Height*72);
 	
 	// Find the length of the rows to write.
-	cache->GetWholeExtent(min1, max1, min2, max2, min3, max3);
+	cache->GetExtent(min1, max1, min2, max2, min3, max3);
 	bpp = cache->GetNumberOfScalarComponents();
 	
 	cols = max1 - min1 + 1;
@@ -105,9 +107,9 @@ void iPostScriptWriter::WriteFileHeader(ofstream *file, vtkImageData *cache)
 	//
 	//  Fit to width
 	//
-	scale = (float)pagewid/cols;
-	scols = (int)(scale*cols*VTK_MARGIN);
-	srows = (int)(scale*rows*VTK_MARGIN);
+	scale = float(pagewid)/cols;
+	scols = int(scale*cols*VTK_MARGIN);
+	srows = int(scale*rows*VTK_MARGIN);
 	//
 	//  If too high, fit to height
 	//
@@ -209,7 +211,7 @@ void iPostScriptWriter::WriteFile(ofstream *file, vtkImageData *data, int extent
 		i0 = 2; i1 = 3; i2 = 0; i3 = 1;
 	}
 
-	wExtent = this->GetInput()->GetWholeExtent();
+	wExtent = this->GetInput()->GetExtent();
 	area = ((extent[5] - extent[4] + 1)*(extent[3] - extent[2] + 1)*
 		(extent[1] - extent[0] + 1)) / 
 		((wExtent[5] -wExtent[4] + 1)*(wExtent[3] -wExtent[2] + 1)*
