@@ -54,7 +54,7 @@ public:
 	virtual void SetOrientation(int o);
 	inline int GetOrientation(){ return mOrient; }
 	
-	static char* GetPaperFormatName(int n){ if(n>=0 && n<NFORMATS) return mPaper[n].Name; else return ""; }
+	static const char* GetPaperFormatName(int n){ if(n>=0 && n<NFORMATS) return mPaper[n].Name; else return ""; }
 
 protected:
 
@@ -67,7 +67,7 @@ private:
 
 	struct Paper
 	{
-		char *Name;
+		const char *Name;
 		float Width, Height;
 	};
 
