@@ -29,29 +29,51 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ireducepolydatafilter.h"
 
 
+#include "ierror.h"
+
+#include <vtkDecimatePro.h>
+#include <vtkTriangleFilter.h>
+
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iReducePolyDataFilter::iReducePolyDataFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkDecimatePro>(vo,1,true,false)
+iReducePolyDataFilter::iReducePolyDataFilter(iDataConsumer *consumer) : iGenericPolyDataFilter<vtkPolyDataAlgorithm>(consumer,1,true)
 {
+	mTriangulator = vtkTriangleFilter::New(); IERROR_CHECK_MEMORY(mTriangulator);
+	mDecimator = vtkDecimatePro::New(); IERROR_CHECK_MEMORY(mDecimator);
+
+	mDecimator->PreserveTopologyOn();
+	mDecimator->BoundaryVertexDeletionOff();
+	mDecimator->SetInputConnection(mTriangulator->GetOutputPort());
 }
 	
 
-void iReducePolyDataFilter::ProduceOutput()
+void iReducePolyDataFilter::SetTargetReduction(double v)
 {
-	vtkPolyData *input = vtkPolyData::SafeDownCast(this->GetInput());
-	vtkPolyData *output = this->GetOutput();
-
-	if(input->GetPoints()==0 || input->GetPoints()->GetDataType()==VTK_FLOAT)
-	{
-		this->ExecuteParent();
-	}
-	else
-	{
-		vtkWarningMacro("Cannot reduce polygonal data with double-valued coordinates due to a VTK bug.");
-		output->ShallowCopy(input);
-	}
+	mDecimator->SetTargetReduction(v);
+	this->Modified();
+}
+
+
+double iReducePolyDataFilter::GetTargetReduction()
+{
+	return mDecimator->GetTargetReduction();
+}
+
+
+iReducePolyDataFilter::~iReducePolyDataFilter()
+{
+	mDecimator->Delete();
+	mTriangulator->Delete();
+}
+
+
+void iReducePolyDataFilter::ProvideOutput()
+{
+	mTriangulator->SetInputData(this->InputData());
+	mDecimator->Update();
+	this->OutputData()->ShallowCopy(mDecimator->GetOutput());
 }
