@@ -31,15 +31,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iactor.h"
 #include "icamera.h"
-#include "icontrolmodule.h"
 #include "ierror.h"
 #include "ieventobserver.h"
-#include "iextensionfactory.h"
-#include "ilightkit.h"
 #include "imagnifier.h"
 #include "irendertoolbackground.h"
 #include "ishell.h"
-#include "ishellfactory.h"
 #include "istereoimage.h"
 #include "istereoimagearray.h"
 #include "iviewmodule.h"
@@ -48,23 +44,27 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkCamera.h>
 #include <vtkCuller.h>
 #include <vtkCullerCollection.h>
+#include <vtkDepthPeelingPass.h>
 #include <vtkLight.h>
 #include <vtkLightCollection.h>
 #include <vtkLineSource.h>
 #include <vtkOpenGLRenderWindow.h>
+#include <vtkPolyDataMapper.h>
 #include <vtkPolyDataMapper2D.h>
 #include <vtkPropAssembly.h>
 #include <vtkPropCollection.h>
+#include <vtkProperty.h>
 #include <vtkProperty2D.h>
 #include <vtkRenderer.h>
 #include <vtkRenderWindow.h>
 #include <vtkRenderWindowCollection.h>
 #include <vtkRenderWindowInteractor.h>
+#include <vtkTranslucentPass.h>
 
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -73,6 +73,44 @@ using namespace iParameter;
 //
 //  Helper classes
 //
+class iMainWindowObserver : public iEventObserver
+{
+
+public:
+
+	vtkTypeMacro(iMainWindowObserver,iEventObserver);
+	static iMainWindowObserver* New(iRenderTool *rt = 0)
+	{
+		IASSERT(rt);
+		return new iMainWindowObserver(rt);
+	}
+
+protected:
+
+	iMainWindowObserver(iRenderTool *rt) : iEventObserver()
+	{
+		mRenderTool = rt;
+	}
+
+	virtual void ExecuteBody(vtkObject *, unsigned long event, void *)
+	{
+		switch(event)
+		{
+		case ModifiedEvent:
+			{
+				mRenderTool->mRenderWindowSize = mRenderTool->mMainWin->GetSize();
+				mRenderTool->mRenderWindowPosition = mRenderTool->mMainWin->GetPosition();
+				break;
+			}
+		}
+	}
+
+private:
+
+	iRenderTool *mRenderTool;
+};
+
+
 class iDualWindowObserver : public iEventObserver
 {
 
@@ -81,13 +119,13 @@ public:
 	vtkTypeMacro(iDualWindowObserver,iEventObserver);
 	static iDualWindowObserver* New(iRenderTool *rt = 0)
 	{
-		IERROR_ASSERT(rt);
+		IASSERT(rt);
 		return new iDualWindowObserver(rt);
 	}
 
 protected:
 
-	iDualWindowObserver(iRenderTool *rt) : iEventObserver(rt->GetViewModule()->GetControlModule()->GetShell())
+	iDualWindowObserver(iRenderTool *rt) : iEventObserver()
 	{
 		mRenderTool = rt;
 	}
@@ -123,13 +161,13 @@ public:
 	vtkTypeMacro(iRendererObserver,iEventObserver);
 	static iRendererObserver* New(iRenderTool *rt = 0)
 	{
-		IERROR_ASSERT(rt);
+		IASSERT(rt);
 		return new iRendererObserver(rt);
 	}
 
 protected:
 
-	iRendererObserver(iRenderTool *rt) : iEventObserver(rt->GetViewModule()->GetControlModule()->GetShell())
+	iRendererObserver(iRenderTool *rt) : iEventObserver()
 	{
 		mRenderTool = rt;
 	}
@@ -140,7 +178,6 @@ protected:
 		{
 		case ModifiedEvent:
 			{
-				mRenderTool->GetViewModule()->ClearCache(); // our size is cached by VM
 				break;
 			}
 		case ResetCameraClippingRangeEvent:
@@ -175,13 +212,13 @@ public:
 	vtkTypeMacro(iStereoRenderObserver,iEventObserver);
 	static iStereoRenderObserver* New(iRenderTool *rt = 0)
 	{
-		IERROR_ASSERT(rt);
+		IASSERT(rt);
 		return new iStereoRenderObserver(rt);
 	}
 
 protected:
 
-	iStereoRenderObserver(iRenderTool *rt) : iEventObserver(rt->GetViewModule()->GetControlModule()->GetShell())
+	iStereoRenderObserver(iRenderTool *rt) : iEventObserver()
 	{
 		mRenderTool = rt;
 	}
@@ -195,7 +232,6 @@ protected:
 				if(mRenderTool->mMainWinStereoRender != (mRenderTool->mMainWin->GetStereoRender()!=0))
 				{
 					mRenderTool->mMainWin->SetStereoRender(mRenderTool->mMainWinStereoRender?1:0);
-					iConsole::Display(iConsole::_Notification,"Pressing 3 to toggle the stereo mode is no longer supported.\nPlease use GUI/command-line controls to toggle the stereo mode.");
 				}
 				break;
 			}
@@ -211,38 +247,33 @@ private:
 //
 //  Main class
 //
-iRenderTool* iRenderTool::New(iViewModule *vm)
-{
-	IERROR_ASSERT(vm);
-	iRenderTool *tmp =  iExtensionFactory::CreateRenderTool(vm);
-	IERROR_ASSERT(tmp);
-	return tmp;
-}
-
-
-iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : mViewModule(vm), mStereoModeOffset(2-VTK_STEREO_CRYSTAL_EYES)
+iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : iViewModuleComponent(vm), mStereoModeOffset(2-VTK_STEREO_CRYSTAL_EYES)
 {
 	//
 	//  Keeping the rendering order (a workaround for a VTK bug)
 	//
-	mActorObjects = vtkPropCollection::New(); IERROR_ASSERT(mActorObjects);
-	mVolumeObjects = vtkPropCollection::New(); IERROR_ASSERT(mVolumeObjects);
+	mActorObjects = vtkPropCollection::New(); IERROR_CHECK_MEMORY(mActorObjects);
+	mVolumeObjects = vtkPropCollection::New(); IERROR_CHECK_MEMORY(mVolumeObjects);
 
 	//
 	//  Main Window stuff
 	//
 	mDualWin = 0;
-	mMainWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT(mMainWin);
 #ifdef I_NO_STEREO
-	mMainWin->SetStereoCapableWindow(0);
+	bool stereo = false;
 #else
-	mMainWin->SetStereoCapableWindow(1);
+	bool stereo = true;
 #endif
+	mMainWin = this->GetViewModule()->GetShell()->CreateRenderWindow(this->GetViewModule(),stereo);	IERROR_CHECK_MEMORY(mMainWin);
+	mMainWin->SetAlphaBitPlanes(1);
+	mMainWin->SetMultiSamples(0);
+
+	mDepthPeelingStyle = DepthPeeling::Low;
+
 	if(ren == 0)
 	{
-		mMainRen = vtkRenderer::New(); IERROR_ASSERT(mMainRen);
-		mMainInt = iShellFactory::CreateRenderWindowInteractor(this); IERROR_ASSERT(mMainInt);
-		mMainCam = iCamera::New(this); IERROR_ASSERT(mMainCam);
+		mMainRen = vtkRenderer::New(); IERROR_CHECK_MEMORY(mMainRen);
+		mMainCam = iCamera::New(this); IERROR_CHECK_MEMORY(mMainCam);
 		mMainRen->SetActiveCamera(mMainCam->GetDevice());
 		//
 		//  Configure Renderer. It is important to switch the backing store off for the
@@ -253,44 +284,45 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 		mMainRen->TwoSidedLightingOff();
 		mMainRen->LightFollowCameraOn();
 		mMainRen->GetActiveCamera()->SetEyeAngle(2.0);
+		this->ConfigureDepthPeeling(mMainRen);
+
 		//
-		//  Configure Interactor
+		//  Configure Interactor (can be null)
 		//
-		mMainInt->SetRenderWindow(mMainWin);
-		mMainInt->LightFollowCameraOff();
-		//
-		//  Create and initiate lights
-		//
-		mLights = iLightKit::New(); IERROR_ASSERT(mLights);	
-		mLights->AddLightsToRenderer(mMainRen);
+		mMainInt = this->GetViewModule()->GetShell()->CreateRenderWindowInteractor(this->GetViewModule());
+		if(mMainInt != 0)
+		{
+			mMainInt->SetRenderWindow(mMainWin);
+			mMainInt->LightFollowCameraOff();
+		}
 		//
 		//  Image magnifier
 		//
-		mMagnifier = iMagnifier::New(); IERROR_ASSERT(mMagnifier);
+		mMagnifier = iMagnifier::New(); IERROR_CHECK_MEMORY(mMagnifier);
 	}
 	else
 	{
 		mMainRen = ren;
 		mMainInt = 0;
 		mMainCam = 0;
-		mLights = 0;
-		mMagnifier = mag; IERROR_ASSERT(mMagnifier);
+		mMagnifier = mag;
+		IASSERT(mag);
 		mMagnifier->Register(ren);
 	}
 
 	//
 	//  Create backgrounds
 	//
-	mMainBkg = iRenderToolBackground::New(); IERROR_ASSERT(mMainBkg);
-	mDualBkg = iRenderToolBackground::New(); IERROR_ASSERT(mDualBkg);
+	mMainBkg = iRenderToolBackground::New(); IERROR_CHECK_MEMORY(mMainBkg);
+	mDualBkg = iRenderToolBackground::New(); IERROR_CHECK_MEMORY(mDualBkg);
 
 	//
 	//  Configure Window
 	//
 	mMainWin->SetSize(640,480);
 	mMainWin->SetNumberOfLayers(2);
-	mMainWin->AddRenderer(mMainBkg->GetRenderer());
 	mMainWin->AddRenderer(mMainRen);
+	mMainWin->AddRenderer(mMainBkg->GetRenderer());
 	mMainWin->SetWindowName("IFrIT - Visualization Window");
 
 	//
@@ -302,19 +334,22 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	mDualRen->LightFollowCameraOff();
 
 	//
-	//  Dual window observer
+	//  Window observers
 	//
-	mDualWindowObserver = iDualWindowObserver::New(this); IERROR_ASSERT(mDualWindowObserver);
+	mMainWindowObserver = iMainWindowObserver::New(this); IERROR_CHECK_MEMORY(mMainWindowObserver);
+	mDualWindowObserver = iDualWindowObserver::New(this); IERROR_CHECK_MEMORY(mDualWindowObserver);
+
+	mMainWin->AddObserver(vtkCommand::ModifiedEvent,mMainWindowObserver);
 
 	//
 	//  Dual window alignment markers (only needed for the primary window)
 	//
 	if(ren == 0)
 	{
-		mStereoAlignmentMarksActor = vtkPropAssembly::New(); IERROR_ASSERT(mStereoAlignmentMarksActor);
+		mStereoAlignmentMarksActor = vtkPropAssembly::New(); IERROR_CHECK_MEMORY(mStereoAlignmentMarksActor);
 		mStereoAlignmentMarksActor->VisibilityOff();
 		mStereoAlignmentMarksActor->PickableOff();
-		vtkPolyDataMapper2D *mapper2D = vtkPolyDataMapper2D::New(); IERROR_ASSERT(mapper2D);
+		vtkPolyDataMapper2D *mapper2D = vtkPolyDataMapper2D::New(); IERROR_CHECK_MEMORY(mapper2D);
 		vtkLineSource *ls;
 		vtkActor2D *actor2D[8];
 
@@ -323,9 +358,9 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 		int i;
 		for(i=0; i<8; i++)
 		{
-			actor2D[i] = vtkActor2D::New(); IERROR_ASSERT(actor2D[i]);
-			mapper2D = vtkPolyDataMapper2D::New(); IERROR_ASSERT(mapper2D);
-			ls = vtkLineSource::New(); IERROR_ASSERT(ls);
+			actor2D[i] = vtkActor2D::New(); IERROR_CHECK_MEMORY(actor2D[i]);
+			mapper2D = vtkPolyDataMapper2D::New(); IERROR_CHECK_MEMORY(mapper2D);
+			ls = vtkLineSource::New(); IERROR_CHECK_MEMORY(ls);
 			ls->SetResolution(1);
 			if(i%2 == 0)
 			{
@@ -338,9 +373,9 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 				ls->SetPoint2(0.0,aml,0.0);
 			}
 			ls->Update();
-			mapper2D->SetInput(ls->GetOutput());
+			mapper2D->SetInputConnection(ls->GetOutputPort());
 			ls->Delete();
-			vtkCoordinate *c = vtkCoordinate::New(); IERROR_ASSERT(c);
+			vtkCoordinate *c = vtkCoordinate::New(); IERROR_CHECK_MEMORY(c);
 			c->SetCoordinateSystemToView();
 			mapper2D->SetTransformCoordinate(c);
 			c->Delete();
@@ -366,7 +401,7 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	//
 	//  Clipping range controls
 	//
-	mRendererObserver = iRendererObserver::New(this); IERROR_ASSERT(mRendererObserver);
+	mRendererObserver = iRendererObserver::New(this); IERROR_CHECK_MEMORY(mRendererObserver);
 	mAutoClippingRange = true;
 	mMainRen->AddObserver(vtkCommand::ResetCameraClippingRangeEvent,mRendererObserver);
 	mMainRen->AddObserver(vtkCommand::ModifiedEvent,mRendererObserver);
@@ -374,13 +409,13 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	//
 	//  Disable pressing 3 in the render window
 	//
-	mStereoRenderObserver = iStereoRenderObserver::New(this); IERROR_ASSERT(mStereoRenderObserver);
+	mStereoRenderObserver = iStereoRenderObserver::New(this); IERROR_CHECK_MEMORY(mStereoRenderObserver);
 	mMainWin->AddObserver(vtkCommand::ModifiedEvent,mStereoRenderObserver);
 
 	//
 	//  RenderWindow collection
 	//
-	mWindowCollection = vtkRenderWindowCollection::New(); IERROR_ASSERT(mWindowCollection);
+	mWindowCollection = vtkRenderWindowCollection::New(); IERROR_CHECK_MEMORY(mWindowCollection);
 	mWindowCollectionUpToDate = false;
 
 	//
@@ -389,7 +424,8 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	mStereoMode = 0;
 	this->SetMainWinStereoRender(false);
 	mMainWin->SetStereoType(0);  // for pressing 3 in the render window
-	mAntialiasing = mBackgroundImageFixedAspect = false;
+	this->SetAntialiasingMode(0*Antialiasing::Points+1*Antialiasing::Lines+1*Antialiasing::Polys);
+	this->SetDepthPeelingStyle(DepthPeeling::Low);
 	mStereoAlignmentMarksOn = true;
 
 	//
@@ -397,7 +433,6 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	//
 	mFontScale = 0;
 	mFontType = TextType::Arial;
-	//this->SetAntialiasing(true);
 }
 
 
@@ -411,6 +446,7 @@ iRenderTool::~iRenderTool()
 	mWindowCollection->RemoveAllItems();
 	mWindowCollection->Delete();
 	mDualWindowObserver->Delete();
+	mMainWindowObserver->Delete();
 
 	mMagnifier->Delete();
 
@@ -420,22 +456,21 @@ iRenderTool::~iRenderTool()
 	mMainRen->RemoveObserver(mRendererObserver);
 	mRendererObserver->Delete();
 
-	if(mLights != 0) mLights->Delete();
 	if(mMainInt != 0) mMainInt->Delete();
 	if(mMainCam != 0) mMainCam->Delete();
 
 	mMainRen->SetRenderWindow(0);
-	mMainWin->RemoveRenderer(mMainRen);
 	mMainWin->RemoveRenderer(mMainBkg->GetRenderer());
+	mMainWin->RemoveRenderer(mMainRen);
 
 	mMainBkg->Delete();
 	mDualBkg->Delete();
 
-	mDualRen->Delete();
-
 	mMainWin->RemoveAllObservers();   
-
+	mDualRen->Delete();
 	mMainRen->Delete();
+
+	mMainWin->Finalize();
 	mMainWin->Delete();
 }
 
@@ -506,8 +541,23 @@ void iRenderTool::AddObserver(unsigned long event, iEventObserver *command)
 }
 
 
-void iRenderTool::UpdateWindowName(const iString &base)
+void iRenderTool::UpdateWindowName()
 {
+	static const iString null;
+
+	this->UpdateWindowName(null);
+}
+
+
+void iRenderTool::UpdateWindowName(const iString& suffix)
+{
+	static iString WindowName("IFrIT - Visualization Window");
+
+	iString base(WindowName);
+	if(this->GetShell()->GetNumberOfViewModules() > 1) base += " #" + iString::FromNumber(this->GetViewModule()->GetWindowNumber()+1);
+
+	if(!suffix.IsEmpty()) base += ": " + suffix;
+
 	if(mDualWin == 0)
 	{
 		mMainWin->SetWindowName(base.ToCharPointer());
@@ -583,24 +633,17 @@ void iRenderTool::AddObject(vtkProp* p)
 		//
 		//  Make sure all actors are ahead of volumes (is it a VTK bug?)
 		//
+		if(mActorObjects->GetNumberOfItems() == 0)
+		{
+			mMainRen->AddViewProp(p);
+			mDualRen->AddViewProp(p);
+		}
+		else
+		{
+			mMainRen->GetViewProps()->InsertItem(mActorObjects->GetNumberOfItems()-1,p);
+			mDualRen->GetViewProps()->InsertItem(mActorObjects->GetNumberOfItems()-1,p);
+		}
 		mActorObjects->AddItem(p);
-
-		mMainRen->RemoveAllViewProps();
-		mDualRen->RemoveAllViewProps();
-
-		vtkProp *p;
-		mActorObjects->InitTraversal();
-		while((p = mActorObjects->GetNextProp()) != 0)
-		{
-			mMainRen->AddViewProp(p);
-			mDualRen->AddViewProp(p);
-		}
-		mVolumeObjects->InitTraversal();
-		while((p = mVolumeObjects->GetNextProp()) != 0)
-		{
-			mMainRen->AddViewProp(p);
-			mDualRen->AddViewProp(p);
-		}
 	}
 }
 
@@ -623,55 +666,26 @@ void iRenderTool::RemoveObject(vtkProp* p)
 }
 
 
-const int* iRenderTool::GetRenderWindowSize() const
-{ 
-	return mMainWin->GetSize(); 
-}
-
-
 void iRenderTool::SetRenderWindowSize(int w, int h)
 { 
-	mMainWin->SetSize(w,h);
-	if(mDualWin != 0) mDualWin->SetSize(w,h);
-}
-
-
-const int* iRenderTool::GetRenderWindowPosition() const
-{ 
-	return mMainWin->GetPosition(); 
+	if(w>0 && h>0)
+	{
+		mMainWin->SetSize(w,h);
+		if(mDualWin != 0) mDualWin->SetSize(w,h);
+		mRenderWindowSize = mMainWin->GetSize();
+	}
 }
 
 
 void iRenderTool::SetRenderWindowPosition(int x, int y)
 { 
 	mMainWin->SetPosition(x,y);
+	mRenderWindowPosition = mMainWin->GetPosition();
 }
 
 
-void iRenderTool::SetAntialiasing(bool s)
+void iRenderTool::Reset()
 {
-	mAntialiasing = s;
-	if(s)
-	{
-		mMainWin->SetLineSmoothing(1);
-		mMainWin->SetPointSmoothing(1);
-		if(mDualWin != 0)
-		{
-			mDualWin->SetLineSmoothing(1);
-			mDualWin->SetPointSmoothing(1);
-		}
-    } 
-	else 
-	{
-		mMainWin->SetLineSmoothing(0);
-		mMainWin->SetPointSmoothing(0);
-		if(mDualWin != 0)
-		{
-			mDualWin->SetLineSmoothing(0);
-			mDualWin->SetPointSmoothing(0);
-		}
- 	}
-
 #ifndef I_OFFSCREEN
 	vtkOpenGLRenderWindow *w = vtkOpenGLRenderWindow::SafeDownCast(mMainWin);
 	if(w!=0 && w->GetNeverRendered()==0)
@@ -692,6 +706,89 @@ void iRenderTool::SetAntialiasing(bool s)
 }
 
 
+void iRenderTool::SetAntialiasingMode(int m)
+{
+	bool s;
+
+	mAntialiasingMode = m;
+
+	s = (m & Antialiasing::Points) > 0;
+	mMainWin->SetPointSmoothing(s?1:0);
+	if(mDualWin != 0)
+	{
+		mDualWin->SetPointSmoothing(s?1:0);
+	}
+
+	s = (m & Antialiasing::Lines) > 0;
+	mMainWin->SetLineSmoothing(s?1:0);
+	if(mDualWin != 0)
+	{
+		mDualWin->SetLineSmoothing(s?1:0);
+	}
+
+	s = (m & Antialiasing::Polys) > 0;
+	mMainWin->SetPolygonSmoothing(s?1:0);
+	if(mDualWin != 0)
+	{
+		mDualWin->SetPolygonSmoothing(s?1:0);
+	}
+
+	this->Reset();
+}
+
+
+void iRenderTool::SetDepthPeelingStyle(int s)
+{
+	mDepthPeelingStyle = s;
+
+	this->ConfigureDepthPeeling(mMainRen);
+	this->ConfigureDepthPeeling(mDualRen);
+
+	this->Reset();
+}
+
+
+void iRenderTool::ConfigureDepthPeeling(vtkRenderer *ren) const
+{
+	if(ren == 0) return;
+
+	ren->SetUseDepthPeeling((mDepthPeelingStyle != DepthPeeling::Off)?1:0);
+ 
+	switch(mDepthPeelingStyle)
+	{
+	case DepthPeeling::Off:
+		{
+			//
+			//  Already set
+			//
+			break;
+		}
+	case DepthPeeling::Low:
+		{
+			ren->SetOcclusionRatio(0.1);
+			ren->SetMaximumNumberOfPeels(3);
+			break;
+		}
+	case DepthPeeling::High:
+		{
+			ren->SetOcclusionRatio(0.03);
+			ren->SetMaximumNumberOfPeels(10);
+			break;
+		}
+	case DepthPeeling::Exact:
+		{
+			ren->SetOcclusionRatio(0.0);
+			ren->SetMaximumNumberOfPeels(0);
+			break;
+		}
+	default:
+		{
+			IBUG_ERROR("Invalid DepthPeelingStyle.");
+		}
+	}
+}
+
+	
 void iRenderTool::SetAdjustCameraClippingRangeAutomatically(bool s)
 {
 	mAutoClippingRange = s;
@@ -861,7 +958,7 @@ void iRenderTool::SetStereoMode(int m)
 			if(mMainWin->GetStereoCapableWindow() == 0)
 			{
 				this->SetStereoMode(0);
-				iConsole::Display(iConsole::_Notification,"Crystal Eyes mode is not supported on this machine.");
+				this->OutputText(MessageType::Error,"Crystal Eyes mode is not supported on this machine.");
 			}
 			else
 			{
@@ -887,8 +984,9 @@ void iRenderTool::ShowDualWindow(bool s)
 	{
 		if(mDualWin == 0) // DualWindow is not shown yet
 		{
-			mDualWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT(mDualWin);
-			mDualWin->SetStereoCapableWindow(0);
+			mDualWin = this->GetViewModule()->GetShell()->CreateRenderWindow(this->GetViewModule(),false); IERROR_CHECK_MEMORY(mDualWin);
+			mDualWin->SetAlphaBitPlanes(1);
+			mDualWin->SetMultiSamples(0);
 			mDualWin->SetStereoTypeToRight();
 			mDualWin->StereoRenderOn();
 			int *s = mMainWin->GetSize();
@@ -905,10 +1003,11 @@ void iRenderTool::ShowDualWindow(bool s)
 			//
 			mDualWin->SetLineSmoothing(mMainWin->GetLineSmoothing());
 			mDualWin->SetPointSmoothing(mMainWin->GetPointSmoothing());
+			mDualWin->SetPolygonSmoothing(mMainWin->GetPolygonSmoothing());
 
 			mDualWin->SetNumberOfLayers(2);
-			mDualWin->AddRenderer(mDualBkg->GetRenderer());
 			mDualWin->AddRenderer(mDualRen);
+			mDualWin->AddRenderer(mDualBkg->GetRenderer());
 
 			mMainWin->SetStereoTypeToLeft();
 			this->SetMainWinStereoRender(true);
@@ -917,7 +1016,7 @@ void iRenderTool::ShowDualWindow(bool s)
 			mMainWin->AddObserver(vtkCommand::ModifiedEvent,mDualWindowObserver);
 
 			if(mStereoAlignmentMarksActor!=0 && mStereoAlignmentMarksOn) mStereoAlignmentMarksActor->VisibilityOn();
-			this->GetViewModule()->UpdateWindowNumber();
+			this->UpdateWindowName();
 		}
 	}
 	else
@@ -929,6 +1028,7 @@ void iRenderTool::ShowDualWindow(bool s)
 			mDualBkg->GetRenderer()->SetRenderWindow(0);
 			mDualWin->RemoveRenderer(mDualRen);
 			mDualWin->RemoveRenderer(mDualBkg->GetRenderer());
+			mDualWin->Finalize();
 			mDualWin->Delete();
 			mDualWin = 0;
 
@@ -936,7 +1036,7 @@ void iRenderTool::ShowDualWindow(bool s)
 			mMainWin->RemoveObserver(mDualWindowObserver);
 
 			if(mStereoAlignmentMarksActor != 0) mStereoAlignmentMarksActor->VisibilityOff();
-			this->GetViewModule()->UpdateWindowNumber();
+			this->UpdateWindowName();
 		}
 	}
 }
@@ -962,6 +1062,7 @@ vtkRenderer* iRenderTool::CreateRenderer() const
 	ren->SetTwoSidedLighting(mMainRen->GetTwoSidedLighting());
 	ren->SetBackground(mMainRen->GetBackground());
 	ren->LightFollowCameraOff(); // only the primary renderer can control lights
+	this->ConfigureDepthPeeling(ren);
 
 	//
 	//  Copy props. The trick is that we need to register the new renderer with every iActor
@@ -1037,3 +1138,43 @@ void iRenderTool::SetMainWinStereoRender(bool s)
 	mMainWin->SetStereoRender(s?1:0);
 }
 
+
+#include <vtkOBJExporter.h>
+#include <vtkVRMLExporter.h>
+#include <vtkX3DExporter.h>
+
+
+void iRenderTool::ExportScene(const iString &fname)
+{
+	vtkExporter *ex = 0;
+
+	iString type = fname.Section(".",-1);
+	
+	if(type == "obj")
+	{
+		vtkOBJExporter *w = vtkOBJExporter::New(); IERROR_CHECK_MEMORY(w);
+		w->SetFilePrefix(fname.Section(".",0,-2).ToCharPointer());
+		ex = w;
+	}
+	else if(type == "x3d")
+	{
+		vtkX3DExporter  *w = vtkX3DExporter ::New(); IERROR_CHECK_MEMORY(w);
+		w->SetBinary(0);
+		w->SetFileName(fname.ToCharPointer());
+		ex = w;
+	}
+	else if(type == "vrml")
+	{
+		vtkVRMLExporter  *w = vtkVRMLExporter ::New(); IERROR_CHECK_MEMORY(w);
+		w->SetFileName(fname.ToCharPointer());
+		ex = w;
+	}
+
+	if(ex != 0)
+	{
+		ex->SetRenderWindow(mMainWin);
+		mMainWin->RemoveRenderer(mMainBkg->GetRenderer());
+		ex->Write();
+		mMainWin->AddRenderer(mMainBkg->GetRenderer());
+	}
+}
