@@ -30,7 +30,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iarray.h"
+#include "iclipplane.h"
 #include "ierror.h"
+#include "iviewmodule.h"
+#include "iviewsubject.h"
 
 #include <vtkMapperCollection.h>
 #include <vtkMatrix4x4.h>
@@ -39,7 +42,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 //
@@ -87,12 +90,13 @@ private:
 	{
 		mReplicas.Add(Replica());
 
-		Replica &tmp = mReplicas.Last();
+		Replica &tmp = mReplicas[mReplicas.MaxIndex()];
 		tmp.Pos[0] = i;
 		tmp.Pos[1] = j;
 		tmp.Pos[2] = k;
-		tmp.Actor = vtkActor::New(); IERROR_ASSERT(tmp.Actor);
+		tmp.Actor = vtkActor::New(); IERROR_CHECK_MEMORY(tmp.Actor);
 		tmp.Actor->SetPosition(2.0*tmp.Pos[0],2.0*tmp.Pos[1],2.0*tmp.Pos[2]);
+		tmp.Actor->SetProperty(this->GetProperty());
 	}
 
 	//
@@ -115,9 +119,10 @@ private:
 
 	iReplicatedActorDevice(iReplicatedActor *parent)
 	{
-		mParent = parent; IERROR_ASSERT(mParent);
+		mParent = parent;
+		IASSERT(parent);
 	
-		vtkMatrix4x4 *m = vtkMatrix4x4::New(); IERROR_ASSERT(m);
+		vtkMatrix4x4 *m = vtkMatrix4x4::New(); IERROR_CHECK_MEMORY(m);
 		this->SetUserMatrix(m);
 		m->Delete();
 
@@ -137,25 +142,26 @@ private:
 //
 //  Main class
 //
-iReplicatedActor* iReplicatedActor::New(iViewSubject *vs, bool scaled)
+iReplicatedActor* iReplicatedActor::New(iViewSubject *owner)
 {
-	IERROR_ASSERT(vs);
-	return new iReplicatedActor(vs,scaled);
+	IASSERT(owner);
+	return new iReplicatedActor(owner);
 }
 
 
-iReplicatedActor::iReplicatedActor(iViewSubject *vs, bool scaled) : iActor(scaled), iReplicatedElement(false)
+iReplicatedActor::iReplicatedActor(iViewSubject *owner) : iActor(owner->GetViewModule()->GetClipPlane()->GetPlanes()), iReplicatedElement(false)
 {
 	//
 	//  Must create property first - it is not created by default
 	//
-	IERROR_ASSERT(this->GetProperty());
+	IASSERT(this->GetProperty());
+
 	//
 	//  Substitute the device
 	//
 	this->Device->Delete();
-	this->Device = mRealDevice = iReplicatedActorDevice::New(this); IERROR_ASSERT(mRealDevice);
-	this->ReplicateAs(vs);
+	this->Device = mRealDevice = iReplicatedActorDevice::New(this); IERROR_CHECK_MEMORY(mRealDevice);
+	this->ReplicateAs(owner);
 }
 
 
@@ -175,8 +181,8 @@ double* iReplicatedActor::GetBounds()
 		mReplicatedBoundsMTime.Modified();
 		for(i=0; i<3; i++)
 		{
-			this->Bounds[2*i+0] -= 2.0*mNumReplicas[2*i+0];
-			this->Bounds[2*i+1] += 2.0*mNumReplicas[2*i+1];
+			this->Bounds[2*i+0] -= 2.0*mReplicationFactors[2*i+0];
+			this->Bounds[2*i+1] += 2.0*mReplicationFactors[2*i+1];
 		}
 	}
 
@@ -190,7 +196,7 @@ void iReplicatedActor::Render(vtkRenderer *ren, vtkMapper *m)
 	//
 	//  Update time
 	//
-	this->EstimatedRenderTime *= (mNumReplicas[0]+mNumReplicas[1])*(mNumReplicas[2]+mNumReplicas[3])*(mNumReplicas[4]+mNumReplicas[5]);
+	this->EstimatedRenderTime *= (mReplicationFactors[0]+mReplicationFactors[1])*(mReplicationFactors[2]+mReplicationFactors[3])*(mReplicationFactors[4]+mReplicationFactors[5]);
 }
 
 
@@ -201,13 +207,13 @@ void iReplicatedActor::UpdateReplicasBody()
 	//
 	//  Add needed actors
 	//
-	for(k=-mNumReplicas[4]; k<=mNumReplicas[5]; k++)
+	for(k=-mReplicationFactors[4]; k<=mReplicationFactors[5]; k++)
 	{
-		for(j=-mNumReplicas[2]; j<=mNumReplicas[3]; j++)
+		for(j=-mReplicationFactors[2]; j<=mReplicationFactors[3]; j++)
 		{
-			for(i=-mNumReplicas[0]; i<=mNumReplicas[1]; i++)
+			for(i=-mReplicationFactors[0]; i<=mReplicationFactors[1]; i++)
 			{
-				if(i<-mOldNumReplicas[0] || i>mOldNumReplicas[1] || j<-mOldNumReplicas[2] || j>mOldNumReplicas[3] || k<-mOldNumReplicas[4] || k>mOldNumReplicas[5])
+				if(i<-mOldReplicationFactors[0] || i>mOldReplicationFactors[1] || j<-mOldReplicationFactors[2] || j>mOldReplicationFactors[3] || k<-mOldReplicationFactors[4] || k>mOldReplicationFactors[5])
 				{
 					mRealDevice->CreateReplica(i,j,k);
 				}
@@ -218,7 +224,7 @@ void iReplicatedActor::UpdateReplicasBody()
 	//
 	//  Delete unneeded actors
 	//
-	mRealDevice->DeleteReplicas(mNumReplicas);
+	mRealDevice->DeleteReplicas(mReplicationFactors);
 
 	//
 	//  Need to redo bounds
