@@ -47,14 +47,14 @@ class iReplicatedActor : public iActor, public iReplicatedElement
 public:
 	
 	vtkTypeMacro(iReplicatedActor,iActor);
-	static iReplicatedActor* New(iViewSubject *vs = 0, bool scaled = false);
+	static iReplicatedActor* New(iViewSubject *owner = 0);
 
 	virtual double* GetBounds();
 	virtual void Render(vtkRenderer *ren, vtkMapper *m);
 
 protected:
 	
-	iReplicatedActor(iViewSubject *vs, bool scaled);
+	iReplicatedActor(iViewSubject *owner);
 	virtual ~iReplicatedActor();
 	
 	virtual void UpdateReplicasBody();
