@@ -37,18 +37,24 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkImageData.h>
 #include <vtkPointData.h>
-#include <vtkStructuredPoints.h>
 #include <vtkUnsignedCharArray.h>
 
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iReplicatedGridData::iReplicatedGridData(iViewSubject *vo) : iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>(vo,1,true,true), iParallelWorker(vo->GetViewModule()->GetParallelManager()), iReplicatedElement(true)
+iReplicatedGridData* iReplicatedGridData::New(iViewInstance *owner)
 {
-	this->ReplicateAs(vo);
+	IASSERT(owner);
+	return new iReplicatedGridData(owner);
+}
+
+
+iReplicatedGridData::iReplicatedGridData(iViewInstance *owner) : iGenericImageDataFilter<vtkImageAlgorithm>(owner,1,true), iParallelWorker(owner->GetViewModule()->GetParallelManager()), iReplicatedElement(true)
+{
+	this->ReplicateAs(owner->Owner());
 }
 
 
@@ -58,38 +64,38 @@ void iReplicatedGridData::UpdateReplicasBody()
 }
 
 
-void iReplicatedGridData::InitExecution()
+void iReplicatedGridData::ProvideInfo()
 {
+	vtkImageData *input = this->InputData();
+	vtkImageData *output = this->OutputData();
 	int i, ext[6];
 	double org[3];
-	
-	vtkImageData *input = this->GetInput();
-	vtkImageData *output = this->GetOutput();
 
-	input->GetWholeExtent(ext);
+	input->GetExtent(ext);
 	input->GetOrigin(org);
 	
 	for(i=0; i<3; i++)
 	{
-		ext[2*i+1] = 1 + (ext[2*i+1]-1)*(mNumReplicas[2*i+1]+mNumReplicas[2*i]+1);
-		org[i] -= 2.0*mNumReplicas[2*i];
+		ext[2*i+1] = 1 + (ext[2*i+1]-1)*(mReplicationFactors[2*i+1]+mReplicationFactors[2*i]+1);
+		org[i] -= 2.0*mReplicationFactors[2*i];
 	}
 
-	output->SetWholeExtent(ext);
+	output->SetExtent(ext);
 	output->SetSpacing(input->GetSpacing());
 	output->SetOrigin(org);
+
+	vtkInformation* outInfo = wCache.OutputVector->GetInformationObject(0);
+	outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),ext,6);
 }
 
 
-void iReplicatedGridData::ProduceOutput()
+void iReplicatedGridData::ProvideOutput()
 {
-	int extDown[3], extUp[3];
-	int i;
+	vtkImageData *input = this->InputData();
+	vtkImageData *output = this->OutputData();
+	int i, extDown[3], extUp[3];
 	double pos[3];
 	
-	vtkImageData *input = this->GetInput();
-	vtkImageData *output = this->GetOutput();
-
 	output->Initialize();
 
 	int n = input->GetNumberOfScalarComponents();
@@ -98,8 +104,8 @@ void iReplicatedGridData::ProduceOutput()
 	bool work = false;
 	for(i=0; i<3; i++)
 	{
-		extDown[i] = -mNumReplicas[2*i];
-		extUp[i] = mNumReplicas[2*i+1];
+		extDown[i] = -mReplicationFactors[2*i];
+		extUp[i] = mReplicationFactors[2*i+1];
 		if(extDown[i] != 0) work = true;
 		if(extUp[i] != 0) work = true;
 	}
@@ -127,23 +133,20 @@ void iReplicatedGridData::ProduceOutput()
 	wSize0 = (wDimsIn[0]-1)*wSize;
 	wSize1 = wSize0 + wSize;
 
-	output->SetScalarType(input->GetScalarType());
-	output->SetNumberOfScalarComponents(input->GetNumberOfScalarComponents());
 		
 	for(i=0; i<3; i++) pos[i] += 2.0*extDown[i];
 	output->SetOrigin(pos);
-	
 	output->SetDimensions(wDimsOut);
-
-	vtkUnsignedCharArray *data;
-	data = vtkUnsignedCharArray::New(); IERROR_ASSERT(data);
-	data->SetNumberOfComponents(wSize);
-	data->SetNumberOfTuples((vtkIdType)wDimsOut[0]*wDimsOut[1]*wDimsOut[2]);
-	output->GetPointData()->SetScalars(data);
-	data->Delete();
+#ifdef IVTK_5
+	output->SetScalarType(input->GetScalarType());
+	output->SetNumberOfScalarComponents(input->GetNumberOfScalarComponents());
+	output->AllocateScalars();
+#else
+	output->AllocateScalars(input->GetScalarType(),input->GetNumberOfScalarComponents());
+#endif
 
 	wPtrIn = (char *)input->GetScalarPointer();
-	wPtrOut = (char *)data->GetVoidPointer(0);
+	wPtrOut = (char *)output->GetScalarPointer();
 	
 	this->ParallelExecute(0);
 }
@@ -159,10 +162,7 @@ int iReplicatedGridData::ExecuteStep(int, iParallel::ProcessorInfo &p)
 
 	for(k1=0; k1<wExt[2]; k1++) for(k=kBeg; k<kEnd; k++) 
 	{
-		if(this->IsMaster(p))
-		{
-			this->UpdateProgress((float)(k-kBeg+wDimsIn[2]*k1)/((kEnd-kBeg)*wExt[2]));
-		}
+		if(p.IsMaster()) this->UpdateProgress(double(k-kBeg+wDimsIn[2]*k1)/((kEnd-kBeg)*wExt[2]));
 		if(this->GetAbortExecute()) break;
 
 		for(j1=0; j1<wExt[1]; j1++) for(j=0; j<wDimsIn[1]; j++)
@@ -182,5 +182,9 @@ int iReplicatedGridData::ExecuteStep(int, iParallel::ProcessorInfo &p)
 
 float iReplicatedGridData::GetMemorySize()
 {
-	if(this->IsReplicated()) return this->iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>::GetMemorySize(); else return 0.0;
+	if(this->IsReplicated())
+	{
+		return this->iGenericImageDataFilter<vtkImageAlgorithm>::GetMemorySize();
+	}
+	else return 0.0;
 }
