@@ -33,24 +33,31 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "igenericfilter.h"
-#include <vtkStructuredPointsToStructuredPointsFilter.h>
+#include <vtkImageAlgorithm.h>
 #include "iparallelworker.h"
 #include "ireplicatedelement.h"
 
 
-class iReplicatedGridData : public iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>, protected iParallelWorker, public iReplicatedElement
+class iViewInstance;
+
+
+class iReplicatedGridData : public iGenericImageDataFilter<vtkImageAlgorithm>, protected iParallelWorker, public iReplicatedElement
 {
 
-	IGENERICFILTER_DECLARE(iReplicatedGridData,vtkStructuredPointsToStructuredPointsFilter);
-
 public:
 
+	vtkTypeMacro(iReplicatedGridData,vtkImageAlgorithm);
+
+	static iReplicatedGridData* New(iViewInstance *owner = 0);
+
 	virtual float GetMemorySize();
 
 protected:
 	
-	virtual void InitExecution();
-	virtual void ProduceOutput();
+	iReplicatedGridData(iViewInstance *owner);
+
+	virtual void ProvideInfo();
+	virtual void ProvideOutput();
 	virtual void UpdateReplicasBody();
 
 	virtual int ExecuteStep(int step, iParallel::ProcessorInfo &p);
