@@ -32,6 +32,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "imath.h"
 #include "iviewmodule.h"
+#include "iviewsubject.h"
 
 #include <vtkCellArray.h>
 #include <vtkFloatArray.h>
@@ -43,7 +44,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
 namespace iReplicatedPolyData_Private
@@ -169,9 +170,9 @@ void Sort(vtkIdType n, vtkIdType *lptr1, vtkIdType *lptr2)
 using namespace iReplicatedPolyData_Private;
 
 
-iReplicatedPolyData::iReplicatedPolyData(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>(vo,1,true,true), iReplicatedElement(true)
+iReplicatedPolyData::iReplicatedPolyData(iViewInstance *owner) : iGenericPolyDataFilter<vtkPolyDataAlgorithm>(owner,1,true), iReplicatedElement(true)
 {
-	this->ReplicateAs(vo);
+	this->ReplicateAs(owner->Owner());
 }
 
 
@@ -181,21 +182,21 @@ void iReplicatedPolyData::UpdateReplicasBody()
 }
 
 
-void iReplicatedPolyData::ProduceOutput()
+void iReplicatedPolyData::ProvideOutput()
 {
+	vtkPolyData *input = this->InputData();
+	vtkPolyData *output = this->OutputData();
+
 	int extDown[3], extUp[3];
 	int i;
 
-	vtkPolyData *input = this->GetInput();
-	vtkPolyData *output = this->GetOutput();
-
 	output->ShallowCopy(input);
 
 	bool work = false;
 	for(i=0; i<3; i++)
 	{
-		extDown[i] = -mNumReplicas[2*i];
-		extUp[i] = mNumReplicas[2*i+1];
+		extDown[i] = -mReplicationFactors[2*i];
+		extUp[i] = mReplicationFactors[2*i+1];
 		if(extDown[i] != 0) work = true;
 		if(extUp[i] != 0) work = true;
 	}
@@ -248,7 +249,7 @@ void iReplicatedPolyData::ExtendDirection(vtkPolyData *input, vtkPolyData *outpu
 	vtkIdType nnor = (inor == 0) ? 0 : inor->GetNumberOfComponents()*inor->GetNumberOfTuples();
 	
 	vtkPoints *opoi;
-	opoi = vtkPoints::New(ipoi->GetDataType()); IERROR_ASSERT(opoi);
+	opoi = vtkPoints::New(ipoi->GetDataType()); IERROR_CHECK_MEMORY(opoi);
 	opoi->SetNumberOfPoints(next*npoi);
 
 	float  *optrpoiF = 0;
@@ -283,30 +284,30 @@ void iReplicatedPolyData::ExtendDirection(vtkPolyData *input, vtkPolyData *outpu
 
 	if(nver > 0) 
 	{
-		over = vtkCellArray::New(); IERROR_ASSERT(over);
+		over = vtkCellArray::New(); IERROR_CHECK_MEMORY(over);
 	}
 	if(nlin > 0) 
 	{
-		olin = vtkCellArray::New(); IERROR_ASSERT(olin);
+		olin = vtkCellArray::New(); IERROR_CHECK_MEMORY(olin);
 	}
 	if(npol > 0) 
 	{
-		opol = vtkCellArray::New(); IERROR_ASSERT(opol);
+		opol = vtkCellArray::New(); IERROR_CHECK_MEMORY(opol);
 	}
 	if(nsrp > 0) 
 	{
-		osrp = vtkCellArray::New(); IERROR_ASSERT(osrp);
+		osrp = vtkCellArray::New(); IERROR_CHECK_MEMORY(osrp);
 	}
 	if(nsca > 0) 
 	{
-		osca = vtkFloatArray::New(); IERROR_ASSERT(osca);
+		osca = vtkFloatArray::New(); IERROR_CHECK_MEMORY(osca);
 		osca->SetNumberOfComponents(isca->GetNumberOfComponents());
 		osca->SetNumberOfTuples(next*isca->GetNumberOfTuples());
 		optrsca = (float *)osca->GetVoidPointer(0);
 	}
 	if(nnor > 0) 
 	{
-		onor = vtkFloatArray::New(); IERROR_ASSERT(onor);
+		onor = vtkFloatArray::New(); IERROR_CHECK_MEMORY(onor);
 		onor->SetNumberOfComponents(3);
 		onor->SetNumberOfTuples(next*inor->GetNumberOfTuples());
 		optrnor = (float *)onor->GetVoidPointer(0);
@@ -336,7 +337,7 @@ void iReplicatedPolyData::ExtendDirection(vtkPolyData *input, vtkPolyData *outpu
 		if(curmax > maxCellSize) maxCellSize = curmax;
 	}
 
-	pts = new vtkIdType[maxCellSize]; IERROR_ASSERT(pts);
+	pts = new vtkIdType[maxCellSize]; IERROR_CHECK_MEMORY(pts);
 
 	double s[3];
 	s[0] = s[1] = s[2] = 0.0;
@@ -346,7 +347,7 @@ void iReplicatedPolyData::ExtendDirection(vtkPolyData *input, vtkPolyData *outpu
 	vtkIdType l, loff1, loff2, noff;
 	for(j=extDown; j<=extUp; j++)
 	{
-		this->UpdateProgress((float)(j-extDown)/next);
+		this->UpdateProgress(double(j-extDown)/next);
 		if(this->GetAbortExecute()) break;
 		
 		noff = off*npoi;
@@ -448,7 +449,7 @@ void iReplicatedPolyData::ExtendDirection(vtkPolyData *input, vtkPolyData *outpu
 
 float iReplicatedPolyData::GetMemorySize()
 {
-	if(this->IsReplicated()) return this->iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>::GetMemorySize(); else return 0.0;
+	if(this->IsReplicated()) return this->iGenericPolyDataFilter<vtkPolyDataAlgorithm>::GetMemorySize(); else return 0.0;
 }
 
 
@@ -492,12 +493,12 @@ void iReplicatedPolyData::PatchStitches(vtkPolyData *input, int ndim, double *ed
 	default: tolerance = 0.0;
 	}
 
-	vtkIdList *edgeIds = vtkIdList::New(); IERROR_ASSERT(edgeIds);
-	vtkIdList *outIds = vtkIdList::New(); IERROR_ASSERT(outIds);
-	vtkIdList *repIds = vtkIdList::New(); IERROR_ASSERT(repIds);
-	vtkIdList *indIds = vtkIdList::New(); IERROR_ASSERT(indIds);
-	vtkPointLocator *loc = vtkPointLocator::New(); IERROR_ASSERT(loc);
-	vtkPoints *tmpPoints = vtkPoints::New(points->GetDataType()); IERROR_ASSERT(tmpPoints);
+	vtkIdList *edgeIds = vtkIdList::New(); IERROR_CHECK_MEMORY(edgeIds);
+	vtkIdList *outIds = vtkIdList::New(); IERROR_CHECK_MEMORY(outIds);
+	vtkIdList *repIds = vtkIdList::New(); IERROR_CHECK_MEMORY(repIds);
+	vtkIdList *indIds = vtkIdList::New(); IERROR_CHECK_MEMORY(indIds);
+	vtkPointLocator *loc = vtkPointLocator::New(); IERROR_CHECK_MEMORY(loc);
+	vtkPoints *tmpPoints = vtkPoints::New(points->GetDataType()); IERROR_CHECK_MEMORY(tmpPoints);
 
 	int div[3];
 	for(i=0; i<3; i++)
