@@ -33,17 +33,21 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "igenericfilter.h"
-#include <vtkPolyDataToPolyDataFilter.h>
+#include <vtkPolyDataAlgorithm.h>
 #include "ireplicatedelement.h"
 
 
-class iReplicatedPolyData : public iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>, public iReplicatedElement
+class iViewInstance;
+
+
+class iReplicatedPolyData : public iGenericPolyDataFilter<vtkPolyDataAlgorithm>, public iReplicatedElement
 {
 
-	IGENERICFILTER_DECLARE(iReplicatedPolyData,vtkPolyDataToPolyDataFilter);
-
 public:
 
+	vtkTypeMacro(iReplicatedPolyData,iGenericPolyDataFilter<vtkPolyDataAlgorithm>);
+	static iReplicatedPolyData* New(iViewInstance *owner = 0) { IERROR_CHECK_MEMORY(owner); return new iReplicatedPolyData(owner); }
+
 	virtual float GetMemorySize();
 
 	//
@@ -53,7 +57,9 @@ public:
 
 protected:
 	
-	virtual void ProduceOutput();
+	iReplicatedPolyData(iViewInstance *owner);
+
+	virtual void ProvideOutput();
 	virtual void UpdateReplicasBody();
 
 private:
