@@ -31,6 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibuffer.h"
 #include "ierror.h"
+#include "iviewsubject.h"
 
 #include <vtkFrustumCoverageCuller.h>
 #include <vtkMatrix4x4.h>
@@ -41,35 +42,35 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
-#include "ibuffertemplate.h"
-#include "igenericproptemplate.h"
+#include "iarray.tlh"
+#include "ibuffer.tlh"
+#include "igenericprop.tlh"
 
 
 //
 //  Main class
 //
-iReplicatedVolume* iReplicatedVolume::New(iViewSubject *vs)
+iReplicatedVolume* iReplicatedVolume::New(iViewSubject *owner)
 {
-	IERROR_ASSERT(vs);
-	return new iReplicatedVolume(vs);
+	IASSERT(owner);
+	return new iReplicatedVolume(owner);
 }
 
 
-iReplicatedVolume::iReplicatedVolume(iViewSubject *vs) : iGenericProp<vtkVolume>(false), iReplicatedElement(false)
+iReplicatedVolume::iReplicatedVolume(iViewSubject *owner) : iGenericProp<vtkVolume>(false), iReplicatedElement(false), iViewModuleComponent(owner->GetViewModule())
 {
 	//
 	//  Must create property first - it is not created by default
 	//
-	IERROR_ASSERT(this->GetProperty());
+	IASSERT(this->GetProperty());
 
 	//
 	//  Create main replica
 	//
 	this->CreateReplica(0,0,0);
-	this->ReplicateAs(vs);
+	this->ReplicateAs(owner);
 
-	mCuller = vtkFrustumCoverageCuller::New(); IERROR_ASSERT(mCuller);
+	mCuller = vtkFrustumCoverageCuller::New(); IERROR_CHECK_MEMORY(mCuller);
 	mCuller->SetSortingStyleToBackToFront();
 }
 
@@ -85,7 +86,7 @@ void iReplicatedVolume::CreateReplica(int i, int j, int k)
 {
 	mReplicas.Add(Replica());
 
-	Replica &tmp = mReplicas.Last();
+	Replica &tmp = mReplicas[mReplicas.MaxIndex()];
 	tmp.Pos[0] = i;
 	tmp.Pos[1] = j;
 	tmp.Pos[2] = k;
@@ -105,8 +106,8 @@ double* iReplicatedVolume::GetBounds()
 	{
 		for(i=0; i<3; i++)
 		{
-			this->Bounds[2*i+0] -= 2.0*mNumReplicas[2*i+0];
-			this->Bounds[2*i+1] += 2.0*mNumReplicas[2*i+1];
+			this->Bounds[2*i+0] -= 2.0*mReplicationFactors[2*i+0];
+			this->Bounds[2*i+1] += 2.0*mReplicationFactors[2*i+1];
 		}
 	}
 
@@ -119,7 +120,7 @@ void iReplicatedVolume::UpdateGeometry(vtkViewport *vp)
 	int initialized = 0;
 	int i, n = mReplicas.Size();
 
-	vtkProp** buf = new vtkProp*[n]; IERROR_ASSERT(buf);
+	vtkProp** buf = new vtkProp*[n]; IERROR_CHECK_MEMORY(buf);
 	for(i=0; i<mReplicas.Size(); i++)
 	{
 		if(mReplicas[i].Volume->GetMTime() < this->GetMTime())
@@ -152,13 +153,13 @@ void iReplicatedVolume::UpdateReplicasBody()
 	//
 	//  Add needed actors
 	//
-	for(k=-mNumReplicas[4]; k<=mNumReplicas[5]; k++)
+	for(k=-mReplicationFactors[4]; k<=mReplicationFactors[5]; k++)
 	{
-		for(j=-mNumReplicas[2]; j<=mNumReplicas[3]; j++)
+		for(j=-mReplicationFactors[2]; j<=mReplicationFactors[3]; j++)
 		{
-			for(i=-mNumReplicas[0]; i<=mNumReplicas[1]; i++)
+			for(i=-mReplicationFactors[0]; i<=mReplicationFactors[1]; i++)
 			{
-				if(i<-mOldNumReplicas[0] || i>mOldNumReplicas[1] || j<-mOldNumReplicas[2] || j>mOldNumReplicas[3] || k<-mOldNumReplicas[4] || k>mOldNumReplicas[5])
+				if(i<-mOldReplicationFactors[0] || i>mOldReplicationFactors[1] || j<-mOldReplicationFactors[2] || j>mOldReplicationFactors[3] || k<-mOldReplicationFactors[4] || k>mOldReplicationFactors[5])
 				{
 					this->CreateReplica(i,j,k);
 				}
@@ -171,7 +172,7 @@ void iReplicatedVolume::UpdateReplicasBody()
 	//
 	for(k=0; k<mReplicas.Size(); k++)
 	{
-		if(mReplicas[k].Pos[0]<-mNumReplicas[0] || mReplicas[k].Pos[0]>mNumReplicas[1] || mReplicas[k].Pos[1]<-mNumReplicas[2] || mReplicas[k].Pos[1]>mNumReplicas[3] || mReplicas[k].Pos[2]<-mNumReplicas[4] || mReplicas[k].Pos[2]>mNumReplicas[5])
+		if(mReplicas[k].Pos[0]<-mReplicationFactors[0] || mReplicas[k].Pos[0]>mReplicationFactors[1] || mReplicas[k].Pos[1]<-mReplicationFactors[2] || mReplicas[k].Pos[1]>mReplicationFactors[3] || mReplicas[k].Pos[2]<-mReplicationFactors[4] || mReplicas[k].Pos[2]>mReplicationFactors[5])
 		{
 			mReplicas[k].Volume->Delete();
 			mReplicas.Remove(k);
