@@ -31,17 +31,33 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "igenericfilter.h"
-#include <vtkExtractVOI.h>
+#include <vtkImageAlgorithm.h>
 
 
-class iResampleImageDataFilter : public iGenericFilter<vtkExtractVOI,vtkImageData,vtkImageData>
+class iResampleImageDataFilter : public iGenericImageDataFilter<vtkImageAlgorithm>
 {
 	
-	IGENERICFILTER_DECLARE(iResampleImageDataFilter,vtkExtractVOI);
-	
+	iGenericFilterTypeMacro(iResampleImageDataFilter,vtkImageAlgorithm);
+
+public:
+
+	void SetResampleRate(int v);
+	inline int GetResampleRate() const { return mResampleRate; }
+
 protected:
 	
-	virtual void ProduceOutput();
+	virtual void ProvideInfo();
+	virtual void ProvideOutput();
+
+	void ResampleArray();
+
+private:
+
+	void ComputeOutputShape(int dims[3], double spac[3], int outDims[3], double outSpac[3]);
+
+	int mResampleRate;
+
+	int wInDims[3], wOutDims[3];
 };
 
 #endif // IRESAMPLEIMAGEDATAFILTER_H
