@@ -42,21 +42,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
-#include "igenericproptemplate.h"
+#include "iarray.tlh"
+#include "igenericprop.tlh"
+#include "iproperty.tlh"
 
 
-iRuler* iRuler::New(iViewModule *vm)
+iRulerActor::iRulerActor(iRuler *owner) : iAxis(owner->GetViewModule()->GetRenderTool()), iViewModuleComponent(owner->GetViewModule())
 {
-	IERROR_ASSERT(vm);
-	return new iRuler(vm);
-}
+	mOwner = owner; 
+	IASSERT(owner);
 
-
-iRuler::iRuler(iViewModule *vm) : iAxis(vm->GetRenderTool()), mViewModule(vm)
-{
 	mStarted = false;
-	mScale = mBaseScale = 1.0;
+	mBaseScale = 1.0;
 
 	this->LabelTextProperty->SetVerticalJustificationToTop();
 	this->TitleTextProperty->SetJustificationToCentered();
@@ -70,12 +67,7 @@ iRuler::iRuler(iViewModule *vm) : iAxis(vm->GetRenderTool()), mViewModule(vm)
 }
 
 
-iRuler::~iRuler()
-{
-}
-
-
-void iRuler::UpdateGeometry(vtkViewport *vp)
+void iRulerActor::UpdateGeometry(vtkViewport *vp)
 {
 	vtkCamera *cam = this->GetOverlayHelper()->GetCamera(vp);
 	if(cam==0 || cam->GetParallelProjection()==0)
@@ -108,9 +100,9 @@ void iRuler::UpdateGeometry(vtkViewport *vp)
 		vp->GetAspect(as);
 		float dx = 0.5/mBaseScale*as[1]/as[0];
 
-		if(!this->GetViewModule()->GetOpenGLCoordinates()) s *= this->GetViewModule()->GetBoxSize();
+		if(!this->GetViewModule()->InOpenGLCoordinates()) s *= this->GetViewModule()->GetBoxSize();
 		this->SetRange(0.0,s);
-		mScale = s;
+		mOwner->SetScale(s);
 		
 		this->SetPoint1(0.5-dx,0.9);
 		this->SetPoint2(0.5+dx,0.9);
@@ -120,7 +112,7 @@ void iRuler::UpdateGeometry(vtkViewport *vp)
 }
 
 
-void iRuler::UpdateOverlay(vtkViewport *vp)
+void iRulerActor::UpdateOverlay(vtkViewport *vp)
 {
 	int mag = this->GetOverlayHelper()->GetRenderingMagnification();
 
@@ -134,7 +126,7 @@ void iRuler::UpdateOverlay(vtkViewport *vp)
 }
 
 
-void iRuler::SetBaseScale(float s)
+void iRulerActor::SetBaseScale(float s)
 {
 	if(s > 0.0)
 	{
@@ -145,7 +137,7 @@ void iRuler::SetBaseScale(float s)
 }
 
 
-void iRuler::SetScale(float s)
+void iRulerActor::SetScale(float s)
 {
 	if(!mStarted)
 	{
@@ -153,20 +145,80 @@ void iRuler::SetScale(float s)
 		mBaseScale = this->GetOverlayHelper()->GetRenderTool()->GetCamera()->GetDevice()->GetParallelScale();
 	}
 
-	if(s > 0.0)
+	if(s>0.0 && this->GetVisibility()!=0)
 	{
-		if(!this->GetViewModule()->GetOpenGLCoordinates()) s /= this->GetViewModule()->GetBoxSize();
+		if(!this->GetViewModule()->InOpenGLCoordinates()) s /= this->GetViewModule()->GetBoxSize();
 		this->GetOverlayHelper()->GetRenderTool()->GetCamera()->GetDevice()->SetParallelScale(s*mBaseScale);
 		this->Modified();
 	}
 }
 
 
-void iRuler::SetTitle(const iString &title)
+void iRulerActor::SetTitle(const iString &title)
 {
-	mTitle = title;
 	this->vtkAxisActor2D::SetTitle(title.ToCharPointer());
-	if(mTitle.IsEmpty()) this->TitleVisibilityOff(); else this->TitleVisibilityOn();
+	if(title.IsEmpty()) this->TitleVisibilityOff(); else this->TitleVisibilityOn();
 	this->Modified();
 }
 
+
+//
+//  Main class
+//
+iRuler* iRuler::New(iViewModule *vm)
+{
+	static iString LongName("Ruler");
+	static iString ShortName("rl");
+
+	IASSERT(vm);
+	return new iRuler(vm,LongName,ShortName);
+}
+
+
+iRuler::iRuler(iViewModule *vm, const iString &fname, const iString &sname) : iViewModuleTool(vm,fname,sname),
+	iObjectConstructPropertyMacroS(Float,iRuler,Scale,s),
+	iObjectConstructPropertyMacroS(String,iRuler,Title,t)
+{
+	mScale = 1.0;
+
+	mActor = new iRulerActor(this); IERROR_CHECK_MEMORY(mActor);
+	mActor->VisibilityOff();
+	mActor->PickableOff();
+
+	this->GetViewModule()->GetRenderTool()->AddObject(mActor);
+}
+
+
+iRuler::~iRuler()
+{
+	this->GetViewModule()->GetRenderTool()->RemoveObject(mActor);
+	mActor->Delete();
+}
+
+
+bool iRuler::ShowBody(bool s)
+{
+	mActor->SetVisibility(s?1:0); 
+	return true;
+}
+
+
+bool iRuler::SetScale(float s)
+{
+	if(s > 0.0)
+	{
+		mScale = s;
+		mActor->SetScale(s);
+		return true;
+	}
+	else return false;
+}
+
+
+bool iRuler::SetTitle(const iString& s)
+{
+	mTitle = s;
+	mActor->SetTitle(s);
+	return true;
+}
+
