@@ -31,45 +31,70 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iaxis.h"
+#include "iviewmoduletool.h"
 
 
 #include "istring.h"
 
-class iViewModule;
+class iRuler;
 
 
-class iRuler: public iAxis
+class iRulerActor: public iAxis, public iViewModuleComponent
 {
 	
-	IPOINTER_AS_PART(ViewModule);
+	friend class iRuler;
 
 public:
 	
-	vtkTypeMacro(iRuler,iAxis);
-	static iRuler* New(iViewModule *vm = 0);
+	vtkTypeMacro(iRulerActor,iAxis);
 	
 	void SetBaseScale(float s);
 
 	void SetScale(float s);
-	inline float GetScale() const { return mScale; }
-
 	void SetTitle(const iString &title);
-	inline const iString& GetTitle() const { return mTitle; }
 
 protected:
 
-	virtual ~iRuler();
-
 	virtual void UpdateGeometry(vtkViewport *vp);
 	virtual void UpdateOverlay(vtkViewport *vp);
 
 private:
 	
-	iRuler(iViewModule *vm);
+	iRulerActor(iRuler *owner);
 	
+	iRuler *mOwner;
 	bool mStarted;
-	float mScale, mBaseScale;
-	iString mTitle;
+	float mBaseScale;
+};
+
+
+class iRuler : public iViewModuleTool
+{
+	
+public:
+
+	vtkTypeMacro(iRuler,iViewModuleTool);
+	static iRuler* New(iViewModule *vm = 0);
+		
+	iObjectPropertyMacro1S(Scale,Float);
+	iObjectPropertyMacro1S(Title,String);
+
+	inline iRulerActor* GetActor() const { return mActor; }
+
+protected:
+
+	virtual ~iRuler();
+
+private:
+	
+	iRuler(iViewModule *vm, const iString &fname, const iString &sname);
+
+	virtual bool ShowBody(bool s);
+
+	//
+	//  Actors displayed by this class
+	//
+	iRulerActor *mActor;
 };
 
 #endif // IRULER_H
