@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -29,12 +29,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ishellcomponent.h"
 
 
+#include "ierror.h"
 #include "ishell.h"
 
 
-iShellComponent::iShellComponent(iShell *s) 
-{ 
-	mShell = s; 
+iShellComponent::iShellComponent(iShell *s) : mShell(s)
+{
+	IASSERT(mShell);
+}
 
-	if(s != 0) s->OnInitAtom();
+
+void iShellComponent::OutputText(int type, const iString &text) const
+{
+	mShell->OutputText(type,text);
 }
