@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -30,24 +30,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define ISHELLCOMPONENT_H
 
 
+#include "ipointermacro.h"
+
+
 class iShell;
+class iString;
 
 
 class iShellComponent
 {
 
+	IPOINTER_AS_PART(Shell);
+
 public:
 
-    inline iShell* GetShell() const { return mShell; }
+	//
+	//  This is just a decorator over iShell::OutputText to avoid extra includes.
+	//  All ShellComponents should use it to output text.
+	//
+	void OutputText(int type, const iString &text) const;
 
 protected:
 
-    iShellComponent(iShell *s);
-	virtual ~iShellComponent(){} 
-
-private:
-
-	iShell *mShell;
+	iShellComponent(iShell *s);
 };
 
 #endif // ISHELLCOMPONENT_H
