@@ -39,10 +39,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iShiftPolyDataFilter::iShiftPolyDataFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>(vo,1,true,false)
+iShiftPolyDataFilter::iShiftPolyDataFilter(iDataConsumer *consumer) : iGenericPolyDataFilter<vtkPolyDataAlgorithm>(consumer,1,true)
 {
 	mShift = 0.003f;
 }
@@ -55,10 +55,10 @@ void iShiftPolyDataFilter::SetShift(float s)
 }
 
 
-void iShiftPolyDataFilter::ProduceOutput()
+void iShiftPolyDataFilter::ProvideOutput()
 {
-	vtkPolyData *input = this->GetInput();
-	vtkPolyData *output = this->GetOutput();
+	vtkPolyData *input = this->InputData();
+	vtkPolyData *output = this->OutputData();
 
 	output->DeepCopy(input);
 
@@ -91,6 +91,7 @@ void iShiftPolyDataFilter::ProduceOutput()
 	default:
 		{
 			vtkErrorMacro("Invalid points data type");
+			return;
 		}
 	}
 }
