@@ -31,13 +31,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "igenericfilter.h"
-#include <vtkPolyDataToPolyDataFilter.h>
+#include <vtkPolyDataAlgorithm.h>
 
 
-class iShiftPolyDataFilter : public iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>
+class iShiftPolyDataFilter : public iGenericPolyDataFilter<vtkPolyDataAlgorithm>
 {
 	
-	IGENERICFILTER_DECLARE(iShiftPolyDataFilter,vtkPolyDataToPolyDataFilter);
+	iGenericFilterTypeMacro(iShiftPolyDataFilter,vtkPolyDataAlgorithm);
 
 public:
 	
@@ -46,7 +46,7 @@ public:
 
 protected:
 	
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 	
 private:
 	
