@@ -40,7 +40,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
 namespace iSmoothPolyDataFilter_Private
@@ -75,12 +75,12 @@ namespace iSmoothPolyDataFilter_Private
 using namespace iSmoothPolyDataFilter_Private;
 
 
-iSmoothPolyDataFilter::iSmoothPolyDataFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkWindowedSincPolyDataFilter>(vo,1,true,false)
+iSmoothPolyDataFilter::iSmoothPolyDataFilter(iDataConsumer *consumer) : iGenericPolyDataFilter<vtkWindowedSincPolyDataFilter>(consumer,1,true)
 {
 }
 	
     
-void iSmoothPolyDataFilter::ProduceOutput()
+void iSmoothPolyDataFilter::ProvideOutput()
 {
 	//
 	//  The code between === lines is copied from vtkWindowedSincPolyDataFilter.cxx file with minor modifications, as marked behind /// comments
@@ -111,11 +111,12 @@ void iSmoothPolyDataFilter::ProduceOutput()
 	vtkMeshVertexPtr Verts;
 	/// ------ Removed ------------------------------------------
 	/// vtkPolyData *input = this->GetInput();
+	/// vtkPolyData *output = this->GetOutput();
 	/// ---------------------------------------------------------
 	/// ++++++ Added ++++++++++++++++++++++++++++++++++++++++++++
-	vtkPolyData *input = vtkPolyData::SafeDownCast(this->GetInput());
+	vtkPolyData *input = this->InputData();
+	vtkPolyData *output = this->OutputData();
 	/// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-	vtkPolyData *output = this->GetOutput();
 
 	// variables specific to windowed sinc interpolation
 	double theta_pb, k_pb, sigma, p_x0[3], p_x1[3], p_x3[3];
@@ -134,13 +135,8 @@ void iSmoothPolyDataFilter::ProduceOutput()
 		return;
 	}
 
-#ifdef IVTK_PRE54
-	CosFeatureAngle = cos((double) vtkMath::DegreesToRadians() * this->FeatureAngle);
-	CosEdgeAngle = cos((double) vtkMath::DegreesToRadians() * this->EdgeAngle);
-#else
 	CosFeatureAngle = cos(vtkMath::RadiansFromDegrees(this->FeatureAngle));
 	CosEdgeAngle = cos(vtkMath::RadiansFromDegrees(this->EdgeAngle));
-#endif
 
 	vtkDebugMacro(<<"Smoothing " << numPts << " vertices, " << numCells 
 		<< " cells with:\n"
@@ -264,7 +260,7 @@ void iSmoothPolyDataFilter::ProduceOutput()
 		{ // convert data to triangles
 			inMesh->SetStrips(inStrips);
 			toTris = vtkTriangleFilter::New();
-			toTris->SetInput(inMesh);
+			toTris->SetInputData(inMesh);
 			toTris->Update();
 			Mesh = toTris->GetOutput();
 		}
