@@ -34,14 +34,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkWindowedSincPolyDataFilter.h>
 
 
-class iSmoothPolyDataFilter : public iGenericPolyDataToPolyDataFilter<vtkWindowedSincPolyDataFilter>
+class iSmoothPolyDataFilter : public iGenericPolyDataFilter<vtkWindowedSincPolyDataFilter>
 {
 	
-	IGENERICFILTER_DECLARE(iSmoothPolyDataFilter,vtkWindowedSincPolyDataFilter);
+	iGenericFilterTypeMacro(iSmoothPolyDataFilter,vtkWindowedSincPolyDataFilter);
 	
 protected:
 	
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 };
 
 #endif // ISMOOTHPOLYDATAFILTER_H
