@@ -34,14 +34,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkSmoothPolyDataFilter.h>
 
 
-class iSmoothPolyDataFilter2 : public iGenericPolyDataToPolyDataFilter<vtkSmoothPolyDataFilter>
+class iSmoothPolyDataFilter2 : public iGenericPolyDataFilter<vtkSmoothPolyDataFilter>
 {
 	
-	IGENERICFILTER_DECLARE(iSmoothPolyDataFilter2,vtkSmoothPolyDataFilter);
+	iGenericFilterTypeMacro(iSmoothPolyDataFilter2,vtkSmoothPolyDataFilter);
 	
 protected:
 	
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 };
 
 #endif // ISMOOTHPOLYDATAFILTER2_H
