@@ -30,51 +30,51 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "idata.h"
-#include "idatahelper.h"
-#include "idatalimits.h"
 #include "ierror.h"
 #include "imath.h"
+#include "iuniformgriddata.h"
 #include "iviewmodule.h"
 #include "ivtk.h"
 
 #include <vtkCellArray.h>
 #include <vtkDoubleArray.h>
 #include <vtkFloatArray.h>
+#include <vtkImageData.h>
 #include <vtkMath.h>
 #include <vtkPointData.h>
 #include <vtkPoints.h>
 #include <vtkPolyData.h>
-#include <vtkStructuredPoints.h>
 
 //
 //  Templates
 //
-#include "ibuffertemplate.h"
-#include "igenericfiltertemplate.h"
+#include "ibuffer.tlh"
+#include "igenericfilter.tlh"
 
 
 using namespace iParameter;
 
 
-iStreamLineFilter::iStreamLineFilter(iViewSubject *vo) : iGenericFilter<vtkStreamTracer,vtkDataSet,vtkPolyData>(vo,1,true,true)
+iStreamLineFilter::iStreamLineFilter(iDataConsumer *consumer) : iGenericFilter<vtkStreamTracer,vtkDataSet,vtkPolyData>(consumer,2,true)
 {
 	mLength = 2.0;
 	mVmin = 1.0e-5;
 	mDir = StreamLine::Direction::BothWays;
 	mSplitLines = 0;
-	mComputeVort = mComputeDiv = true;
 	mQuality = 0;
 	this->SetQuality(mQuality);
 	mDmin = 1.0e-3;
 
 	this->SetIntegratorTypeToRungeKutta45();
-#ifdef IVTK_PRE56
-	this->SetMaximumPropagationUnitToLengthUnit();
-#endif
 	this->SetMaximumPropagation(mLength);
 	this->SetTerminalSpeed(mVmin);
 	this->SetIntegrationDirectionToBoth();
-	this->SetComputeVorticity(vtkSwitch(mComputeVort));
+}
+
+
+vtkDataSet* iStreamLineFilter::SourceData()
+{
+	return this->GetSource();
 }
 
 
@@ -89,27 +89,6 @@ void iStreamLineFilter::SetLength(float d)
 }
 
 
-void iStreamLineFilter::SetComputeVorticity(bool d)
-{
-	if(d != mComputeVort)
-	{
-		mComputeVort = d;
-		this->SetComputeVorticity(vtkSwitch(d));
-		this->Modified();
-	}
-}
-
-
-void iStreamLineFilter::SetComputeDivergence(bool d)
-{
-	if(d != mComputeDiv)
-	{
-		mComputeDiv = d;
-		this->Modified();
-	}
-}
-
-
 void iStreamLineFilter::SetMinimumSpeed(float v)
 {
 	if(v > 1.0e-30)
@@ -170,21 +149,21 @@ void iStreamLineFilter::SetQuality(int q)
 	{ 
 		mQuality = q; 
 		mEps = eps0*pow(0.1,(double)mQuality);
-		mItMax = itMax0*round(pow(10.0,0.25*q));
+		mItMax = itMax0*iMath::Round2Int(pow(10.0,0.25*q));
 		this->Modified(); 
 	} 
 }
 
 
-void iStreamLineFilter::ProduceOutput()
+void iStreamLineFilter::ProvideOutput()
 {
-	vtkDataObject *input = this->GetInput();
-	vtkPolyData *output = this->GetOutput();
-	vtkDataSet *source = this->GetSource();
+	vtkDataSet *input = this->InputData();
+	vtkPolyData *output = this->OutputData();
+	vtkDataSet *source = this->SourceData();
 
 	if(input->IsA("vtkImageData") && source->IsA("vtkPointSet"))
 	{
-		this->ProduceOutputForImageData(vtkImageData::SafeDownCast(input),output,vtkPointSet::SafeDownCast(source));
+		this->ProvideOutputForImageData(vtkImageData::SafeDownCast(input),output,vtkPointSet::SafeDownCast(source));
 	}
 	else
 	{
@@ -193,7 +172,7 @@ void iStreamLineFilter::ProduceOutput()
 }
 
 
-void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyData *output, vtkPointSet *source)
+void iStreamLineFilter::ProvideOutputForImageData(vtkImageData *input, vtkPolyData *output, vtkPointSet *source)
 {
 	int i,line;
 
@@ -212,9 +191,9 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 
 	int nlines = srcPoints->GetNumberOfPoints();
 	
-	vtkPoints *poi = vtkPoints::New(VTK_DOUBLE); IERROR_ASSERT(poi);
-	vtkCellArray *lin = vtkCellArray::New(); IERROR_ASSERT(lin);
-	vtkFloatArray *sca = vtkFloatArray::New(); IERROR_ASSERT(sca);
+	vtkPoints *poi = vtkPoints::New(VTK_DOUBLE); IERROR_CHECK_MEMORY(poi);
+	vtkCellArray *lin = vtkCellArray::New(); IERROR_CHECK_MEMORY(lin);
+	vtkFloatArray *sca = vtkFloatArray::New(); IERROR_CHECK_MEMORY(sca);
 
 	input->GetDimensions(wDims);
 	input->GetOrigin(wOrg);
@@ -224,13 +203,12 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 	if(cell > wSpa[1]) cell = wSpa[1];
 	if(cell > wSpa[2]) cell = wSpa[2];
 	
+	this->GetPeriodicities(wPer);
+
 	//
 	//  Determine how many scalar components we need to carry with us
 	//
-	int nsca = 2;
-	if(mComputeVort) nsca++;
-	if(mComputeDiv) nsca++;
-	nsca += wNsca;
+	int nsca = wNsca + 1; // +1 is for 1/vv for tube scaling
 	sca->SetNumberOfComponents(nsca);
 
 	//
@@ -244,11 +222,6 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 	bool done;
 	vtkIdType l, l0;
 
-	float vort0[3], div0[1];
-	float *vort = 0, *div = 0;
-	if(mComputeVort) vort = vort0;
-	if(mComputeDiv) div = div0;
-
 	iBuffer<float> bsca; 
 	bsca.Extend(nsca);
 
@@ -271,11 +244,11 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 	vtkIdType vertex = 0;
 	for(line=0; line<nlines; line++) 
 	{
-		this->UpdateProgress((float)line/nlines);
+		this->UpdateProgress(double(line)/nlines);
 		if(this->GetAbortExecute()) break;
 		
 		srcPoints->GetPoint(line,x0);
-		l0 = GetVector(x0,v0);
+		l0 = this->GetVector(x0,v0);
 		if(ptrNorms != 0)
 		{
 			vn = ptrNorms + 3*line;
@@ -322,7 +295,7 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 							if(x1[i] < -1.0) x1[i] = -1.0;
 							if(x1[i] > 1.0) x1[i] = 1.0;
 						}
-						l = GetVector(x1,v1);
+						l = this->GetVector(x1,v1);
 					}
 
 					if((mDir==StreamLine::Direction::Forward && sdir*vtkMath::Dot(vn,v0)<0.0 || (mDir==StreamLine::Direction::Backward && sdir*vtkMath::Dot(vn,v0)>0.0)))
@@ -343,7 +316,7 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 						//
 						//  Save the point
 						//
-						l = GetVector(x1,v1,vort,div);
+						l = this->GetVector(x1,v1);
 						
 						out = false;
 						for(i=0; i<3; i++)
@@ -355,27 +328,10 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 
 						vv1 = sqrt(v1[0]*v1[0]+v1[1]*v1[1]+v1[2]*v1[2]);
 						poi->InsertNextPoint(x1); npoi++;
-						i = 0;
-						bsca[i++] = 1.0/sqrt(1.0+vv1/mVmin);
-						bsca[i++] = vv1;
-						if(mComputeVort)
-						{
-							//
-							//  vorticity calculation will be here
-							//
-							bsca[i++] = vtkMath::Dot(v1,vort);
-						}
-						if(mComputeDiv)
-						{
-							//
-							//  divergence calculation will be here
-							//
-							bsca[i++] = div[0];
-						}
-
+						bsca[0] = 1.0/sqrt(1.0+vv1/mVmin);
 						if(wNsca > 0) 
 						{
-							this->AssignScalars(bsca+i,l);
+							this->AssignScalars(bsca+1,l);
 						}
 
 						sca->InsertNextTuple(bsca);
@@ -411,12 +367,6 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 }
 
 
-float iStreamLineFilter::GetMemorySize()
-{
-	return this->GetOutput()->GetActualMemorySize();
-}
-
-
 int iStreamLineFilter::FollowLine(double x[3], double &d, float &h, float eps, vtkIdType l)
 {
 	const float b21 = 2.0/9.0;
@@ -454,35 +404,35 @@ int iStreamLineFilter::FollowLine(double x[3], double &d, float &h, float eps, v
 
 	this->GetDmin(l,ddmin,dx);
 
-	GetVector(x,vtmp);
+	this->GetVector(x,vtmp);
 	for(i=0; i<3; i++)
 	{
 		k1[i] = h*vtmp[i];
 		xtmp[i] = x[i] + b21*k1[i];
 	}
 
-	GetVector(xtmp,vtmp);
+	this->GetVector(xtmp,vtmp);
 	for(i=0; i<3; i++)
 	{
 		k2[i] = h*vtmp[i];
 		xtmp[i] = x[i] + b31*k1[i] + b32*k2[i];
 	}
 
-	GetVector(xtmp,vtmp);
+	this->GetVector(xtmp,vtmp);
 	for(i=0; i<3; i++)
 	{
 		k3[i] = h*vtmp[i];
 		xtmp[i] = x[i] + b41*k1[i] + b42*k2[i] + b43*k3[i];
 	}
 
-	GetVector(xtmp,vtmp);
+	this->GetVector(xtmp,vtmp);
 	for(i=0; i<3; i++)
 	{
 		k4[i] = h*vtmp[i];
 		xtmp[i] = x[i] + b51*k1[i] + b52*k2[i] + b53*k3[i] + b54*k4[i];
 	}
 
-	GetVector(xtmp,vtmp);
+	this->GetVector(xtmp,vtmp);
 	for(i=0; i<3; i++)
 	{
 		k5[i] = h*vtmp[i];
@@ -490,7 +440,7 @@ int iStreamLineFilter::FollowLine(double x[3], double &d, float &h, float eps, v
 	}
 
 	errmax = 0.0;
-	GetVector(xtmp,vtmp);
+	this->GetVector(xtmp,vtmp);
 	for(i=0; i<3; i++)
 	{
 		k6[i] = h*vtmp[i];
@@ -569,22 +519,20 @@ void iStreamLineFilter::AssignScalars(float *p, vtkIdType l)
 }
 
 
-vtkIdType iStreamLineFilter::GetVector(double x[3], float v[3], float *vort, float *div)
+vtkIdType iStreamLineFilter::GetVector(double x[3], float v[3])
 {
-	return iStreamLineFilter::GetVector(x,v,wPtrVec,wDims,wOrg,wSpa,wLimits,vort,div);
+	return iStreamLineFilter::GetVectorWithCIC(x,v,wPtrVec,wDims,wOrg,wSpa,wPer);
 }
 
 
-vtkIdType iStreamLineFilter::GetVector(double x[3], float v[3], float *ptrvec, int dims[3], double org[3], double spa[3], const iDataLimits *limits, float *vort, float *div)
+vtkIdType iStreamLineFilter::GetVectorWithCIC(double x[3], float v[3], float *ptrvec, int dims[3], double org[3], double spa[3], bool per[3])
 {
 	int ijk1[3], ijk2[3];
 	int i;
 	double w1[3], w2[3];
 	float *v111, *v112, *v121, *v122, *v211, *v212, *v221, *v222;
 
-	bool per[3];
-	limits->GetPeriodicities(per);
-	iDataHelper::CIC(per,dims,org,spa,x,ijk1,ijk2,w1,w2);
+	iUniformGridData::CIC(per,dims,org,spa,x,ijk1,ijk2,w1,w2);
 
 	//
 	//  Vectors of the CIC neigbors
@@ -611,56 +559,6 @@ vtkIdType iStreamLineFilter::GetVector(double x[3], float v[3], float *ptrvec, i
 			v222[i]*w2[0]*w2[1]*w2[2];
 	}
 
-	if(vort != 0)
-	{
-		vort[0] = (
-			(v112[1]-v111[1])*w1[0]*w1[1] +
-			(v122[1]-v121[1])*w1[0]*w2[1] +
-			(v212[1]-v211[1])*w2[0]*w1[1] +
-			(v222[1]-v221[1])*w2[0]*w2[1])/spa[2] - (
-			(v121[2]-v111[2])*w1[0]*w1[2] +
-			(v122[2]-v112[2])*w1[0]*w2[2] +
-			(v221[2]-v211[2])*w2[0]*w1[2] +
-			(v222[2]-v212[2])*w2[0]*w2[2])/spa[1];
-		
-		vort[1] = (
-			(v211[2]-v111[2])*w1[1]*w1[2] +
-			(v212[2]-v112[2])*w1[1]*w2[2] +
-			(v221[2]-v121[2])*w2[1]*w1[2] +
-			(v222[2]-v122[2])*w2[1]*w2[2])/spa[0] - (
-			(v112[0]-v111[0])*w1[0]*w1[1] +
-			(v122[0]-v121[0])*w1[0]*w2[1] +
-			(v212[0]-v211[0])*w2[0]*w1[1] +
-			(v222[0]-v221[0])*w2[0]*w2[1])/spa[2];
-		
-		vort[2] = (
-			(v121[0]-v111[0])*w1[0]*w1[2] +
-			(v122[0]-v112[0])*w1[0]*w2[2] +
-			(v221[0]-v211[0])*w2[0]*w1[2] +
-			(v222[0]-v212[0])*w2[0]*w2[2])/spa[1] - (
-			(v211[1]-v111[1])*w1[1]*w1[2] +
-			(v212[1]-v112[1])*w1[1]*w2[2] +
-			(v221[1]-v121[1])*w2[1]*w1[2] +
-			(v222[1]-v122[1])*w2[1]*w2[2])/spa[0];
-	}
-
-	if(div != 0)
-	{
-		*div = (
-			(v211[0]-v111[0])*w1[1]*w1[2] +
-			(v212[0]-v112[0])*w1[1]*w2[2] +
-			(v221[0]-v121[0])*w2[1]*w1[2] +
-			(v222[0]-v122[0])*w2[1]*w2[2])/spa[0] + (
-			(v121[1]-v111[1])*w1[0]*w1[2] +
-			(v122[1]-v112[1])*w1[0]*w2[2] +
-			(v221[1]-v211[1])*w2[0]*w1[2] +
-			(v222[1]-v212[1])*w2[0]*w2[2])/spa[1] + (
-			(v112[2]-v111[2])*w1[0]*w1[1] +
-			(v122[2]-v121[2])*w1[0]*w2[1] +
-			(v212[2]-v211[2])*w2[0]*w1[1] +
-			(v222[2]-v221[2])*w2[0]*w2[1])/spa[2];
-	}
-
 	return ijk1[0] + dims[0]*(ijk1[1]+(vtkIdType)dims[1]*ijk1[2]);
 }
 
