@@ -59,17 +59,6 @@ namespace iParameter
 			inline bool IsValid(int m){ return m>=0 && m<=4; }
 			//const int COUNT = 5;
 		};
-
-		namespace Source
-		{
-			const int Disk =	0;
-			const int Plane =	1;
-			const int Sphere =	2;
-			const int Marker =	3;
-
-			inline bool IsValid(int m){ return m>=0 && m<=3; }
-			//const int COUNT =	4;
-		};
 	};
 };
 
@@ -77,41 +66,37 @@ namespace iParameter
 class iStreamLineFilter : public iGenericFilter<vtkStreamTracer,vtkDataSet,vtkPolyData>
 {
 
-	IGENERICFILTER_DECLARE(iStreamLineFilter,vtkStreamTracer);
+	iGenericFilterTypeMacro(iStreamLineFilter,vtkStreamTracer);
 
 public:
 
+	vtkDataSet* SourceData();
+
 	void SetLength(float d);
-	void SetComputeVorticity(bool d);
-	void SetComputeDivergence(bool d);
-	void SetMinimumSpeed(float v);
+	void SetQuality(int q);
 	void SetDirection(int d);
 	void SetSplitLines(bool s);
-	void SetQuality(int q);
+	void SetMinimumSpeed(float v);
 
 	inline float GetLength() const { return mLength; }
-	inline bool GetComputeVorticity() const { return mComputeVort; }
-	inline bool GetComputeDivergence() const { return mComputeDiv; }
-	inline float GetMinimumSpeed() const { return mVmin; }
+	inline int GetQuality() const { return mQuality; }
 	inline int GetDirection() const { return mDir; }
 	inline bool GetSplitLines() const { return mSplitLines; }
-	inline int GetQuality() const { return mQuality; }
-
-	virtual float GetMemorySize();
-
-	static vtkIdType GetVector(double x[3], float v[3], float *ptrdata, int dims[3], double origin[3], double spacing[3], const iDataLimits *limits, float *vort = 0, float *div = 0);
+	inline float GetMinimumSpeed() const { return mVmin; }
 
 protected:
 	
-	virtual void ProduceOutput();
+	virtual void ProvideOutput();
 
-	virtual vtkIdType GetVector(double x[3], float v[3], float *vort = 0, float *div = 0);
+	virtual vtkIdType GetVector(double x[3], float v[3]);
 	virtual int FollowLine(double x[3], double &d, float &h, float eps, vtkIdType l);
 	
 	virtual bool DefinePointers(vtkImageData *input);
 	virtual void AssignScalars(float *p, vtkIdType l);
 	virtual void GetDmin(vtkIdType l, float &ddmin, float &dx);
 
+	static vtkIdType GetVectorWithCIC(double x[3], float v[3], float *ptrdata, int dims[3], double origin[3], double spacing[3], bool per[3]);
+
 	//
 	//  Work variables
 	//
@@ -119,19 +104,20 @@ protected:
 	int wDims[3], wNsca;
 	float *wPtrVec, *wPtrSca;
 	double wOrg[3], wSpa[3];
+	bool wPer[3];
 
 	float mDmin;
 
 private:
 
-	void ProduceOutputForImageData(vtkImageData *input, vtkPolyData *output, vtkPointSet *source);
+	void ProvideOutputForImageData(vtkImageData *input, vtkPolyData *output, vtkPointSet *source);
 
 	float mVmin, mEps;
 	float mLength;
-	bool mComputeVort, mComputeDiv;
 	int mDir, mQuality, mItMax, mAxisDir;
 	bool mSplitLines;
 
+	/* blocked */ vtkDataSet *GetSource(){ return this->vtkStreamTracer::GetSource(); }
 };
 
 #endif  // ISTREAMLINEFILTER_H
