@@ -29,7 +29,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 
 
-#include "ierror.h"
+#include "iexception.h"
 #include "imath.h"
 
 #include <math.h>
@@ -72,7 +72,7 @@ public:
 	{ 
 		if(s<=0 || s==mLen || mRef>1) return; 
 		delete [] mData;
-		mData = new char[s]; IERROR_ASSERT(mData);
+		mData = new char[s]; if(mData == 0) throw iException::TotalDisaster();
 		mLen = s;
 	}
 	inline void DeepCopy(iCharArray *arr)
@@ -91,7 +91,7 @@ private:
 	iCharArray(int s)
 	{ 
 		if(s < 1) s = 1;
-		mData = new char[s]; IERROR_ASSERT(mData); 
+		mData = new char[s]; if(mData == 0) throw iException::TotalDisaster();
 		mRef = 1; 
 		mLen = s;
 	}
@@ -108,14 +108,14 @@ iString::iString(const iString &str)
 	mArr->Register();
 	mLen = str.mLen;
 #ifdef I_DEBUG
-	ptr = mArr->GetPointer(0);
+	Ptr = mArr->GetPointer(0);
 #endif
 }
 
 
 iString::iString(const char *s, int l)
 {
-	mArr = iCharArray::New(); IERROR_ASSERT(mArr);
+	mArr = iCharArray::New(); if(mArr == 0) throw iException::TotalDisaster();
 
 	if(s != 0) 
 	{
@@ -127,11 +127,11 @@ iString::iString(const char *s, int l)
 	else 
 	{
 		mLen = 0;
-		mArr->SetSize(ARRSIZE(0));
+		if(l > 0) mArr->SetSize(ARRSIZE(l)); else mArr->SetSize(ARRSIZE(0));
 	}
 	*(mArr->GetPointer(mLen)) = 0;
 #ifdef I_DEBUG
-	ptr = mArr->GetPointer(0);
+	Ptr = mArr->GetPointer(0);
 #endif
 }
 
@@ -146,12 +146,12 @@ void iString::Clear()
 {
 	if(mArr->GetReferenceCount() > 1)
 	{
-		iCharArray *tmp = iCharArray::New(); IERROR_ASSERT(tmp);
+		iCharArray *tmp = iCharArray::New(); if(tmp == 0) throw iException::TotalDisaster();
 		tmp->SetSize(ARRSIZE(0));
 		mArr->UnRegister();
 		mArr = tmp;
 #ifdef I_DEBUG
-		ptr = mArr->GetPointer(0);
+		Ptr = mArr->GetPointer(0);
 #endif
 	}
 	mLen = 0;
@@ -165,7 +165,7 @@ void iString::Init(int size)
 
 	if(mArr->GetReferenceCount() > 1)
 	{
-		iCharArray *tmp = iCharArray::New(); IERROR_ASSERT(tmp);
+		iCharArray *tmp = iCharArray::New(); if(tmp == 0) throw iException::TotalDisaster();
 		mArr->UnRegister();
 		mArr = tmp;
 	}
@@ -174,7 +174,7 @@ void iString::Init(int size)
 	mLen = 0;
 	*(mArr->GetPointer(mLen)) = 0;
 #ifdef I_DEBUG
-	ptr = mArr->GetPointer(0);
+	Ptr = mArr->GetPointer(0);
 #endif
 }
 
@@ -195,12 +195,12 @@ char* iString::GetWritePointer(int len)
 		//  Need to re-allocate
 		//
 		iCharArray *tmp;
-		tmp = iCharArray::New(); IERROR_ASSERT(tmp);
+		tmp = iCharArray::New(); if(tmp == 0) throw iException::TotalDisaster();
 		tmp->SetSize(ARRSIZE(len));
 		mArr->UnRegister();
 		mArr = tmp;
 #ifdef I_DEBUG
-		ptr = mArr->GetPointer(0);
+		Ptr = mArr->GetPointer(0);
 #endif
 	}
 	mLen = len;
@@ -218,7 +218,7 @@ iString& iString::operator=(const iString &str)
 		mArr->Register();
 		mLen = str.mLen;
 #ifdef I_DEBUG
-		ptr = mArr->GetPointer(0);
+		Ptr = mArr->GetPointer(0);
 #endif
 	}
 	return *this;
@@ -243,14 +243,14 @@ iString& iString::operator+=(const iString &str)
 		//  Need to re-allocate
 		//
 		iCharArray *tmp;
-		tmp = iCharArray::New(); IERROR_ASSERT(tmp);
+		tmp = iCharArray::New(); if(tmp == 0) throw iException::TotalDisaster();
 		tmp->SetSize(newsize);
 		memcpy(tmp->GetPointer(0),mArr->GetPointer(0),mLen);
 		memcpy(tmp->GetPointer(mLen),str.mArr->GetPointer(0),str.mLen+1);
 		mArr->UnRegister();
 		mArr = tmp;
 #ifdef I_DEBUG
-		ptr = mArr->GetPointer(0);
+		Ptr = mArr->GetPointer(0);
 #endif
 	}
 
@@ -292,22 +292,22 @@ const char* iString::ToCharPointer(int i) const
 }
 
 
-bool iString::IsEmpty() const
-{
-	return mLen == 0;
-}
-
-
 bool iString::IsAt(const iString &str, int index) const
 {
 	if(index>=0 && index<=mLen-str.mLen)
 	{
-		return (this->Find(str,index) == index);
+		return (strncmp(mArr->GetPointer(index),str.mArr->GetPointer(0),str.mLen)==0);
 	}
 	else return false;
 }
 
 
+bool iString::BeginsWith(const iString &str) const
+{
+	return (mLen>=str.mLen) && (strncmp(mArr->GetPointer(0),str.mArr->GetPointer(0),str.mLen)==0);
+}
+
+
 bool iString::EndsWith(const iString &str) const
 {
 	return (mLen>=str.mLen) && (strcmp(mArr->GetPointer(mLen-str.mLen),str.mArr->GetPointer(0))==0);
@@ -363,6 +363,13 @@ int iString::Find(char c, int index) const
 }
 
 
+int iString::FindLast(char c) const
+{
+	char *tmp = strrchr(mArr->GetPointer(0),c);
+	if(tmp != 0) return int(tmp-mArr->GetPointer(0)); else return -1;
+}
+
+
 int iString::Find(const char *s, int index) const
 {
 	if(s==0 || s[0]==0 || index>=mLen) return -1;
@@ -456,13 +463,13 @@ void iString::Replace(int index, char c)
 			//  Need to re-allocate
 			//
 			iCharArray *tmp;
-			tmp = iCharArray::New(); IERROR_ASSERT(tmp);
+			tmp = iCharArray::New(); if(tmp == 0) throw iException::TotalDisaster();
 			tmp->SetSize(ARRSIZE(mLen));
 			memcpy(tmp->GetPointer(0),mArr->GetPointer(0),mLen+1);
 			mArr->UnRegister();
 			mArr = tmp;
 #ifdef I_DEBUG
-			ptr = mArr->GetPointer(0);
+			Ptr = mArr->GetPointer(0);
 #endif
 		}
 		*(mArr->GetPointer(index)) = c;
@@ -494,7 +501,7 @@ void iString::Replace(int index, int length, const iString &str)
 		//  Need to re-allocate
 		//
 		iCharArray *tmp;
-		tmp = iCharArray::New(); IERROR_ASSERT(tmp);
+		tmp = iCharArray::New(); if(tmp == 0) throw iException::TotalDisaster();
 		tmp->SetSize(newsize);
 		if(index > 0) memcpy(tmp->GetPointer(0),mArr->GetPointer(0),index);
 		memcpy(tmp->GetPointer(index),str.mArr->GetPointer(0),str.mLen);
@@ -502,7 +509,7 @@ void iString::Replace(int index, int length, const iString &str)
 		mArr->UnRegister();
 		mArr = tmp;
 #ifdef I_DEBUG
-		ptr = mArr->GetPointer(0);
+		Ptr = mArr->GetPointer(0);
 #endif
 	}
 	mLen = newlen;
@@ -569,10 +576,10 @@ iString iString::FromNumber(int d, const char *format)
 	const unsigned int n = 99;
 	char s[n];
 	sprintf(s,format,d);
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 	if(strlen(s) > n)
 	{
-		IERROR_FATAL("Array out of bounds.");
+		throw iException::TotalDisaster();
 	}
 #endif
 	return iString(s);
@@ -584,10 +591,25 @@ iString iString::FromNumber(long d, const char *format)
 	const unsigned int n = 99;
 	char s[n];
 	sprintf(s,format,d);
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 	if(strlen(s) > n)
 	{
-		IERROR_FATAL("Array out of bounds.");
+		throw iException::TotalDisaster();
+	}
+#endif
+	return iString(s);
+}
+
+
+iString iString::FromNumber(size_t d, const char *format)
+{
+	const unsigned int n = 99;
+	char s[n];
+	sprintf(s,format,d);
+#ifndef I_NO_CHECK
+	if(strlen(s) > n)
+	{
+		throw iException::TotalDisaster();
 	}
 #endif
 	return iString(s);
@@ -602,10 +624,10 @@ iString iString::FromNumber(long long d, const char *format)
 	const unsigned int n = 99;
 	char s[n];
 	sprintf(s,format,d);
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 	if(strlen(s) > n)
 	{
-		IERROR_FATAL("Array out of bounds.");
+		throw iException::TotalDisaster();
 	}
 #endif
 	return iString(s);
@@ -618,10 +640,10 @@ iString iString::FromNumber(float d, const char *format)
 	const unsigned int n = 99;
 	char s[n];
 	sprintf(s,format,d);
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 	if(strlen(s) > n)
 	{
-		IERROR_FATAL("Array out of bounds.");
+		throw iException::TotalDisaster();
 	}
 #endif
 	return iString(s);
@@ -633,10 +655,10 @@ iString iString::FromNumber(double d, const char *format)
 	const unsigned int n = 99;
 	char s[n];
 	sprintf(s,format,d);
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 	if(strlen(s) > n)
 	{
-		IERROR_FATAL("Array out of bounds.");
+		throw iException::TotalDisaster();
 	}
 #endif
 	return iString(s);
@@ -648,10 +670,10 @@ iString iString::FromNumber(void *d)
 	const unsigned int n = 99;
 	char s[n];
 	sprintf(s,"%p",d);
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 	if(strlen(s) > n)
 	{
-		IERROR_FATAL("Array out of bounds.");
+		throw iException::TotalDisaster();
 	}
 #endif
 	return iString(s);
@@ -666,7 +688,8 @@ iString iString::FromNumber(bool n)
 
 int iString::ToInt(bool &ok) const
 {
-	int d; char c;
+	int d = 0;
+	char c;
 	ok = (sscanf(mArr->GetPointer(0),"%d%c",&d,&c) == 1);
 	return d;
 }
@@ -674,7 +697,8 @@ int iString::ToInt(bool &ok) const
 
 float iString::ToFloat(bool &ok) const
 {
-	float d; char c;
+	float d = 0.0;
+	char c;
 	switch(sscanf(mArr->GetPointer(0),"%g%c",&d,&c))
 	{
 	case 1:
@@ -684,7 +708,6 @@ float iString::ToFloat(bool &ok) const
 			//
 			ok = true;
 			return d;
-			break;
 		}
 	case 2:
 		{
@@ -705,7 +728,8 @@ float iString::ToFloat(bool &ok) const
 
 double iString::ToDouble(bool &ok) const
 {
-	double d; char c;
+	double d = 0.0;
+	char c;
 	ok = (sscanf(mArr->GetPointer(0),"%lg%c",&d,&c) == 1);
 	return d;
 }
@@ -713,7 +737,8 @@ double iString::ToDouble(bool &ok) const
 
 void* iString::ToPointer(bool &ok) const
 {
-	void *d; char c;
+	void *d = 0;
+	char c;
 	ok = (sscanf(mArr->GetPointer(0),"%p%c",&d,&c) == 1);
 	return d;
 }
@@ -753,7 +778,7 @@ iString iString::Upper() const
 }
 
 
-void iString::ReduceWhiteSpace()
+void iString::ReduceWhiteSpace(bool preserve_quotes)
 {
 	//
 	//  Turn all whitespace characters (codes 9-13 and 32) into a single space (code 32) character, and
@@ -769,7 +794,7 @@ void iString::ReduceWhiteSpace()
 		//
 		//  Dereference
 		//
-		tmp = iCharArray::New(); IERROR_ASSERT(tmp);
+		tmp = iCharArray::New(); if(tmp == 0) throw iException::TotalDisaster();
 		tmp->SetSize(ARRSIZE(mLen));
 		pd = tmp->GetPointer(0);
 	}
@@ -778,15 +803,19 @@ void iString::ReduceWhiteSpace()
 		pd = mArr->GetPointer(0);
 	}
 
-	int is, id;
 	bool on = true;
+	int is, id;
+	bool in_quotes = false;
+	bool is_nws;
 	for(is=id=0; is<mLen; is++)
 	{
-		if(ps[is]!=32 && (ps[is]<9 || ps[is]>13)) 
+		is_nws = (ps[is]!=32 && (ps[is]<9 || ps[is]>13));
+		if(is_nws || (preserve_quotes && in_quotes))
 		{
 			//
 			//  not a whitespace
 			//
+			if(ps[is]=='"' && (is==0 || ps[is-1]!='\\')) in_quotes = !in_quotes;
 			pd[id++] = ps[is];
 			on = false;
 		}
@@ -815,13 +844,13 @@ void iString::ReduceWhiteSpace()
 		mArr->UnRegister();
 		mArr = tmp;
 #ifdef I_DEBUG
-		ptr = mArr->GetPointer(0);
+		Ptr = mArr->GetPointer(0);
 #endif
 	}
 }
 
 
-void iString::RemoveWhiteSpace()
+void iString::RemoveWhiteSpace(bool preserve_quotes)
 {
 	//
 	//  Remove all whitespace characters (codes 9-13 and 32).
@@ -836,7 +865,7 @@ void iString::RemoveWhiteSpace()
 		//
 		//  Dereference
 		//
-		tmp = iCharArray::New(); IERROR_ASSERT(tmp);
+		tmp = iCharArray::New(); if(tmp == 0) throw iException::TotalDisaster();
 		tmp->SetSize(ARRSIZE(mLen));
 		pd = tmp->GetPointer(0);
 	}
@@ -846,13 +875,17 @@ void iString::RemoveWhiteSpace()
 	}
 
 	int is, id;
+	bool in_quotes = false;
+	bool is_nws;
 	for(is=id=0; is<mLen; is++)
 	{
-		if(ps[is]!=32 && (ps[is]<9 || ps[is]>13)) 
+		is_nws = (ps[is]!=32 && (ps[is]<9 || ps[is]>13));
+		if(is_nws || (preserve_quotes && in_quotes))
 		{
 			//
 			//  not a whitespace
 			//
+			if(ps[is]=='"' && (is==0 || ps[is-1]!='\\')) in_quotes = !in_quotes;
 			pd[id++] = ps[is];
 		}
 	}
@@ -865,7 +898,7 @@ void iString::RemoveWhiteSpace()
 		mArr->UnRegister();
 		mArr = tmp;
 #ifdef I_DEBUG
-		ptr = mArr->GetPointer(0);
+		Ptr = mArr->GetPointer(0);
 #endif
 	}
 }
@@ -955,7 +988,9 @@ void iString::ReformatHTMLToText(int length)
 	//
 	//  Replace HTML new-line commands with newlines
 	//
-	this->Replace("<li>","\n* ");
+	this->Replace("<li>","* ");
+	this->Replace("</li>","\n");
+	//this->Replace("<ul>","\n");
 	this->Replace("<br>","\n");
 	this->Replace("<p>","\n\n");
 
@@ -1019,3 +1054,17 @@ void iString::ReformatHTMLToText(int length)
 	}
 }
 
+
+iString iString::Whitespace(int len)
+{
+	int i;
+	iString str;
+	char *ptr = str.GetWritePointer((len>0)?len:1);
+
+	for(i=0; i<len; i++)
+	{
+		ptr[i] = ' ';
+	}
+
+	return str;
+}
