@@ -87,6 +87,7 @@ public:
     int Find(char c, int index = 0) const;
     int Find(const char *str, int index = 0) const;
     int Find(const iString &str, int index = 0) const;  // inlined below
+    int FindLast(char c) const;
     int FindIgnoringWhiteSpace(const iString &str, int index = 0, int *last = 0) const;
 	int FindFromSet(const char *set, int index = 0, int *length = 0) const;
 	void Replace(int index, char c);
@@ -94,6 +95,7 @@ public:
 	void Replace(const iString &tar, const iString &str, int index = 0, bool once = false); 
 	iString Substitute(const iString &tar, const iString &str) const;
 	bool IsAt(const iString &str, int index) const;
+	bool BeginsWith(const iString &str) const;
 	bool EndsWith(const iString &str) const;
 	bool IsWhiteSpace(int i) const;
 
@@ -111,6 +113,7 @@ public:
     static iString FromNumber(long n, const char *format = "%ld");
     static iString FromNumber(float n, const char *format = "%g");
     static iString FromNumber(double n, const char *format = "%lg");
+    static iString FromNumber(size_t n, const char *format = "%ld");
     static iString FromNumber(void *n);
     static iString FromNumber(bool n);
 
@@ -134,19 +137,24 @@ public:
 	//
 	//  Formatting functions
 	//
-	void ReduceWhiteSpace();
-	void RemoveWhiteSpace();
+	void ReduceWhiteSpace(bool preserve_quotes = false);
+	void RemoveWhiteSpace(bool preserve_quotes = false);
 	void RemoveFormatting(const iString &tokBeg, const iString &tokEnd, bool multiLevel = false);
 	void ReformatHTMLToText(int length = 0);
 	void FindTokenMatch(const iString &tokBeg, int &indBeg, const iString &tokEnd, int &indEnd, int index = 0, bool multiLevel = false) const;
 
+	//
+	//  Misc functions
+	//
+	static iString Whitespace(int len);
+
 private:
 
+#ifdef I_DEBUG
+	char *Ptr;
+#endif
 	iCharArray *mArr;
 	int mLen;
-#ifdef I_DEBUG
-	char *ptr;
-#endif
 };
 
 
@@ -164,6 +172,12 @@ inline int iString::Length() const
 }
 
 
+inline bool iString::IsEmpty() const
+{
+	return mLen == 0;
+}
+
+
 inline int iString::Contains(const iString &str, int index) const 
 { 
 	return this->Contains(str.ToCharPointer(),index); 
