@@ -30,92 +30,63 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define ISURFACEPIPELINE_H
 
 
-#include "iviewsubjectpipeline.h"
+#include "ireplicatedviewsubjectpipeline.h"
 
 
 class iBoundedPlaneSource;
 class iBoundedSphereSource;
 class iContourFilter;
 class iFlipNormalsFilter;
-class iIdentityFilter;
 class iOptimizePolyDataFilter;
 class iProbeFilter;
 class iReducePolyDataFilter;
 class iReducePolyDataFilter2;
-class iReplicatedPolyData;
-class iShiftPolyDataFilter;
 class iSmoothPolyDataFilter;
-class iSurfaceViewSubject;
+class iSurfaceViewInstance;
 
 
-class iSurfacePipeline : public iViewSubjectPipeline
+class iSurfacePipeline : public iReplicatedViewSubjectPipeline
 {
 
-	friend class iSurfaceViewSubject;
+	friend class iSurfaceViewInstance;
 
 public:
 	
-	enum
-	{
-		_FixedSurfacePosition = iViewSubjectPipeline::__Last,
-		_FixedSurfaceSize,
-		_IsoSurfaceLevel,
-		_IsoSurfaceMethod,
-		_IsoSurfacePipeline,
-		_IsoSurfaceVar,
-		_Method,
-		_NormalsFlipped,
-		_PlaneDirection,
-		_PlaneResolution,
-		_SphereResolution,
-		_VarPaint,
-		__Last
-	};
+	vtkTypeMacro(iSurfacePipeline,iReplicatedViewSubjectPipeline);
 
-	vtkTypeMacro(iSurfacePipeline,iViewSubjectPipeline);
-
-	virtual void UpdateContents(int n, int info = 0);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,Method);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,IsoVar);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,IsoLevel);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,IsoMethod);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,IsoPipeline);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,NormalsFlipped);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,SphereSize);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,SphereResolution);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,PlaneDirection);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,PlaneResolution);
+	iPipelineKeyDeclareMacro(iSurfacePipeline,ObjectPosition);
 
 protected:
 	
-	iSurfacePipeline(iSurfaceViewSubject *s);
+	iSurfacePipeline(iSurfaceViewInstance *owner);
 	virtual ~iSurfacePipeline();
 
-	virtual void ProduceOutput();
-	virtual float GetContentsMemorySize() const;
+	virtual bool PrepareInput();
 
-	//
-	//  Pipeline operation
-	//
-	virtual void UpdateFixedSurfacePosition();
-	virtual void UpdateFixedSurfaceSize();
-	virtual void UpdateIsoSurfaceLevel();
-	virtual void UpdateIsoSurfaceMethod();
-	virtual void UpdateIsoSurfacePipeline(int force);
-	virtual void UpdateIsoSurfaceVar();
-	virtual void UpdateMethod();
-	virtual void UpdateNormalsFlipped();
-	virtual void UpdatePlaneDirection();
-	virtual void UpdatePlaneResolution();
-	virtual void UpdateReplicas();
-	virtual void UpdateSphereResolution();
-	virtual void UpdateVarPaint(int s);
+	virtual vtkAlgorithm* GetIsoFilter() const; // for extensions' use
 
-	iSurfaceViewSubject *mParent;
+	iSurfaceViewInstance *mOwner;
 
 	//
 	//  VTK stuff
 	//
-	iIdentityFilter *mGateway, *mIsoSurfaceEntryGateway, *mIsoSurfaceExitGateway;
-	iContourFilter *mIsoSurfaceSource;
-	iReplicatedPolyData *mDataReplicated[2];
-	iProbeFilter *mProbeFilter[2];
+	iContourFilter *mIsoFilter;
+	iProbeFilter *mProbeFilter;
 
-	iShiftPolyDataFilter *mShiftFilter;
 	iReducePolyDataFilter *mReduceFilter;
 	iReducePolyDataFilter2 *mReduce2Filter;
 	iSmoothPolyDataFilter *mSmoothFilter;
-	iFlipNormalsFilter *mFlipNormalsFilter[2];
+	iFlipNormalsFilter *mFlipNormalsFilter;
 	iOptimizePolyDataFilter *mOptimizeFilter;
 
 	iBoundedSphereSource *mSphereSource;
