@@ -67,15 +67,15 @@ namespace iSystem
 #ifdef _WIN32
 		MEMORYSTATUS r;
 		::GlobalMemoryStatus(&r);
-		return (float)r.dwTotalPhys/__MB;
+		return float(r.dwTotalPhys)/__MB;
 #else
 		static struct rlimit r;
 		int d = getrlimit(RLIMIT_DATA,&r);
-		float v1 = (float)r.rlim_cur/__MB;
+		float v1 = float(r.rlim_cur)/__MB;
 #if defined(_SC_PHYS_PAGES) && defined(_SC_PAGESIZE)
 		unsigned long np = sysconf(_SC_PHYS_PAGES);
 		unsigned long ps = sysconf(_SC_PAGESIZE);
-		float v2 = (float)np*(float)ps/__MB;
+		float v2 = float(np)*float(ps)/__MB;
 		if(v1 > v2) v1 = v2;
 #endif
 		if(d == 0) return v1; else return ULONG_MAX/__MB;
