@@ -34,42 +34,58 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 class iPolyDataExtender;
+class iTensorFieldViewSubject;
+class iViewObject;
+
+
+class iTensorFieldViewInstance : public iFieldViewInstance
+{
+	
+	friend class iTensorFieldViewSubject;
+
+public:
+	
+	iDataConsumerTypeMacroPass(iTensorFieldViewInstance,iFieldViewInstance);
+		
+	iObjectSlotMacro1SV(Method,int);
+	iObjectSlotMacro1SV(Scaling,bool);
+	iObjectSlotMacro1SV(GlyphType,int);
+
+	virtual bool CanBeShown() const;
+
+protected:
+	
+	iTensorFieldViewInstance(iTensorFieldViewSubject *owner);
+	virtual ~iTensorFieldViewInstance();
+	virtual void ConfigureBody();
+	virtual void ConfigureMainPipeline(iViewSubjectPipeline *p, int id);
+
+	virtual iViewSubjectPipeline* CreatePipeline(int id);
+	virtual void ResetPipelineInput(vtkDataSet *input);
+
+	virtual void ShowBody(bool s);
+
+	virtual void UpdatePainting();
+	virtual void UpdateGlyphSize();
+	virtual void UpdateGlyphSampleRate();
+};
 
 
 class iTensorFieldViewSubject : public iFieldViewSubject
 {
 	
-	friend class iAbstractExtension;
-	friend class iObjectFactory;
-
 public:
 	
-	vtkTypeMacro(iTensorFieldViewSubject,iFieldViewSubject);
-	static const iObjectType& Type();
+	iViewSubjectTypeMacro2(iTensorFieldView,iFieldViewSubject);
 		
-	IOBJECT_DECLARE_GETSET1(ScalingOn,bool);
-	//virtual void SetScalingOn(bool s);
-	//inline bool isScalingOn() const { return mScalingOn; }
-	
-	IOBJECT_DECLARE_GET1(Method,int);
-	//inline int GetMethod() const { return mMethod; }
-
-	//
-	//  Inherited members
-	//
-	virtual iViewSubjectPipeline* CreatePipeline(int id);
-	IFIELDVIEWSUBJECT_DECLARE_INHERITED_KEYS;
-	IFIELDVIEWSUBJECT_DECLARE_INHERITED_MEMBERS;
+	iType::vsp_int Method;
+	iType::vsp_bool Scaling;
+	iType::vsp_int GlyphType;
 
 protected:
 	
-	iTensorFieldViewSubject(iViewModule *vm, const iDataType &type, const iDataType &scalarType, const iString &name);
+	iTensorFieldViewSubject(iViewObject *parent, const iDataType &type, const iDataType &stype);
 	virtual ~iTensorFieldViewSubject();
-	virtual void ConfigureBody();
-	virtual void ConfigureMainPipeline(iViewSubjectPipeline *p, int id);
-
-	bool mScalingOn;
-	int mMethod;
 };
 
 #endif // ITENSORFIELDVIEWSUBJECT_H
