@@ -46,8 +46,9 @@ public:
 	//
 	//  Transform so that Z-axis becomes this direction 
 	//
-	void SetDirection(float x, float y, float z);
+	void SetDirection(double x, double y, double z);
 	void SetDirection(const float *dir);
+	void SetDirection(const double *dir);
 
 protected:
 
