@@ -29,7 +29,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iuniformgriddata.h"
 
 
+namespace iUniformGridData_Private
+{
+	template<class T>
+	void CICTemplate(bool periodic[3], int dims[3], double org[3], double spa[3], T pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3]);
+};
+
+
 using namespace iParameter;
+using namespace iUniformGridData_Private;
 
 
 iUniformGridData* iUniformGridData::New()
@@ -140,7 +148,7 @@ void iUniformGridData::Initialize()
 	mVoxelLocation = VoxelLocation::Vertex;
 	mPeriodicOffsets[0] = mPeriodicOffsets[1] = mPeriodicOffsets[2] = 0;
 
-	this->vtkStructuredPoints::Initialize();
+	this->vtkImageData::Initialize();
 }
 
 
@@ -154,7 +162,7 @@ void iUniformGridData::ShallowCopy(vtkDataObject *obj)
 		mVoxelLocation = data->mVoxelLocation;
 	}
 
-	this->vtkStructuredPoints::ShallowCopy(obj);
+	this->vtkImageData::ShallowCopy(obj);
 }
 
 
@@ -168,6 +176,60 @@ void iUniformGridData::DeepCopy(vtkDataObject *obj)
 		mVoxelLocation = data->mVoxelLocation;
 	}
 
-	this->vtkStructuredPoints::DeepCopy(obj);
+	this->vtkImageData::DeepCopy(obj);
 }
 
+
+//
+//  Two helper functions
+//
+void iUniformGridData::CIC(bool periodic[3], int dims[3], double org[3], double spa[3], float pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3])
+{
+	CICTemplate(periodic,dims,org,spa,pos,ijk1,ijk2,d1,d2);
+}
+
+
+void iUniformGridData::CIC(bool periodic[3], int dims[3], double org[3], double spa[3], double pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3])
+{
+	CICTemplate(periodic,dims,org,spa,pos,ijk1,ijk2,d1,d2);
+}
+
+
+namespace iUniformGridData_Private
+{
+	template<class T>
+	void CICTemplate(bool periodic[3], int dims[3], double org[3], double spa[3], T pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3])
+	{
+		int i;
+		for(i=0; i<3; i++)
+		{
+			d1[i] = (pos[i]-org[i])/spa[i];
+			ijk1[i] = (int)floor(d1[i]);
+			d2[i] = d1[i] - ijk1[i];
+			d1[i] = 1.0 - d2[i];
+
+			if(periodic[i])
+			{
+				while(ijk1[i] < 0) ijk1[i] += dims[i];  // in case it is extended 
+				while(ijk1[i] >= dims[i]) ijk1[i] -= dims[i];
+			}
+			else
+			{
+				if(ijk1[i] < 0) ijk1[i] = 0;  
+				if(ijk1[i] >= dims[i]) ijk1[i] = dims[i] - 1;
+			}
+
+			ijk2[i] = ijk1[i] + 1;
+
+			if(periodic[i])
+			{
+				while(ijk2[i] >= dims[i]) ijk2[i] -= dims[i]; 
+			}
+			else
+			{
+				if(ijk2[i] >= dims[i]) ijk2[i] = dims[i] - 1;
+			}
+		}
+	}
+};
+
