@@ -30,7 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IUNIFORMGRIDDATA_H
 
 
-#include <vtkStructuredPoints.h>
+#include <vtkImageData.h>
 
 
 class iUniformGridFileLoader;
@@ -48,14 +48,14 @@ namespace iParameter
 };
 
 
-class iUniformGridData : public vtkStructuredPoints
+class iUniformGridData : public vtkImageData
 {
 
 	friend class iUniformGridFileLoader;
 
 public:
 	
-	vtkTypeMacro(iUniformGridData,vtkStructuredPoints);
+	vtkTypeMacro(iUniformGridData,vtkImageData);
 	static iUniformGridData* New();
 
 	//
@@ -75,6 +75,12 @@ public:
 	void GetBounds(double min[3], double max[3]);
 	void GetGlobalOrigin(double org[3]);
 
+	//
+	//  Just keep them here because they should be somewhere
+	//
+	static void CIC(bool periodic[3], int dims[3], double org[3], double spa[3],  float pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3]);
+	static void CIC(bool periodic[3], int dims[3], double org[3], double spa[3], double pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3]);
+
 protected:
 	
 	iUniformGridData();
