@@ -30,57 +30,39 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IVECTORFIELDGLYPHPIPELINE_H
 
 
-#include "iviewsubjectpipeline.h"
+#include "ifieldglyphpipeline.h"
 
 
-class iReplicatedPolyData;
-class iResampleImageDataFilter;
 class iVectorGlyphFilter;
-class iVectorFieldViewSubject;
+class iVectorFieldViewInstance;
 
 
-class iVectorFieldGlyphPipeline : public iViewSubjectPipeline
+class iVectorFieldGlyphPipeline : public iFieldGlyphPipeline
 {
 
-	friend class iVectorFieldViewSubject;
+	friend class iVectorFieldViewInstance;
 
 public:
 	
-	enum
-	{
-		_SampleRate = iViewSubjectPipeline::__Last,
-		_Size,
-		__Last
-	};
+	vtkTypeMacro(iVectorFieldGlyphPipeline,iFieldGlyphPipeline);
 
-	vtkTypeMacro(iVectorFieldGlyphPipeline,iViewSubjectPipeline);
-
-	virtual void UpdateContents(int n, int info = 0);
+	iPipelineKeyDeclareMacro(iVectorFieldGlyphPipeline,GlyphBaseSize);
 
 protected:
 	
-	iVectorFieldGlyphPipeline(iVectorFieldViewSubject *s);
+	iVectorFieldGlyphPipeline(iVectorFieldViewInstance *owner);
 	virtual ~iVectorFieldGlyphPipeline();
 
-	virtual void ProduceOutput();
-	virtual float GetContentsMemorySize() const;
-	virtual void SyncWithData(const iDataSyncRequest &r);
-
-	//
-	//  Pipeline operation
-	//
-	virtual void UpdateReplicas();
-	virtual void UpdateSampleRate();
-	virtual void UpdateSize();
+	virtual void SetGlyphFilterInput(vtkDataSet *input);
+	virtual void SetGlyphFilterScale(double s);
 	
-	iVectorFieldViewSubject *mParent;
+	iVectorFieldViewInstance *mOwner;
+
 	//
 	//  VTK stuff
 	//
-	iVectorGlyphFilter *mGlyph;
-	iResampleImageDataFilter *mFilter;
-	iReplicatedPolyData *mDataReplicated;
+	iVectorGlyphFilter *mGlyphFilter;
 };
 
-#endif // IVECTORFIELDGLYPHPIPELINE1_H
+#endif // IVECTORFIELDGLYPHPIPELINE_H
 
