@@ -40,20 +40,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
-#include "igenericfiltertemplate.h"
-#include "iviewsubjectpipelinetemplate.h"
+#include "iarray.tlh"
+#include "igenericfilter.tlh"
+#include "iviewsubjectpipeline.tlh"
 
 
 using namespace iParameter;
 
 
+iPipelineKeyDefineMacro(iVectorFieldStreamLinePipeline,Pipeline);
+iPipelineKeyDefineMacro(iVectorFieldStreamLinePipeline,LineLength);
+iPipelineKeyDefineMacro(iVectorFieldStreamLinePipeline,LineDirection);
+iPipelineKeyDefineMacro(iVectorFieldStreamLinePipeline,LineQuality);
+iPipelineKeyDefineMacro(iVectorFieldStreamLinePipeline,TubeSize);
+iPipelineKeyDefineMacro(iVectorFieldStreamLinePipeline,TubeRangeFactor);
+iPipelineKeyDefineMacro(iVectorFieldStreamLinePipeline,TubeVariationFactor);
+
+
 //
-// iVectorFieldStreamLinePipeline class
+//  iVectorFieldStreamLinePipeline class
 //
-iVectorFieldStreamLinePipeline::iVectorFieldStreamLinePipeline(iVectorFieldViewSubject *s) : iViewSubjectPipeline(s,2)
+iVectorFieldStreamLinePipeline::iVectorFieldStreamLinePipeline(iVectorFieldViewInstance *owner) : iReplicatedViewSubjectPipeline(owner,2)
 {
-	mParent = s;
+	mOwner = owner;
 
 	//
 	//  Do VTK stuff
@@ -61,7 +70,6 @@ iVectorFieldStreamLinePipeline::iVectorFieldStreamLinePipeline(iVectorFieldViewS
 	mLine = this->CreateFilter<iStreamLineFilter>();
 	mTubeFilter = this->CreateFilter<iLineToTubeFilter>();
 	mBandFilter = this->CreateFilter<iLineToBandFilter>();
-	mDataReplicated = this->CreateFilter<iReplicatedPolyData>();
 	
 	mTubeFilter->SetNumberOfSides(6);
 	mTubeFilter->SetVaryRadiusToVaryRadiusByScalar();
@@ -72,7 +80,7 @@ iVectorFieldStreamLinePipeline::iVectorFieldStreamLinePipeline(iVectorFieldViewS
 	mBandFilter->SetOnRatio(2);
 	mBandFilter->PassLinesOn();
 
-	this->UpdateContents(_All);
+	this->UpdateContents();
 }
 
 
@@ -81,61 +89,32 @@ iVectorFieldStreamLinePipeline::~iVectorFieldStreamLinePipeline()
 }
 
 
-void iVectorFieldStreamLinePipeline::ProduceOutput()
+bool iVectorFieldStreamLinePipeline::PrepareInput()
 {
-	vtkDataSet *input = this->GetInput();
-	vtkPolyData *output = this->GetOutput();
-	vtkDataSet *data = vtkDataSet::SafeDownCast(this->GetInputs()[1]);
-	if(data == 0)
+	vtkDataSet *input = this->InputData(1);   // input(0) for Pipeline(1) is streamline sources for parallel execution
+	vtkDataSet *source = this->InputData(0);
+
+	if(input==0 || source==0)
 	{
-		output->Initialize();
-		return;
+		return false;
 	}
 
-	if(mLine->GetSource() != input)
+	if(mLine->SourceData() != source)
 	{
-		mLine->SetSource(input);
+		mLine->SetSourceData(source);
 	}
-	if(mLine->GetInput() != data)
+	if(mLine->InputData() != input)
 	{
-		mLine->SetInput(data);
+		mLine->SetInputData(input);
 	}
 
-	//
-	//  Update the pipeline
-	//
-	mDataReplicated->Update();
-	output->ShallowCopy(mDataReplicated->GetOutput());
-}
-
-
-float iVectorFieldStreamLinePipeline::GetContentsMemorySize() const
-{
-	float s = 0.0f;
-	s += mLine->GetMemorySize();
-	s += mTubeFilter->GetMemorySize();
-	s += mDataReplicated->GetMemorySize();
-	s += mBandFilter->GetMemorySize();
-	return s;
-}
-
-
-void iVectorFieldStreamLinePipeline::UpdateContents(int n, int)
-{
-	if(n==_All || n==_Direction) this->UpdateDirection();
-	if(n==_All || n==_Length) this->UpdateLength();
-	if(n==_All || n==_Pipeline) this->UpdatePipeline();
-	if(n==_All || n==_Quality) this->UpdateQuality();
-	if(n==_All || n==_Replicas) this->UpdateReplicas();
-	if(n==_All || n==_TubeRangeFactor) this->UpdateTubeRangeFactor();
-	if(n==_All || n==_TubeSize) this->UpdateTubeSize();
-	if(n==_All || n==_TubeVariationFactor) this->UpdateTubeVariationFactor();
+	return true;
 }
 
 
 void iVectorFieldStreamLinePipeline::UpdatePipeline()
 {
-	switch(mParent->GetMethod())
+	switch(mOwner->GetMethod())
 	{
 	case VectorField::Method::Glyph:
 		{
@@ -147,27 +126,27 @@ void iVectorFieldStreamLinePipeline::UpdatePipeline()
 	case VectorField::Method::StreamLine:
 		{
 			mLine->SetSplitLines(false);
-			mDataReplicated->SetInput(mLine->GetOutput()); 
+			this->CompletePipeline(mLine->GetOutputPort()); 
 			break;
 		}
 	case VectorField::Method::StreamTube:
 		{
 			mLine->SetSplitLines(false);
-			mTubeFilter->SetInput(mLine->GetOutput());
-			mDataReplicated->SetInput(mTubeFilter->GetOutput());
+			mTubeFilter->SetInputConnection(mLine->GetOutputPort());
+			this->CompletePipeline(mTubeFilter->GetOutputPort());
 			break;
 		}
 	case VectorField::Method::StreamBand:
 		{
 			mLine->SetSplitLines(true);
-			mBandFilter->SetInput(mLine->GetOutput());
-			mDataReplicated->SetInput(mBandFilter->GetOutput());
+			mBandFilter->SetInputConnection(mLine->GetOutputPort());
+			this->CompletePipeline(mBandFilter->GetOutputPort());
 			break;
 		}
 	default:
 		{
-#ifdef I_CHECK1
-			IERROR_REPORT_BUG;
+#ifndef I_NO_CHECK
+			IBUG_WARN("Internal check failed.");
 #endif
 		}
 	}
@@ -175,37 +154,37 @@ void iVectorFieldStreamLinePipeline::UpdatePipeline()
 }
 
 
-void iVectorFieldStreamLinePipeline::UpdateDirection()
+void iVectorFieldStreamLinePipeline::UpdateLineDirection()
 { 
-	mLine->SetDirection(mParent->GetLineDir());
+	mLine->SetDirection(mOwner->GetLineDirection());
 	this->Modified();
 }
 
 
-void iVectorFieldStreamLinePipeline::UpdateLength()
+void iVectorFieldStreamLinePipeline::UpdateLineLength()
 { 
-	mLine->SetLength(2.0*mParent->GetLineLength());
+	mLine->SetLength(2.0*mOwner->GetLineLength());
 	this->Modified();
 }
 
 
-void iVectorFieldStreamLinePipeline::UpdateQuality()
+void iVectorFieldStreamLinePipeline::UpdateLineQuality()
 { 
-	mLine->SetQuality(mParent->GetLineQuality());
+	mLine->SetQuality(mOwner->GetLineQuality());
 	this->Modified();
 }
 
 
 void iVectorFieldStreamLinePipeline::UpdateTubeSize()
 { 
-	mTubeFilter->SetRadius(0.005*mParent->GetTubeSize());
+	mTubeFilter->SetRadius(0.005*mOwner->GetTubeSize());
 	this->Modified();
 }
 
 
 void iVectorFieldStreamLinePipeline::UpdateTubeRangeFactor()
 { 
-	mTubeFilter->SetRadiusFactor(mParent->GetTubeRangeFactor());
+	mTubeFilter->SetRadiusFactor(mOwner->GetTubeRangeFactor());
 	this->Modified();
 }
 
@@ -215,23 +194,10 @@ void iVectorFieldStreamLinePipeline::UpdateTubeVariationFactor()
 	//
 	//  Do not update unless necessary
 	//
-	if(mParent->CanBeShown())
+	if(mOwner->CanBeShown())
 	{
-		mLine->SetMinimumSpeed(mParent->GetTubeVariationFactor()*this->GetLimits()->GetUpperLimit(mParent->GetDataOffset()));
+		mLine->SetMinimumSpeed(mOwner->GetTubeVariationFactor()*this->GetLimits()->GetMax(0));
 		this->Modified();
 	}
 }
 
-
-void iVectorFieldStreamLinePipeline::UpdateReplicas()
-{
-	mDataReplicated->Modified();
-	this->Modified();
-}
-
-
-void iVectorFieldStreamLinePipeline::SyncWithData(const iDataSyncRequest &)
-{
-	this->UpdateTubeVariationFactor();
-}
-
