@@ -30,69 +30,48 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IVECTORFIELDSTREAMLINEPIPELINE_H
 
 
-#include "iviewsubjectpipeline.h"
+#include "ireplicatedviewsubjectpipeline.h"
 
 
 class iLineToBandFilter;
 class iLineToTubeFilter;
-class iReplicatedPolyData;
 class iStreamLineFilter;
-class iVectorFieldViewSubject;
+class iVectorFieldViewInstance;
 
 
-class iVectorFieldStreamLinePipeline : public iViewSubjectPipeline
+class iVectorFieldStreamLinePipeline : public iReplicatedViewSubjectPipeline
 {
 
-	friend class iVectorFieldViewSubject;
+	friend class iVectorFieldViewInstance;
 
 public:
 	
-	enum
-	{
-		_Direction = iViewSubjectPipeline::__Last,
-        _Length,
-		_Pipeline,
-		_Quality,
-		_TubeRangeFactor,
-		_TubeSize,
-		_TubeVariationFactor,
-		__Last
-	};
+	vtkTypeMacro(iVectorFieldStreamLinePipeline,iReplicatedViewSubjectPipeline);
 
-	vtkTypeMacro(iVectorFieldStreamLinePipeline,iViewSubjectPipeline);
-
-	virtual void UpdateContents(int n, int info = 0);
+	iPipelineKeyDeclareMacro(iVectorFieldStreamLinePipeline,Pipeline);
+	iPipelineKeyDeclareMacro(iVectorFieldStreamLinePipeline,LineLength);
+	iPipelineKeyDeclareMacro(iVectorFieldStreamLinePipeline,LineDirection);
+	iPipelineKeyDeclareMacro(iVectorFieldStreamLinePipeline,LineQuality);
+	iPipelineKeyDeclareMacro(iVectorFieldStreamLinePipeline,TubeSize);
+	iPipelineKeyDeclareMacro(iVectorFieldStreamLinePipeline,TubeRangeFactor);
+	iPipelineKeyDeclareMacro(iVectorFieldStreamLinePipeline,TubeVariationFactor);
 
 protected:
 	
-	iVectorFieldStreamLinePipeline(iVectorFieldViewSubject *s);
+	iVectorFieldStreamLinePipeline(iVectorFieldViewInstance *owner);
 	virtual ~iVectorFieldStreamLinePipeline();
 
-	virtual void ProduceOutput();
-	virtual float GetContentsMemorySize() const;
-	virtual void SyncWithData(const iDataSyncRequest &r);
+	virtual bool PrepareInput();
 
-	//
-	//  Pipeline operation
-	//
-	virtual void UpdateDirection();
-	virtual void UpdateLength();
-	virtual void UpdatePipeline();
-	virtual void UpdateQuality();
-	virtual void UpdateReplicas();
-	virtual void UpdateTubeRangeFactor();
-	virtual void UpdateTubeSize();
-	virtual void UpdateTubeVariationFactor();
-	
-	iVectorFieldViewSubject *mParent;
+	iVectorFieldViewInstance *mOwner;
 	double mCurSpacing;
+
 	//
 	//  VTK stuff
 	//
 	iStreamLineFilter *mLine;
 	iLineToTubeFilter *mTubeFilter;
 	iLineToBandFilter *mBandFilter;
-	iReplicatedPolyData *mDataReplicated;
 };
 
 #endif // IVECTORFIELDSTREAMLINEPIPELINE_H
