@@ -29,19 +29,57 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ivectorglyphfilter.h"
 
 
+#include "ierror.h"
+
+#include <vtkFloatArray.h>
+#include <vtkCellArray.h>
+#include <vtkPointData.h>
+#include <vtkPoints.h>
+#include <vtkPolyData.h>
+
 //
 //  Templates
 //
-#include "igenericfiltertemplate.h"
+#include "igenericfilter.tlh"
 
 
-iVectorGlyphFilter::iVectorGlyphFilter(iViewSubject *vo) : iGenericFilter<vtkHedgeHog,vtkDataSet,vtkPolyData>(vo,1,true,false)
+iVectorGlyphFilter::iVectorGlyphFilter(iDataConsumer *consumer) : iGenericFilter<vtkHedgeHog,vtkDataSet,vtkPolyData>(consumer,1,true)
 {
+	mIncludeVerts = false;
+}
+
+	
+void iVectorGlyphFilter::SetIncludeVerts(bool s)
+{
+	if(mIncludeVerts != s)
+	{
+		mIncludeVerts = s;
+		this->Modified();
+	}
 }
 
 
-void iVectorGlyphFilter::ProduceOutput()
+void iVectorGlyphFilter::ProvideOutput()
 {
 	this->ExecuteParent();
+
+	if(!mIncludeVerts) return;
+
+	vtkPolyData *output = this->OutputData();
+
+	vtkPoints *pts = output->GetPoints();
+	if(pts == 0) return;
+
+	vtkCellArray *verts = vtkCellArray::New(); IERROR_CHECK_MEMORY(verts);
+	vtkIdType i, n = pts->GetNumberOfPoints()/2; // vtkHedheHog places end points of glyphs in the second half of the point array
+	vtkIdType *ptr = verts->WritePointer(n,2*n);
+	for(i=0; i<n; i++)
+	{
+		ptr[2*i+0] = 1;
+		ptr[2*i+1] = i;
+	}
+
+	output->SetVerts(verts);
+	verts->Delete();
 }
 
