@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -29,15 +29,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewmodulecomponent.h"
 
 
-#include "icontrolmodule.h"
-#include "ishell.h"
 #include "iviewmodule.h"
 
 
-iViewModuleComponent::iViewModuleComponent(iViewModule *vm) 
-{ 
-	mViewModule = vm; 
-
-	if(vm != 0) vm->GetControlModule()->GetShell()->OnInitAtom();
+iViewModuleComponent::iViewModuleComponent(iViewModule *vm) : iShellComponent((vm==0)?0:vm->GetShell()), mViewModule(vm)
+{
 }
 
