@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -30,26 +30,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IVIEWMODULECOMPONENT_H
 
 
+#include "ishellcomponent.h"
+
+
 class iViewModule;
 
 
-class iViewModuleComponent
+class iViewModuleComponent : public iShellComponent
 {
 
-	friend class iImageComposerWindow;
-
-public:
-
-	inline iViewModule* GetViewModule() const { return mViewModule; }
+	IPOINTER_AS_PART(ViewModule);
 
 protected:
 
-    iViewModuleComponent(iViewModule *vm);
-    virtual ~iViewModuleComponent(){}
-
-private:
-
-	iViewModule *mViewModule;
+	iViewModuleComponent(iViewModule *vm);
 };
 
 #endif // IVIEWMODULECOMPONENT_H
