@@ -29,7 +29,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewsubjectobserver.h"
 
 
-#include "icontrolmodule.h"
 #include "idata.h"
 #include "idatareader.h"
 #include "ierror.h"
@@ -40,18 +39,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
-iViewSubjectObserver *iViewSubjectObserver::New(iViewSubject *vo)
+iViewSubjectObserver *iViewSubjectObserver::New(iViewSubject *subject)
 {
-	IERROR_ASSERT(vo);
-	return new iViewSubjectObserver(vo);
+	IASSERT(subject);
+	return new iViewSubjectObserver(subject);
 }
 
 
-iViewSubjectObserver::iViewSubjectObserver(iViewSubject *vo)
+iViewSubjectObserver::iViewSubjectObserver(iViewSubject *subject)
 {
-	mSubject = vo;
-	mIsoSurfaceData.Var = 0;
-	mIsoSurfaceData.Level = 0.0f;
+	mSubject = subject;
 }
 
 
@@ -60,20 +57,14 @@ iViewSubjectObserver::~iViewSubjectObserver()
 }
 
 
-int iViewSubjectObserver::GetSubjectId() const
-{
-	if(mSubject != 0) return mSubject->GetSubjectId(); else return ViewSubject::Id::Undefined;
-}
-
-
 const iString& iViewSubjectObserver::GetSubjectName() const
 {
 	static const iString none("Unknown");
-	if(mSubject != 0) return mSubject->GetSubjectName(); else return none;
+	if(mSubject != 0) return mSubject->LongName(); else return none;
 }
 
 
-const iDataType& iViewSubjectObserver::GetDataType() const
+const iDataType& iViewSubjectObserver::GetSubjectDataType() const
 {
 	if(mSubject != 0) return mSubject->GetDataType(); else return iDataType::Null();
 }
