@@ -49,34 +49,40 @@ class iViewSubjectParallelPipeline : public iViewSubjectPipeline, protected iPar
 public:
 
 	vtkTypeMacro(iViewSubjectParallelPipeline,iViewSubjectPipeline);
-	static iViewSubjectParallelPipeline* New(iViewSubject *vo = 0, int numInputs = 0, int id = 0);
+	static iViewSubjectParallelPipeline* New(iViewInstance *owner = 0, int numInputs = 0, int id = 0);
 
-	virtual void UpdateContents(int n, int info = 0);
+	virtual void UpdateContents();
+	virtual void UpdateContents(const iViewSubjectPipeline::Key &key);
 
 	void Modified();
 	void Reconfigure();
 
 	inline iViewSubjectPipelineDataManager* GetDataManager() const { return mDataManager; }
 
+	virtual float GetMemorySize();
+	virtual void RemoveInternalData();
+
 protected:
 
-	iViewSubjectParallelPipeline(iViewSubject *vo, int numInputs, int id);
+	iViewSubjectParallelPipeline(iViewInstance *owner, int numInputs, int id);
 	virtual ~iViewSubjectParallelPipeline();
 
-	virtual void InitExecution();
-	virtual void ProduceOutput(); 
-	virtual float GetContentsMemorySize() const;
-	virtual int ExecuteStep(int step, iParallel::ProcessorInfo &p);
+	virtual int FillInputPortInformation(int port, vtkInformation *info);
+	virtual int FillOutputPortInformation(int port, vtkInformation *info);
 
-	virtual void RemoveInternalDataForExtraComponents(bool keepOutputs);
+	virtual void ProvideInfo();
+	virtual void ProvideOutput(); 
+	virtual void UpdateReplicas();
+
+	virtual int ExecuteStep(int step, iParallel::ProcessorInfo &p);
 
 private:
 
 	void ConfigurePipelines(vtkDataSet *input);
-	void TransferInputInformation(vtkDataSet *input);
 
 	const int mId;
 	unsigned long mConfigureTime;
+	iViewInstance *mOwner;
 	iViewSubjectPipelineDataManager *mDataManager;
 	iArray<iViewSubjectPipeline*> mWorkPipelines;
 };
