@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 //
@@ -45,7 +45,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 iViewSubjectPipelineDataDistributor::iViewSubjectPipelineDataDistributor(iViewSubjectPipelineDataManager *manager, const iString &type)
 {
-	mManager = manager; IERROR_ASSERT(mManager);
+	IASSERT(manager);
+	
+	mManager = manager;
 	mType = type;
 }
 
@@ -68,7 +70,9 @@ bool iViewSubjectPipelineDataDistributor::DistributeData(vtkDataSet *globalInput
 //
 iViewSubjectPipelineDataCollector::iViewSubjectPipelineDataCollector(iViewSubjectPipelineDataManager *manager, const iString &type)
 {
-	mManager = manager; IERROR_ASSERT(mManager);
+	IASSERT(manager);
+	
+	mManager = manager;
 	mType = type;
 }
 
@@ -95,14 +99,15 @@ bool iViewSubjectPipelineDataCollector::CollectData(iArray<vtkDataSet*> &localOu
 //
 //  iViewSubjectPipelineDataManager class
 //
-iViewSubjectPipelineDataManager* iViewSubjectPipelineDataManager::New(iViewSubject *vo)
+iViewSubjectPipelineDataManager* iViewSubjectPipelineDataManager::New(iViewInstance *owner)
 {
-	return new iViewSubjectPipelineDataManager(vo);
+	return new iViewSubjectPipelineDataManager(owner);
 }
 
 
-iViewSubjectPipelineDataManager::iViewSubjectPipelineDataManager(iViewSubject *vo) : iViewSubjectComponent(vo)
+iViewSubjectPipelineDataManager::iViewSubjectPipelineDataManager(iViewInstance *owner) : iDataHandler(owner)
 {
+	mOwner = owner;
 }
 
 
@@ -121,7 +126,7 @@ void iViewSubjectPipelineDataManager::DistributeData(vtkDataSet *globalInput, iA
 		if(mDistributors[i]->DistributeData(globalInput,localInputs)) return;
 	}
 
-	IERROR_LOW("Unable to find a helper to distribute data in parallel. IFrIT will fall back to serial execution.");
+	IBUG_WARN("Unable to find a helper to distribute data in parallel. IFrIT will fall back to serial execution.");
 
 	//
 	//  Channel all data into the master pipeline
@@ -142,7 +147,7 @@ void iViewSubjectPipelineDataManager::CollectData(iArray<vtkDataSet*> &localOutp
 		if(mCollectors[i]->CollectData(localOutputs,globalOutput)) return;
 	}
 
-	IERROR_LOW("Misconfiguration in iViewSubjectPipelineDataManager: unable to find a helper to collect the data.");
+	IBUG_WARN("Misconfiguration in iViewSubjectPipelineDataManager: unable to find a helper to collect the data.");
 
 	//
 	//  Use the master pipeline output
