@@ -31,7 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkObjectBase.h>
-#include "iviewsubjectcomponent.h"
+#include "idatahandler.h"
 
 
 #include "iarray.h"
@@ -40,6 +40,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkSetGet.h>
 
 class iViewSubjectPipelineDataManager;
+class iViewInstance;
 
 class vtkDataSet;
 
@@ -96,12 +97,12 @@ protected:
 };
 
 
-class iViewSubjectPipelineDataManager : public iViewSubjectComponent
+class iViewSubjectPipelineDataManager : public iDataHandler
 {
 
 public:
 
-	static iViewSubjectPipelineDataManager* New(iViewSubject *vo);
+	static iViewSubjectPipelineDataManager* New(iViewInstance *owner);
 	virtual void Delete(){ delete this; }
 
 	void DistributeData(vtkDataSet *globalInput, iArray<vtkDataSet*> &localInputs);
@@ -113,16 +114,23 @@ public:
 	void AddDistributor(iViewSubjectPipelineDataDistributor *distributor);
 	void AddCollector(iViewSubjectPipelineDataCollector *collector);
 
+	iViewInstance* Owner() const { return mOwner; }
+
 protected:
 
 	virtual ~iViewSubjectPipelineDataManager();
 
+	virtual float GetMemorySize(){ return 0.0; }
+	virtual void RemoveInternalData(){}
+
 private:
 
-	iViewSubjectPipelineDataManager(iViewSubject *vo);
+	iViewSubjectPipelineDataManager(iViewInstance *owner);
 
 	iArray<iViewSubjectPipelineDataDistributor*> mDistributors;
 	iArray<iViewSubjectPipelineDataCollector*> mCollectors;
+
+	iViewInstance *mOwner;
 };
 
 #endif  // IVIEWSUBJECTPIPELINEDATAMANAGER_H
