@@ -31,23 +31,26 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "idata.h"
 #include "idatalimits.h"
-#include "idatastretch.h"
 #include "imath.h"
 #include "iparallel.h"
+#include "istretch.h"
 #include "iviewmodule.h"
 #include "iviewsubject.h"
 
+#include <vtkImageData.h>
 #include <vtkPointData.h>
-#include <vtkStructuredPoints.h>
 
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
-#include "igenericfiltertemplate.h"
+#include "iarray.tlh"
+#include "igenericfilter.tlh"
 
 
-iVolumeDataConverter::iVolumeDataConverter(iViewSubject *vo) : iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>(vo,1,true,true), iParallelWorker(vo->GetViewModule()->GetParallelManager())
+using namespace iParameter;
+
+
+iVolumeDataConverter::iVolumeDataConverter(iDataConsumer *consumer) : iGenericImageDataFilter<vtkImageAlgorithm>(consumer,1,true), iParallelWorker(consumer->GetViewModule()->GetParallelManager())
 {
 	mCurVar = 0;
 }
@@ -63,14 +66,22 @@ void iVolumeDataConverter::SetCurrentVar(int n)
 }
 
 
-void iVolumeDataConverter::ProduceOutput()
+void iVolumeDataConverter::OnLimitsChanged(int var, int mode)
 {
+	if(var==mCurVar && (mode==LimitsChangeMode::Range || mode==LimitsChangeMode::Stretch))
+	{
+		this->Modified();
+	}
+}
+
+
+void iVolumeDataConverter::ProvideOutput()
+{
+	vtkImageData *input = this->InputData();
+	vtkImageData *output = this->OutputData();
 	int dims[3];
 	double pos[3];
 	
-	vtkImageData *input = this->GetInput();
-	vtkImageData *output = this->GetOutput();
-
 	output->Initialize();
 
 	wNumComp = input->GetPointData()->GetScalars()->GetNumberOfComponents();
@@ -99,20 +110,26 @@ void iVolumeDataConverter::ProduceOutput()
 	input->GetOrigin(pos);
 	output->SetOrigin(pos);
 	
-	output->SetScalarTypeToUnsignedChar();
+#ifdef IVTK_5
+	output->SetScalarType(VTK_UNSIGNED_CHAR);
 	output->SetNumberOfScalarComponents(1);
 	output->AllocateScalars();
-	
+#else
+	output->AllocateScalars(VTK_UNSIGNED_CHAR,1);
+#endif
+
 	wInPtr = (float *)input->GetPointData()->GetScalars()->GetVoidPointer(0) + mCurVar;
 	wOutPtr = (unsigned char *)output->GetScalarPointer();
 	
-	wStretch = this->GetLimits()->GetStretch(mCurVar);
-	wFoffset = iDataStretch::ApplyStretch(this->GetLimits()->GetLowerLimit(mCurVar),wStretch,false);
-	wFscale = 255.0f/(iDataStretch::ApplyStretch(this->GetLimits()->GetUpperLimit(mCurVar),wStretch,true)-wFoffset+1.0e-30f);
+	wStretch = this->GetLimits()->GetStretchId(mCurVar);
+	wFoffset = iStretch::Apply(this->GetLimits()->GetMin(mCurVar),wStretch,false);
+	wFscale = 255.0f/(iStretch::Apply(this->GetLimits()->GetMax(mCurVar),wStretch,true)-wFoffset+1.0e-30f);
 
 	if(this->ParallelExecute(0) != 0)
 	{
 		vtkErrorMacro("Parallel execution error in iVolumeDataConverter");
+		this->SetAbortExecute(1);
+		return;
 	}
 }
 
@@ -127,20 +144,15 @@ int iVolumeDataConverter::ExecuteStep(int, iParallel::ProcessorInfo &p)
 	{
 		if(l%1000 == 0)
 		{
-			if(this->IsMaster(p)) this->UpdateProgress((float)l/lEnd);
+			if(p.IsMaster()) this->UpdateProgress(double(l-lBeg)/lEnd);
 			if(this->GetAbortExecute()) break;
 		}
 
-		f = wFscale*(iDataStretch::ApplyStretch(wInPtr[l*wNumComp],wStretch,false)-wFoffset);
+		f = wFscale*(iStretch::Apply(wInPtr[l*wNumComp],wStretch,false)-wFoffset);
 		if(f < 0.0f) f = 0.0f;
 		if(f > 255.0f) f = 255.0f;
-		wOutPtr[l] = (unsigned char)round(f);
+		wOutPtr[l] = (unsigned char)iMath::Round2Int(f);
 	}
 	return 0;
 }
 
-
-float iVolumeDataConverter::GetMemorySize()
-{
-	return this->GetOutput()->GetActualMemorySize();
-}
