@@ -29,40 +29,35 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ivolumeviewsubject.h"
 
 
-#include "ibuffer.h"
 #include "iclipplane.h"
-#include "icolorbars.h"
-#include "icommoneventobservers.h"
-#include "icontrolmodule.h"
-#include "idatahelper.h"
+#include "icolorbar.h"
+#include "icoredatasubjects.h"
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "idatasubject.h"
 #include "ierror.h"
-#include "ifunctionmapping.h"
-#include "ihistogrammaker.h"
+#include "imaterial.h"
 #include "ipalette.h"
-#include "ipaletteset.h"
+#include "ipalettecollection.h"
 #include "ipiecewisefunction.h"
 #include "ireplicatedgriddata.h"
 #include "ireplicatedvolume.h"
+#include "ishell.h"
 #include "iviewmodule.h"
-#include "iviewsubjectobserver.h"
+#include "iviewobject.h"
 #include "ivolumedataconverter.h"
 #include "ivtk.h"
 
 #include <vtkToolkits.h>
 
 #include <vtkFixedPointVolumeRayCastMapper.h> 
-#ifndef IVTK_PRE56
 #include <vtkGPUVolumeRayCastMapper.h>
-#endif
-#include <vtkStructuredPoints.h>
+#include <vtkImageData.h>
+#include <vtkRenderWindow.h>
 #include <vtkVolumeProperty.h>
 #include <vtkVolumeRayCastCompositeFunction.h>
 #include <vtkVolumeRayCastMIPFunction.h>
 #include <vtkVolumeRayCastMapper.h>
-//#include <vtkVolumeShearWarpMapper.h> 
 #include <vtkVolumeTextureMapper2D.h>
 #include <vtkVolumeTextureMapper3D.h>
 
@@ -87,33 +82,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
-#include "ibuffertemplate.h"
+#include "iarray.tlh"
+#include "iproperty.tlh"
+#include "igenericfilter.tlh"
 
 
 using namespace iParameter;
 
 
-IVIEWSUBJECT_DEFINE_TYPE(iVolumeViewSubject,Volume,w);
-
-IOBJECT_DEFINE_KEY(iVolumeViewSubject,BlendMode,bm,Int,1);
-IOBJECT_DEFINE_KEY(iVolumeViewSubject,ImageDownsampleFactor,di,Float,1);
-IOBJECT_DEFINE_KEY(iVolumeViewSubject,DepthDownsampleFactor,dd,Float,1);
-IOBJECT_DEFINE_KEY(iVolumeViewSubject,InterpolationType,it,Int,1);
-IOBJECT_DEFINE_KEY(iVolumeViewSubject,Method,m,OffsetInt,1);
-IOBJECT_DEFINE_KEY(iVolumeViewSubject,MethodNames,mn,String,0);
-IOBJECT_DEFINE_KEY(iVolumeViewSubject,OpacityFunction,of,Any,1);
-IOBJECT_DEFINE_KEY(iVolumeViewSubject,Palette,p,Int,1);
-IOBJECT_DEFINE_KEY(iVolumeViewSubject,Var,v,OffsetInt,1);
-
-//
-//  Inherited keys
-//
-IVIEWSUBJECT_DEFINE_INHERITED_KEYS_COMMON(iVolumeViewSubject);
-IVIEWSUBJECT_DEFINE_INHERITED_KEYS_SHADING(iVolumeViewSubject);
-IVIEWSUBJECT_DEFINE_INHERITED_KEYS_REPLICATING(iVolumeViewSubject);
-
-
 int iVolumeViewSubject::mGPUMode = 0;  // auto
 
 
@@ -124,7 +100,7 @@ namespace iVolumeViewSubject_Private
 
 	public:
 
-		UniformGridVolumeRenderingHelper(iVolumeViewSubject *parent, const iString &name) : iVolumeRenderingHelper(parent,name,false)
+		UniformGridVolumeRenderingHelper(iVolumeViewInstance *parent, const iString &name) : iVolumeRenderingHelper(parent,name,false)
 		{
 		}
 
@@ -145,18 +121,18 @@ namespace iVolumeViewSubject_Private
 
 	public:
 
-		RayCastHelper(iVolumeViewSubject *parent, vtkImageData *input) : UniformGridVolumeRenderingHelper(parent,"Ray casting")
+		RayCastHelper(iVolumeViewInstance *parent, vtkAlgorithmOutput *port) : UniformGridVolumeRenderingHelper(parent,"Ray casting")
 		{
-			mMapper = vtkVolumeRayCastMapper::New(); IERROR_ASSERT(mMapper);
-			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
+			mMapper = vtkVolumeRayCastMapper::New(); IERROR_CHECK_MEMORY(mMapper);
+			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetRenderEventObserver());
 			mMapper->IntermixIntersectingGeometryOn();
 			mMapper->AutoAdjustSampleDistancesOn();
-			mMapper->SetInput(input);
+			mMapper->SetInputConnection(port);
 
-			mCF = vtkVolumeRayCastCompositeFunction::New(); IERROR_ASSERT(mCF);
+			mCF = vtkVolumeRayCastCompositeFunction::New(); IERROR_CHECK_MEMORY(mCF);
 			mCF->SetCompositeMethodToInterpolateFirst();
 			
-			mMF = vtkVolumeRayCastMIPFunction::New(); IERROR_ASSERT(mMF);
+			mMF = vtkVolumeRayCastMIPFunction::New(); IERROR_CHECK_MEMORY(mMF);
 			
 			mMapper->SetVolumeRayCastFunction(mCF);
 		}
@@ -168,7 +144,7 @@ namespace iVolumeViewSubject_Private
 			mMapper->Delete();
 		}
 
-		virtual vtkAbstractVolumeMapper* GetMapper()
+		virtual vtkVolumeMapper* GetMapper()
 		{
 			return mMapper;
 		}
@@ -214,11 +190,11 @@ namespace iVolumeViewSubject_Private
 
 	public:
 
-		Texture2DHelper(iVolumeViewSubject *parent, vtkImageData *input) : UniformGridVolumeRenderingHelper(parent,"2D textures")
+		Texture2DHelper(iVolumeViewInstance *parent, vtkAlgorithmOutput *port) : UniformGridVolumeRenderingHelper(parent,"2D textures")
 		{
-			mMapper = vtkVolumeTextureMapper2D::New(); IERROR_ASSERT(mMapper);
-			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
-			mMapper->SetInput(input);
+			mMapper = vtkVolumeTextureMapper2D::New(); IERROR_CHECK_MEMORY(mMapper);
+			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetRenderEventObserver());
+			mMapper->SetInputConnection(port);
 		}
 
 		~Texture2DHelper()
@@ -226,7 +202,7 @@ namespace iVolumeViewSubject_Private
 			mMapper->Delete();
 		}
 
-		virtual vtkAbstractVolumeMapper* GetMapper()
+		virtual vtkVolumeMapper* GetMapper()
 		{
 			return mMapper;
 		}
@@ -247,11 +223,11 @@ namespace iVolumeViewSubject_Private
 
 	public:
 
-		Texture3DHelper(iVolumeViewSubject *parent, vtkImageData *input) : UniformGridVolumeRenderingHelper(parent,"3D textures")
+		Texture3DHelper(iVolumeViewInstance *parent, vtkAlgorithmOutput *port) : UniformGridVolumeRenderingHelper(parent,"3D textures")
 		{
-			mMapper = vtkVolumeTextureMapper3D::New(); IERROR_ASSERT(mMapper);
-			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
-			mMapper->SetInput(input);
+			mMapper = vtkVolumeTextureMapper3D::New(); IERROR_CHECK_MEMORY(mMapper);
+			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetRenderEventObserver());
+			mMapper->SetInputConnection(port);
 		}
 
 		~Texture3DHelper()
@@ -267,14 +243,14 @@ namespace iVolumeViewSubject_Private
 
 		virtual bool IsAvailable()
 		{
-#ifdef IVTK_PRE561
+#ifdef IVTK_5_PRE8
 			return (mMapper->IsRenderSupported(mParent->GetVolume()->GetProperty()) != 0);
 #else
 			return (mMapper->IsRenderSupported(mParent->GetVolume()->GetProperty(),mParent->GetViewModule()->GetRenderer()) != 0);
 #endif
 		}
 
-		virtual vtkAbstractVolumeMapper* GetMapper()
+		virtual vtkVolumeMapper* GetMapper()
 		{
 			return mMapper;
 		}
@@ -302,13 +278,13 @@ namespace iVolumeViewSubject_Private
 
 	public:
 
-		FixedPointRayCastHelper(iVolumeViewSubject *parent, vtkImageData *input) : UniformGridVolumeRenderingHelper(parent,"Fixed point ray casting")
+		FixedPointRayCastHelper(iVolumeViewInstance *parent, vtkAlgorithmOutput *port) : UniformGridVolumeRenderingHelper(parent,"Fixed point ray casting")
 		{
-			mMapper = vtkFixedPointVolumeRayCastMapper::New(); IERROR_ASSERT(mMapper);
-			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
+			mMapper = vtkFixedPointVolumeRayCastMapper::New(); IERROR_CHECK_MEMORY(mMapper);
+			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetRenderEventObserver());
 			mMapper->IntermixIntersectingGeometryOn();
 			mMapper->AutoAdjustSampleDistancesOn();
-			mMapper->SetInput(input);
+			mMapper->SetInputConnection(port);
 			mMapper->SetBlendModeToComposite();
 		}
 
@@ -317,7 +293,7 @@ namespace iVolumeViewSubject_Private
 			mMapper->Delete();
 		}
 
-		virtual vtkAbstractVolumeMapper* GetMapper()
+		virtual vtkVolumeMapper* GetMapper()
 		{
 			return mMapper;
 		}
@@ -344,19 +320,18 @@ namespace iVolumeViewSubject_Private
 	};
 
 
-#ifndef IVTK_PRE56
 	class GPURayCastHelper  : public UniformGridVolumeRenderingHelper
 	{
 
 	public:
 
-		GPURayCastHelper(iVolumeViewSubject *parent, vtkImageData *input) : UniformGridVolumeRenderingHelper(parent,"GPU ray casting")
+		GPURayCastHelper(iVolumeViewInstance *parent, vtkAlgorithmOutput *port) : UniformGridVolumeRenderingHelper(parent,"GPU ray casting")
 		{
-			mMapper = vtkGPUVolumeRayCastMapper::New(); IERROR_ASSERT(mMapper);
-			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
+			mMapper = vtkGPUVolumeRayCastMapper::New(); IERROR_CHECK_MEMORY(mMapper);
+			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetRenderEventObserver());
 			//mMapper->IntermixIntersectingGeometryOn();
 			mMapper->AutoAdjustSampleDistancesOn();
-			mMapper->SetInput(input);
+			mMapper->SetInputConnection(port);
 			mMapper->SetBlendModeToComposite();
 		}
 
@@ -365,7 +340,12 @@ namespace iVolumeViewSubject_Private
 			mMapper->Delete();
 		}
 
-		virtual vtkAbstractVolumeMapper* GetMapper()
+		virtual void Reset()
+		{
+			mMapper->ReleaseGraphicsResources(mParent->GetViewModule()->GetRenderWindow());
+		}
+
+		virtual vtkVolumeMapper* GetMapper()
 		{
 			return mMapper;
 		}
@@ -403,7 +383,6 @@ namespace iVolumeViewSubject_Private
 
 		vtkGPUVolumeRayCastMapper *mMapper;
 	};
-#endif
 
 #ifdef VTK_USE_VOLUMEPRO
 	class VolumeProHelper : public UniformGridVolumeRenderingHelper
@@ -411,13 +390,13 @@ namespace iVolumeViewSubject_Private
 
 	public:
 
-		VolumeProHelper(iVolumeViewSubject *parent, vtkImageData *input) : UniformGridVolumeRenderingHelper(parent,"VolumePro board")
+		VolumeProHelper(iVolumeViewInstance *parent, vtkAlgorithmOutput *port) : UniformGridVolumeRenderingHelper(parent,"VolumePro board")
 		{
-			mMapper = iVolumeProHelper::New(); IERROR_ASSERT(mThisMapper);
+			mMapper = iVolumeProHelper::New(); IERROR_CHECK_MEMORY(mThisMapper);
 			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
 			mMapper->IntermixIntersectingGeometryOn();
 			mMapper->SuperSamplingOn();
-			mMapper->SetInput(input);
+			mMapper->SetInputConnection(port);
 		}
 
 		~VolumeProHelper()
@@ -431,7 +410,7 @@ namespace iVolumeViewSubject_Private
 			return (mMapper->GetNoHardware()==0 && mMapper->GetWrongVLIVersion()==0 && mMapper->GetNumberOfBoards()>0);
 		}
 
-		virtual vtkAbstractVolumeMapper* GetMapper()
+		virtual vtkVolumeMapper* GetMapper()
 		{
 			return mMapper;
 		}
@@ -462,158 +441,123 @@ using namespace iVolumeViewSubject_Private;
 
 
 //
-// iVolumeViewSubject class
+//  Single instance class
 // 
-iVolumeViewSubject::iVolumeViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iViewSubject(vm,type,name,0U)
+iVolumeViewInstance::iVolumeViewInstance(iVolumeViewSubject *owner) : iViewInstance(owner)
 {
-	mSubjectId = ViewSubject::Id::Volume;
-
 	mVar = 0;
 	mPalette = 1;
-	mMethod = 1;
-	
-	mOpacityFunction = iPiecewiseFunction::New(0.0,1.0); IERROR_ASSERT(mOpacityFunction);
+	mMethodId = 0;
 	
 	mBlendMode = 0;
 	mInterpolationType = 1; 
 
-	mImageDownsampleFactor = mDepthDownsampleFactor = 1.0;
+	mOpacityScaleFactor = mImageDownsampleFactor = mDepthDownsampleFactor = 1.0;
 	mBlendMode = 0;
 	
-	mVolume = iReplicatedVolume::New(this); IERROR_ASSERT(mVolume);
+	mOpacityFunction = iPiecewiseFunction::New(); IERROR_CHECK_MEMORY(mOpacityFunction);
+
+	mVolume = iReplicatedVolume::New(owner); IERROR_CHECK_MEMORY(mVolume);
 	mVolume->SetPosition(0.0,0.0,0.0);
 	
-	mVolume->GetProperty()->SetShade(mShading?1:0);
 	mVolume->GetProperty()->SetScalarOpacity(mOpacityFunction->GetVTKFunction());
-	mVolume->GetProperty()->SetColor(iPaletteSet::Default()->GetColorTransferFunction(1));
+	mVolume->GetProperty()->SetColor(this->GetViewModule()->GetShell()->GetPalettes()->GetColorTransferFunction(1));
 	mVolume->GetProperty()->SetInterpolationTypeToLinear();
-	this->UpdateMaterialProperties();
 	
-	mDataConverter = iVolumeDataConverter::New(this); IERROR_ASSERT(mDataConverter);
-	mDataReplicated = iReplicatedGridData::New(this); IERROR_ASSERT(mDataReplicated);
-	mHistogramMaker = this->GetViewModule()->GetReader()->GetSubject(this->GetDataType())->CreateHistogramMaker(); IERROR_ASSERT(mHistogramMaker);
-	mFunctionMappings = new iFunctionMapping(mOpacityFunction,mHistogramMaker,0); IERROR_ASSERT(mFunctionMappings);
+	mDataConverter = iVolumeDataConverter::New(this); IERROR_CHECK_MEMORY(mDataConverter);
+	mDataReplicated = iReplicatedGridData::New(this); IERROR_CHECK_MEMORY(mDataReplicated);
 	
-	mDataConverter->AddObserver(vtkCommand::ProgressEvent,this->GetViewModule()->GetAbortRenderEventObserver());
-	mDataReplicated->AddObserver(vtkCommand::ProgressEvent,this->GetViewModule()->GetAbortRenderEventObserver());
+	mDataConverter->AddObserver(vtkCommand::ProgressEvent,this->GetViewModule()->GetRenderEventObserver());
+	mDataReplicated->AddObserver(vtkCommand::ProgressEvent,this->GetViewModule()->GetRenderEventObserver());
 
-	mDataReplicated->SetInput(mDataConverter->GetOutput());
-
-	//
-	//  Add observer to keep information about this object
-	//
-	mVolume->AddObserver(vtkCommand::UserEvent,mObjectObserver);
+	mDataReplicated->SetInputConnection(mDataConverter->GetOutputPort());
 
 	mVolume->SetVisibility(0);
 	this->GetViewModule()->AddObject(mVolume);
+	this->Owner()->GetMaterial()->AddProperty(mVolume->GetProperty());
 }
 
 
-iVolumeViewSubject::~iVolumeViewSubject()
+iVolumeViewInstance::~iVolumeViewInstance()
 {
+	this->iViewInstance::Owner()->GetMaterial()->RemoveProperty(mVolume->GetProperty());
 	this->GetViewModule()->RemoveObject(mVolume);
 
 	while(mHelpers.Size() > 0) delete mHelpers.RemoveLast();
 
-	mHistogramMaker->Delete();
-	delete mFunctionMappings;
-
 	mOpacityFunction->Delete();
+
 	mDataConverter->Delete();
 	mDataReplicated->Delete();
 	mVolume->Delete();
 }
 
 
-void iVolumeViewSubject::ConfigureBody()
+void iVolumeViewInstance::ConfigureBody()
 {
 	iVolumeRenderingHelper *m;
 
 	//
 	//  Create helpers; do it here so that children can replace all mappers
 	//
-	m = new RayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
+	m = new RayCastHelper(this,mDataReplicated->GetOutputPort()); IERROR_CHECK_MEMORY(m); mHelpers.Add(m);
 
-	m = new FixedPointRayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
-//	m = new ShearWarpRayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
-	mMethod = 2;
+	m = new FixedPointRayCastHelper(this,mDataReplicated->GetOutputPort()); IERROR_CHECK_MEMORY(m); mHelpers.Add(m);
+//	m = new ShearWarpRayCastHelper(this,mDataReplicated->GetOutput()); IERROR_CHECK_MEMORY(m); mHelpers.Add(m);
 
-	m = new Texture2DHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
-	m = new Texture3DHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
+	m = new Texture2DHelper(this,mDataReplicated->GetOutputPort()); IERROR_CHECK_MEMORY(m); mHelpers.Add(m);
+	m = new Texture3DHelper(this,mDataReplicated->GetOutputPort()); IERROR_CHECK_MEMORY(m); mHelpers.Add(m);
+	mMethodId = 3;
 
-#ifndef IVTK_PRE56
-	m = new GPURayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
-#endif
+	m = new GPURayCastHelper(this,mDataReplicated->GetOutputPort()); IERROR_CHECK_MEMORY(m); mHelpers.Add(m);
 #ifdef VTK_USE_VOLUMEPRO
-	m = new VolumeProHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
+	m = new VolumeProHelper(this,mDataReplicated->GetOutputPort()); IERROR_CHECK_MEMORY(m); mHelpers.Add(m);
 #endif
 }
 
 
-void iVolumeViewSubject::FinishInitialization()
+void iVolumeViewInstance::FinishInitialization()
 {
-	this->SetMethod(mMethod);
+	this->SetMethodId(mMethodId);
 	this->SetBlendMode(mBlendMode);
-}
 
-
-void iVolumeViewSubject::Reset()
-{
-	this->SyncWithData(this->RequestAll());
-
-	//
-	//  Un-initialize, if needed
-	//
-	if(mIsInitialized)
-	{
-		this->ShowColorBars(false);
-		mVolume->SetVisibility(0);
-		mIsInitialized = false;
-	}
-}
-
-
-void iVolumeViewSubject::ShowClipPlane(bool s)
-{
 	int i;
-
-	if(s && !mClipPlaneOn)
+	for(i=0; i<mHelpers.Size(); i++)
 	{
-		for(i=0; i<mHelpers.Size(); i++) mHelpers[i]->GetMapper()->AddClippingPlane(this->GetViewModule()->GetClipPlane());
-		mClipPlaneOn = true;
+		mHelpers[i]->GetMapper()->SetClippingPlanes(this->GetViewModule()->GetClipPlane()->GetPlanes());
+	}
+}
+
+
+void iVolumeViewInstance::ResetBody()
+{
+	mVolume->SetVisibility(0);
+}
+
+
+void iVolumeViewInstance::ShowBody(bool show)
+{
+	if(show)
+	{
+		mVolume->SetVisibility(1);
 	} 
-	if(!s && mClipPlaneOn)
+	else 
 	{
-		for(i=0; i<mHelpers.Size(); i++) mHelpers[i]->GetMapper()->RemoveClippingPlane(this->GetViewModule()->GetClipPlane());
-		mClipPlaneOn = false;
-	}
-	this->ClearCache();
-}
-
-
-void iVolumeViewSubject::ShowColorBars(bool show)
-{
-	if(!this->IsVisible()) return;
-	this->GetViewModule()->GetColorBars()->ShowBar(ColorBarsPriority::Volume,mVar,this->GetDataType(),mPalette,show);
-	this->ClearCache();
-}
-
-
-void iVolumeViewSubject::SetVar(int v)
-{
-	if(v>=0 && v<this->GetLimits()->GetNumVars())
-	{
-		this->ShowColorBars(false);
-		mVar = v;
-		this->ShowColorBars(true);
-		this->UpdateVar();
-		this->SyncWithData(this->Request(mVar));
-		this->ClearCache();
+		mVolume->SetVisibility(0);
 	}
 }
 
 
-void iVolumeViewSubject::UpdateVar()
+void iVolumeViewInstance::UpdateColorBars()
+{
+	if(mColorBars.Size() == 0)
+	{
+		this->AddColorBar(ColorBarPriority::Volume,mVar,mPalette,this->GetDataType());
+	}
+}
+
+
+void iVolumeViewInstance::UpdateIndex()
 {
 	int i;
 
@@ -623,81 +567,75 @@ void iVolumeViewSubject::UpdateVar()
 	}
 
 	mDataConverter->SetCurrentVar(mVar);
-	mFunctionMappings->AttachToLimits(this->GetLimits(),mVar);
-	mHistogramMaker->SetInputComponent(mVar);
 }
 
 
-void iVolumeViewSubject::SetPalette(int p)
+bool iVolumeViewInstance::SetVar(int v)
+{
+	if(v<0 || (this->IsThereData() && v>=this->GetLimits()->GetNumVars())) return false;
+
+	if(v != mVar)
+	{
+		mVar = v;
+		if(this->IsThereData())
+		{
+			this->RemoveColorBars();
+			this->UpdateColorBars();
+			this->UpdateIndex();
+			if(this->Owner()->IsVisible()) this->Show(true);
+		}
+	}
+	return true;
+}
+
+
+bool iVolumeViewInstance::SetPalette(int p)
 { 
-	vtkColorTransferFunction *ctf = iPaletteSet::Default()->GetColorTransferFunction(p);
+	vtkColorTransferFunction *ctf = this->GetViewModule()->GetShell()->GetPalettes()->GetColorTransferFunction(p);
 
 	if(ctf != 0)
 	{
-		this->ShowColorBars(false);
+		this->RemoveColorBars();
 		mPalette = p;
-		this->ShowColorBars(true);
+		this->UpdateColorBars();
 		mVolume->GetProperty()->SetColor(ctf);
-		this->ClearCache();
+		if(mMethodId != -1) mHelpers[mMethodId]->Reset();
+		return true;
 	}
+	else return false;
 }
 
 
-void iVolumeViewSubject::UpdateMaterialProperties()
-{
-	if(mShading) mVolume->GetProperty()->SetShade(1); else mVolume->GetProperty()->SetShade(0);
-
-	mVolume->GetProperty()->SetAmbient(mAmbient);
-	mVolume->GetProperty()->SetDiffuse(mDiffuse);
-	mVolume->GetProperty()->SetSpecular(mSpecular);
-	mVolume->GetProperty()->SetSpecularPower(mSpecularPower);
-	this->ClearCache();
-}
-
-
-void iVolumeViewSubject::ShowBody(bool show)
-{
-	if(show)
-	{
-		mVolume->SetVisibility(1);
-		this->ShowColorBars(true);
-	} 
-	else 
-	{
-		this->ShowColorBars(false);
-		mVolume->SetVisibility(0);
-	}
-}
-
-
-void iVolumeViewSubject::SetMethod(int m)
+bool iVolumeViewInstance::SetMethodId(int m)
 {
 	if(m>=0 && m<mHelpers.Size())
 	{
-		if(this->IsThereData() && !mHelpers[m]->IsUsingData(this->GetData()))
+		if(this->IsThereData() && !mHelpers[m]->IsUsingData(this->GetSubject()->GetData()))
 		{
 			int i;
 			for(i=mHelpers.MaxIndex(); i>=0; i--)
 			{
-				if(mHelpers[i]->IsUsingData(this->GetData())) break;
+				if(mHelpers[i]->IsUsingData(this->GetSubject()->GetData())) break;
 			}
 			m = i;
 		}
-		mMethod = m;
-		if(mMethod != -1)
+		if(mMethodId != -1) mHelpers[mMethodId]->Reset();
+		mMethodId = m;
+		if(mMethodId != -1)
 		{
-            mVolume->SetMapper(mHelpers[mMethod]->GetMapper());
+            mVolume->SetMapper(mHelpers[mMethodId]->GetMapper());
 		}
 		else
 		{
 			this->Show(false);
 		}
-		this->ClearCache();
+		return true;
 	}
+	else return false;
 }
 
 
-void iVolumeViewSubject::SetInterpolationType(int m) 
+bool iVolumeViewInstance::SetInterpolationType(int m) 
 {
 	if(m>=0 && m<2) 
 	{
@@ -715,14 +653,26 @@ void iVolumeViewSubject::SetInterpolationType(int m)
 				break;
 			}
 		}
-		this->ClearCache();
+		return true;
 	}
+	else return false;
 }
 
 
-void iVolumeViewSubject::SetDepthDownsampleFactor(float m) 
+bool iVolumeViewInstance::SetOpacityScaleFactor(float m) 
 {
-	if(m < 1.0e-3) return;
+	if(m < 0.5) return false;
+
+	mVolume->GetProperty()->SetScalarOpacityUnitDistance(1.0/m);
+
+	mOpacityScaleFactor = m;
+	return true;
+}
+
+
+bool iVolumeViewInstance::SetDepthDownsampleFactor(float m) 
+{
+	if(m < 1.0e-3) return false;
 
 	int i;
 
@@ -732,13 +682,13 @@ void iVolumeViewSubject::SetDepthDownsampleFactor(float m)
 	}
 
 	mDepthDownsampleFactor = m;
-	this->ClearCache();
+	return true;
 }
 
 
-void iVolumeViewSubject::SetImageDownsampleFactor(float m) 
+bool iVolumeViewInstance::SetImageDownsampleFactor(float m) 
 {
-	if(m < 1.0e-3) return;
+	if(m < 1.0e-3) return false;
 
 	int i;
 
@@ -748,13 +698,13 @@ void iVolumeViewSubject::SetImageDownsampleFactor(float m)
 	}
 
 	mImageDownsampleFactor = m;
-	this->ClearCache();
+	return true;
 }
 
 
-void iVolumeViewSubject::SetBlendMode(int m) 
+bool iVolumeViewInstance::SetBlendMode(int m) 
 {
-	if(m<0 || m>1) return;
+	if(m<0 || m>1) return false;
 	
 	int i;
 
@@ -764,20 +714,14 @@ void iVolumeViewSubject::SetBlendMode(int m)
 	}
 
 	mBlendMode = m;
-	this->ClearCache();
+	return true;
 }
 
 
-bool iVolumeViewSubject::IsVisible() const
-{
-	return (mVolume->GetVisibility() == 1);
-}
-
-
-float iVolumeViewSubject::GetMemorySize() const
+float iVolumeViewInstance::GetMemorySize()
 {
 	int i;
-	float s = 0.0;
+	float s = this->iViewInstance::GetMemorySize();
 
 	for(i=0; i<mHelpers.Size(); i++)
 	{
@@ -785,53 +729,32 @@ float iVolumeViewSubject::GetMemorySize() const
 	}
 	s += mDataConverter->GetMemorySize();
 	s += mDataReplicated->GetMemorySize();
+
 	return s;
 }
-//
-//  Two functions used in saving/restoring the state and in creating new instances with
-//
-void iVolumeViewSubject::ViewSubjectPackStateBody(iString &s) const
+
+
+const iString& iVolumeViewInstance::GetMethod() const
 {
-	this->PackValue(s,KeyVar(),mVar);
-	this->PackValue(s,KeyMethod(),mMethod);
-	this->PackValue(s,KeyPalette(),mPalette);
-	this->PackValue(s,KeyBlendMode(),mBlendMode);
-	this->PackValue(s,KeyInterpolationType(),mInterpolationType);
+	return this->GetMethodName(mMethodId);
+}
 
-	this->PackValue(s,KeyImageDownsampleFactor(),mImageDownsampleFactor);
-	this->PackValue(s,KeyDepthDownsampleFactor(),mDepthDownsampleFactor);
 
-	this->PackValuePiecewiseFunction(s,KeyOpacityFunction(),mOpacityFunction);
-
-	//
-	//  Query keys
-	//
+bool iVolumeViewInstance::SetMethod(const iString& name)
+{
 	int i;
-	iBuffer<iString> sbuf;
 
-	for(i=0; i<mHelpers.Size(); i++) sbuf[i] = mHelpers[i]->GetName();
-	this->PackValue(s,KeyMethodNames(),sbuf,mHelpers.Size());
+	for(i=0; i<mHelpers.Size(); i++)
+	{
+		if(name == mHelpers[i]->GetName()) return this->SetMethodId(i);
+	}
+
+	return false;
 }
 
 
-void iVolumeViewSubject::ViewSubjectUnPackStateBody(const iString &s)
-{
-	int i; float f;
-		
-	if(this->UnPackValue(s,KeyVar(),i)) this->SetVar(i);
-	if(this->UnPackValue(s,KeyMethod(),i)) this->SetMethod(i);
-	if(this->UnPackValue(s,KeyPalette(),i)) this->SetPalette(i);
-	if(this->UnPackValue(s,KeyBlendMode(),i)) this->SetBlendMode(i);
-	if(this->UnPackValue(s,KeyInterpolationType(),i)) this->SetInterpolationType(i);
-	
-	if(this->UnPackValue(s,KeyImageDownsampleFactor(),f)) this->SetImageDownsampleFactor(f);
-	if(this->UnPackValue(s,KeyDepthDownsampleFactor(),f)) this->SetDepthDownsampleFactor(f);
 
-	this->UnPackValuePiecewiseFunction(s,KeyOpacityFunction(),mOpacityFunction); // it resets the function only if successfull
-}
-
-
-const iString& iVolumeViewSubject::GetMethodName(int i) const
+const iString& iVolumeViewInstance::GetMethodName(int i) const
 {
 	static const iString none;
 
@@ -839,47 +762,28 @@ const iString& iVolumeViewSubject::GetMethodName(int i) const
 }
 
 
-bool iVolumeViewSubject::IsMethodAvailable(int i) const
+bool iVolumeViewInstance::IsMethodAvailable(int i) const
 {
 	if(i>=0 && i<mHelpers.Size())
 	{
-		if(!this->IsThereData()) return true; else return mHelpers[i]->IsUsingData(this->GetData());
+		if(!this->IsThereData()) return true; else return mHelpers[i]->IsUsingData(this->GetSubject()->GetData());
 	}
 	else return false;
 }
 
 
-iFunctionMapping* iVolumeViewSubject::GetOpacityFunction() const
+bool iVolumeViewInstance::SyncWithDataBody()
 {
-	mCacheInvalid = true;
-	return mFunctionMappings;
-}
-
-
-bool iVolumeViewSubject::CanBeShown() const
-{
-	if(mMethod == -1) return false;
-
-	iDataHelper *h = this->CreateDataHelper(this->GetData());
-	bool ret = (h->IsThereScalarData() && mVar<this->GetLimits()->GetNumVars());
-	delete h;
-	return ret;
-}
-
-
-void iVolumeViewSubject::ViewSubjectSyncWithData(const iDataSyncRequest &)
-{
-	int i;
-
 	if(this->IsThereData())
 	{
 		//
 		//  Input is ImageData
 		//
-		vtkImageData *id = vtkImageData::SafeDownCast(this->GetData());
+		int i;
+		vtkImageData *id = vtkImageData::SafeDownCast(this->GetSubject()->GetData());
 	 	if(id != 0)
 		{
-			mDataConverter->SetInput(id);
+			mDataConverter->SetInputData(id);
 
 			double s = id->GetSpacing()[2];
 			for(i=0; i<mHelpers.Size(); i++)
@@ -893,15 +797,80 @@ void iVolumeViewSubject::ViewSubjectSyncWithData(const iDataSyncRequest &)
 		//
 		for(i=0; i<mHelpers.Size(); i++) if(mHelpers[i]->IsAttachedDirectly())
 		{
-			mHelpers[i]->GetMapper()->SetInput(this->GetData());
+			mHelpers[i]->GetMapper()->SetInputData(this->GetSubject()->GetData());
 		}
 
-		this->SetMethod(mMethod); // may need to reset the mapper.
-
-		mHistogramMaker->SetInput(this->GetData(),mVar);
+		this->SetMethodId(mMethodId); // may need to reset the mapper.
 	}
 
-    mFunctionMappings->AttachToLimits(this->GetLimits(),mVar);
+	return true;
+}
+
+
+bool iVolumeViewInstance::CanBeShown() const
+{
+	return (this->IsThereData() && mVar<this->GetLimits()->GetNumVars());
+}
+
+
+//
+//  Main class
+//
+iVolumeViewSubject::iVolumeViewSubject(iViewObject *parent, const iDataType &type) : iViewSubject(parent,parent->LongName(),parent->ShortName(),parent->GetViewModule(),type,0U,1,1),
+	iViewSubjectPropertyConstructMacro(Int,iVolumeViewInstance,Var,v),
+	iViewSubjectPropertyConstructMacro(String,iVolumeViewInstance,Method,m),
+	iViewSubjectPropertyConstructMacro(Int,iVolumeViewInstance,MethodId,mid),
+	iViewSubjectPropertyConstructMacro(Int,iVolumeViewInstance,Palette,p),
+	iViewSubjectPropertyConstructMacro(Int,iVolumeViewInstance,BlendMode,bm),
+	iViewSubjectPropertyConstructMacro(Int,iVolumeViewInstance,InterpolationType,it),
+	iViewSubjectPropertyConstructMacro(Float,iVolumeViewInstance,OpacityScaleFactor,os),
+	iViewSubjectPropertyConstructMacro(Float,iVolumeViewInstance,ImageDownsampleFactor,di),
+	iViewSubjectPropertyConstructMacro(Float,iVolumeViewInstance,DepthDownsampleFactor,dd),
+	OpacityFunction(iObject::Self(),"OpacityFunction","of"),
+	iObjectConstructPropertyMacroQ(String,iVolumeViewSubject,AllMethods,am)
+{
+	Var.AddFlag(iProperty::_FunctionsAsIndex);
+}
+
+
+iVolumeViewSubject::~iVolumeViewSubject()
+{
+}
+
+
+const iString& iVolumeViewSubject::GetMethodName(int i) const
+{
+	return iRequiredCast<iVolumeViewInstance>(INFO,mInstances[0])->GetMethodName(i);
+}
+
+
+const iString& iVolumeViewSubject::GetAllMethods() const
+{
+	if(mMethodsCache.IsEmpty())
+	{
+		int i = 0;
+		while(!this->GetMethodName(i).IsEmpty())
+		{
+			if(!mMethodsCache.IsEmpty()) mMethodsCache += ",";
+			mMethodsCache += this->GetMethodName(i);
+			i++;
+		}
+	}
+
+	return mMethodsCache;
+}
+
+
+bool iVolumeViewSubject::IsMethodAvailable(int i) const
+{
+	return iRequiredCast<iVolumeViewInstance>(INFO,mInstances[0])->IsMethodAvailable(i);
+}
+
+
+void iVolumeViewSubject::InitInstances()
+{
+	this->iViewSubject::InitInstances();
+	OpacityFunction.AttachFunction(iRequiredCast<iVolumeViewInstance>(INFO,mInstances[0])->mOpacityFunction);
 }
 
 
@@ -911,12 +880,18 @@ void iVolumeViewSubject::SetGPUMode(int m)
 }
 
 
+void iVolumeViewSubject::UpdateAutomaticShadingBody()
+{
+	this->GetMaterial()->SetShading(false);
+}
+
+
 //
 //  Helper class
 //
-iVolumeRenderingHelper::iVolumeRenderingHelper(iVolumeViewSubject *parent, const iString &name, bool attachedDirectly) : mParent(parent), mName(name), mAttachedDirectly(attachedDirectly)
+iVolumeRenderingHelper::iVolumeRenderingHelper(iVolumeViewInstance *parent, const iString &name, bool attachedDirectly) : mParent(parent), mName(name), mAttachedDirectly(attachedDirectly)
 {
-	IERROR_ASSERT(mParent);
+	IASSERT(parent);
 
 	mDataSpacing = 1.0;
 	mImageDownsampleFactor = mDepthDownsampleFactor = 1.0f;
@@ -956,4 +931,3 @@ void iVolumeRenderingHelper::SetDepthDownsampleFactor(float v)
 		this->AdjustSpacing();
 	}
 }
-
