@@ -37,16 +37,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icolor.h"
 
 
-class iFunctionMapping;
-class iHistogramMaker;
 class iPiecewiseFunction;
 class iReplicatedGridData;
 class iReplicatedVolume;
+class iViewObject;
 class iVolumeDataConverter;
 class iVolumeViewSubject;
+class iVolumeViewInstance;
 
-class vtkAbstractVolumeMapper;
 class vtkImageData;
+class vtkVolumeMapper;
 
 
 //
@@ -55,12 +55,14 @@ class vtkImageData;
 class iVolumeRenderingHelper
 {
 
-	friend class iVolumeViewSubject;
+	friend class iVolumeViewInstance;
 
 public:
 
 	virtual bool IsUsingData(vtkDataSet *ds) = 0;
-	virtual vtkAbstractVolumeMapper* GetMapper() = 0;
+	virtual vtkVolumeMapper* GetMapper() = 0;
+
+	virtual void Reset(){}
 
 	virtual void SetVar(int){}
 	virtual void SetBlendMode(int){}
@@ -76,14 +78,14 @@ public:
 	
 protected:
 	
-	iVolumeRenderingHelper(iVolumeViewSubject *parent, const iString &name, bool attachedDirectly);
+	iVolumeRenderingHelper(iVolumeViewInstance *parent, const iString &name, bool attachedDirectly);
 	virtual ~iVolumeRenderingHelper();
 
 	virtual void AdjustSpacing(){}
 
 	double mDataSpacing;
 	float mImageDownsampleFactor, mDepthDownsampleFactor;
-	iVolumeViewSubject *mParent;
+	iVolumeViewInstance *mParent;
 
 private:
 
@@ -94,80 +96,47 @@ private:
 };
 
 
-class iVolumeViewSubject : public iViewSubject
+class iVolumeViewInstance : public iViewInstance
 {
 	
-	friend class iAbstractExtension;
-	friend class iObjectFactory;
+	friend class iVolumeViewSubject;
 
 public:
 	
-	vtkTypeMacro(iVolumeViewSubject,iViewSubject);
-	static const iObjectType& Type();
+	iDataConsumerTypeMacro(iVolumeViewInstance,iViewInstance);
 		
-	IOBJECT_DECLARE_GETSET(Var,mVar,int);
-//	virtual void SetVar(int v);
-//	inline int GetVar() const { return mVar; }
-
-	IOBJECT_DECLARE_GETSET1(Method,int);
-//	virtual void SetMethod(int m);
-//	inline int GetMethod() const { return mMethod; }
-	static const iObjectKey& KeyMethodNames();
-
-	IOBJECT_DECLARE_GETSET1(Palette,int);
-//	virtual void SetPalette(int p);
-//	inline int GetPalette() const { return mPalette; }
-
-	IOBJECT_DECLARE_GETSET1(BlendMode,int);
-//	virtual void SetBlendMode(int m);
-//	inline int GetBlendMode() const { return mBlendMode; }
-
-	IOBJECT_DECLARE_GETSET1(InterpolationType,int);
-//	virtual void SetInterpolationType(bool m);
-//	inline bool GetInterpolationType() const { return mInterpolationType; }
-	
-	IOBJECT_DECLARE_GETSET1(ImageDownsampleFactor,float);
-//	virtual void SetImageDownsampleFactor(float m);
-//	inline float GetImageDownsampleFactor() const { return mImageDownsampleFactor; }
-	
-	IOBJECT_DECLARE_GETSET1(DepthDownsampleFactor,float);
-//	virtual void SetDepthDownsampleFactor(float m);
-//	inline float GetDepthDownsampleFactor() const { return mDepthDownsampleFactor; }
-	
-	IOBJECT_DECLARE_GET2(OpacityFunction,iFunctionMapping * );
-//	iFunctionMapping* GetOpacityFunction() const;
+	iObjectSlotMacro1SV(Var,int);
+	iObjectSlotMacro2S(Method,const iString&);
+	iObjectSlotMacro1SV(MethodId,int);
+	iObjectSlotMacro1SV(Palette,int);
+	iObjectSlotMacro1SV(BlendMode,int);
+	iObjectSlotMacro1SV(InterpolationType,int);
+	iObjectSlotMacro1SV(OpacityScaleFactor,float);
+	iObjectSlotMacro1SV(ImageDownsampleFactor,float);
+	iObjectSlotMacro1SV(DepthDownsampleFactor,float);
 
 	inline iReplicatedVolume* GetVolume() const { return mVolume; }
+	inline iPiecewiseFunction* GetOpacityFunction() const { return mOpacityFunction; }
 	
 	const iString& GetMethodName(int i) const;
 	bool IsMethodAvailable(int i) const;
 
-	//
-	//  Inherited members
-	//
-	IVIEWSUBJECT_DECLARE_INHERITED_KEYS;
-	IVIEWSUBJECT_DECLARE_INHERITED_MEMBERS;
-
-	static void SetGPUMode(int m);
-	static int GPUMode(){ return mGPUMode; }
-
 protected:
 	
-	iVolumeViewSubject(iViewModule *vm, const iDataType &type, const iString &name);
-	virtual ~iVolumeViewSubject();
+	iVolumeViewInstance(iVolumeViewSubject *owner);
+	virtual ~iVolumeViewInstance();
 	virtual void ConfigureBody();
-
 	virtual void FinishInitialization();
-	virtual void UpdateVar();
-
-	int mVar, mPalette, mMethod;
-	iPiecewiseFunction *mOpacityFunction;
-	iFunctionMapping *mFunctionMappings;
 	
-	int mBlendMode, mInterpolationType; 
-	float mImageDownsampleFactor, mDepthDownsampleFactor;
+	virtual float GetMemorySize();
 
-	static int mGPUMode;
+	virtual void ResetBody();
+	virtual void ShowBody(bool s);
+	virtual bool CanBeShown() const;
+
+	virtual void UpdateColorBars();
+
+	virtual void UpdateIndex();
 
 	//
 	//  VTK members
@@ -175,8 +144,49 @@ protected:
 	iReplicatedVolume *mVolume;
 	iReplicatedGridData *mDataReplicated;
 	iVolumeDataConverter *mDataConverter;
-	iHistogramMaker *mHistogramMaker;
 	iArray<iVolumeRenderingHelper*> mHelpers;
+	iPiecewiseFunction *mOpacityFunction;
+};
+
+
+class iVolumeViewSubject : public iViewSubject
+{
+	
+public:
+	
+	iViewSubjectTypeMacro(iVolumeView,iViewSubject);
+	
+	iType::vsp_int Var;
+	iType::vsp_string Method;
+	iType::vsp_int MethodId;
+	iType::vsp_int Palette;
+	iType::vsp_int BlendMode;
+	iType::vsp_int InterpolationType;
+	iType::vsp_float OpacityScaleFactor;
+	iType::vsp_float ImageDownsampleFactor;
+	iType::vsp_float DepthDownsampleFactor;
+
+	iPropertyPiecewiseFunction OpacityFunction;
+
+	iObjectPropertyMacro2Q(AllMethods,String);
+
+	const iString& GetMethodName(int i) const;
+	bool IsMethodAvailable(int i) const;
+
+	static void SetGPUMode(int m);
+	static int GPUMode(){ return mGPUMode; }
+
+protected:
+	
+	iVolumeViewSubject(iViewObject *parent, const iDataType &type);
+	virtual ~iVolumeViewSubject();
+
+	virtual void InitInstances();
+
+	virtual void UpdateAutomaticShadingBody();
+
+	static int mGPUMode;
+	mutable iString mMethodsCache;
 };
 
 #endif // IVOLUMEVIEWSUBJECT_H
