@@ -29,11 +29,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iwriter.h"
 
 
-#include "icommoneventobservers.h"
-#include "icontrolmodule.h"
 #include "ierror.h"
 #include "ipostscriptwriter.h"
 #include "ishell.h"
+#include "ishelleventobservers.h"
 #include "iviewmodule.h"
 #include "ivtk.h"
 
@@ -59,20 +58,28 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
+#include "iproperty.tlh"
 
 
 using namespace iParameter;
 
 
+//
+//  Declare static members
+//
+int iWriter::mImageIndex = 1;
+int iWriter::mMovieIndex = 1;
+iString iWriter::mImageRootName;
+iString iWriter::mMovieRootName;
+
+
 //
 //  Helper class
 //
-class iGenericMultiImageMovieWriter : public vtkObjectBase
+class iGenericMultiImageMovieWriter : public vtkObjectBase, public iViewModuleComponent
 {
 
-	IPOINTER_AS_PART(ViewModule);
-
 public:
 
 	vtkTypeMacro(iGenericMultiImageMovieWriter,vtkObjectBase);
@@ -93,7 +100,7 @@ public:
 			mImageWriters[i]->End();
 			if(mImageWriters[i]->GetError() != 0)
 			{
-				IERROR_LOW("Unable to write a movie file: different frames have varied number of images");
+				IBUG_WARN("Unable to write a movie file: different frames have varied number of images");
 				return;
 			}
 		}
@@ -102,9 +109,9 @@ public:
 
 protected:
 
-	iGenericMultiImageMovieWriter(iViewModule *vm, vtkImageWriter *writer) : mViewModule(vm)
+	iGenericMultiImageMovieWriter(iViewModule *vm, vtkImageWriter *writer) : iViewModuleComponent(vm)
 	{
-		IERROR_ASSERT(vm);
+		IASSERT(vm);
 		mStarted = false;
 		mParentWriter = writer;
 	}
@@ -139,7 +146,7 @@ namespace iWriter_Private
 			mRoot = iString(FileName);
 			if(mRoot[mRoot.Length()-1] != '-')
 			{
-				vtkDirectory *d = vtkDirectory::New(); IERROR_ASSERT(d);
+				vtkDirectory *d = vtkDirectory::New(); IERROR_CHECK_MEMORY(d);
 				if(d->Open(mRoot.ToCharPointer()) == 0)
 				{
 					if(vtkDirectory::MakeDirectory(mRoot.ToCharPointer())==0 || d->Open(mRoot.ToCharPointer())==0)
@@ -173,7 +180,7 @@ namespace iWriter_Private
 			if(mWriter->IsA("vtkTIFFWriter") != 0) suf = ".tif";
 			if(mWriter->IsA("vtkEPSWriter")  != 0) suf = ".eps";
 
-			mWriter->SetInput(this->GetInput());
+			mWriter->SetInputData(this->GetInput());
 			mWriter->SetFileName((mRoot+iString::FromNumber(mFrame,"%05d")+suf).ToCharPointer());
 			mWriter->Write();
 			mFrame++;
@@ -187,7 +194,9 @@ namespace iWriter_Private
 
 		FileSetMovieWriter(vtkImageWriter *writer)
 		{
-			mWriter = writer; IERROR_ASSERT(mWriter);
+			IASSERT(writer);
+
+			mWriter = writer; 
 			mWriter->Register(this);
 		}
 
@@ -281,10 +290,10 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 		while(2*images.Size() < mImageWriters.Size()) mImageWriters.RemoveLast()->Delete();
 		while(2*images.Size() > mImageWriters.Size())
 		{
-			vtkGenericMovieWriter *tmp = this->CreateWriter(); IERROR_ASSERT(tmp);
-			tmp->AddObserver(vtkCommand::StartEvent,this->GetViewModule()->GetProgressEventObserver());
-			tmp->AddObserver(vtkCommand::ProgressEvent,this->GetViewModule()->GetProgressEventObserver());
-			tmp->AddObserver(vtkCommand::EndEvent,this->GetViewModule()->GetProgressEventObserver());
+			vtkGenericMovieWriter *tmp = this->CreateWriter(); IERROR_CHECK_MEMORY(tmp);
+			tmp->AddObserver(vtkCommand::StartEvent,this->GetShell()->GetExecutionEventObserver());
+			tmp->AddObserver(vtkCommand::ProgressEvent,this->GetShell()->GetExecutionEventObserver());
+			tmp->AddObserver(vtkCommand::EndEvent,this->GetShell()->GetExecutionEventObserver());
 			mImageWriters.Add(tmp);
 		}
 
@@ -302,20 +311,20 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 			{
 				mImageWriters[i]->SetFileName((name+this->GetFileSuffix()).ToCharPointer());
 			}
-			mImageWriters[i]->SetInput(images[i/2].LeftEye().DataObject());
+			mImageWriters[i]->SetInputData(images[i/2].LeftEye().DataObject());
 			mImageWriters[i]->Start();
 			//
 			//  Right eye
 			//
 			if(images[i/2].IsStereo())
 			{
-				mImageWriters[i+1]->SetInput(images[i/2].RightEye().DataObject());
+				mImageWriters[i+1]->SetInputData(images[i/2].RightEye().DataObject());
 				mImageWriters[i+1]->SetFileName((name+"-right"+this->GetFileSuffix()).ToCharPointer());
 				mImageWriters[i+1]->Start();
 			}
 			else
 			{
-				mImageWriters[i+1]->SetInput(0);
+				mImageWriters[i+1]->SetInputData(0);
 			}
 		}
 		mStarted = false;
@@ -323,29 +332,29 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 
 	if(!mStarted && 2*images.Size()!=mImageWriters.Size())
 	{
-		IERROR_LOW("Unable to write a movie file: different frames have varied number of images.");
+		IBUG_WARN("Unable to write a movie file: different frames have varied number of images.");
 		return;
 	}
 
 	int i;
 	for(i=0; i<mImageWriters.Size(); i+=2)
 	{
-		mImageWriters[i]->SetInput(images[i/2].LeftEye().DataObject());
+		mImageWriters[i]->SetInputData(images[i/2].LeftEye().DataObject());
 		mImageWriters[i]->Write();
-		mImageWriters[i]->SetInput(0);
+		mImageWriters[i]->SetInputData(0);
 		if(mImageWriters[i]->GetError() != 0)
 		{
-			IERROR_LOW("Unable to write a movie file: VTK reported an unidentified error.");
+			IBUG_WARN("Unable to write a movie file: VTK reported an unidentified error.");
 			return;
 		}
 		if(images[i/2].IsStereo())
 		{
-			mImageWriters[i+1]->SetInput(images[i/2].RightEye().DataObject());
+			mImageWriters[i+1]->SetInputData(images[i/2].RightEye().DataObject());
 			mImageWriters[i+1]->Write();
-			mImageWriters[i+1]->SetInput(0);
+			mImageWriters[i+1]->SetInputData(0);
 			if(mImageWriters[i+1]->GetError() != 0)
 			{
-				IERROR_LOW("Unable to write a movie file: VTK reported an unidentified error.");
+				IBUG_WARN("Unable to write a movie file: VTK reported an unidentified error.");
 				return;
 			}
 		}
@@ -358,21 +367,36 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 //
 iWriter* iWriter::New(iViewModule *vm)
 {
-	IERROR_ASSERT(vm);
-	return new iWriter(vm);
+	static iString LongName("ImageWriter");
+	static iString ShortName("iw");
+
+	IASSERT(vm);
+	return new iWriter(vm,LongName,ShortName);
 }
 
 
-iWriter::iWriter(iViewModule *vm) : mViewModule(vm)
+iWriter::iWriter(iViewModule *vm, const iString &fname, const iString &sname) : iObject(vm,fname,sname), iViewModuleComponent(vm),
+	iObjectConstructPropertyMacroS(Int,iWriter,ImageFormat,f),
+	iObjectConstructPropertyMacroS(Int,iWriter,MovieOutput,mo),
+	iObjectConstructPropertyMacroS(Int,iWriter,PostScriptPaperFormat,pf),
+	iObjectConstructPropertyMacroS(Int,iWriter,PostScriptOrientation,po),
+	iObjectConstructPropertyMacroS(String,iWriter,ImageRootName,in),
+	iObjectConstructPropertyMacroS(String,iWriter,MovieRootName,mn),
+	iObjectConstructPropertyMacroA(iWriter,Write,w)
 {
+	mRenderMode = RenderMode::NoRender;
+
 	mPostScriptPaperFormat = 9;
 	mPostScriptOrientation = 0;
 
 	mImageWriter = 0;
 	mMovieWriter = 0;
 
-	mImageFormat = -1;
-	mAnimationOutput = -1;
+	this->SetImageFormat(ImageFormat::PNG);
+	this->SetMovieOutput(MovieOutput::Image);
+
+	if(mImageRootName.IsEmpty()) this->SetImageRootName("+image");
+	if(mMovieRootName.IsEmpty()) this->SetMovieRootName("+movie");
 }
 
 
@@ -383,9 +407,9 @@ iWriter::~iWriter()
 }
 
 
-void iWriter::SetImageFormat(int i)
+bool iWriter::SetImageFormat(int i)
 {
-	if(ImageFormat::IsValid(i) && i!=mImageFormat)
+	if(ImageFormat::IsValid(i))
 	{
 		mImageFormat = i;
 		if(mImageWriter != 0) mImageWriter->Delete();
@@ -393,27 +417,27 @@ void iWriter::SetImageFormat(int i)
 		{
 		case ImageFormat::JPG:
 			{
-				mImageWriter = vtkJPEGWriter::New(); IERROR_ASSERT(mImageWriter); 
+				mImageWriter = vtkJPEGWriter::New(); IERROR_CHECK_MEMORY(mImageWriter); 
 				break;
 			}
 		case ImageFormat::PNM:
 			{
-				mImageWriter = vtkPNMWriter::New(); IERROR_ASSERT(mImageWriter); 
+				mImageWriter = vtkPNMWriter::New(); IERROR_CHECK_MEMORY(mImageWriter); 
 				break;
 			}
 		case ImageFormat::BMP:
 			{
-				mImageWriter = vtkBMPWriter::New(); IERROR_ASSERT(mImageWriter); 
+				mImageWriter = vtkBMPWriter::New(); IERROR_CHECK_MEMORY(mImageWriter); 
 				break;
 			}
 		case ImageFormat::TIF:
 			{
-				mImageWriter = vtkTIFFWriter::New(); IERROR_ASSERT(mImageWriter); 
+				mImageWriter = vtkTIFFWriter::New(); IERROR_CHECK_MEMORY(mImageWriter); 
 				break;
 			}
 		case ImageFormat::EPS:
 			{
-				iPostScriptWriter *p = iPostScriptWriter::New(); IERROR_ASSERT(p);
+				iPostScriptWriter *p = iPostScriptWriter::New(); IERROR_CHECK_MEMORY(p);
 				p->SetPaperFormat(mPostScriptPaperFormat);
 				p->SetOrientation(mPostScriptOrientation);
 				mImageWriter = p;
@@ -421,51 +445,53 @@ void iWriter::SetImageFormat(int i)
 			}
 		default:
 			{
-				mImageWriter = vtkPNGWriter::New(); IERROR_ASSERT(mImageWriter); 
+				mImageWriter = vtkPNGWriter::New(); IERROR_CHECK_MEMORY(mImageWriter); 
 				break;
 			}
 		}
 
-		mImageWriter->AddObserver(vtkCommand::StartEvent,this->GetViewModule()->GetProgressEventObserver());
-		mImageWriter->AddObserver(vtkCommand::ProgressEvent,this->GetViewModule()->GetProgressEventObserver());
-		mImageWriter->AddObserver(vtkCommand::EndEvent,this->GetViewModule()->GetProgressEventObserver());
-		this->GetViewModule()->ClearCache();
+		mImageWriter->AddObserver(vtkCommand::StartEvent,this->GetShell()->GetExecutionEventObserver());
+		mImageWriter->AddObserver(vtkCommand::ProgressEvent,this->GetShell()->GetExecutionEventObserver());
+		mImageWriter->AddObserver(vtkCommand::EndEvent,this->GetShell()->GetExecutionEventObserver());
 
 		//
 		//  Reset the animation writer if needed
 		//
-		if(mAnimationOutput == AnimationOutput::Image)
+		if(mMovieOutput == MovieOutput::Image)
 		{
-			mAnimationOutput = -1;
-			this->SetAnimationOutput(AnimationOutput::Image);
+			mMovieOutput = -1;
+			this->SetMovieOutput(MovieOutput::Image);
 		}
+
+		return true;
 	}
+	else return false;
 }
 
 
-void iWriter::SetAnimationOutput(int i)
+bool iWriter::SetMovieOutput(int i)
 {
-	if(AnimationOutput::IsValid(i) && i!=mAnimationOutput)
+	if(MovieOutput::IsValid(i))
 	{
-		mAnimationOutput = i;
+		mMovieOutput = i;
 		if(mMovieWriter != 0)
 		{
 			mMovieWriter->Delete();
 			mMovieWriter = 0;
 		}
-		switch(mAnimationOutput)
+		switch(mMovieOutput)
 		{
 #ifdef IVTK_SUPPORTS_MPEG
-		case AnimationOutput::MPEG2:
+		case MovieOutput::MPEG2:
 			{
-				mMovieWriter = MultiImageMovieWriter<vtkMPEG2Writer>::New(this->GetViewModule(),"mpg"); IERROR_ASSERT(mMovieWriter);
+				mMovieWriter = MultiImageMovieWriter<vtkMPEG2Writer>::New(this->GetViewModule(),"mpg"); IERROR_CHECK_MEMORY(mMovieWriter);
 				break;
 			}
 #endif
 #ifdef IVTK_SUPPORTS_AVI
-		case AnimationOutput::AVI:
+		case MovieOutput::AVI:
 			{
-				mMovieWriter = MultiImageMovieWriter<vtkAVIWriter>::New(this->GetViewModule(),"avi"); IERROR_ASSERT(mMovieWriter);
+				mMovieWriter = MultiImageMovieWriter<vtkAVIWriter>::New(this->GetViewModule(),"avi"); IERROR_CHECK_MEMORY(mMovieWriter);
 				break;
 			}
 #endif
@@ -474,56 +500,68 @@ void iWriter::SetAnimationOutput(int i)
 				//
 				//  File-set movie writer
 				//
-				mMovieWriter = MultiImageMovieWriter<FileSetMovieWriter>::New(this->GetViewModule(),"",mImageWriter); IERROR_ASSERT(mMovieWriter);
+				mMovieWriter = MultiImageMovieWriter<FileSetMovieWriter>::New(this->GetViewModule(),"",mImageWriter); IERROR_CHECK_MEMORY(mMovieWriter);
 			}
 		}
-		this->GetViewModule()->ClearCache();
+
+		return true;
 	}
+	else return false;
 }
 
 
-void iWriter::SetPostScriptPaperFormat(int i)
+bool iWriter::SetPostScriptPaperFormat(int i)
 {
-	if(i>=0 && i!=mPostScriptPaperFormat)
+	if(i >= 0)
 	{
 		mPostScriptPaperFormat = i;
-		this->GetViewModule()->ClearCache();
 		if(mImageFormat == ImageFormat::EPS) iRequiredCast<iPostScriptWriter>(INFO,mImageWriter)->SetPaperFormat(i);
+		return true;
 	}
+	else return false;
 }
 
 
-void iWriter::SetPostScriptOrientation(int i)
+bool iWriter::SetPostScriptOrientation(int i)
 {
-	if(i>=0 && i!=mPostScriptOrientation)
+	if(i >= 0)
 	{
 		mPostScriptOrientation = i;	
-		this->GetViewModule()->ClearCache();
 		if(mImageFormat == ImageFormat::EPS) iRequiredCast<iPostScriptWriter>(INFO,mImageWriter)->SetOrientation(i);
+		return true;
 	}
+	else return false;
 }
 
 
 void iWriter::StartMovie()
 {
-	IERROR_ASSERT(mMovieWriter);
+	IASSERT(mMovieWriter);
 	mMovieWriter->Start();
 }
 
 
 void iWriter::FinishMovie()
 {
-	IERROR_ASSERT(mMovieWriter);
+	IASSERT(mMovieWriter);
 	mMovieWriter->Finish();
+	
+	mMovieIndex++;
 }
 
 
-void iWriter::WriteImageFrame(const iStereoImageArray& images, const iString &root)
+bool iWriter::CallWrite()
+{
+	return this->GetViewModule()->CallWriteImage();
+}
+
+
+void iWriter::WriteImageFrame(const iStereoImageArray& images)
 {
 	int i;
 	iString suf, name;
 
-	IERROR_ASSERT(mImageWriter);
+	IASSERT(mImageWriter);
 
 	switch(mImageFormat) 
 	{
@@ -532,7 +570,7 @@ void iWriter::WriteImageFrame(const iStereoImageArray& images, const iString &ro
 	case ImageFormat::BMP: { suf = ".bmp"; break; }
 	case ImageFormat::TIF: { suf = ".tif"; break; }
 	case ImageFormat::EPS: { suf = ".eps"; break; }
-	default:			  { suf = ".png"; }
+	default:			   { suf = ".png"; }
 	}
 	
 	//
@@ -540,9 +578,9 @@ void iWriter::WriteImageFrame(const iStereoImageArray& images, const iString &ro
 	//
 	for(i=0; i<images.Size(); i++)
 	{
-		name = FrameFileName(i,images[i].GetTag(),root);
+		name = FrameFileName(i,images[i].GetTag(),this->GetImageFileName());
 
-		mImageWriter->SetInput(images[i].LeftEye().DataObject());
+		mImageWriter->SetInputData(images[i].LeftEye().DataObject());
 		if(images[i].IsStereo())
 		{
 			mImageWriter->SetFileName((name+"-left"+suf).ToCharPointer());
@@ -557,17 +595,98 @@ void iWriter::WriteImageFrame(const iStereoImageArray& images, const iString &ro
 		//
 		if(images[i].IsStereo())
 		{
-			mImageWriter->SetInput(images[i].RightEye().DataObject());
+			mImageWriter->SetInputData(images[i].RightEye().DataObject());
 			mImageWriter->SetFileName((name+"-right"+suf).ToCharPointer());
 			mImageWriter->Write();
 		}
 	}
+
+	mImageIndex++;
 }
 
 
-void iWriter::WriteMovieFrame(const iStereoImageArray& images, const iString &root)
+void iWriter::WriteMovieFrame(const iStereoImageArray& images)
 {
-	IERROR_ASSERT(mMovieWriter);
-	mMovieWriter->WriteFrame(images,root);
+	IASSERT(mMovieWriter);
+	mMovieWriter->WriteFrame(images,this->GetMovieFileName());
+}
+
+
+bool iWriter::SetImageRootName(const iString& name)
+{
+	if(!name.IsEmpty())
+	{
+		mImageIndex = 1;
+		mImageRootName = name;
+
+		if(mImageRootName[0] == '+')
+		{
+			mImageRootName = this->GetShell()->GetEnvironment(Environment::Image) + mImageRootName.Part(1);
+		}
+
+#ifdef _WIN32
+		mImageRootName.Replace("\\","/");
+#endif		
+		return true;
+	}
+	else return false;
+}
+
+
+const iString& iWriter::GetImageRootName() const
+{
+	return mImageRootName;
+}
+
+
+iString iWriter::GetImageFileName()
+{
+	return mImageRootName + "-" + iString::FromNumber(mImageIndex,"%05d");
+}
+
+
+bool iWriter::SetMovieRootName(const iString& name)
+{
+	if(!name.IsEmpty())
+	{
+		mMovieIndex = 1; 
+		mMovieRootName = name;
+
+		if(mMovieRootName[0] == '+')
+		{
+			mMovieRootName = this->GetShell()->GetEnvironment(Environment::Image) + mMovieRootName.Part(1);
+		}
+
+#ifdef _WIN32
+		mMovieRootName.Replace("\\","/");
+#endif
+		return true;
+	}
+	else return false;
+}
+
+
+const iString& iWriter::GetMovieRootName() const
+{
+	return mMovieRootName;
+}
+
+
+iString iWriter::GetMovieFileName()
+{
+	iString root = mMovieRootName;
+	
+	if(mMovieIndex > 1)
+	{
+		iString tail;
+		if(root[root.Length()-1] == '-')
+		{
+			tail = "-";
+			root = root.Part(0,root.Length()-1);
+		}
+		root += iString::FromNumber(mMovieIndex) + tail;
+	}
+
+	return root;
 }
 
