@@ -30,21 +30,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iconfigure.h"
-#include "iconsole.h"
 #include "ierror.h"
 #include "ifile.h"
 #include "iobject.h"
-#include "iobjecthelp.h"
-#include "iparticledatasubject.h"
 #include "iversion.h"
 
-#include <vtkCriticalSection.h>
 #include <vtkZLibDataCompressor.h>
 
+//
+//  Templates
+//
+#include "iarray.tlh"
+
+
+using namespace iParameter;
+
 
 #define I_CHECK_MISSING_REFERENCES
 
 
+iOrderedArray<iString> iHelpFactory::mObjectTags;
+iOrderedArray<iString> iHelpFactory::mPropertyTags;
+
+
 namespace iHelpFactory_Private
 {
 	const int _IconTag = 0;
@@ -53,7 +61,6 @@ namespace iHelpFactory_Private
 
 	void Uncompress(const char *data, unsigned int csize, iString &str, int usize)
 	{
-		static vtkCriticalSection *dataCompressorMutex = vtkCriticalSection::New();
 		static vtkZLibDataCompressor *dataCompressor = vtkZLibDataCompressor::New();
 		
 		unsigned char *destData = (unsigned char *)str.GetWritePointer(usize);
@@ -62,12 +69,8 @@ namespace iHelpFactory_Private
 			str.Clear();
 			return;
 		}
-		//
-		//  Thread-safe
-		//
-		dataCompressorMutex->Lock();
+
 		dataCompressor->Uncompress((unsigned char *)data,csize,destData,usize);
-		dataCompressorMutex->Unlock();
 		destData[usize] = 0;
 	}
 
@@ -115,7 +118,7 @@ namespace iHelpFactory_Private
 #ifdef I_DEBUG
 			if(ss && !sorted)
 			{
-				IERROR_LOW("Help data are not sorted.");
+				IBUG_WARN("Help data are not sorted.");
 			}
 #endif
 		}
@@ -162,18 +165,16 @@ namespace iHelpFactory_Private
 	void CreateChapter(iString &text, const iHelpFactory::ChapterInfo info, iHelpFactory::InfoSource source, bool nl = false)
 	{
 		int i;
-		iHelpDataBuffer *pb;
 		
 		text += "<p>&nbsp;";
 		text += iString("<p><a name=\"") + info.Tag + "\"><h2>" + info.Name + "</h2></a>\n";
 		
 		for(i=0; info.SectionTags[i]!=0; i++)
 		{
-			pb = iHelpFactory::FindData(info.SectionTags[i],source);
-			if(pb != 0)
+			const iHelpDataBuffer &b(iHelpFactory::FindData(info.SectionTags[i],source));
+			if(!b.IsNull())
 			{
-				text += pb->GetExtraTag(_BeginExtraTag) + "<a name=\"" + info.SectionTags[i] + "\"></a><p><h3>" + pb->GetTitle() + "</h3><p>\n" + pb->GetHTML(true) + pb->GetExtraTag(_EndExtraTag);
-				delete pb;
+				text += b.GetExtraTag(_BeginExtraTag) + "<a name=\"" + info.SectionTags[i] + "\"></a><p><h3>" + b.GetTitle() + "</h3><p>\n" + b.GetHTML(true) + b.GetExtraTag(_EndExtraTag);
 			}
 		}
 		//
@@ -188,35 +189,33 @@ namespace iHelpFactory_Private
 	void CreateTopicEntry(iString &text, const iHelpFactory::ChapterInfo info, iHelpFactory::InfoSource source)
 	{
 		int i;
-		iHelpDataBuffer *pb;
 		
 		text += "<p><b>" + info.Name + "</b><ul>";
 		
 		for(i=0; info.SectionTags[i]!=0; i++)
 		{
-			pb = iHelpFactory::FindData(info.SectionTags[i],source);
-			if(pb != 0)
+			const iHelpDataBuffer &b(iHelpFactory::FindData(info.SectionTags[i],source));
+			if(!b.IsNull())
 			{
-				text += pb->GetExtraTag(_BeginExtraTag) + "<li><a href=\"" + info.SectionTags[i] + "\">" + pb->GetTitle() + "</a></li>" + pb->GetExtraTag(_EndExtraTag);
-				delete pb;
+				text += b.GetExtraTag(_BeginExtraTag) + "<li><a href=\"" + info.SectionTags[i] + "\">" + b.GetTitle() + "</a></li>" + b.GetExtraTag(_EndExtraTag);
 			}
 		}
 		text += "</ul>";
 	}
 
-	void CreateCompressedHeader(const iString &outroot, iHelpData *data)
+	void CreateCompressedHeader(const iString &label, iHelpData *data)
 	{
 		//
 		//  Actually create the data
 		//
 		iString ws, wlist;
 
-		iFile f("Code/"+outroot+".h");
+		iFile f("Code/help/ihelpfactorydata"+label+".h");
 		if(!f.Open(iFile::_Write,iFile::_Text))  return;
 
 		f.WriteLine("//LICENSE A");
 		f.WriteLine("#if 0");
-		f.WriteLine("#include \"../../Work/"+outroot+".txt\"");
+		f.WriteLine("#include \"../../Work/help/helpdata"+label+".txt\"");
 		f.WriteLine("#else");
 		f.WriteLine("static iHelpData data[] = {");
 
@@ -267,7 +266,7 @@ namespace iHelpFactory_Private
 		f.WriteLine("#endif");
 		f.Close();
 
-		iConsole::Display(iConsole::_Warning,"IFrIT is creating compressed help data...\nPlease compile again and re-run.");
+		iOutput::Display(MessageType::Warning,"IFrIT is creating compressed help data...\nPlease compile again and re-run.");
 
 		exit(0);
 	}
@@ -286,7 +285,7 @@ namespace iHelpFactory_Private
 #include "ihelpfactorydataUG.h"
 		if(data!=0 && data[0].CompressedSize==0U)
 		{
-			CreateCompressedHeader("help/ihelpfactorydataUG",data);
+			CreateCompressedHeader("UG",data);
 		}
 
 		return GetData(tag,data,num,sorted);
@@ -302,7 +301,7 @@ namespace iHelpFactory_Private
 #include "ihelpfactorydataOR.h"
 		if(data!=0 && data[0].CompressedSize==0U)
 		{
-			CreateCompressedHeader("help/ihelpfactorydataOR",data);
+			CreateCompressedHeader("OR",data);
 		}
 
 		return GetData(tag,data,num,sorted);
@@ -318,65 +317,67 @@ namespace iHelpFactory_Private
 #include "ihelpfactorydataSR.h"
 		if(data!=0 && data[0].CompressedSize==0U)
 		{
-			CreateCompressedHeader("help/ihelpfactorydataSR",data);
+			CreateCompressedHeader("SR",data);
 		}
 
 		return GetData(tag,data,num,sorted);
 	}
 
-	void CreateTypeReference(const iObjectType *type, iString &text, bool hidden, bool extraType, bool inherited = true)
+	void TreeDisplayHelper(int id, const iArray<iString>& tags, iString &text)
 	{
-		iString stmp;
-		const iObjectKey *key;
-		iHelpDataBuffer *dtmp1, *dtmp2;
+		text += iHelpFactory::FormReference(tags[id],true);
 
-		iObjectKeyRegistry::InitTraversal(type,inherited);
-		while((key=iObjectKeyRegistry::GetNextKey(hidden)) != 0) if(key->GetHelp()->GetText() != "#") // if not for internal use
+		iString s, cds = tags[id].Section("+",3);
+		if(cds.IsEmpty()) return;
+
+		text += "<ul>";
+		int i, j, n = cds.Contains(',');
+		iOrderedArray<iString> arr;
+		for(i=0; i<=n; i++)
 		{
-			dtmp1 = iHelpFactory::FindData(key->GetHelp()->GetTag(),iHelpFactory::_All,false);
-			stmp = dtmp1->GetHTML(true);
-			if(stmp[0] == '&')
+			s = cds.Section(",",i,i);
+			for(j=0; j<tags.Size(); j++)
 			{
-				//
-				//  Reference
-				//
-				dtmp2 = iHelpFactory::FindData(stmp.ToCharPointer(2),iHelpFactory::_All,true);
 #ifdef I_DEBUG
-				if(dtmp2->GetTitle().IsEmpty())
-				{
-					IERROR_LOW("Referenced item is missing a title.");
-				}
+				iString str = tags[j];
 #endif
-				stmp = iString("<br>See <a href=\"") + dtmp2->GetTag() + "\">" + dtmp2->GetTitle() + "</a>.";
-				delete dtmp2;
+				if(tags[j].Section("+",0,0) == s)
+				{
+					arr.AddUnique(tags[j].Section("+",1,2));  // arr will be alphabetically ordered; including the parent is to separate Data.Particles/p from Window.Particles/p
+					break;
+				}
 			}
-			else
-			{
-				stmp = "<br>" + stmp;
-			}
-
-			text += iHelpFactory::FormKeyDescription(*key,stmp,true,!extraType);
-			delete dtmp1;
 		}
+		for(i=0; i<arr.Size(); i++)
+		{
+			for(j=0; j<tags.Size(); j++)
+			{
+				if(tags[j].Section("+",1,2) == arr[i])
+				{
+					TreeDisplayHelper(j,tags,text);
+				}
+			}
+		}
+		text += "</ul>";
 	}
 
 	//
 	//  Chapter components (they are small, so are kept here
 	//
-	const char *gdTags[] = { "ug.gd.ov", "ug.gd.gs", "ug.gd.cc", 0 };
+	const char *gdTags[] = { "ug.gd.ov", "ug.gd.gs", "ug.gd.op", "ug.gd.do", 0 };
 	const iHelpFactory::ChapterInfo ugOverview("ug.gd","Overview",gdTags);
 
 	const char *cnTags[] = { "ug.cn.i", "ug.cn.ms", "ug.cn.ev", "ug.cn.cl", "ug.cn.ef", 0 };
-	const iHelpFactory::ChapterInfo ugControls("ug.cn","Controlling IFrIT",cnTags);
+	const iHelpFactory::ChapterInfo ugControls("ug.cn","Running IFrIT",cnTags);
 
-	const char *ffTags[] = { "ug.ff.i", "ug.ff.us", "ug.ff.uv", "ug.ff.ut", "ug.ff.bp", 0 };
+	const char *ffTags[] = { "ug.ff.i", "ug.ff.cs", "ug.ff.cv", "ug.ff.ct", "ug.ff.cp", 0 };
 	const iHelpFactory::ChapterInfo ugFormats("ug.ff","File Formats",ffTags);
 
-	const char *asTags[] = { "ug.as.i", "ug.as.f", 0 };
+	const char *asTags[] = { "ug.as.i", "ug.as.f", "ug.as.r", 0 };
 	const iHelpFactory::ChapterInfo ugAnimation("ug.as","Animation Support",asTags);
 
-	const char *scTags[] = { "ug.sc.i", "ug.sc.ex", "ug.sc.cc", "ug.sc.cs", "ug.sc.as", "ug.sc.av", 0 };
-	const iHelpFactory::ChapterInfo ugScripts("ug.sc","Animation and Control Scripts",scTags);
+	//const char *scTags[] = { "ug.sc.i", "ug.sc.st", "ug.sc.va", "ug.sc.ex", "ug.sc.cc", "ug.sc.cs", "ug.sc.as", 0 };
+	//const iHelpFactory::ChapterInfo ugScripts("ug.sc","Animation and Control Scripts",scTags);
 
 	const char *paTags[] = { "ug.pa.i", 0 };
 	const iHelpFactory::ChapterInfo ugPalettes("ug.pa","IFrIT Palettes",paTags);
@@ -387,14 +388,14 @@ namespace iHelpFactory_Private
 	const char *liTags[] = { "ug.li.i", "ug.li.g", "ug.li.h", 0 };
 	const iHelpFactory::ChapterInfo ugLicense("ug.li","License Agreement",liTags);
 
-	const char *clTags[] = { "sr.cl.i", 0 };
-	const iHelpFactory::ChapterInfo ugCLShell("sr.cl","Command-line Shell Reference",clTags);
+	const char *clTags[] = { "sr.cl.i", "sr.os.i", 0 };
+	const iHelpFactory::ChapterInfo ugCLShell("sr.cl","Non-GUI Shell Reference",clTags);
 
-	const char *ggTags[] = { "sr.gg.i", "sr.gg.ds", "sr.gg.da", "sr.gg.dc", "sr.gg.dd", "sr.gg.de", "sr.gg.df", "sr.gg.di", "sr.gg.dk", "sr.gg.dp", "sr.gg.dr", "sr.gg.hcw", "sr.gg.hfo", "sr.gg.hmc", "sr.gg.hme", "sr.gg.cl", 0 };
+	const char *ggTags[] = { "sr.gg.i", "sr.gg.dsw", "sr.gg.dpe", "sr.gg.dde", "sr.gg.dfe", "sr.gg.dic", "sr.gg.dpi", "sr.gg.dpc", "sr.gg.hfo", "sr.gg.hcw", "sr.gg.hme", 0 };
 	const iHelpFactory::ChapterInfo ugGGShell("sr.gg","GUI Shell Reference",ggTags);
 
-	const char *orTags[] = { "or.i.i", "or.i.r", 0 };
-	const iHelpFactory::ChapterInfo ugObjects("or.i","Overview",orTags);
+	const char *orTags[] = { "ug.gd.op", "ug.gd.oh", 0 };
+	const iHelpFactory::ChapterInfo ugObjects("or.op","Overview",orTags);
 };
 
 
@@ -403,7 +404,7 @@ using namespace iHelpFactory_Private;
 //
 //  Helper class
 //
-iHelpDataBuffer::iHelpDataBuffer(iHelpData &data, bool null) : mData(data), mNull(null)
+iHelpDataBuffer::iHelpDataBuffer(iHelpData &data) : mData(data)
 {
 	if(mData.CompressedSize == 0)
 	{
@@ -415,6 +416,11 @@ iHelpDataBuffer::iHelpDataBuffer(iHelpData &data, bool null) : mData(data), mNul
 }
 
 
+iHelpDataBuffer::iHelpDataBuffer(const iHelpDataBuffer &other) : mData(other.mData)
+{
+}
+
+
 iString iHelpDataBuffer::GetTitle() const
 {
 	return mData.Title;
@@ -444,7 +450,7 @@ iString iHelpDataBuffer::GetHTML(bool untagged) const
 	//  Default implementation uses HTML formatting, so thus return the data, but
 	//  add an anchor with the tag in front
 	//
-	if(untagged || s.IsEmpty() || s[0]=='&') return s; else return iString("<a name=\"") + mData.Tag + "\"></a>" + s;
+	if(untagged || s[0]=='*' || s[0]=='&') return s; else return iString("<a name=\"") + mData.Tag + "\"></a>" + s;
 }
 
 
@@ -476,11 +482,11 @@ const iString iHelpDataBuffer::GetExtraTag(int type) const
 		}
 	case _BeginExtraTag:
 		{
-			if(mData.Extra!=0 && mData.Extra[0]=='-' && (mData.Extra[1]=='-' || mData.Extra[1]=='[')) return iString(iHelpFactory::IsTagPrivate(mData.Extra+2)?"<private>":"") + "<extra type="+iString(mData.Extra+2)+">"; else return none;
+			if(mData.Extra!=0 && mData.Extra[0]=='-' && (mData.Extra[1]=='-' || mData.Extra[1]=='[')) return "<extra type="+iString(mData.Extra+2)+">"; else return none;
 		}
 	case _EndExtraTag:
 		{
-			if(mData.Extra!=0 && mData.Extra[0]=='-' && (mData.Extra[1]=='-' || mData.Extra[1]==']')) return "</extra>" + iString(iHelpFactory::IsTagPrivate(mData.Extra+2)?"</private>":""); else return none;
+			if(mData.Extra!=0 && mData.Extra[0]=='-' && (mData.Extra[1]=='-' || mData.Extra[1]==']')) return "</extra>"; else return none;
 		}
 	default:
 		{
@@ -493,41 +499,63 @@ const iString iHelpDataBuffer::GetExtraTag(int type) const
 //
 //  iHelpFactory implementation
 //
-iHelpDataBuffer* iHelpFactory::FindData(const char *tag, InfoSource source, bool replaceRefs, int level)
+iHelpDataBuffer iHelpFactory::FindData(const char *ref, InfoSource source, bool replaceRefs, int level)
 {
-	static iHelpData null = { 0U, 0, " ", 0, 0, "No help is available for this item." };
+	static iHelpData null = { 0U, 0, "", 0, 0, "* No help is available for this item." };
 	iHelpData *tmp = 0;
 
 	if(level > 9)
 	{
-		IERROR_LOW("References are looped.");
-		return new iHelpDataBuffer(null,true);
+		IBUG_WARN("References are looped.");
+		return iHelpDataBuffer(null);
 	}
 
 	if(tmp==0 && (source==_All || source==_UserGuide))
 	{
-		tmp = GetDataUG(tag);
+		tmp = GetDataUG(ref);
 	}
 
 	if(tmp==0 && (source==_All || source==_ShellReference))
 	{
-		tmp = GetDataSR(tag);
+		tmp = GetDataSR(ref);
 	}
 
 	if(tmp==0 && (source==_All || source==_ObjectReference))
 	{
-		tmp = GetDataOR(tag);
+		tmp = GetDataOR(ref);
+		if(tmp == 0)
+		{
+			iString s = iString(ref).Section(".",0,1) + ".*";
+			tmp = GetDataOR(s.ToCharPointer());
+			if(tmp!=0 && tmp->Buffer!=0 && tmp->Buffer[0]=='&')
+			{
+				s = iString(tmp->Buffer+1) + "." + iString(ref).Section(".",2);
+				return FindData(s.ToCharPointer(),_ObjectReference,replaceRefs,level+1);
+			}
+			else tmp = 0;
+		}
 	}
 
 	if(tmp == 0)
 	{
-#if defined(I_DEBUG) && defined (I_CHECK_MISSING_REFERENCES)
-		if(iString(tag).Contains(".-") == 0)
+		//
+		//  Special case - object hierarchy is created dynamically
+		//
+		if(strcmp(ref,"ug.gd.oh") == 0)
 		{
-			IERROR_LOW(("Missing reference:"+iString(tag)).ToCharPointer());
+			static iString tree = FormObjectTree(iHelpFactory::_AllObjects);
+			static iHelpData data = { 0U, 0, "ug.gd.oh", "Object Hierarchy", 0, tree.ToCharPointer() };
+
+			return iHelpDataBuffer(data);
+		}
+
+#if defined(I_DEBUG) && defined (I_CHECK_MISSING_REFERENCES)
+		if(iString(ref).Contains(".-") == 0)
+		{
+			IBUG_WARN("Missing reference:"+iString(ref));
 		}
 #endif
-		return new iHelpDataBuffer(null,true);
+		return iHelpDataBuffer(null);
 	}
 	else
 	{
@@ -544,18 +572,328 @@ iHelpDataBuffer* iHelpFactory::FindData(const char *tag, InfoSource source, bool
 			{
 				return FindData(tmp->Buffer+2,_All,replaceRefs,level+1);
 			}
-			return new iHelpDataBuffer(*tmp);
+			return iHelpDataBuffer(*tmp);
 		}
 	}
 }
 
 
+void iHelpFactory::RegisterObject(const iString &tag)
+{
+	mObjectTags.AddUnique(tag);
+}
+
+
+void iHelpFactory::RegisterObjectProperty(const iString &tag)
+{
+	mPropertyTags.AddUnique(tag);
+}
+
+
+const iString iHelpFactory::FormObjectTree(ObjectType type)
+{
+	int i, head;
+	iString text;
+	iArray<iString> tags;
+
+	switch(type)
+	{
+	case _DataObjects:
+		{
+			for(i=0; i<mObjectTags.Size(); i++)
+			{
+				if(mObjectTags[i].Section("+",0,0) == "d")
+				{
+					head = tags.Size();
+					tags.Add(mObjectTags[i]);
+				}
+				if(mObjectTags[i][0] == '~')
+				{
+					tags.Add(mObjectTags[i]);
+				}
+			}
+			break;
+		}
+	case _MainObjects:
+		{
+			for(i=0; i<mObjectTags.Size(); i++)
+			{
+				if(mObjectTags[i].Section("+",2,2).IsEmpty()) head = tags.Size();
+				if(mObjectTags[i][0]!='~' && mObjectTags[i][0]!='_')
+				{
+					tags.Add(mObjectTags[i]);
+				}
+			}
+			break;
+		}
+	default:
+		{
+			for(i=0; i<mObjectTags.Size(); i++)
+			{
+				tags.Add(mObjectTags[i]);
+				if(mObjectTags[i].Section("+",2,2).IsEmpty()) head = i;
+			}
+			break;
+		}
+	}
+
+	if(head < tags.Size())
+	{
+		TreeDisplayHelper(head,tags,text);
+	}
+
+	return text;
+}
+
+
+const iString iHelpFactory::FormReference(const iString &tag, bool bold)
+{
+	iString tmp, ref = "or." + tag.Section("+",0,0);
+	const iHelpDataBuffer &b = iHelpFactory::FindData(ref.ToCharPointer(),iHelpFactory::_ObjectReference,false);
+	if(!b.IsNull()) tmp += b.GetExtraTag(_BeginExtraTag);
+	tmp += "<li><a href=\"or." + tag.Section("+",0,0) + "\">" + (bold?"<b>":"") + tag.Section("+",1,1).Section("/",0,0) + (bold?"</b>":"") + "</a></li>";
+	if(!b.IsNull()) tmp += b.GetExtraTag(_EndExtraTag);
+	return tmp;
+}
+
+
+const iString iHelpFactory::FormObjectDescription(const iString &str, bool full)
+{
+	int i;
+	iString tag, ref, text;
+
+	if(str.Contains('+') > 0)
+	{
+		tag = str; // complete tag
+	}
+	else
+	{
+		//
+		//  Find our tag: binary search of the ordered array
+		//
+		int ia, ib, i;
+		ia = 0;
+		ib = mObjectTags.Size() - 1;
+		while(ib > ia+1)
+		{
+			i = (ia+ib)/2;
+			if(mObjectTags[i] < str) ia = i; else ib = i;
+		}
+
+		for(i=ia; i<=ib; i++)
+		{
+			if(mObjectTags[i].BeginsWith(str+"+"))
+			{
+				tag = mObjectTags[i];
+			}
+		}
+		if(tag.IsEmpty()) return tag; // not found
+	}
+
+	iString head = tag.Section("+",0,0) + ".";
+
+	//
+	//  Sort properties alphabetically.
+	//
+	iOrderedArray<iString> arr;
+	for(i=0; i<mPropertyTags.Size(); i++) if(mPropertyTags[i].BeginsWith(head))
+	{
+		arr.Add(mPropertyTags[i].Section("+",1,1));
+	}
+
+	ref = "or." + tag.Section("+",0,0);
+	const iHelpDataBuffer &b = FindData(ref.ToCharPointer(),_ObjectReference,true);
+
+	text = b.GetExtraTag(_BeginExtraTag);
+	text += "<p><a name=\"or." + tag.Section("+",0,0) + "\"><h3>" + tag.Section("+",1,1).Section("/",0,0);
+	text += ((tag[0]!='~') ? " object " : " data object ");
+	text += b.GetExtraTag(_IconTag) + "</h3><ul>Short form: <b>" + tag.Section("+",1,1).Section("/",1,1) + "</b><p>" + b.GetHTML() + "<p>Available properties:<p><ul>\n";
+
+	if(arr.Size() == 0) text += "(This object has no properties.)";
+
+	int j;
+	for(j=0; j<arr.Size(); j++)
+	{
+		for(i=0; i<mPropertyTags.Size(); i++) if(mPropertyTags[i].BeginsWith(head) && mPropertyTags[i].Section("+",1,1)==arr[j])
+		{
+			ref = "or." + mPropertyTags[i].Section("+",0,0);
+			const iHelpDataBuffer &b = iHelpFactory::FindData(ref.ToCharPointer(),iHelpFactory::_ObjectReference,true);
+			iString s = b.GetHTML();
+			if(s[0] == '&')
+			{
+				//
+				//  Reference
+				//
+				const iHelpDataBuffer &b = iHelpFactory::FindData(s.ToCharPointer(2),iHelpFactory::_ObjectReference,true);
+#ifdef I_DEBUG
+				if(b.GetTitle().IsEmpty())
+				{
+					IBUG_WARN("Referenced item is missing a title.");
+				}
+#endif
+				s = iString("<br>See <a href=\"") + b.GetTag() + "\">" + b.GetTitle() + "</a>.";
+			}
+			else
+			{
+				s = "<li>" + FormPropertyDescription(mPropertyTags[i],true,full) + "</li>";
+#ifdef I_DEBUG
+				if(s == "<li></li>")
+				{
+					iString tmp = FormPropertyDescription(mPropertyTags[i],true,full);
+				}
+#endif
+			}
+
+			text += s;
+			break;
+		}
+	}
+
+	text += "</ul>\n";
+
+	iString cds = tag.Section("+",3);
+	if(!cds.IsEmpty())
+	{
+		text += "<br><p>Child objects:<p><ul>\n";
+		int i, j, n = cds.Contains(',');
+		iOrderedArray<iString> arr;
+		for(i=0; i<=n; i++)
+		{
+			iString s = cds.Section(",",i,i);
+			for(j=0; j<mObjectTags.Size(); j++)
+			{
+				if(mObjectTags[j].Section("+",0,0) == s)
+				{
+					arr.AddUnique(mObjectTags[j].Section("+",1,1).Section("/",0,0)+"/"+s);
+					break;
+				}
+			}
+		}
+		for(i=0; i<arr.Size(); i++)
+		{
+			text += "<li><a href=\"or." + arr[i].Section("/",1,1) + "\"><b>" + arr[i].Section("/",0,0) + "</b></a></li>\n";
+		}
+	}
+
+	text += "</ul></ul>" + b.GetExtraTag(_EndExtraTag) + "\n";
+	return text;
+}
+
+
+const iString iHelpFactory::FormPropertyDescription(const iString &str, bool line, bool full)
+{
+	iString tag;
+	if(str.Contains('+') > 0)
+	{
+		tag = str; // complete tag
+	}
+	else
+	{
+		//
+		//  Find our tag: binary search of the ordered array
+		//
+		int ia, ib, i;
+		ia = 0;
+		ib = mPropertyTags.Size() - 1;
+		while(ib > ia+1)
+		{
+			i = (ia+ib)/2;
+			if(mPropertyTags[i] < str) ia = i; else ib = i;
+		}
+
+		for(i=ia; i<=ib; i++)
+		{
+			if(mPropertyTags[i].BeginsWith(str+"+"))
+			{
+				tag = mPropertyTags[i];
+			}
+		}
+	}
+
+	iString text, ref;
+
+	bool inherited;
+	if(tag.IsEmpty())
+	{
+		//
+		//  Inherited property
+		//
+		ref = "or." + str;
+		tag = str;
+		inherited = true;
+	}
+	else
+	{
+		ref = "or." + tag.Section("+",0,0);
+		inherited = false;
+	}
+	const iHelpDataBuffer &b(iHelpFactory::FindData(ref.ToCharPointer(),iHelpFactory::_ObjectReference,false));
+	if(b.IsNull())
+	{
+		IBUG_WARN("Missing reference "+ref);
+		return text;
+	}
+
+	text = b.GetExtraTag(_BeginExtraTag);
+
+	if(inherited || line || !full)
+	{
+		if(full)
+		{
+			text += "<a name=\"or.";
+		}
+		else
+		{
+			text += "<a href=\"or.";
+		}
+		text += tag.Section("+",0,0) + "\">";
+		text += "<b>" + tag.Section("+",1,1).Section("/",0,0) + "</b></a>";
+		if(full && !inherited)
+		{
+			text += b.GetExtraTag(_IconTag);
+			text += "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;(short form: <b>" + tag.Section("+",1,1).Section("/",1,1) + "</b>);&nbsp;&nbsp;<b><tt>" + tag.Section("+",2,2) + tag.Section("+",3) + "</tt></b>\n";
+		}
+	}
+	else
+	{
+		text += "Long name: <b>" + tag.Section("+",1,1).Section("/",0,0) + "</b><br>";
+		text += "Short name: <b>" + tag.Section("+",1,1).Section("/",1,1) + "</b><br>";
+		text += "Type: <b>" + tag.Section("+",2,2) + tag.Section("+",3) + "</b><p>";
+	}
+	
+	if(full)
+	{
+		iString s = b.GetHTML();
+		if(s[0] == '&')
+		{
+			//
+			//  Reference
+			//
+			const iHelpDataBuffer &b = iHelpFactory::FindData(s.ToCharPointer(2),iHelpFactory::_ObjectReference,true);
+#ifdef I_DEBUG
+			if(b.GetTitle().IsEmpty())
+			{
+				IBUG_WARN("Referenced item is missing a title.");
+			}
+#endif
+			text += iString("<br>See <a href=\"") + b.GetTag() + "\">" + b.GetTitle() + "</a>.";
+		}
+		else
+		{
+			text += "<br>" + s;
+		}
+	}
+
+	text += b.GetExtraTag(_EndExtraTag);
+	return text;
+}
+
+
 #ifdef I_DEBUG
 void iHelpFactory::CreateUserGuide()
 {
 	static const iString afterPartTitle("<p>&nbsp;");
 	iString text, stmp;
-	iHelpDataBuffer *dtmp1;
 
 	//
 	//  Create the title page
@@ -565,14 +903,9 @@ void iHelpFactory::CreateUserGuide()
 	//
 	//  Create preface
 	//
-	dtmp1 = iHelpFactory::FindData("ug.pf");
-	if(dtmp1 != 0)
-	{
-		stmp += "<!-- NEW SHEET -->";
-		stmp += "<!-- HALF PAGE -->";
-		stmp += dtmp1->GetHTML();
-		delete dtmp1;
-	}
+	stmp += "<!-- NEW SHEET -->";
+	stmp += "<!-- HALF PAGE -->";
+	stmp += iHelpFactory::FindData("ug.pf").GetHTML();
 	stmp += "</body></html>";
 	WriteFile("Work/docs/ugTitle.html",stmp);
 
@@ -610,7 +943,7 @@ void iHelpFactory::CreateUserGuide()
 	//
 	//  Create chapter on script syntax
 	//
-	CreateChapter(text,ugScripts,_UserGuide);
+	//CreateChapter(text,ugScripts,_UserGuide);
 
 	//
 	//  Create part on shell reference
@@ -618,133 +951,61 @@ void iHelpFactory::CreateUserGuide()
 	text += "<center><a name=\"sr\"><h1>Shell Reference</h1></a></center>\n";
 	text += afterPartTitle;
 
-	//
-	//  Command-line shell
-	//
-	CreateChapter(text,ugCLShell,_ShellReference);
-
 	//
 	//  GUI shell
 	//
 	CreateChapter(text,ugGGShell,_ShellReference);
 
+	//
+	//  Command-line shell
+	//
+	CreateChapter(text,ugCLShell,_ShellReference);
+
 	//
 	//  Create object reference
 	//
-	const iObjectType *type;
-	
-	text += "<center><a name=\"ug\"><h1>Object Reference</h1></a></center>\n";
+	text += "<center><a name=\"or\"><h1>Object Reference</h1></a></center>\n";
 	text += afterPartTitle;
 
 	//
 	//  Intro
 	//
-	CreateChapter(text,ugObjects,_ObjectReference,false);
-	
-	text += "<h2>Available objects</h2>\n";
+	CreateChapter(text,ugObjects,_UserGuide,false);
 
-	text += "<p><a name=\"or.mod\"><b>Modules</b></a>:<ul>\n";
-	iObjectTypeRegistry::InitTraversal(iObjectType::_Module);
-	while((type=iObjectTypeRegistry::GetNextType(false)) != 0)
-	{
-		text += FormTypeReference(*type,true);
-	}
-	text += "</ul>\n";
-
-	text += "<p><a name=\"or.vis\"><b>View objects</b></a>:<ul>\n";
-	iObjectTypeRegistry::InitTraversal(iObjectType::_View);
-	while((type=iObjectTypeRegistry::GetNextType(false)) != 0)
-	{
-		text += FormTypeReference(*type,true);
-	}
-	text += "</ul>\n";
-
-	text += "<p><a name=\"or.hel\"><b>Helper objects</b></a>:<ul>\n";
-	iObjectTypeRegistry::InitTraversal(iObjectType::_Helper);
-	while((type=iObjectTypeRegistry::GetNextType(false)) != 0)
-	{
-		text += FormTypeReference(*type,true);
-	}
-	text += "</ul>\n";
-	
 	//
-	//  Data objects are special
+	//  Include all objects, sorted alphabetically, but place data objects at the end
 	//
-	text += "<p><a name=\"ordat\"><b>Data objects and data types</b></a>";
-	text += "<p>Names of data objects are derived from the corresponding names of data types by adding \"Data-\" in front. The following data objects are available:<ul>\n";
-	iObjectTypeRegistry::InitTraversal(iObjectType::_Data);
-	while((type=iObjectTypeRegistry::GetNextType(false))!=0)
+	int i;
+	iOrderedArray<iString> arr;
+	for(i=0; i<mObjectTags.Size(); i++) if(!mObjectTags[i].BeginsWith("~"))
 	{
-		if(type->GetHelp() != 0) text += type->GetHelp()->GetExtraTag(_BeginExtraTag);
-		text += "<li><b>" + type->FullName() + "</b> object (short form: <b>" + type->ShortName() + "</b>)";
-		if(type->GetHelp() != 0)
+		arr.AddUnique(mObjectTags[i].Section("+",1,1));
+	}
+	int idata = arr.Size();
+	for(i=0; i<mObjectTags.Size(); i++) if(mObjectTags[i].BeginsWith("~"))
+	{
+		arr.AddUnique("~"+mObjectTags[i].Section("+",1,1));
+	}
+
+	text += "<p><h2>Regular (Non-Data) Objects</h2><p>\n";
+
+	int j;
+	for(i=0; i<arr.Size(); i++)
+	{
+		if(i == idata)
 		{
-			text += type->GetHelp()->GetExtraTag(_IconTag) + "<br>" + type->GetHelp()->GetHTML();
-		}
-		text += "</li>";
-		if(type->GetHelp() != 0) text += type->GetHelp()->GetExtraTag(_EndExtraTag);
-	}
-	text += "</ul>\n";
-	text += "All Data objects have the same set of <a href=\"or.d-a\">propeties</a>\n";
-	
-	text += "<p><hr><p>\n";
-
-	//
-	//  Include all objects except data objects.
-	//
-	bool extraType;
-	iObjectTypeRegistry::InitTraversal();
-	while((type=iObjectTypeRegistry::GetNextType(false)) != 0) if(type->Class() != iObjectType::_Data)
-	{
-		extraType = !type->GetHelp()->GetExtraTag(_BeginExtraTag).IsEmpty();
-		text += type->GetHelp()->GetExtraTag(_BeginExtraTag) + "<p>" + "<a name=\"or."+type->ShortName()+"\"><h2>" + type->FullName() + " object "  + type->GetHelp()->GetExtraTag(_IconTag) + "</h2><br>" + type->GetHelp()->GetHTML() + "<p>Short form: <b>" + type->ShortName() + "</b><p>Available properties:<p><ul>\n";
-
-		CreateTypeReference(type,text,false,extraType);
-
-		text += "</ul><p><hr>" + type->GetHelp()->GetExtraTag(_EndExtraTag) + "<p>\n";
-	}
-
-	//
-	//  Include the Data object.
-	//
-	text += "<p><a name=\"or.d-a\"><h2>Properties of Data Objects</h2></a><br>All data objects support the following common properties.<ul>\n";
-	CreateTypeReference(&iDataSubject::Type(),text,true,false);
-	text += "</ul>\n";
-
-	//
-	//  Include the ParticleData object.
-	//
-	text += "<p>All particle data objects also support additional properties:<ul>";
-	CreateTypeReference(&iParticleDataSubject::Type(),text,true,false);
-	text += "</ul>\n";
-
-	//
-	//  Include special properties of specific Data objects.
-	//
-	text += "<p>Some data objects can also have properties that are specific just for them:<ul>";
-
-	const iObjectKey *key;
-	iObjectTypeRegistry::InitTraversal();
-	while((type=iObjectTypeRegistry::GetNextType(false)) != 0) if(type->Class() == iObjectType::_Data)
-	{
-		iObjectKeyRegistry::InitTraversal(type,false);
-		bool hasKeys = false;
-		while((key=iObjectKeyRegistry::GetNextKey(false)) != 0) if(key->GetHelp()->GetText() != "#") // if not for internal use
-		{
-			hasKeys = true;
+			text += "<p><h2>Data Objects</h2><p>\n";
 		}
 
-		if(hasKeys)
+		for(j=0; j<mObjectTags.Size(); j++)
 		{
-			extraType = !type->GetHelp()->GetExtraTag(_BeginExtraTag).IsEmpty();
-			text += type->GetHelp()->GetExtraTag(_BeginExtraTag) + "<li><a name=\"or."+type->ShortName()+"\"><b>" + type->FullName() + " object "  + type->GetHelp()->GetExtraTag(_IconTag) + "</b>(short form: <b>" + type->ShortName() + "</b>)<br>" + type->GetHelp()->GetHTML() + "<br>Available properties:<ul>\n";
-
-			CreateTypeReference(type,text,false,extraType,false);
-
-			text += "</ul>" + type->GetHelp()->GetExtraTag(_EndExtraTag) + "</li><p>\n";
+			if((!mObjectTags[j].BeginsWith("~") && mObjectTags[j].Section("+",1,1)==arr[i]) || (mObjectTags[j].BeginsWith("~") && ("~"+mObjectTags[j].Section("+",1,1))==arr[i]))
+			{
+				text += FormObjectDescription(mObjectTags[j],true);
+				break;
+			}
 		}
 	}
-	text += "</ul>\n";
 
 	//
 	//  Create appendices
@@ -758,36 +1019,35 @@ void iHelpFactory::CreateUserGuide()
 	//  Verify integrity
 	//
 #if defined(I_DEBUG) && defined (I_CHECK_MISSING_REFERENCES)
-	int i = -1;
+	i = -1;
 	bool ok = true;
-	iString mr;
+	iString mr, context;
 	while((i = text.Find("<a href=\"",i+1)) > -1)
 	{
-		stmp = text.Part(i+9).Section("\"",0,0);
+		context = text.Part(i);
+		stmp = context.Part(9).Section("\"",0,0);
 		if(stmp[2] == '.')  // omit volume references
 		{
-			dtmp1 = FindData(stmp.ToCharPointer(),_All,true);
-			if(dtmp1->IsNull())
+			if(FindData(stmp.ToCharPointer(),_All,true).IsNull())
 			{
 				mr += stmp + ",";
 				ok = false;
 			}
-			delete dtmp1;
 		}
 	}
 	if(!ok)
 	{
-		IERROR_LOW(("Missing references: "+mr).ToCharPointer());
+		IBUG_WARN("Missing references: "+mr);
 	}
 #endif
 
 	//
-	//  If extra info is included, remove special <extra type=...> </extra> and <private></private> tags 
+	//  If extra info is included, remove special <extra type=...> </extra> and <pdfonly></pdfonly> tags 
 	//
 	text.RemoveFormatting("<extra type=",">");
 	text.Replace("</extra>","");
-	text.Replace("<private>","");
-	text.Replace("</private>","");
+	text.Replace("<pdfonly>","");
+	text.Replace("</pdfonly>","");
 
 	//
 	//  Create the html file
@@ -833,7 +1093,7 @@ void iHelpFactory::CreateTopicList(iString &text)
 	//
 	//  Create chapter on script syntax
 	//
-	CreateTopicEntry(text,ugScripts,_UserGuide);
+	//CreateTopicEntry(text,ugScripts,_UserGuide);
 
 	//
 	//  GUI shell
@@ -843,16 +1103,7 @@ void iHelpFactory::CreateTopicList(iString &text)
 	//
 	//  Create object reference
 	//
-	const iObjectType *type;
-	
-	text += "<p><b>Objects</b><ul>";
-
-	iObjectTypeRegistry::InitTraversal();
-	while((type=iObjectTypeRegistry::GetNextType(false)) != 0)
-	{
-		text += FormTypeReference(*type,false);
-	}
-	text += "</ul>";
+	//CreateTopicEntry(text,ugObjects,_UserGuide);
 
 	//
 	//  Create appendices
@@ -867,122 +1118,9 @@ void iHelpFactory::CreateTopicList(iString &text)
 }
 
 
-const iString iHelpFactory::FormTypeReference(const iObjectType &type, bool bold)
-{
-	iString tmp;
-	if(type.GetHelp() != 0) tmp += type.GetHelp()->GetExtraTag(_BeginExtraTag);
-	tmp += "<li><a href=\"or." + type.ShortName() + "\">" + (bold?"<b>":"") + type.FullName() + (bold?"</b>":"") + "</a></li>";
-	if(type.GetHelp() != 0) tmp += type.GetHelp()->GetExtraTag(_EndExtraTag);
-	return tmp;
-}
-
-
-const iString iHelpFactory::FormKeyReference(const iObjectKey &key, bool bold)
-{
-	iString tmp;
-	if(key.GetHelp() != 0) tmp += key.GetHelp()->GetExtraTag(_BeginExtraTag);
-	tmp += "<li><a href=\"or." + key.HelpEntryKey() + "\">" + (bold?"<b>":"") + key.UnprefixedFullName() + (bold?"</b>":"") + "</a></li>";
-	if(key.GetHelp() != 0) tmp += key.GetHelp()->GetExtraTag(_EndExtraTag);
-	return tmp;
-}
-
-
-const iString iHelpFactory::FormKeyDescription(const iObjectKey &key, const iString &body, bool line, bool full)
-{
-	iString text;
-
-	if(key.GetHelp()!=0 && full) text += key.GetHelp()->GetExtraTag(_BeginExtraTag);
-
-	if(line)
-	{
-		text += "<li><a name=\"or." + key.HelpEntryKey() + "\">";
-		if(key.GetHelp() != 0)
-		{
-			if(full) text += key.GetHelp()->GetExtraTag(_BeginExtraTag);
-			text += key.GetHelp()->GetExtraTag(_IconTag);
-		}
-		text += "<b>" + key.UnprefixedFullName() + "</b>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;(short form: <b>" + key.UnprefixedShortName() + "</b>;&nbsp;&nbsp;type: ";
-	}
-	else
-	{
-		text += "<h4>Property:</h4><br><table>";
-		text += "<tr><td><b>Complete long name:</b></td><td><tt>" + key.UnprefixedFullName() + "</tt></td></tr>";
-		text += "<tr><td><b>Complete short name:</b></td><td><tt>" + key.UnprefixedShortName() + "</tt></td></tr>";
-		text += "<tr><td><b>Type:</b></td><td><tt>";
-	}
-
-	switch(key.Argument())
-	{
-	case iObjectKey::_OffsetInt:
-	case iObjectKey::_Int:
-		{
-			text += "<b><tt>int</tt></b>";
-			break;
-		}
-	case iObjectKey::_Bool:
-		{
-			text += "<b><tt>bool</tt></b>";
-			break;
-		}
-	case iObjectKey::_Float:
-		{
-			text += "<b><tt>float</tt></b>";
-			break;
-		}
-	case iObjectKey::_Double:
-		{
-			text += "<b><tt>double</tt></b>";
-			break;
-		}
-	case iObjectKey::_Color:
-		{
-			text += "<b><tt>color</tt></b>";
-			break;
-		}
-	case iObjectKey::_String:
-		{
-			text += "<b><tt>string</tt></b>";
-			break;
-		}
-	case iObjectKey::_Any:
-		{
-			text += "any";
-			break;
-		}
-	}
-
-	if(line)
-	{
-		text += ";&nbsp;&nbsp;# of arguments: <b><tt>";
-		if(key.Dimension() > 0) text += iString::FromNumber(key.Dimension()); else text += "any";
-		text += "</tt></b>)\n" + body + "</li>\n";
-	}
-	else
-	{
-		text += "</tt></td></tr>";
-		text += "<tr><td><b>Dimension:</b></td><td><tt>" + (key.Dimension()>0?iString::FromNumber(key.Dimension()):"any") + "</tt></td></tr></table>";
-		text += "<p>" + body;
-	}
-
-	if(key.GetHelp()!=0 && full) text += key.GetHelp()->GetExtraTag(_EndExtraTag);
-
-	return text;
-}
-
-
 //
 //  Explicitly configued members
 //
-bool iHelpFactory::IsTagPrivate(const char *tag)
-{
-#if IEXTENSION_INCLUDED(IEXTENSION_ART)
-	static const char *hTag = "ART";
-	if(strcmp(tag,hTag) == 0) return true;
-#endif
-	return false;
-}
-
-
 void iHelpFactory::InterpretExtraElements(iString &text, const iString &tag)
 {
 	if(tag.IsEmpty() || tag=="ART")
