@@ -34,11 +34,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IHELPFACTORY_H
 
 
+#include "iarray.h"
 #include "istring.h"
 
 
-class iObjectKey;
-class iObjectType;
+class iObject;
+class iProperty;
 
 
 struct iHelpData
@@ -59,11 +60,13 @@ class iHelpDataBuffer
 
 public:
 
+ 	iHelpDataBuffer(const iHelpDataBuffer&);
+
 	iString GetTitle() const;
 	iString GetText(int length = 0) const;
 	iString GetHTML(bool untagged = false) const;
 
-	inline bool IsNull() const { return mNull; }
+	inline bool IsNull() const { return mData.Tag[0] == 0; }
 
 	//
 	//  Extra controls
@@ -76,17 +79,15 @@ protected:
 	//
 	//  Cannot be created except by the factory or children
 	//
-	iHelpDataBuffer(iHelpData &data, bool null = false);
-
+	iHelpDataBuffer(iHelpData &data);
+ 
 	void TranformDataToString(iString &s) const;
 
 	iHelpData &mData;
-	const bool mNull;
 
 private:
 
  	iHelpDataBuffer();  // Not implemented.
-  	iHelpDataBuffer(const iHelpDataBuffer&);  // Not implemented.
 	void operator=(const iHelpDataBuffer&);  // Not implemented.
 };
 
@@ -108,6 +109,13 @@ public:
 		_All
 	};
 
+	enum ObjectType
+	{
+		_AllObjects,
+		_DataObjects,
+		_MainObjects
+	};
+
 	struct ChapterInfo
 	{
 		iString Name;
@@ -125,21 +133,27 @@ public:
 	//
 	//  Find data by tag
 	//
-	static iHelpDataBuffer* FindData(const char *tag, InfoSource source = _All, bool replaceRefs = false, int level = 0);
-
-	//
-	//  Convient helpers for forming key and type references
-	//
-	static const iString FormTypeReference(const iObjectType &type, bool bold = false);
-	static const iString FormKeyReference(const iObjectKey &key, bool bold = false);
-	static const iString FormKeyDescription(const iObjectKey &key, const iString &body, bool line, bool withPrivate = true);
+	static iHelpDataBuffer FindData(const char *ref, InfoSource source = _All, bool replaceRefs = true, int level = 0);
 
 	//
 	//  Functions for working with private data - they are the only ones that explicitly depend on the extension configuration
 	//
-	static bool IsTagPrivate(const char *tag);
 	static void InterpretExtraElements(iString &text, const iString &tag = iString());
 	static const iString& GetIconTag(const char *extra);
+
+	static void RegisterObject(const iString &tag);
+	static void RegisterObjectProperty(const iString &tag);
+
+	static const iString FormObjectTree(ObjectType type);
+	static const iString FormReference(const iString &tag, bool bold);
+	static const iString FormObjectDescription(const iString &tag, bool full);
+	static const iString FormPropertyDescription(const iString &tag, bool line, bool full);
+
+private:
+
+
+	static iOrderedArray<iString> mObjectTags;
+	static iOrderedArray<iString> mPropertyTags;
 };
 
 
