@@ -43,7 +43,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 ibgDialogSubject::ibgDialogSubject(iggDialog *owner, const ibgWindowSubject* /*base*/, unsigned int mode, const iImage *icon, const iString &title) : ibgWindowSubject(owner?owner->GetShell():0)
 {
-	IERROR_ASSERT(owner);
+	IASSERT(owner);
+
 	mOwner = owner;
 	mMode = mode;
 }
