@@ -41,7 +41,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 ibgExtensionWindowSubject::ibgExtensionWindowSubject(iggExtensionWindow *ew) : ibgWindowSubject(ew?ew->GetShell():0)
 {
-	mExtensionWindow = ew; IERROR_ASSERT(ew);
+	IASSERT(ew);
+
+	mExtensionWindow = ew;
 	mExtensionWindow->GetMainWindow()->Register(this);
 }
 
