@@ -91,4 +91,12 @@ ibgFrameScrollSubject::ibgFrameScrollSubject(iggFrameScroll *owner, bool) : ibgW
 {
 }
 
+
+//
+//  FrameSplit class
+//
+ibgFrameSplitSubject::ibgFrameSplitSubject(iggFrameSplit *owner, bool) : ibgWidgetSubject(owner)
+{
+}
+
 #endif
