@@ -56,10 +56,6 @@ public:
 
 	virtual void AttachRenderWindow(iggRenderWindow *rw) = 0;
 
-#ifdef I_DEBUG
-	static void SetEmphasizeUnderCursor(bool s){ mEmphasizeUnderCursor = s; }
-#endif
-
 protected:
 
 	ibgMainWindowSubject(iggMainWindow *owner);
@@ -68,10 +64,9 @@ protected:
 	//
 	//  General members
 	//
-	virtual int PopupWindow(const iggFrame *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2) = 0;
-	virtual int PopupWindow(const iggRenderWindow *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2) = 0;
 	virtual void ShowToolTips(bool s) = 0;
 	virtual void SetTheme(const iString &name) = 0;
+	virtual void StartTimer() = 0;
 
 	//
 	//  Construction helpers
@@ -89,10 +84,6 @@ protected:
 	//  Helper variables
 	//
 	iggMainWindow *mMainWindow;
-
-#ifdef I_DEBUG
-	static bool mEmphasizeUnderCursor;
-#endif
 };
 
 #endif  // IBGMAINWINDOWSUBJECT_H
