@@ -40,7 +40,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 ibgMenuWindowSubject::ibgMenuWindowSubject(iggMenuWindow *owner, const iImage* /*icon*/, const iString& /*title*/) : ibgWindowSubject(owner->GetShell())
 {
-	mOwner = owner; IERROR_ASSERT(owner);
+	IASSERT(owner);
+
+	mOwner = owner;
 }
 
 
