@@ -38,9 +38,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "imath.h"
 
-class iObjectKey;
-
 class iggFrameTopParent;
+class iggMenuHelperBase;
 class iggMenuWindow;
 
 
@@ -56,9 +55,9 @@ public:
 	//
 	virtual void BeginMenu(const iString &text, bool exclusive) = 0;
 	virtual void EndMenu() = 0;
-	virtual void AddMenuItem(int id, const iString &text, const iImage *icon, const iString &accel, bool toggle, bool on, const iObjectKey *ekey = 0, bool reverse = false, const iObjectKey *vkey = 0, int val = iMath::_IntMax) = 0;
+	virtual void AddMenuItem(int id, const iString &text, const iImage *icon, const iString &accel, bool toggle, bool on, const iggMenuHelperBase *enabler = 0, const iggMenuHelperBase *checker = 0) = 0;
 	virtual void AddMenuSeparator() = 0;
-	virtual void AddToolBarButton(int id, const iString &tooltip, const iImage *icon = 0, bool toggle = false, const iObjectKey *ekey = 0, bool reverse = false, const iObjectKey *vkey = 0, int val = iMath::_IntMax) = 0;
+	virtual void AddToolBarButton(int id, const iString &tooltip, const iImage *icon, bool toggle, const iggMenuHelperBase *enabler = 0, const iggMenuHelperBase *checker = 0) = 0;
 	virtual void AddToolBarSeparator() = 0;
 	virtual void CompleteMenu() = 0;
 
