@@ -33,7 +33,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgrenderwindowsubject.h"
 
 
-#include "icontrolmodule.h"
 #include "ierror.h"
 #include "iviewmodule.h"
 
@@ -46,9 +45,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 bool ibgRenderWindowSubject::RenderOnFocus = false;
 
 
-ibgRenderWindowSubject::ibgRenderWindowSubject(iggRenderWindow *owner) : ibgWindowSubject(owner?owner->GetViewModule()->GetControlModule()->GetShell():0)
+ibgRenderWindowSubject::ibgRenderWindowSubject(iggRenderWindow *owner) : ibgWindowSubject(owner?iRequiredCast<iggShell>(INFO,owner->GetViewModule()->GetShell()):0)
 {
-	mOwner = owner; IERROR_ASSERT(owner);
+	IASSERT(owner);
+
+	mOwner = owner;
 	mInteractor = 0;
 
 	mInRender = false;
