@@ -33,6 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwindowsubject.h"
 
 
+class iggMainWindow;
 class iggRenderWindow;
 class iggRenderWindowInteractor;
 
@@ -40,6 +41,7 @@ class iggRenderWindowInteractor;
 class ibgRenderWindowSubject : public ibgWindowSubject
 {
 
+	friend class iggMainWindow;
 	friend class iggRenderWindow;
 	friend class iggRenderWindowInteractor;
 
@@ -52,10 +54,16 @@ protected:
 	ibgRenderWindowSubject(iggRenderWindow *owner);
 	virtual ~ibgRenderWindowSubject();
 
+	//
+	//  Shell-specific
+	//
+	virtual void UpdateActiveStatus(bool last) = 0;
+
 	//
 	//  RenderWindow methods
 	//
 	virtual void Initialize(bool show) = 0;
+	virtual void Finalize() = 0;
 	virtual void SwapBuffers() = 0;
 
 	virtual void SetBorder(bool) = 0;
