@@ -37,10 +37,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgelement.h"
 
 
-class iString;
+#include "istring.h"
 
 class iggShell;
 
+class ibgWindowSubject;
+
 
 class ibgShellSubject : public ibgElement
 {
@@ -49,7 +51,7 @@ class ibgShellSubject : public ibgElement
 
 protected:
 
-	ibgShellSubject(iggShell *owner, int argc, char **argv);
+	ibgShellSubject(iggShell *owner);
 	virtual ~ibgShellSubject();
 
 	//
@@ -62,13 +64,9 @@ protected:
 	virtual void Exit() = 0;
 
 	//
-	//  Shell capabilities
+	//  User notification
 	//
-	virtual bool CanRecognize8BitDisplay(bool check = false) const = 0;
-	virtual bool CanDockWindows() const = 0;
-	virtual bool CanChangeFontSize() const = 0;
-	
-	virtual bool CheckCondition(int flag) const = 0;
+	virtual int PopupWindow(ibgWindowSubject *parent, const iString &text, int type, const char *button0, const char *button1, const char *button2) const = 0;
 
 	iggShell *mOwner;
 };
