@@ -38,7 +38,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
