@@ -76,7 +76,8 @@ public:
 	//
 	virtual void SetText(const iString &text) = 0;
 	virtual void SetImage(const iImage *image, bool withMask, bool scaled) = 0;
-	virtual void AlignLeft(bool s) = 0;
+	virtual void SetAlignment(int s) = 0;
+	virtual void ShowFrame(bool s) = 0;
 
 protected:
 
