@@ -33,7 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetbuttonsubject.h"
 
 
-ibgWidgetButtonSubject::ibgWidgetButtonSubject(iggWidget *owner, int /*type*/, const iString& /*text*/, int /*slot*/) : ibgWidgetSubject(owner)
+ibgWidgetButtonSubject::ibgWidgetButtonSubject(iggWidget *owner, int type, const iString& text, int slot, int minsize) : ibgWidgetSubject(owner)
 {
 }
 
