@@ -46,7 +46,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 ibgWidgetHelper::ibgWidgetHelper(iggWidget *owner)
 {
-	mOwner = owner; IERROR_ASSERT(owner);
+	IASSERT(owner);
+
+	mOwner = owner;
 }
 
 
@@ -105,11 +107,4 @@ void ibgWidgetHelper::OnBool1Body(bool v)
 	mOwner->UpdateDependents();
 }
 
-
-void ibgWidgetHelper::OnString1Body(const iString &v)
-{
-	mOwner->OnString1Body(v);
-	mOwner->UpdateDependents();
-}
-
 #endif
