@@ -74,25 +74,18 @@ public:
 	//
 	virtual void SetBoldText(bool s) = 0;
 	virtual void SetTextColor(const iColor &color) = 0;
-	virtual void SetPointSize(int s) = 0;
 	virtual void SetLineColor(int line, const iColor &color) = 0;
+	virtual void AdjustFontSize(int s) = 0;
 	virtual void UnSetLineColor(int line) = 0;
 	virtual iColor GetLineColor(int line) const = 0;
+	virtual void SetReadOnly(bool s) = 0;
 
 	//
 	//  Selection & cursor location
 	//
 	virtual void Select(int lineFrom, int indexFrom, int lineTo, int indexTo, bool leftJustified = false, int selNum = 0) = 0;
 	virtual void GetCursorPosition(int &line, int &index) = 0;
-
-	//
-	//  Syntax highlighting
-	//
-	virtual void HighlightSyntax(bool s) = 0;
-	virtual void AddKeyword(const iString &word, int category) = 0;
-	virtual void AddCategory(const iColor &color) = 0;
-	virtual void HighlightComments(const iString &comment, const iColor &color) = 0;
-	virtual void HighlightStrings(const iColor &color) = 0;
+	virtual void SetCursorPosition(int line, int index) = 0;
 
 	//
 	//  Editing functions
