@@ -35,13 +35,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ierror.h"
 
+#include "iggshell.h"
+
 #include "ibgwindowhelper.h"
 
 
 bool ibgWindowSubject::mIsBlocked = false;
 
 
-ibgWindowSubject::ibgWindowSubject(iShell *shell) : mShell(shell)
+ibgWindowSubject::ibgWindowSubject(iggShell *shell) : mShell(shell)
 {
 	mWindowHelper = 0;
 	mIsBeingDeleted = false;
@@ -50,7 +52,7 @@ ibgWindowSubject::ibgWindowSubject(iShell *shell) : mShell(shell)
 
 ibgWindowSubject::~ibgWindowSubject()
 {
-	IERROR_ASSERT(mWindowHelper);
+	IASSERT(mWindowHelper);
 	delete mWindowHelper;
 }
 
@@ -64,35 +66,35 @@ void ibgWindowSubject::Delete()
 
 void ibgWindowSubject::SetWindowGeometry(int wg[4], bool force)
 {
-	IERROR_ASSERT(mWindowHelper);
+	IASSERT(mWindowHelper);
 	mWindowHelper->SetWindowGeometry(wg,force);
 }
 
 
 void ibgWindowSubject::GetWindowGeometry(int wg[4], bool force) const
 {
-	IERROR_ASSERT(mWindowHelper);
+	IASSERT(mWindowHelper);
 	mWindowHelper->GetWindowGeometry(wg,force);
 }
 
 
 void ibgWindowSubject::GetFrameSize(int &w, int &h) const
 {
-	IERROR_ASSERT(mWindowHelper);
+	IASSERT(mWindowHelper);
 	mWindowHelper->GetFrameSize(w,h);
 }
 
 
 void ibgWindowSubject::Show(bool s)
 {
-	IERROR_ASSERT(mWindowHelper);
+	IASSERT(mWindowHelper);
 	mWindowHelper->Show(s);
 }
 
 
 bool ibgWindowSubject::IsVisible() const
 {
-	IERROR_ASSERT(mWindowHelper);
+	IASSERT(mWindowHelper);
 	return mWindowHelper->IsVisible();
 }
 
