@@ -39,17 +39,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ipointermacro.h"
 
 class iImage;
-class iShell;
 class iString;
 
+class iggShell;
+
 class ibgWindowHelper;
 
 
 class ibgWindowSubject : public ibgElement
 {
 
-	IPOINTER_AS_PART(Shell);
-
 public:
 
 	void Delete();
@@ -66,9 +65,11 @@ public:
 
 	static void Block(bool s);
 
+	inline iggShell* GetShell() const { return mShell; }
+
 protected:
 
-	ibgWindowSubject(iShell *shell);
+	ibgWindowSubject(iggShell *shell);
 	virtual ~ibgWindowSubject();
 
 	virtual bool IsBlocked() const;
@@ -77,6 +78,8 @@ protected:
 
 private:
 
+	iggShell *mShell;
+
 	bool mIsBeingDeleted;
 	static bool mIsBlocked;
 };
