@@ -35,46 +35,53 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ishell.h"
 
 
-class iclCommandInterpreter;
-class iclInputChannel;
-
 class vtkRenderWindowInteractor;
+class vtkTimerLog;
 
 
 class iclShell : public iShell
 {
 
-	friend class iShellFactory;
+	friend class iShell;
 
 public:
 
 	vtkTypeMacro(iclShell,iShell);
 
-	virtual void Exit();
+	iObjectPropertyMacro1S(Trace,Bool);
 
-	iclInputChannel* GetInputChannel() const { return mInputChannel; }
+	//
+	//  Factory methods
+	//
+	virtual vtkRenderWindow* CreateRenderWindow(iViewModule *vm, bool stereo) const;
+	virtual vtkRenderWindowInteractor* CreateRenderWindowInteractor(iViewModule *vm) const;
+	virtual iEventObserver* CreateViewModuleEventObserver(iParameter::ViewModuleObserver::Type type, iViewModule *vm) const;
+
+	virtual bool IsInterrupted() const;
 
 protected:
 
-	iclShell(int argc, char **argv);
+	iclShell(iRunner *runner, bool threaded, const iString &type, int argc, const char **argv);
 	virtual ~iclShell();
 
-	virtual void ConstructorBody();  
-	virtual void DestructorBody();  
+	virtual void DisplayPrompt() const;
+	virtual void OnInterrupt();
 
-	virtual void Start();
-	virtual void RunBody();
-	virtual void PrepareForConstruction();
-	virtual void PrepareToLoadStateFile();
-	virtual bool LoadShellStateFromFileBody(iFile &F);
-	virtual bool SaveShellStateToFileBody(iFile &F) const;
-	virtual void DefineSpecificCommandLineOptions();
-	virtual bool AnalyseOneExtendedCommandLineOption(const struct Option &o);
+	virtual bool ConstructorBody();  
+	virtual void DestructorBody();  
+	virtual void StartBody();
+	virtual void StopBody();
+
+	virtual void OnLoadStateAtomBody(int prog);
+
+	virtual iDataReaderObserver* CreateDataReaderObserver();
+	virtual iEventObserver* CreateShellEventObserver(iParameter::ShellObserver::Type type);
+	virtual iOutputChannel* CreateOutputChannel();
 
 	int mTimerId;
-	iclCommandInterpreter *mInterpreter;
-	iclInputChannel *mInputChannel;
 	vtkRenderWindowInteractor *mDriver;
+
+	int wCount;
 };
 
 #endif  // ICLSHELL_H
