@@ -29,7 +29,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iconfigure.h"
 #if ISHELL_INCLUDED(ISHELL_GG)
 
-#include "icontrolmodule.h"
 #include "ierror.h"
 #include "ishell.h"
 #include "istring.h"
@@ -69,10 +68,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 
 
-#if ISHELL_INCLUDED(ISHELL_FX)
-#endif
-
-
 const iString iggSubjectFactory::qt = "qt";
 const iString iggSubjectFactory::fx = "fx";
 
@@ -128,15 +123,6 @@ ibgDialogSubject* iggSubjectFactory::CreateDialogSubject(iggDialog *owner, const
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT4(fx,Dialog,base,mode,icon,title);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -154,15 +140,6 @@ ibgExtensionWindowSubject* iggSubjectFactory::CreateExtensionWindowSubject(iggEx
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		return new ifxExtensionWindowSubject(owner);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -180,15 +157,6 @@ ibgFrameSubject* iggSubjectFactory::CreateFrameSubject(iggFrame *owner, int cols
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT1(fx,Frame,cols);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -206,15 +174,6 @@ ibgFrameBookSubject* iggSubjectFactory::CreateFrameBookSubject(iggFrameBook *own
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT1(fx,FrameBook,withFeedback);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -232,15 +191,6 @@ ibgFrameFlipSubject* iggSubjectFactory::CreateFrameFlipSubject(iggFrameFlip *own
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT1(fx,FrameFlip,expanding);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -258,15 +208,23 @@ ibgFrameScrollSubject* iggSubjectFactory::CreateFrameScrollSubject(iggFrameScrol
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
+	return 0;
+}
+
+
+ibgFrameSplitSubject* iggSubjectFactory::CreateFrameSplitSubject(iggFrameSplit *owner, bool hor)
+{
+	if(owner->GetShell() == 0) return 0;
+
+	if(owner->GetShell()->Type() == qt)
 	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT2(fx,FrameScroll,withHor,withVer);
+#if ISHELL_INCLUDED(ISHELL_QT)
+		RETURN_SUBJECT1(qt,FrameSplit,hor);
 #else
 		return 0;
 #endif
 	}
-
+	
 	return 0;
 }
 
@@ -286,17 +244,6 @@ ibgMainWindowSubject* iggSubjectFactory::CreateMainWindowSubject(iggMainWindow *
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		ifxMainWindowSubject *tmp = new ifxMainWindowSubject(owner);
-		owner->AttachSubject(tmp,cols);
-		return tmp;
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -314,24 +261,15 @@ ibgMenuWindowSubject* iggSubjectFactory::CreateMenuWindowSubject(iggMenuWindow *
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		return new ifxMenuWindowSubject(owner,icon,title);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
 
 ibgRenderWindowSubject* iggSubjectFactory::CreateRenderWindowSubject(iggRenderWindow *owner)
 {
-	if(owner->GetViewModule()->GetControlModule()->GetShell() == 0) return 0;
+	if(owner->GetViewModule()->GetShell() == 0) return 0;
 
-	if(owner->GetViewModule()->GetControlModule()->GetShell()->Type() == qt)
+	if(owner->GetViewModule()->GetShell()->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
 		return new iqtRenderWindowSubject(owner);
@@ -340,66 +278,39 @@ ibgRenderWindowSubject* iggSubjectFactory::CreateRenderWindowSubject(iggRenderWi
 #endif
 	}
 	
-	if(owner->GetViewModule()->GetControlModule()->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		return new ifxRenderWindowSubject(owner);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
-ibgShellSubject* iggSubjectFactory::CreateShellSubject(iggShell *owner, int argc, char **argv)
+ibgShellSubject* iggSubjectFactory::CreateShellSubject(iggShell *owner)
 {
 	if(owner == 0) return 0;
 
 	if(owner->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
-		return new iqtShellSubject(owner,argc,argv);
+		return new iqtShellSubject(owner);
 #else
 		return 0;
 #endif
 	}
 	
-	if(owner->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		return new ifxShellSubject(owner,,argc,argv);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
 
-ibgWidgetButtonSubject* iggSubjectFactory::CreateWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot)
+ibgWidgetButtonSubject* iggSubjectFactory::CreateWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot, int minsize)
 {
 	if(owner->GetShell() == 0) return 0;
 
 	if(owner->GetShell()->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
-		RETURN_SUBJECT3(qt,WidgetButton,type,text,slot);
+		RETURN_SUBJECT4(qt,WidgetButton,type,text,slot,minsize);
 #else
 		return 0;
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT3(fx,WidgetButton,type,text,slot);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 	
@@ -417,15 +328,6 @@ ibgWidgetColorSelectionSubject* iggSubjectFactory::CreateWidgetColorSelectionSub
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT0(fx,WidgetColorSelection);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 	
@@ -442,15 +344,6 @@ ibgWidgetComboBoxSubject* iggSubjectFactory::CreateWidgetComboBoxSubject(iggWidg
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT2(fx,WidgetComboBox,title,bold);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 	
@@ -468,15 +361,6 @@ ibgWidgetDisplayAreaSubject* iggSubjectFactory::CreateWidgetDisplayAreaSubject(i
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT1(fx,WidgetDisplayArea,text);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 	
@@ -494,15 +378,6 @@ ibgWidgetDrawAreaSubject* iggSubjectFactory::CreateWidgetDrawAreaSubject(iggWidg
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT1(fx,WidgetDrawArea,interactive);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 	
@@ -520,15 +395,6 @@ ibgWidgetEntrySubject* iggSubjectFactory::CreateWidgetEntrySubject(iggWidget *ow
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT3(fx,WidgetEntry,slider,numdig,label);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -546,15 +412,6 @@ ibgWidgetHelpBrowserSubject* iggSubjectFactory::CreateWidgetHelpBrowserSubject(i
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT0(fx,WidgetHelpBrowser);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -572,15 +429,6 @@ ibgWidgetMultiImageDisplayAreaSubject* iggSubjectFactory::CreateWidgetMultiImage
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT0(fx,WidgetMultiImageDisplayArea);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 	
@@ -598,15 +446,6 @@ ibgWidgetProgressBarSubject* iggSubjectFactory::CreateWidgetProgressBarSubject(i
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT0(fx,WidgetProgressBar);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -624,15 +463,6 @@ ibgWidgetRadioBoxSubject* iggSubjectFactory::CreateWidgetRadioBoxSubject(iggWidg
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT2(fx,WidgetRadioBox,cols,title);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -650,15 +480,6 @@ ibgWidgetSpinBoxSubject* iggSubjectFactory::CreateWidgetSpinBoxSubject(iggWidget
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT4(fx,WidgetSpinBox,min,max,title,step);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -676,15 +497,6 @@ ibgWidgetTextEditorSubject* iggSubjectFactory::CreateWidgetTextEditorSubject(igg
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT0(fx,WidgetTextEditor,mode);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
@@ -702,44 +514,18 @@ ibgWidgetTrackBallSubject* iggSubjectFactory::CreateWidgetTrackBallSubject(iggWi
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT1(fx,WidgetTrackBall,followCamera);
-#else
-		return 0;
-#endif
-	}
-
 	return 0;
 }
 
-#endif
-/*
 
-ibgWidgetSubject* iggSubjectFactory::CreateWidgetSubject(iggWidget *owner, )
-{
-	if(owner->GetShell() == 0) return 0;
-
-	if(owner->GetShell()->Type() == qt)
-	{
+const iString iggSubjectFactory::GetIncludedShells()
+{ 
+	iString tmp;
 #if ISHELL_INCLUDED(ISHELL_QT)
-		RETURN_SUBJECT(qt,Widget,);
-#else
-		return 0;
+	tmp += iString("Qt-based GUI shell (Qt ") + QT_VERSION_STR + ");";
 #endif
-	}
-	
-	if(owner->GetShell()->Type() == fx)
-	{
-#if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT(fx,Widget,);
-#else
-		return 0;
-#endif
-	}
-
-	return 0;
+	return tmp;
 }
-	
-*/
+
+#endif
+
