@@ -43,6 +43,7 @@ class iggFrame;
 class iggFrameBook;
 class iggFrameFlip;
 class iggFrameScroll;
+class iggFrameSplit;
 class iggMainWindow;
 class iggMenuWindow;
 class iggRenderWindow;
@@ -58,6 +59,7 @@ class ibgFrameSubject;
 class ibgFrameBookSubject;
 class ibgFrameFlipSubject;
 class ibgFrameScrollSubject;
+class ibgFrameSplitSubject;
 class ibgMainWindowSubject;
 class ibgMenuWindowSubject;
 class ibgRenderWindowSubject;
@@ -91,15 +93,16 @@ public:
 	static ibgFrameBookSubject*						CreateFrameBookSubject(iggFrameBook *owner, bool withFeedback);
 	static ibgFrameFlipSubject*						CreateFrameFlipSubject(iggFrameFlip *owner, bool expanding);
 	static ibgFrameScrollSubject*					CreateFrameScrollSubject(iggFrameScroll *owner, bool withHor, bool withVer);
+	static ibgFrameSplitSubject*					CreateFrameSplitSubject(iggFrameSplit *owner, bool hor);
 
 	static ibgMainWindowSubject*					CreateMainWindowSubject(iggMainWindow *owner, int cols);
 	static ibgMenuWindowSubject*					CreateMenuWindowSubject(iggMenuWindow *owner, const iImage *icon, const iString &title);
 
 	static ibgRenderWindowSubject*					CreateRenderWindowSubject(iggRenderWindow *owner);
 
-	static ibgShellSubject*							CreateShellSubject(iggShell *owner, int argc, char **argv);
+	static ibgShellSubject*							CreateShellSubject(iggShell *owner);
 
-	static ibgWidgetButtonSubject*					CreateWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot);
+	static ibgWidgetButtonSubject*					CreateWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot, int minsize = 0);
 	static ibgWidgetColorSelectionSubject*			CreateWidgetColorSelectionSubject(iggWidget *owner);
 	static ibgWidgetComboBoxSubject*				CreateWidgetComboBoxSubject(iggWidget *owner, const iString &title, bool bold = false);
 	static ibgWidgetDisplayAreaSubject*				CreateWidgetDisplayAreaSubject(iggWidget *owner, const iString &text);
@@ -113,6 +116,8 @@ public:
 	static ibgWidgetTextEditorSubject*				CreateWidgetTextEditorSubject(iggWidgetTextEditor *owner, unsigned int mode);
 	static ibgWidgetTrackBallSubject*				CreateWidgetTrackBallSubject(iggWidget *owner, bool followCamera);
 
+	static const iString GetIncludedShells();
+
 private:
 
 	static const iString qt, fx;
