@@ -71,14 +71,12 @@ protected:
 class iggAbstractExtension : public iggFrame
 {
 
-	friend class iggExtensionFactory;
 	friend class iggExtensionWindow;
 
 public:
 
 	virtual ~iggAbstractExtension();
 
-	virtual bool LogDataInfo(const iDataType &type, bool details);
 	virtual void OpenBookPageByIndex(int index);
 	virtual void SetTabMode(int m);
 
@@ -144,7 +142,9 @@ private:
 
 
 //
-//  Helper class
+//  Helper class - a creator class needed for the auto-build mechanism to work;
+//  GUI extensions need the MainWindow class, so they cannot be created at
+//  start-up.
 //
 class iggExtensionCreator
 {
@@ -165,12 +165,10 @@ protected:
 //
 //  Useful macros
 //
-#define IGGEXTENSION_DECLARE(_class_) \
-	public: \
-		static int Build(); \
+#define iggExtensionDeclareMacro(_class_) \
 	private: \
 		_class_(iggMainWindow *mw, int id); \
-		static const int mAutoBuild; \
+		static const int mAutoInstall; \
 		static const iggExtensionCreator* Creator(); \
 		class ThisCreator : public iggExtensionCreator \
 		{ \
@@ -179,36 +177,31 @@ protected:
 			virtual iggAbstractExtension* Create(iggMainWindow *mw) const; \
 		}
 
-#define IGGEXTENSION_DEFINE(_class_,_name_,_icon_,_book_) \
-	const int _class_::mAutoBuild = _class_::Creator()->GetId(); \
+#define iggExtensionDefineMacro(_class_,_name_,_icon_,_book_) \
 	const iggExtensionCreator* _class_::Creator() \
 	{ \
 		static iggExtensionCreator* self = new _class_::ThisCreator(IEXTENSION_##_name_); \
 		return self; \
 	} \
-	int _class_::Build() \
-	{ \
-		return Creator()->GetId() - mAutoBuild; \
-	} \
 	iggAbstractExtension* _class_::ThisCreator::Create(iggMainWindow *mw) const { return new _class_(mw,mId); } \
-	_class_::_class_(iggMainWindow *mw, int id) : iggAbstractExtension(mw,id,iImageFactory::FindIcon(_icon_),#_name_,_book_){}
+	_class_::_class_(iggMainWindow *mw, int id) : iggAbstractExtension(mw,id,iggImageFactory::FindIcon(_icon_),#_name_,_book_){}
 
-#define IGGEXTENSION_DECLARE_CLASS(_prefix_) \
+#define iggExtensionDeclareClassMacro(_prefix_) \
 	class _prefix_##ggExtension : public iggAbstractExtension \
 	{ \
-		IGGEXTENSION_DECLARE(_prefix_##ggExtension); \
+		iggExtensionDeclareMacro(_prefix_##ggExtension); \
 	protected: \
 		void StandardInitialization(); \
 		virtual void CompleteInitializationBody(); \
 		virtual bool IsUsingData(const iDataType &type) const; \
 	}
 
-#define IGGEXTENSION_DEFINE_CLASS_PARTLY(_prefix_,_name_,_icon_,_book_,_wildcard_,_subject_) \
-	IGGEXTENSION_DEFINE(_prefix_##ggExtension,_name_,_icon_".png",_book_); \
+#define iggExtensionDefineClassMacro(_prefix_,_name_,_icon_,_book_,_wildcard_,_subject_) \
+	iggExtensionDefineMacro(_prefix_##ggExtension,_name_,_icon_".png",_book_); \
 	void _prefix_##ggExtension::StandardInitialization() \
 	{ \
-		this->CreateFrontPage(iImageFactory::FindIcon(_icon_"large.png")); \
-		this->ConfigureDefaultOpenFileMenu(1,"&"#_name_,#_name_" File ("_wildcard_")",iImageFactory::FindIcon(_icon_"fileopen.png"),_subject_::DataType()); \
+		this->CreateFrontPage(iggImageFactory::FindIcon(_icon_"large.png")); \
+		this->ConfigureDefaultOpenFileMenu(1,"&"#_name_,#_name_" File ("_wildcard_")",iggImageFactory::FindIcon(_icon_"fileopen.png"),_subject_::DataType()); \
 	} \
 	bool _prefix_##ggExtension::IsUsingData(const iDataType &type) const \
 	{ \
