@@ -52,30 +52,30 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 //
 //  Main class
 //
-iggDialog::iggDialog(iShell *shell, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext) : iggElement(shell)
+iggDialog::iggDialog(iggShell *shell, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext) : iggRenderingElement(shell)
 {
 	mMainWindow = 0;
 	this->Define(0,mode,icon,title,helpkey,cols,closetext);
 }
 
 
-iggDialog::iggDialog(const iggMenuWindow *mw, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext) : iggElement(mw==0?0:mw->GetShell())
+iggDialog::iggDialog(const iggMenuWindow *mw, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext) : iggRenderingElement(mw==0?0:mw->GetShell())
 {
-	IERROR_ASSERT(mw);
+	IASSERT(mw);
 	mMainWindow = mw->GetMainWindow();
 	this->Define(mw->GetSubject(),mode,icon,title,helpkey,cols,closetext);
 }
 
 
-iggDialog::iggDialog(const iggDialog *pd, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext) : iggElement(pd==0?0:pd->GetShell())
+iggDialog::iggDialog(const iggDialog *pd, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext) : iggRenderingElement(pd==0?0:pd->GetShell())
 {
-	IERROR_ASSERT(pd);
+	IASSERT(pd);
 	mMainWindow = pd->GetMainWindow();
 	this->Define(pd->GetSubject(),mode,icon,title,helpkey,cols,closetext);
 }
@@ -83,22 +83,22 @@ iggDialog::iggDialog(const iggDialog *pd, unsigned int mode, const iImage *icon,
 
 void iggDialog::Define(const ibgWindowSubject *base, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext)
 {
-	mSubject = iggSubjectFactory::CreateDialogSubject(this,base,mode,icon,title.IsEmpty()?title:("IFrIT - "+title)); IERROR_ASSERT(mSubject);
+	mSubject = iggSubjectFactory::CreateDialogSubject(this,base,mode,icon,title.IsEmpty()?title:("IFrIT - "+title)); IERROR_CHECK_MEMORY(mSubject);
 	if(mMainWindow != 0) mMainWindow->Register(mSubject);
 
 	if(cols < 1)
 	{
 		cols = 1;
-		IERROR_LOW("Incorrect number of columns in iggDialog frame.");
+		IBUG_WARN("Incorrect number of columns in iggDialog frame.");
 	}
 
 	mMode = mode;
 
 	if(closetext!=0 && (closetext[0]!=0 || iDynamicCast<iggShell,iShell>(INFO,this->GetShell())->CheckCondition(iParameter::Condition::OldWindowManager)))
 	{
-		iggFrame *tmp = new iggFrame(this->GetShell(),3); IERROR_ASSERT(tmp);
+		iggFrame *tmp = new iggFrame(this->GetShell(),3); IERROR_CHECK_MEMORY(tmp);
 		mSubject->SetFrame(tmp->GetSubject());
-		mFrame = new iggFrame(tmp,cols); IERROR_ASSERT(mFrame);
+		mFrame = new iggFrame(tmp,cols); IERROR_CHECK_MEMORY(mFrame);
 		tmp->AddLine(mFrame,3);
 		iggFrame *tmp1 = new iggFrame("",tmp);
 		tmp1->AddLine(new iggWidgetDialogCloseButton(this,tmp1,(closetext[0]==0)?"Close":closetext));
@@ -112,7 +112,7 @@ void iggDialog::Define(const ibgWindowSubject *base, unsigned int mode, const iI
 	}
 	else
 	{
-		mFrame = new iggFrame(this->GetShell(),cols); IERROR_ASSERT(mFrame);
+		mFrame = new iggFrame(this->GetShell(),cols); IERROR_CHECK_MEMORY(mFrame);
 		mSubject->SetFrame(mFrame->GetSubject());
 	}
 	mFrame->SetPadding(true);
@@ -123,7 +123,7 @@ void iggDialog::Define(const ibgWindowSubject *base, unsigned int mode, const iI
 	}
 	else
 	{
-		mHelp = iHelpFactory::FindData(helpkey,iHelpFactory::_ShellReference);
+		mHelp = new iHelpDataBuffer(iHelpFactory::FindData(helpkey,iHelpFactory::_ShellReference));
 	}
 	mFrame->SetBaloonHelp(this->GetToolTip(),this->GetBaloonHelp());
 
@@ -144,9 +144,9 @@ iggDialog::~iggDialog()
 }
 
 
-iPointerArray<iggDialog>& iggDialog::List()
+iLookupArray<iggDialog*>& iggDialog::List()
 {
-	static iPointerArray<iggDialog> list(100);
+	static iLookupArray<iggDialog*> list(100);
 	return list;
 }
 
@@ -181,7 +181,7 @@ void iggDialog::Show(bool s)
 {
 	if(mFrame == 0)
 	{
-		IERROR_LOW("No frame was set for this dialog.");
+		IBUG_WARN("No frame was set for this dialog.");
 		return;
 	}
 
@@ -214,7 +214,7 @@ void iggDialog::UpdateDialog()
 {
 	if(mFrame == 0)
 	{
-		IERROR_LOW("No frame was set for this dialog.");
+		IBUG_WARN("No frame was set for this dialog.");
 		return;
 	}
 	mFrame->UpdateWidget();
@@ -245,7 +245,7 @@ void iggDialog::Close()
 
 bool iggDialog::ImmediateConstruction() const
 {
-	return iRequiredCast<iggShell>(INFO,this->GetShell())->CheckCondition(iParameter::Condition::DisableDelayedInitialization);
+	return this->GetShell()->CheckCondition(iParameter::Condition::DisableDelayedInitialization);
 }
 
 
@@ -255,9 +255,6 @@ void iggDialog::CompleteConstruction()
 
 	this->CompleteConstructionBody();
 	mCompleteConstructionCalled = true;
-#ifdef I_DEBUG
-	iConsole::PrintDebugMessage(iString("Completing delayed construction for element #")+iString::FromNumber(this->GetId()));
-#endif
 }
 
 
@@ -265,7 +262,7 @@ void iggDialog::CompleteConstruction()
 void iggDialog::FlashAllDialogs()
 {
 	int i;
-	iPointerArray<iggDialog>& list = List();
+	iLookupArray<iggDialog*>& list(List());
 	for(i=0; i<list.Size(); i++)
 	{
 		list[i]->Show(true);
