@@ -31,17 +31,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iggdialog.h"
-#include "iscript.h"
 
 
-class iViewModule;
-
-class iggWidgetTextArea;
-
-class vtkTimerLog;
+class iggWidgetNumberLabel;
+class iggWidgetTextLabel;
 
 
-class iggDialogAnimatingProgress : public iggDialog, public iScriptObserver
+class iggDialogAnimatingProgress : public iggDialog
 {
 
 public:
@@ -61,19 +57,11 @@ public:
 protected:
 
 	virtual void CompleteConstructionBody();
-
-	virtual void OnScriptStartBody();
-	virtual void OnScriptStopBody(const iString &error);
-	virtual void OnScriptBeginLineBody(int line, const iString &text);
-	virtual void OnScriptEndLineBody(int line, const iString &text);
-	virtual bool OnScriptCheckAbortBody(int cur, int num, int level);
-
-	void DisplayInfo();
 	virtual bool CanBeClosed();
 
-	iViewModule *mCurrentViewModule;
 	bool mCancelled, mPaused;
-	iggWidgetTextArea *mCurrentFrame, *mCurrentRecord, *mWarning;
+	iggWidgetNumberLabel *mCurrentFrame, *mCurrentRecord;
+	iggWidgetTextLabel *mWarning;
 	iggFrame *mInfoFrame, *mWarningFrame;
 	int mLastRecord, mLastFrame;
 };
