@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -54,7 +54,7 @@ iggDialogAuto::~iggDialogAuto()
 }
 
 
-void iggDialogAuto::Show(bool s)
+void iggDialogAuto::ShowBody(bool s)
 {
 	if(!s || !mBlockShowing)
 	{
@@ -65,7 +65,8 @@ void iggDialogAuto::Show(bool s)
 
 void iggDialogAuto::ForceShow(bool s)
 {
-	this->iggDialog::Show(s);
+	if(!mCompleteConstructionCalled) this->CompleteConstruction();
+	this->iggDialog::ShowBody(s);
 	if((mMode & iParameter::DialogFlag::Modal) == 0) this->GetMainWindow()->PlaceAutoDialogs();
 }
 
