@@ -33,22 +33,22 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdialogdataexplorer.h"
 
 
-#include "icontrolmodule.h"
 #include "idata.h"
-#include "idataexplorer.h"
 #include "idatalimits.h"
 #include "idatareader.h"
+#include "idatasubject.h"
 #include "ierror.h"
 #include "ihistogram.h"
-#include "iimagefactory.h"
-#include "ishell.h"
+#include "ihistogrammaker.h"
 #include "iviewmodule.h"
 
-#include "iggdatatypeprovider.h"
 #include "iggframedatatypeselector.h"
 #include "iggframedoublebutton.h"
-#include "iggframehistogramareaextra.h"
+#include "iggframehistogramcontrols.h"
+#include "igghandle.h"
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
+#include "iggshell.h"
 #include "iggwidgetarea.h"
 #include "iggwidgetmisc.h"
 #include "iggwidgetotherbutton.h"
@@ -68,7 +68,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -76,140 +76,83 @@ using namespace iParameter;
 
 namespace iggDialogDataExplorer_Private
 {
+	//
+	//  Controls the DataType of this page
+	//
+	class DataTypeHandle : public iggDataTypeHandle
+	{
+
+	public:
+
+		DataTypeHandle(iggDialogDataExplorer *owner)
+		{
+			mOwner = owner;
+			mIndex = 0;
+		}
+
+		virtual const iDataInfo& GetDataInfo() const
+		{
+			mDataInfo.Clear();
+
+			int i;
+			const iDataInfo &di(iDataInfo::Any());
+			for(i=0; i<di.Size(); i++)
+			{
+				if(mOwner->GetShell()->GetViewModule()->GetReader()->IsThereData(di.Type(i)))
+				{
+					mDataInfo += di.Type(i);
+				}
+			}
+
+			if(mIndex >= di.Size()) mIndex = di.Size() - 1;
+
+			return mDataInfo;
+		}
+
+		virtual int GetActiveDataTypeIndex() const
+		{
+			return mIndex;
+		}
+
+	protected:
+
+		virtual void OnActiveDataTypeChanged(int v)
+		{
+			if(v>=0 && v<mDataInfo.Size())
+			{
+				mIndex = v;
+				mOwner->UpdateDialog();
+			}
+		}
+
+		virtual void AfterFileLoadBody(const iDataInfo &info)
+		{
+		}
+
+	private:
+
+		mutable int mIndex;
+		mutable iDataInfo mDataInfo;
+		iggDialogDataExplorer *mOwner;
+	};
+
 	struct Variable
 	{
+		int Var;
 		iString Name;
-		iViewModule *View;
 		iDataInfo Data;
-		iDataExplorer *Explorer;
+		iViewModule *View;
+		iHistogramMaker *Maker;
 		iColor Color;
 		float Opacity;
 		Variable()
 		{
 			View = 0;
-			Explorer = 0;
+			Maker = 0;
 			Opacity = 0.0f;
 		}
 	};
-	//
-	//  A small dialog for setting variable's color and opacity, and its widgets
-	//
-	class VariablePropertyDialog;
 
-	class VariablePropertyDialogOpacitySlider : public iggWidget
-	{
-
-	public:
-
-		VariablePropertyDialogOpacitySlider(VariablePropertyDialog *dialog, iggFrame *parent) : iggWidget(parent)
-		{
-			mDialog = dialog;
-			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,true,0,"Opacity");
-			mNeedsBaloonHelp = false;
-		}
-
-	protected:
-
-		virtual void UpdateWidgetBody();
-		virtual void OnInt1Body(int i);
-
-		VariablePropertyDialog *mDialog;
-		ibgWidgetEntrySubject *mSubject;
-	};
-
-	class VariablePropertyDialogColorSelection : public iggWidget
-	{
-
-	public:
-
-		VariablePropertyDialogColorSelection(VariablePropertyDialog *dialog, iggFrame *parent) : iggWidget(parent)
-		{
-			mDialog = dialog;
-			mSubject = iggSubjectFactory::CreateWidgetColorSelectionSubject(this);
-			mNeedsBaloonHelp = false;
-		}
-
-	protected:
-
-		virtual void UpdateWidgetBody();
-		virtual void OnVoid1Body();
-
-		VariablePropertyDialog *mDialog;
-		ibgWidgetColorSelectionSubject *mSubject;
-	};
-
-	class VariablePropertyDialog : public iggDialog
-	{
-
-	public:
-
-		VariablePropertyDialog(iggWidgetListView *list, iggWidgetHistogramArea *area, iggDialog *parent) : iggDialog(parent,DialogFlag::Modal,0,"Variable Properties",0,1)
-		{
-			mList = list;
-			mArea = area;
-			mVariable = 0;
-		}
-
-		void CompleteConstructionBody()
-		{
-			mFrame->AddLine(new VariablePropertyDialogOpacitySlider(this,mFrame));
-			mFrame->AddLine(new VariablePropertyDialogColorSelection(this,mFrame));
-		}
-
-		void SetChanged(bool color)
-		{
-			mArea->UpdateWidget();
-			if(color)
-			{
-				mList->Clear();
-				mList->UpdateWidget();
-			}
-		}
-
-		void AttachVariable(Variable *v)
-		{
-			mVariable = v;
-		}
-
-		Variable* GetVariable() const
-		{
-			return mVariable;
-		}
-
-	protected:
-
-		Variable *mVariable;
-		iggWidgetListView *mList;
-		iggWidgetHistogramArea *mArea;
-	};
-
-	void VariablePropertyDialogOpacitySlider::UpdateWidgetBody()
-	{
-		if(mDialog->GetVariable() != 0) mSubject->SetValue(round(20.0*mDialog->GetVariable()->Opacity));
-	}
-
-	void VariablePropertyDialogOpacitySlider::OnInt1Body(int)
-	{
-		if(mDialog->GetVariable() != 0)
-		{
-			mDialog->GetVariable()->Opacity = 0.05*mSubject->GetValue();
-			mDialog->SetChanged(false);
-		}
-	}
-
-	void VariablePropertyDialogColorSelection::UpdateWidgetBody()
-	{
-		if(mDialog->GetVariable() != 0) mSubject->SetColor(mDialog->GetVariable()->Color);
-	}
-
-	void VariablePropertyDialogColorSelection::OnVoid1Body()
-	{
-		if(mDialog->GetVariable() != 0)
-		{
-			mDialog->GetVariable()->Color = mSubject->GetColor();
-			mDialog->SetChanged(true);
-		}
-	}
 	//
 	//  List of explored variables - does most of work
 	//
@@ -232,30 +175,29 @@ namespace iggDialogDataExplorer_Private
 			mDefaultColor[3] = iColor(255,255,  0);
 			mDefaultColor[4] = iColor(255,  0,255);
 			mDefaultColor[5] = iColor(  0,255,255);
-
-			mPropertiesDialog = 0;
 		}
 
 		~ExploredVariablesList()
 		{
-			delete mPropertiesDialog;
             while(mVariables.Size() > 0) this->RemoveVariable(0);
 		}
 
+		inline iggDialogDataExplorer* DataExplorer() const { return mDataExplorer; }
 		inline const iArray<Variable>& GetVariables() const { return mVariables; }
 
 		void AddVariable(int n)
 		{
-			iDataReader *dr = this->GetShell()->GetControlModule()->GetViewModule()->GetReader();
-			iDataLimits *l = dr->GetLimits(mDataExplorer->GetProvider()->GetActiveDataType());
+			iDataSubject *subject = this->GetShell()->GetViewModule()->GetReader()->GetSubject(mDataExplorer->GetActiveDataType()); IASSERT(subject);
+			iDataLimits *lims = subject->GetLimits(); IASSERT(lims);
 
-			if(l!=0 && n>=0 && n<l->GetNumVars())
+			if(n>=0 && n<lims->GetNumVars())
 			{
 				Variable v;
 
-				v.Name = l->GetName(n);
-				v.View = this->GetShell()->GetControlModule()->GetViewModule();
-				v.Data = l->GetDataType();
+				v.Var = n;
+				v.Name = lims->GetName(n);
+				v.Data = lims->GetDataType();
+				v.View = this->GetShell()->GetViewModule();
 
 				//
 				//  Check for duplicates
@@ -265,14 +207,11 @@ namespace iggDialogDataExplorer_Private
 				{
 					if(mVariables[i].Name==v.Name && mVariables[i].View==v.View && mVariables[i].Data.Type(0)==v.Data.Type(0))
 					{
-						if(this->GetMainWindow()->PopupWindow(mDataExplorer->GetFrame(),"This variables is already on the list!",PopupWindow::Message,"Cancel","Add anyway") == 0) return; else break;
+						if(this->GetShell()->PopupWindow(mDataExplorer,"This variables is already on the list!",MessageType::Information,"Cancel","Add anyway") == 0) return; else break;
 					}
 				}
 
-				v.Explorer = iDataExplorer::New(v.View);
-				if(v.Data.Count() > 0) v.Explorer->SetActiveDataType(v.Data.Type(0));
-				v.Explorer->SetInputComponent(n);
-				v.Explorer->SetStretch(mDataExplorer->GetStretch());
+				v.Maker = subject->GetHistogramMaker();
 
 				if(mVariables.Size() < 6)
 				{
@@ -301,7 +240,6 @@ namespace iggDialogDataExplorer_Private
 		{
 			if(n>=0 && n<mVariables.Size())
 			{
-				mVariables[n].Explorer->Delete();
 				mVariables.Remove(n);
 			}
 		}
@@ -312,11 +250,6 @@ namespace iggDialogDataExplorer_Private
 			this->UpdateDependents();
 		}
 
-		void CreatePropertiesDialog(iggWidgetHistogramArea *area)
-		{
-			mPropertiesDialog = new VariablePropertyDialog(this,area,mDataExplorer);
-		}
-
 		void Modify(int type)
 		{
 			static Variable *buffer = 0;
@@ -386,13 +319,33 @@ namespace iggDialogDataExplorer_Private
 			this->UpdateWidget();
 		}
 
+		Variable& GetSelectedVar()
+		{
+			static Variable null;
+			if(this->HasSelection())
+			{
+				return mVariables[mSelectedRange[0]];
+			}
+			else return null;
+		}
+
+		void UpdateVariableColor()
+		{
+			if(this->HasSelection())
+			{
+				int s = mSelectedRange[0];
+				this->UpdateWidget();
+				this->Select(s,s);
+			}
+		}
+
 	protected:
 
 		virtual void UpdateWidgetBody()
 		{
 			bool ok;
 			int i, j, wn, n = mVariables.Size();
-			iControlModule *cm = this->GetShell()->GetControlModule();
+			iggShell *s = this->GetShell();
 
 			mMaxNameLength = -1;
 			bool redo = true;
@@ -423,20 +376,20 @@ namespace iggDialogDataExplorer_Private
 						}
 						ws.ReduceWhiteSpace();
 						wn = ws.Section(" ",0,0).ToInt(ok) - 1;
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 						if(!ok)
 						{
-							IERROR_REPORT_BUG;
+							IBUG_WARN("Internal check failed.");
 						}
 #endif
 					}
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 					else
 					{
-						IERROR_REPORT_BUG;
+						IBUG_WARN("Internal check failed.");
 					}
 #endif
-					if(wn<0 || cm->GetViewModule(wn)!=mVariables[i].View)
+					if(wn<0 || s->GetViewModule(wn)!=mVariables[i].View)
 					{
 						redo = true;
 					}
@@ -448,11 +401,11 @@ namespace iggDialogDataExplorer_Private
 				//
 				//  remove non-existent VMs
 				//
-				n = cm->GetNumberOfViewModules();
+				n = s->GetNumberOfViewModules();
 				for(i=0; i<mVariables.Size(); i++) // the upper limit is variable!!!
 				{
 					ok = false;
-					for(j=0; !ok && j<n; j++) if(cm->GetViewModule(j) == mVariables[i].View) ok = true;
+					for(j=0; !ok && j<n; j++) if(s->GetViewModule(j) == mVariables[i].View) ok = true;
 					if(!ok)
 					{
 						this->RemoveVariable(i--);
@@ -505,27 +458,78 @@ namespace iggDialogDataExplorer_Private
 			if(mSubject->SupportsHTML()) ws += "</b>";
 			ws += " data: ";
 			if(mSubject->SupportsHTML()) ws += "<b>";
-			ws += mVariables[n].Data.Type(0).GetTextName();
+			ws += mVariables[n].Data.Type(0).TextName();
 			if(mSubject->SupportsHTML()) ws += "</b>";
 			return ws;
 		}
 
-		virtual void OnReturnPressed()
-		{
-			if(this->HasSelection())
-			{
-				mPropertiesDialog->AttachVariable(&mVariables[mSelectedRange[0]]);
-				mPropertiesDialog->Show(true);
-				this->UpdateWidget();
-			}
-		}
-
 		int mMaxNameLength;
 		iColor mDefaultColor[9];
 		iArray<Variable> mVariables;  // not pointers for cache coherence
-		VariablePropertyDialog *mPropertiesDialog;
 		iggDialogDataExplorer *mDataExplorer;
 	};
+	//
+	//  Widgets for setting variable's color and opacity
+	//
+	class VariablePropertyOpacitySlider : public iggWidget
+	{
+
+	public:
+
+		VariablePropertyOpacitySlider(ExploredVariablesList *list, iggFrame *parent) : iggWidget(parent)
+		{
+			mList = list;
+			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,true,0,"Opacity");
+			mNeedsBaloonHelp = false;
+		}
+
+	protected:
+
+		void UpdateWidgetBody()
+		{
+			this->Enable(mList->HasSelection());
+			mSubject->SetValue(iMath::Round2Int(20.0*mList->GetSelectedVar().Opacity));
+		}
+
+		void OnInt1Body(int)
+		{
+			mList->GetSelectedVar().Opacity = 0.05*mSubject->GetValue();
+		}
+
+		ExploredVariablesList *mList;
+		ibgWidgetEntrySubject *mSubject;
+	};
+
+	class VariablePropertyColorSelection : public iggWidget
+	{
+
+	public:
+
+		VariablePropertyColorSelection(ExploredVariablesList *list, iggFrame *parent) : iggWidget(parent)
+		{
+			mList = list;
+			mSubject = iggSubjectFactory::CreateWidgetColorSelectionSubject(this);
+			mNeedsBaloonHelp = false;
+		}
+
+	protected:
+
+		void UpdateWidgetBody()
+		{
+			this->Enable(mList->HasSelection());
+			mSubject->SetColor(mList->GetSelectedVar().Color);
+		}
+
+		void OnVoid1Body()
+		{
+			mList->GetSelectedVar().Color = mSubject->GetColor();
+			mList->UpdateVariableColor();
+		}
+
+		ExploredVariablesList *mList;
+		ibgWidgetColorSelectionSubject *mSubject;
+	};
+
 	//
 	//  Fraction info list
 	//
@@ -534,9 +538,10 @@ namespace iggDialogDataExplorer_Private
 
 	public:
 
-		FractionInfoList(ExploredVariablesList *list, iggFrame *parent) : iggFrameFlip(parent)
+		FractionInfoList(ExploredVariablesList *list, iggFrameHistogramControls *controls, iggFrame *parent) : iggFrameFlip(parent)
 		{
 			mList = list;
+			mControls = controls;
 			mValue = 0.0;
 			
 			//
@@ -569,36 +574,28 @@ namespace iggDialogDataExplorer_Private
 			//
 			//  Cache a few things
 			//
-			const iArray<Variable> &v = mList->GetVariables();
-			int i, j, stretch, n = v.Size();
-			iDataExplorer::Info d;
-			const iHistogram *h;
-			float xv, sMin, sMax;
-			double sum1, sum2;
+			const iArray<Variable> &vars = mList->GetVariables();
 
-			int maxlength = 0;
-			for(i=0; i<n; i++)
+			int i, maxlength = 0;
+			for(i=0; i<vars.Size(); i++)
 			{
-				if(v[i].Name.Length() > maxlength) maxlength = v[i].Name.Length();
+				if(vars[i].Name.Length() > maxlength) maxlength = vars[i].Name.Length();
 			}
 			while(dummy.Length() < maxlength+3) dummy += ".........";
 
 			mView->Clear();
 			mView->AppendTextLine("Value",iString::FromNumber(mValue));
-			for(i=0; i<n; i++)
+			int sid = mControls->GetStretchId();
+			for(i=0; i<vars.Size(); i++)
 			{
-				d = v[i].Explorer->GetInfo();
-				h = d.Histogram;
-				stretch = h->GetStretch();
-				sMin = iDataStretch::ApplyStretch(d.Minimum,stretch,false);
-				sMax = iDataStretch::ApplyStretch(d.Maximum,stretch,true);
-				xv = (iDataStretch::ApplyStretch(mValue,stretch,false)-sMin)/(sMax-sMin+1.0e-36f);
-				if(xv < 0.0)
+				const iHistogram &h(vars[i].Maker->GetHistogram(vars[i].Var,sid,true));
+				double sum1, sum2;
+				if(mValue < h.GetMin())
 				{
 					sum1 = 0.0;
 					sum2 = 1.0;
 				}
-				else if(xv > 1.0)
+				else if(mValue > h.GetMax())
 				{
 					sum1 = 1.0;
 					sum2 = 0.0;
@@ -606,13 +603,14 @@ namespace iggDialogDataExplorer_Private
 				else
 				{
 					sum1 = sum2 = 0.0;
-					for(j=0; j<h->N(); j++)
+					int j;
+					for(j=0; j<h.NumBins(); j++)
 					{
-						if(xv < h->X(j)) sum2 += h->Y(j); else sum1 += h->Y(j); 
+						if(mValue < h.GetBinMax(j)) sum2 += h.Value(j); else sum1 += h.Value(j); 
 					}
-					if(sum1+sum2 < 0.5) sum1 = sum2 = 0.5;
+					if(sum1+sum2 < 1.0e-30) sum1 = sum2 = 1.0;
 				}
-				mView->AppendTextLine(v[i].Name+dummy.Part(0,3+maxlength-v[i].Name.Length()),"below "+iString::FromNumber(sum1/(sum1+sum2))+", above "+iString::FromNumber(sum2/(sum1+sum2)),v[i].Color);
+				mView->AppendTextLine(vars[i].Name+dummy.Part(0,3+maxlength-vars[i].Name.Length()),"below "+iString::FromNumber(sum1/(sum1+sum2))+", above "+iString::FromNumber(sum2/(sum1+sum2)),vars[i].Color);
 			}
 			if(mView == mView1)
 			{
@@ -630,10 +628,9 @@ namespace iggDialogDataExplorer_Private
 
 		float mValue;
 		ExploredVariablesList *mList;
+		iggFrameHistogramControls *mControls;
 		iggWidgetTextBrowser *mView, *mView0, *mView1;
 	};
-
-
 	//
 	//  Draw area
 	//
@@ -642,10 +639,9 @@ namespace iggDialogDataExplorer_Private
 
 	public:
 
-		Area(iggDialogDataExplorer *dialog, ExploredVariablesList *list, iggFrame *parent) : iggWidgetHistogramArea(false,true,parent)
+		Area(ExploredVariablesList *list, iggFrameHistogramControls *controls, iggFrame *parent) : iggWidgetHistogramArea(controls,parent)
 		{
 			mList = list;
-			mDialog = dialog;
 		
 			mGlobalMin = 0.0;
 			mGlobalMax = 1.0;
@@ -673,19 +669,19 @@ namespace iggDialogDataExplorer_Private
 				mPosX = x;
 				mPosY = y;
 				this->UpdateInfoList();
-				mDialog->ShowFractionInfo(true);
+				mList->DataExplorer()->ShowFractionInfo(true);
 				mSubject->RequestPainting(DrawMode::Foreground);
 			}
 		}
 
-		virtual void OnMouseRelease(int /*x*/, int /*y*/, int b)
+		virtual void OnMouseRelease(int x, int y, int b)
 		{
 			if(b != MouseButton::LeftButton) return;
 
 			if(mUnderInteraction)
 			{
 				mUnderInteraction = false;
-				mDialog->ShowFractionInfo(false);
+				mList->DataExplorer()->ShowFractionInfo(false);
 				mSubject->RequestPainting(DrawMode::Foreground);
 			}
 		}
@@ -707,12 +703,12 @@ namespace iggDialogDataExplorer_Private
 
 		void UpdateInfoList()
 		{
-			float min = mDialog->ApplyStretch(mGlobalMin,false);
-			float max = mDialog->ApplyStretch(mGlobalMax,true);
+			float min = iStretch::Apply(mGlobalMin,mControls->GetStretchId(),false);
+			float max = iStretch::Apply(mGlobalMax,mControls->GetStretchId(),true);
 			float f = float(mPosX)/float(mSubject->Width()-1);
 			if(f < 0.0f) f = 0.0f;
 			if(f > 1.0f) f = 1.0f;
-			mInfoList->SetValue(mDialog->ResetStretch(min+(max-min)*f));
+			mInfoList->SetValue(iStretch::Reset(min+(max-min)*f,mControls->GetStretchId()));
 		}
 
 		virtual void DrawBackgroundBody()
@@ -720,26 +716,22 @@ namespace iggDialogDataExplorer_Private
 			//
 			//  Cache a few things
 			//
-			const iArray<Variable> &v = mList->GetVariables();
-			int i, n = v.Size();
-			iDataExplorer::Info d;
-
-			this->GetMainWindow()->Block(true);
+			const iArray<Variable> &vars = mList->GetVariables();
+			this->GetMainWindow()->BLOCK(true);
 
 			//
 			//  Compute the global range first
 			//
-			float range[2];
-			if(n > 0)
+			int i;
+			if(vars.Size() > 0)
 			{
-				d = v[0].Explorer->GetInfo();
-				mGlobalMin = d.Minimum;
-				mGlobalMax = d.Maximum;
-				for(i=1; i<n; i++)
+				vars[0].Maker->GetRange(vars[0].Var,mGlobalMin,mGlobalMax);
+				for(i=1; i<vars.Size(); i++)
 				{
-					d = v[i].Explorer->GetInfo();
-					if(mGlobalMin > d.Minimum) mGlobalMin = d.Minimum;
-					if(mGlobalMax < d.Maximum) mGlobalMax = d.Maximum;
+					float min, max;
+					vars[i].Maker->GetRange(vars[i].Var,min,max);
+					if(mGlobalMin > min) mGlobalMin = min;
+					if(mGlobalMax < max) mGlobalMax = max;
 				}
 			}
 
@@ -748,27 +740,32 @@ namespace iggDialogDataExplorer_Private
 			//  Paint in the reverse order, so that the variable on top in the
 			//  list is on top in the image too
 			//
-			float min = mDialog->ApplyStretch(mGlobalMin,false);
-			float max = mDialog->ApplyStretch(mGlobalMax,true);
-			for(i=n-1; i>=0; i--)
+			int sid = mControls->GetStretchId();
+			float min = iStretch::Apply(mGlobalMin,sid,false);
+			float max = iStretch::Apply(mGlobalMax,sid,true);
+			for(i=vars.Size()-1; i>=0; i--)
 			{
-				if(i < n-1)
+				if(i < vars.Size()-1)
 				{
 					mSubject->Begin(DrawMode::Foreground,true);
 				}
-				d = v[i].Explorer->GetInfo();
-				range[0] = (mDialog->ApplyStretch(d.Minimum,false)-min)/(max-min+1.0e-36f);
-				range[1] = (mDialog->ApplyStretch(d.Maximum,true)-min)/(max-min+1.0e-36f);
-				this->SetHistogram(d.Histogram,range);
-				this->DrawHistogram(v[i].Color);
+				float range[2];
+				vars[i].Maker->GetRange(vars[i].Var,range);
+				range[0] = (iStretch::Apply(range[0],sid,false)-min)/(max-min+1.0e-36f);
+				range[1] = (iStretch::Apply(range[1],sid,true)-min)/(max-min+1.0e-36f);
+
+				this->DrawHistogram(vars[i].Maker->GetHistogram(vars[i].Var,sid,true),range,vars[i].Color);
+
 				if(i > 0) mSubject->End();
 				//
 				//  Blend images
 				//
-				if(i < n-1) mSubject->BlendForegroundOntoBackground(v[i].Opacity);
+				if(i < vars.Size()-1) mSubject->BlendForegroundOntoBackground(vars[i].Opacity);
 			}
 
-			this->GetMainWindow()->Block(false);
+			mControls->DisplayRange(mGlobalMin,mGlobalMax);
+
+			this->GetMainWindow()->BLOCK(false);
 		}
 
 		virtual void DrawForegroundBody()
@@ -795,7 +792,6 @@ namespace iggDialogDataExplorer_Private
 		bool mUnderInteraction;
 		ExploredVariablesList *mList;
 		FractionInfoList *mInfoList;
-		iggDialogDataExplorer *mDialog;
 	};
 	//
 	//  List of available variables
@@ -839,8 +835,8 @@ namespace iggDialogDataExplorer_Private
 		{
 			mSelector->UpdateWidget();
 
-			iDataReader *dr = this->GetShell()->GetControlModule()->GetViewModule()->GetReader();
-			iDataLimits *l = dr->GetLimits(mDataExplorer->GetProvider()->GetActiveDataType());
+			iDataReader *dr = this->GetShell()->GetViewModule()->GetReader();
+			iDataLimits *l = dr->GetLimits(mDataExplorer->GetActiveDataType());
 
 			if(l!=0 && dr->IsThereData(l->GetDataType()))
 			{
@@ -896,7 +892,7 @@ namespace iggDialogDataExplorer_Private
 		AddVariableButton(AvailableVariablesList *list, iggFrame *parent) : iggWidgetSimpleButton("",parent,true)
 		{
 			mList = list;
-			mSubject->SetIcon(*iImageFactory::FindIcon("moveleft.png"));
+			mSubject->SetIcon(*iggImageFactory::FindIcon("moveleft.png"));
 
 			this->SetBaloonHelp("Show selected variables");
 		}
@@ -934,31 +930,31 @@ namespace iggDialogDataExplorer_Private
 			{
 			case 0:
 				{
-					mSubject->SetIcon(*iImageFactory::FindIcon("movetop.png"));
+					mSubject->SetIcon(*iggImageFactory::FindIcon("movetop.png"));
 					this->SetBaloonHelp("Move the current variables to the top");
 					break;
 				}
 			case 1:
 				{
-					mSubject->SetIcon(*iImageFactory::FindIcon("moveup.png"));
+					mSubject->SetIcon(*iggImageFactory::FindIcon("moveup.png"));
 					this->SetBaloonHelp("Move the current variables up");
 					break;
 				}
 			case 2:
 				{
-					mSubject->SetIcon(*iImageFactory::FindIcon("movedown.png"));
+					mSubject->SetIcon(*iggImageFactory::FindIcon("movedown.png"));
 					this->SetBaloonHelp("Move the current variables down");
 					break;
 				}
 			case 3:
 				{
-					mSubject->SetIcon(*iImageFactory::FindIcon("close.png"));
+					mSubject->SetIcon(*iggImageFactory::FindIcon("delete.png"));
 					this->SetBaloonHelp("Remove selected variables");
 					break;
 				}
 			default:
 				{
-					IERROR_FATAL("Invalid type");
+					IBUG_FATAL("Invalid type");
 				}
 			}
 		}
@@ -985,24 +981,12 @@ namespace iggDialogDataExplorer_Private
 
 	public:
 
-		DataComboBox(int type, ExploredVariablesList *list, iggFrame *parent) : iggWidget(parent)
+		DataComboBox(bool ismin, ExploredVariablesList *list, iggFrame *parent) : iggWidget(parent)
 		{
 			mList = list;
-			mType = type;
+			mIsMin = ismin;
 
-			switch(type)
-			{
-			case 0:
-			case 1:
-				{
-					mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,"");
-					break;
-				}
-			default:
-				{
-					IERROR_FATAL("Invalid type");
-				}
-			}
+			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,"");
 			mNeedsBaloonHelp = false;
 		}
 
@@ -1014,99 +998,30 @@ namespace iggDialogDataExplorer_Private
 			
 			if(mList->GetVariables().Size() > 0)
 			{
-				const iHistogram *h = mList->GetVariables()[0].Explorer->GetInfo().Histogram;
-				if(h != 0)
-				{
-					switch(mType)
-					{
-					case 0:
-						{
-							mSubject->InsertItem(iString::FromNumber(h->GetMaxValue()));
-							mSubject->InsertItem("Cell: "+iString::FromNumber(h->GetMaxCellIndex()));
-							mSubject->InsertItem("at X: "+iString::FromNumber(h->GetMaxCellPosition()[0]));
-							mSubject->InsertItem("at Y: "+iString::FromNumber(h->GetMaxCellPosition()[1]));
-							mSubject->InsertItem("at Z: "+iString::FromNumber(h->GetMaxCellPosition()[2]));
-							break;
-						}
-					case 1:
-						{
-							mSubject->InsertItem(iString::FromNumber(h->GetMinValue()));
-							mSubject->InsertItem("Cell: "+iString::FromNumber(h->GetMinCellIndex()));
-							mSubject->InsertItem("at X: "+iString::FromNumber(h->GetMinCellPosition()[0]));
-							mSubject->InsertItem("at Y: "+iString::FromNumber(h->GetMinCellPosition()[1]));
-							mSubject->InsertItem("at Z: "+iString::FromNumber(h->GetMinCellPosition()[2]));
-							break;
-						}
-					}
-				}
+				const Variable &v(mList->GetVariables()[0]);
+				const iHistogramMaker::PointInfo &p(mIsMin?v.Maker->GetMin(v.Var):v.Maker->GetMax(v.Var));
+				mSubject->InsertItem(iString::FromNumber(p.Value));
+				mSubject->InsertItem("Cell: "+iString::FromNumber(p.Cell));
+				mSubject->InsertItem("at X: "+iString::FromNumber(p.Position[0]));
+				mSubject->InsertItem("at Y: "+iString::FromNumber(p.Position[1]));
+				mSubject->InsertItem("at Z: "+iString::FromNumber(p.Position[2]));
 			}
 		}
 
-		int mType;
+		bool mIsMin;
 		ibgWidgetComboBoxSubject *mSubject;
 		ExploredVariablesList *mList;
 	};
 
 
-	class DataDisplay : public iggWidgetNumberDisplay
-	{
-
-	public:
-
-		DataDisplay(int type, ExploredVariablesList *list, iggFrame *parent) : iggWidgetNumberDisplay("",parent)
-		{
-			mList = list;
-			mType = type;
-			mNeedsBaloonHelp = false;
-		}
-
-	protected:
-
-		virtual void UpdateWidgetBody()
-		{
-			if(mList->GetVariables().Size() > 0)
-			{
-				const iDataExplorer::Info &d = mList->GetVariables()[0].Explorer->GetInfo();
-				switch(mType)
-				{
-				case 0:
-					{
-						this->Display(d.Median);
-						break;
-					}
-				case 1:
-					{
-						this->Display(d.Average);
-						break;
-					}
-				case 2:
-					{
-						this->Display(d.Dispersion);
-						break;
-					}
-				}
-			}
-			else this->Display(0.0);
-		}
-
-		int mType;
-		ExploredVariablesList *mList;
-	};
-
-
 	class MoveFocalPointFrame : public iggFrameMoveFocalPointButton
 	{
 		
 	public:
 		
-		MoveFocalPointFrame(ExploredVariablesList *list, iggFrame *parent) : iggFrameMoveFocalPointButton("Select a point",parent,true)
+		MoveFocalPointFrame(bool min, ExploredVariablesList *list, iggFrame *parent) : iggFrameMoveFocalPointButton(min?"Minimum":"Maximum",parent,true)
 		{
-			mBox = new iggWidgetSimpleRadioBox(2,"",this);
-			mBox->InsertItem("Maximum");
-			mBox->InsertItem("Minimum");
-			mBox->SetBaloonHelp("Choose where to move the focal point to","This box is used to select whether the focal point in moved to the location where the top variable has the maximum or the minimum value.");
-			this->AddLine(mBox,2);
-
+			mIsMin = min;
 			mList = list;
 
 			this->SetBaloonHelp("Move the camera focal point or place a marker at the location of the maximum or minimum value");
@@ -1121,38 +1036,21 @@ namespace iggDialogDataExplorer_Private
 			else return -1;
 		}
 
-		virtual void GetPosition(double x[3]) const
+		virtual iVector3D GetPosition() const
 		{
-			const double *p = 0;
-
 			if(mList->GetVariables().Size() > 0)
 			{
 				const Variable &v = mList->GetVariables()[0];
-				switch(mBox->GetValue())
+				if(mIsMin)
 				{
-				case 0:
-					{
-						p = v.Explorer->GetInfo().Histogram->GetMaxCellPosition();
-						break;
-					}
-				case 1:
-					{
-						p = v.Explorer->GetInfo().Histogram->GetMinCellPosition();
-						break;
-					}
-				default:
-					{
-						IERROR_LOW("Invalid choice.");
-						p = 0;
-					}
+					return v.Maker->GetMin(v.Var).Position.BoxValue();
+				}
+				else
+				{
+					return v.Maker->GetMax(v.Var).Position.BoxValue();
 				}
 			}
-			if(p != 0)
-			{
-				x[0] = p[0];
-				x[1] = p[1];
-				x[2] = p[2];
-			}
+			return iVector3D();
 		}
 
 	protected:
@@ -1163,65 +1061,8 @@ namespace iggDialogDataExplorer_Private
 			this->iggFrameMoveFocalPointButton::UpdateWidgetBody();
 		}
 
+		bool mIsMin;
 		ExploredVariablesList *mList;
-		iggWidgetSimpleRadioBox *mBox;
-	};
-
-	//
-	//  Stretch combo box
-	//
-	class StretchComboBox : public iggWidget
-	{
-
-	public:
-
-		StretchComboBox(iggDialogDataExplorer *de, ExploredVariablesList *list, iggFrameBase *parent) : iggWidget(parent)
-		{
-			mDataExplorer = de;
-			mList = list;
-
-			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,"Data stretch");
-			
-			int i, n;
-			const iString &s = iDataStretch::GetStretchNames();
-			n = s.Contains(',') + 1;
-			for(i=0; i<n; i++)
-			{
-				mSubject->InsertItem(s.Section(",",i,i));
-			}
-
-			this->OnInt1Body(mDataExplorer->GetStretch());
-
-			this->SetBaloonHelp("Set the stretch for X-axis","This box sets the stretch (scaling) for the horizontal axis. All variables must have the same stretch, since they are shown on one plot.");
-		}
-
-	protected:
-
-		virtual void UpdateWidgetBody()
-		{
-			mSubject->SetValue(mDataExplorer->GetStretch());
-		}
-
-		void OnInt1Body(int s)
-		{
-			mDataExplorer->SetStretch(s);
-			//
-			//  Cache a few things
-			//
-			const iArray<Variable> &v = mList->GetVariables();
-			int i, n = v.Size();
-
-			for(i=0; i<n; i++)
-			{
-				v[i].Explorer->SetStretch(s);
-			}
-
-			mDataExplorer->UpdateDialog();
-		}
-
-		ibgWidgetComboBoxSubject *mSubject;
-		ExploredVariablesList *mList;
-		iggDialogDataExplorer *mDataExplorer;
 	};
 };
 
@@ -1229,9 +1070,9 @@ namespace iggDialogDataExplorer_Private
 using namespace iggDialogDataExplorer_Private;
 
 
-iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("dataexp.png"),"Data Explorer","sr.gg.dd",2)
+iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(parent,0U,iggImageFactory::FindIcon("dataexp.png"),"Data Explorer","sr.gg.dde",2)
 {
-	mProvider = 0;
+	mHandle = new DataTypeHandle(this); IERROR_CHECK_MEMORY(mHandle);
 
 	if(this->ImmediateConstruction()) this->CompleteConstruction();
 }
@@ -1241,10 +1082,6 @@ void iggDialogDataExplorer::CompleteConstructionBody()
 {
 	iggFrame *box1, *box2, *tmp1, *tmp2;
 
-	this->SetStretch(iDataStretch::Log);
-
-	mProvider = new iggKeywordDataTypeProvider("",this->GetFrame()); IERROR_ASSERT(mProvider);
-
 	mFlashFrame = new iggFrameFlip(mFrame);
 	tmp1 = new iggFrame(mFlashFrame,2);
 	mFlashFrame->AddLayer(tmp1);
@@ -1252,18 +1089,19 @@ void iggDialogDataExplorer::CompleteConstructionBody()
 	box1 = new iggFrame(tmp1,2);
 	box2 = new iggFrame(tmp1,2);
 
-	iggFrameDataTypeSelector *dts = new iggFrameDataTypeSelector(mProvider,false,"Use data",box2,ListDataTypes::WithVariables);
+	iggFrameDataTypeSelector *dts = new iggFrameDataTypeSelector(mHandle,"Use data",box2,ListDataTypes::WithVariables);
 	ExploredVariablesList *el = new ExploredVariablesList(this,box1);
 	AvailableVariablesList *al = new AvailableVariablesList(this,el,dts,box2);
-	tmp1->AddLine(new iggWidgetTextArea("   Shown variables",tmp1),new iggWidgetTextArea("   All variables",tmp1));
+	tmp1->AddLine(new iggWidgetTextLabel("   Shown variables",tmp1),new iggWidgetTextLabel("   All variables",tmp1));
 	tmp1->AddLine(box1,box2);
 
 	tmp1 = new iggFrame(mFrame,1);
-	Area *area = new Area(this,el,tmp1);
-	el->CreatePropertiesDialog(area);
+	iggFrameHistogramControls *controls = new iggFrameHistogramControls(false,true,tmp1);
+	controls->SetYLogScale(true);
+	controls->SetStretchId(iStretch::Log);
+	Area *area = new Area(el,controls,tmp1);
 	tmp1->AddLine(area);
-	tmp1->AddLine(new iggFrameHistogramAreaExtra(area,tmp1,false));
-	tmp1->AddLine(new StretchComboBox(this,el,tmp1));
+	tmp1->AddLine(controls);
 	tmp1->SetRowStretch(0,10);
 
 	tmp2 = new iggFrame(mFrame);
@@ -1271,28 +1109,31 @@ void iggDialogDataExplorer::CompleteConstructionBody()
 	iggWidget *w;
 	w = new DataComboBox(0,el,b);
 	el->AddDependent(w);
-	b->AddLine(new iggWidgetTextArea("Maximum",b),w);
+	b->AddLine(new iggWidgetTextLabel("Maximum",b),w);
 	w = new DataComboBox(1,el,b);
 	el->AddDependent(w);
-	b->AddLine(new iggWidgetTextArea("Minimum",b),w);
-	w = new DataDisplay(0,el,b);
-	el->AddDependent(w);
-	b->AddLine(new iggWidgetTextArea("Median",b),w);
-	w = new DataDisplay(1,el,b);
-	el->AddDependent(w);
-	b->AddLine(new iggWidgetTextArea("Average",b),w);
-	w = new DataDisplay(2,el,b);
-	el->AddDependent(w);
-	b->AddLine(new iggWidgetTextArea("Dispersion",b),w);
+	b->AddLine(new iggWidgetTextLabel("Minimum",b),w);
 	tmp2->AddLine(b);
-	w = new MoveFocalPointFrame(el,tmp2);
+	w = new MoveFocalPointFrame(false,el,tmp2);
 	el->AddDependent(w);
 	tmp2->AddLine(w);
+	w = new MoveFocalPointFrame(true,el,tmp2);
+	el->AddDependent(w);
+	tmp2->AddLine(w);
+	iggFrame *tmp3 = new iggFrame("Shown variable",tmp2,2);
+	w = new VariablePropertyColorSelection(el,tmp3);
+	w->AddDependent(area);
+	tmp3->AddLine(w);
+	w = new VariablePropertyOpacitySlider(el,tmp3);
+	w->AddDependent(area);
+	tmp3->AddLine(w,2);
+	el->AddDependent(tmp3);
+	tmp2->AddLine(tmp3);
 	tmp2->AddSpace(10);
 
 	mFrame->AddLine(tmp1,tmp2);
 
-//	box1->AddLine(0,new iggWidgetTextArea("Shown variables",box1));
+//	box1->AddLine(0,new iggWidgetTextLabel("Shown variables",box1));
 	tmp1 = new iggFrame(box1);
 	ControlButton *b2;
 	b2 = new ControlButton(0,el,tmp1);
@@ -1310,7 +1151,7 @@ void iggDialogDataExplorer::CompleteConstructionBody()
 	tmp1->AddSpace(10);
 	box1->AddLine(tmp1,el);
 
-//	box2->AddLine(0,new iggWidgetTextArea("All variables",box2));
+//	box2->AddLine(0,new iggWidgetTextLabel("All variables",box2));
 	tmp1 = new iggFrame(box2);
 	AddVariableButton *b1 = new AddVariableButton(al,tmp1);
 	al->SetButton(b1);
@@ -1325,7 +1166,7 @@ void iggDialogDataExplorer::CompleteConstructionBody()
 
 	tmp1 = new iggFrame("",mFlashFrame);
 	tmp1->SetPadding(false);
-	FractionInfoList *fi = new FractionInfoList(el,tmp1);
+	FractionInfoList *fi = new FractionInfoList(el,controls,tmp1);
 	area->AttachInfoList(fi);
 	tmp1->AddLine(fi);
 	mFlashFrame->AddLayer(tmp1);
@@ -1333,6 +1174,7 @@ void iggDialogDataExplorer::CompleteConstructionBody()
 
 	mFrame->SetRowStretch(0,10);
 	mFrame->SetRowStretch(1,5);
+	mFrame->SetColStretch(0,10);
 
 	this->ResizeContents(700,500);
 }
@@ -1340,7 +1182,13 @@ void iggDialogDataExplorer::CompleteConstructionBody()
 
 iggDialogDataExplorer::~iggDialogDataExplorer()
 {
-	if(mProvider != 0) delete mProvider;
+	delete mHandle;
+}
+
+
+const iDataType& iggDialogDataExplorer::GetActiveDataType() const
+{
+	return mHandle->GetActiveDataType();
 }
 
 
