@@ -33,12 +33,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdialoghelp.h"
 
 
+#include "ioutput.h"
 #include "ihelpfactory.h"
-#include "iimagefactory.h"
 
 #include "iggframe.h"
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
-#include "iggwidgetarea.h"
+#include "iggshell.h"
+#include "iggwidgetmisc.h"
 #include "iggwidgetotherbutton.h"
 #include "iggwidgettext.h"
 
@@ -53,41 +55,56 @@ namespace iggDialogHelp_Private
 	class HelpBrowser : public iggWidgetHelpBrowser
 	{
 
-		friend class TopicList;
+		friend class ContentsList;
 
 	public:
 
-		HelpBrowser(const iggDialog *dialog, iggFrame *parent) : iggWidgetHelpBrowser(parent), mDialog(dialog)
+		HelpBrowser(iggDialogHelp *dialog, iggFrame *parent) : iggWidgetHelpBrowser(parent), mDialog(dialog)
 		{
 		}
 
+		iggDialogHelp* GetDialog() const { return mDialog; }
+
 	protected:
 
 		virtual void OnNullHelpBuffer()
 		{
-			this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"The data for this link are missing.");
+			this->GetShell()->PopupWindow(mDialog,"The data for this link are missing.",MessageType::Warning);
 		}
 
-		const iggDialog *mDialog;
+		iggDialogHelp *mDialog;
 	};
 
 
-	class TopicList : public iggWidgetHelpBrowser
+	class ContentsList : public iggWidgetHelpBrowser
 	{
 
 	public:
 
-		TopicList(HelpBrowser *browser, iggFrame *parent) : iggWidgetHelpBrowser(parent)
+		ContentsList(HelpBrowser *browser, iggFrame *parent) : iggWidgetHelpBrowser(parent)
 		{
 			mBrowser = browser;
-
-			iString text;
-			iHelpFactory::CreateTopicList(text);
-			this->SetContentsText(text);
+			mInit = true;
 		}
 
 	protected:
 
+		bool mInit;
+
+		virtual void GenerateContents(iString &text) const = 0;
+
+		virtual void UpdateWidgetBody()
+		{
+			if(mInit)
+			{
+				iString text;
+				this->GenerateContents(text);
+				this->SetContentsText(text);
+				mInit = false;
+			}
+			this->iggWidgetHelpBrowser::UpdateWidgetBody();
+		}
+
 		virtual void OnMousePress(int line, int index)
 		{
 			mBrowser->OnMousePress(-1-line,-1-index);
@@ -107,6 +124,70 @@ namespace iggDialogHelp_Private
 	};
 
 
+	class TopicsList : public ContentsList
+	{
+
+	public:
+
+		TopicsList(HelpBrowser *browser, iggFrame *parent) : ContentsList(browser,parent)
+		{
+		}
+
+	protected:
+
+		virtual void GenerateContents(iString &text) const
+		{
+			iHelpFactory::CreateTopicList(text);
+		}
+	};
+
+
+	class MainObjectsList : public ContentsList
+	{
+
+	public:
+
+		MainObjectsList(HelpBrowser *browser, iggFrame *parent) : ContentsList(browser,parent)
+		{
+		}
+
+	protected:
+
+		virtual void GenerateContents(iString &text) const
+		{
+			text = iHelpFactory::FormObjectTree(iHelpFactory::_MainObjects);
+		}
+
+		virtual void OnLinkFollowed(const char *tag)
+		{
+			this->ContentsList::OnLinkFollowed(tag);
+
+			if(strcmp(tag,"or.d") == 0)
+			{
+				mBrowser->GetDialog()->OpenList(2);
+			}
+		}
+	};
+
+
+	class DataObjectsList : public ContentsList
+	{
+
+	public:
+
+		DataObjectsList(HelpBrowser *browser, iggFrame *parent) : ContentsList(browser,parent)
+		{
+		}
+
+	protected:
+
+		virtual void GenerateContents(iString &text) const
+		{
+			text = iHelpFactory::FormObjectTree(iHelpFactory::_DataObjects);
+		}
+	};
+
+
 	class NavigationButton : public iggWidgetSimpleButton
 	{
 
@@ -123,19 +204,19 @@ namespace iggDialogHelp_Private
 			{
 			case -1:
 				{
-					mSubject->SetIcon(*iImageFactory::FindIcon("moveleft.png"));
+					mSubject->SetIcon(*iggImageFactory::FindIcon("moveleft.png"));
 					this->SetBaloonHelp("Go back one page","Go back to the previous visited page.");
 					break;
 				}
 			case 0:
 				{
-					mSubject->SetIcon(*iImageFactory::FindIcon("movetop.png"));
+					mSubject->SetIcon(*iggImageFactory::FindIcon("movetop.png"));
 					this->SetBaloonHelp("Go home","Go to the first visited page.");
 					break;
 				}
 			case 1:
 				{
-					mSubject->SetIcon(*iImageFactory::FindIcon("moveright.png"));
+					mSubject->SetIcon(*iggImageFactory::FindIcon("moveright.png"));
 					this->SetBaloonHelp("Go forward one page","Go forward to the next visited page.");
 					break;
 				}
@@ -196,7 +277,7 @@ using namespace iggDialogHelp_Private;
 //
 //  Main class
 //
-iggDialogHelp::iggDialogHelp(iggMainWindow *parent) : iggDialog(parent,0U,0,"Help","sr.gg.dh",2)
+iggDialogHelp::iggDialogHelp(iggMainWindow *parent) : iggDialog(parent,0U,0,"Help","sr.gg.dhw",2)
 {
 	if(this->ImmediateConstruction()) this->CompleteConstruction();
 }
@@ -205,16 +286,32 @@ iggDialogHelp::iggDialogHelp(iggMainWindow *parent) : iggDialog(parent,0U,0,"Hel
 void iggDialogHelp::CompleteConstructionBody()
 {
 	HelpBrowser *hb = new HelpBrowser(this,mFrame);
-	TopicList *tc = new TopicList(hb,mFrame);
 	mBrowser = hb;
 
 	iggFrame *tmp = new iggFrame(mFrame,5);
 	mFrame->AddLine(tmp,2);
 	tmp->AddLine(new NavigationButton(-1,mBrowser,tmp),new NavigationButton(1,mBrowser,tmp),new NavigationButton(0,mBrowser,tmp),static_cast<iggWidget*>(0),new iggWidgetDialogCloseButton(this,tmp));
-	tmp->AddLine(new iggWidgetTextArea("Back",tmp),new iggWidgetTextArea("Forward",tmp),new iggWidgetTextArea("Home",tmp),static_cast<iggWidget*>(0),static_cast<iggWidget*>(0));
+	tmp->AddLine(new iggWidgetTextLabel("Back",tmp),new iggWidgetTextLabel("Forward",tmp),new iggWidgetTextLabel("Home",tmp),static_cast<iggWidget*>(0),static_cast<iggWidget*>(0));
 	tmp->SetColStretch(3,10);
 
-	mFrame->AddLine(tc->Self(),mBrowser->Self());
+	mBook = new iggFrameBook(mFrame);
+
+	tmp = new iggFrame(mBook);
+	TopicsList *tl = new TopicsList(hb,tmp);
+	tmp->AddLine(tl->Self());
+	mBook->AddPage("Topics",0,tmp);
+	
+	tmp = new iggFrame(mBook);
+	MainObjectsList *ol = new MainObjectsList(hb,tmp);
+	tmp->AddLine(ol->Self());
+	mBook->AddPage("Objects",0,tmp);
+
+	tmp = new iggFrame(mBook);
+	DataObjectsList *dl = new DataObjectsList(hb,tmp);
+	tmp->AddLine(dl->Self());
+	mBook->AddPage("Data Objects",0,tmp);
+
+	mFrame->AddLine(mBook,mBrowser->Self());
 
 	mBrowser->SetContents("ug.pf");
 
@@ -228,8 +325,16 @@ void iggDialogHelp::CompleteConstructionBody()
 
 void iggDialogHelp::Open(const char *tag)
 {
+	this->CompleteConstruction();
+
 	mBrowser->SetContents(tag);
 	this->Show(true);
 }
 
+
+void iggDialogHelp::OpenList(int n)
+{
+	mBook->OpenPage(n);
+}
+
 #endif
