@@ -33,21 +33,19 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdialogimagecomposer.h"
 
 
-#include "icontrolmodule.h"
 #include "iimagecomposer.h"
 #include "iimagecomposerwindows.h"
-#include "iimagefactory.h"
-#include "imath.h"
 #include "ishell.h"
 #include "iviewmodule.h"
 
 #include "iggframe.h"
-#include "iggmainwindow.h"
+#include "iggimagefactory.h"
 #include "iggwidgetarea.h"
-#include "iggwidgetkeybutton.h"
-#include "iggwidgetkeycolorselection.h"
-#include "iggwidgetkeyselectionbox.h"
-#include "iggwidgetkeyslider.h"
+#include "iggwidgetmisc.h"
+#include "iggwidgetpropertycontrolbutton.h"
+#include "iggwidgetpropertycontrolcolorselection.h"
+#include "iggwidgetpropertycontrolselectionbox.h"
+#include "iggwidgetpropertycontrolslider.h"
 #include "iggwidgetotherbutton.h"
 
 #include "ibgwidgetareasubject.h"
@@ -58,15 +56,70 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates (needed for some compilers)
 //
-#include "iggwidgetkeyhandlertemplate.h"
+#include "iarray.tlh"
+#include "iggwidgetpropertycontrol.tlh"
 
 
-using namespace iParameter;
 using namespace iParameter;
 
 
 namespace iggDialogImageComposer_Private
 {
+	class ImageComposerHandle : public iggObjectHandle
+	{
+
+	public:
+
+		ImageComposerHandle(iggShell *s) : iggObjectHandle(s)
+		{
+		}
+
+		virtual const iObject* Object(int mod = -1) const
+		{
+			return this->GetShell()->GetImageComposer();
+		}
+	};
+
+	class BackgroundWindowHandle : public iggIndexHandle
+	{
+
+	public:
+
+		BackgroundWindowHandle(iggDialogImageComposer *owner)
+		{
+			mOwner = owner; IASSERT(mOwner);
+		}
+
+		virtual int Index() const
+		{
+			return mOwner->GetActiveBackgroundWindow();
+		}
+
+	private:
+
+		iggDialogImageComposer *mOwner;
+	};
+
+	class ForegroundWindowHandle : public iggIndexHandle
+	{
+
+	public:
+
+		ForegroundWindowHandle(iggDialogImageComposer *owner)
+		{
+			mOwner = owner; IASSERT(mOwner);
+		}
+
+		virtual int Index() const
+		{
+			return mOwner->GetActiveForegroundWindow();
+		}
+
+	private:
+
+		iggDialogImageComposer *mOwner;
+	};
+
 	class Area : public iggWidgetDrawArea
 	{
 
@@ -77,11 +130,18 @@ namespace iggDialogImageComposer_Private
 			mDialog = dialog;
 			mSubject->SetBackgroundColor(iColor(100,100,100));
 
+			mZoomFrame = 0;
+
 			mPosX = mPosY = 0;
 			mIsMovingForegroundWindow = false;
 			mNeedsBaloonHelp = false;
 		}
 
+		void AddZoomFrame(iggFrame *f)
+		{
+			mZoomFrame = f;
+		}
+
 		virtual void OnMousePress(int dx, int dy, int b)
 		{
 			int i, j, n, x, y;
@@ -111,7 +171,7 @@ namespace iggDialogImageComposer_Private
 					//
 					//  Found a window - make it current
 					//
-					mDialog->SetCurrentForegroundWindow(i);
+					mDialog->SetActiveForegroundWindow(i);
 					mIsMovingForegroundWindow = true;
 					mSubject->RequestPainting(DrawMode::Foreground);
 					return;
@@ -133,20 +193,20 @@ namespace iggDialogImageComposer_Private
 			j = (y-bw)/th;
 			if(i>=0 && i<ic->GetNumTilesX() && j>=0 && j<ic->GetNumTilesY())
 			{
-				mDialog->SetCurrentBackgroundWindow(i+j*ic->GetNumTilesX());
+				mDialog->SetActiveBackgroundWindow(i+j*ic->GetNumTilesX());
 				mSubject->RequestPainting();
 				this->UpdateDependents();
 			}
 		}
 
-		virtual void OnMouseRelease(int /*dx*/, int /*dy*/, int b)
+		virtual void OnMouseRelease(int , int , int b)
 		{
 			if(b != MouseButton::LeftButton) return;
 
 			if(mIsMovingForegroundWindow)
 			{
 				iImageComposer *ic = mDialog->GetImageComposer();
-				iImageComposerForegroundWindow *fw = ic->GetForegroundWindow(mDialog->GetCurrentForegroundWindow());
+				iImageComposerForegroundWindow *fw = ic->GetForegroundWindow(mDialog->GetActiveForegroundWindow());
 				fw->SetPosition(fw->GetPositionX()+mPosX-mOldPosX,fw->GetPositionY()+mPosY-mOldPosY);
 				mIsMovingForegroundWindow = false;
 				mSubject->RequestPainting(DrawMode::Foreground);
@@ -170,11 +230,14 @@ namespace iggDialogImageComposer_Private
 				mPosX = x;
 				mPosY = y;
 				mSubject->RequestPainting(DrawMode::Foreground);
+				if(mZoomFrame != 0) mZoomFrame->UpdateWidget();
 			}
 		}
 
 	protected:
 
+		iggFrame *mZoomFrame;
+
 		virtual void UpdateWidgetBody()
 		{
 			//
@@ -207,10 +270,10 @@ namespace iggDialogImageComposer_Private
 			//
 			//  Compute reduced sizes
 			//
-			int drawnBorderWidth = round(mScaleFactor*ic->GetBorderWidth());
+			int drawnBorderWidth = iMath::Round2Int(mScaleFactor*ic->GetBorderWidth());
 			if(ic->GetBorderWidth()>0 && drawnBorderWidth<1) drawnBorderWidth = 1;
-			int drawnTileWidth = round(mScaleFactor*ic->GetTileWidth());
-			int drawnTileHeight = round(mScaleFactor*ic->GetTileHeight());
+			int drawnTileWidth = iMath::Round2Int(mScaleFactor*ic->GetTileWidth());
+			int drawnTileHeight = iMath::Round2Int(mScaleFactor*ic->GetTileHeight());
 			mDrawnFullWidth = nx*drawnTileWidth + 2*drawnBorderWidth;
 			mDrawnFullHeight = ny*drawnTileHeight + 2*drawnBorderWidth;
 			if(ib)
@@ -259,11 +322,11 @@ namespace iggDialogImageComposer_Private
 				}
 				if(ic->GetInnerBorder())
 				{
-					this->DrawWindow(x,y,drawnTileWidth+2*drawnBorderWidth,drawnTileHeight+2*drawnBorderWidth,c,drawnBorderWidth,ic->GetBorderColor(),v,&bw->GetWallpaperImage(),i==mDialog->GetCurrentBackgroundWindow());
+					this->DrawWindow(x,y,drawnTileWidth+2*drawnBorderWidth,drawnTileHeight+2*drawnBorderWidth,c,drawnBorderWidth,ic->GetBorderColor(),v,&bw->GetWallpaperImage(),i==mDialog->GetActiveBackgroundWindow());
 				}
 				else
 				{
-					this->DrawWindow(x,y,drawnTileWidth,drawnTileHeight,c,0,ic->GetBorderColor(),v,&bw->GetWallpaperImage(),i==mDialog->GetCurrentBackgroundWindow());
+					this->DrawWindow(x,y,drawnTileWidth,drawnTileHeight,c,0,ic->GetBorderColor(),v,&bw->GetWallpaperImage(),i==mDialog->GetActiveBackgroundWindow());
 				}
 			}
 		}
@@ -283,9 +346,8 @@ namespace iggDialogImageComposer_Private
 			//
 			//  Draw
 			//
-			bool needUpdate = false;
 			n = ic->GetNumberOfForegroundWindows();
-			int cfw = mDialog->GetCurrentForegroundWindow();
+			int cfw = mDialog->GetActiveForegroundWindow();
 			for(i=0; i<n; i++)
 			{
 				fw = ic->GetForegroundWindow(i);
@@ -295,17 +357,17 @@ namespace iggDialogImageComposer_Private
 				//
 				if(i==cfw && mIsMovingForegroundWindow)
 				{
-					x = round(mScaleFactor*(fw->GetPositionX()+mPosX-mOldPosX));
-					y = round(mScaleFactor*(fw->GetPositionY()+mPosY-mOldPosY));
+					x = iMath::Round2Int(mScaleFactor*(fw->GetPositionX()+mPosX-mOldPosX));
+					y = iMath::Round2Int(mScaleFactor*(fw->GetPositionY()+mPosY-mOldPosY));
 				}
 				else
 				{
-					x = round(mScaleFactor*fw->GetPositionX());
-					y = round(mScaleFactor*fw->GetPositionY());
+					x = iMath::Round2Int(mScaleFactor*fw->GetPositionX());
+					y = iMath::Round2Int(mScaleFactor*fw->GetPositionY());
 				}
 
-				w = round(mScaleFactor*fw->GetImageWidth());
-				h = round(mScaleFactor*fw->GetImageHeight());
+				w = iMath::Round2Int(mScaleFactor*fw->GetImageWidth());
+				h = iMath::Round2Int(mScaleFactor*fw->GetImageHeight());
 
 				if(x < 0) x = 0;
 				if(y < 0) y = 0;
@@ -329,12 +391,11 @@ namespace iggDialogImageComposer_Private
 				if(fw->GetZoomSource() != 0)
 				{
 					fw->UpdateWindow();
-					needUpdate = true;
 
-					int zx = mStartX + round(mScaleFactor*(fw->GetZoomSource()->GetContentsX()+(fw->GetZoomX()*fw->GetZoomSource()->GetContentsWidth()-0.5*fw->GetZoomWidth())));
-					int zy = mStartY + round(mScaleFactor*(fw->GetZoomSource()->GetContentsY()+(fw->GetZoomY()*fw->GetZoomSource()->GetContentsHeight()-0.5*fw->GetZoomHeight())));
-					int zw = round(mScaleFactor*fw->GetZoomWidth());
-					int zh = round(mScaleFactor*fw->GetZoomHeight());
+					int zx = mStartX + iMath::Round2Int(mScaleFactor*(fw->GetZoomSource()->GetContentsX()+(fw->GetZoomX()*fw->GetZoomSource()->GetContentsWidth()-0.5*fw->GetZoomWidth())));
+					int zy = mStartY + iMath::Round2Int(mScaleFactor*(fw->GetZoomSource()->GetContentsY()+(fw->GetZoomY()*fw->GetZoomSource()->GetContentsHeight()-0.5*fw->GetZoomHeight())));
+					int zw = iMath::Round2Int(mScaleFactor*fw->GetZoomWidth());
+					int zh = iMath::Round2Int(mScaleFactor*fw->GetZoomHeight());
 
 					this->DrawWindowBase(zx,zy,zw,zh,iColor::Invalid(),bw,bc);
 
@@ -348,15 +409,13 @@ namespace iggDialogImageComposer_Private
 				//
 				//  Draw the window itself
 				//
-				this->DrawWindow(x,y,w,h,fw->GetViewModule()->GetBackgroundColor(),bw,bc,v,0,i==mDialog->GetCurrentForegroundWindow());
+				this->DrawWindow(x,y,w,h,fw->GetViewModule()->GetBackgroundColor(),bw,bc,v,0,i==mDialog->GetActiveForegroundWindow());
 			}
 
-			if(needUpdate) mDialog->UpdateZooms();
-
 			if(!ic->IsActive())
 			{
-				w = round(0.9*mSubject->Width());
-				h = round(0.9*mSubject->Height());
+				w = iMath::Round2Int(0.9*mSubject->Width());
+				h = iMath::Round2Int(0.9*mSubject->Height());
 				x = (mSubject->Width()-w)/2;
 				y = (mSubject->Height()-h)/2;
 				mSubject->DrawTextLine(x,y,x+w-1,y+h-1,"BYPASSED",iColor(200,0,0));
@@ -420,8 +479,8 @@ namespace iggDialogImageComposer_Private
 
 		bool FindPosition(iImageComposer *ic, int dx, int dy, int &x, int &y)
 		{
-			x = round((dx-mStartX)/mScaleFactor);
-			y = round((dy-mStartY)/mScaleFactor);
+			x = iMath::Round2Int((dx-mStartX)/mScaleFactor);
+			y = iMath::Round2Int((dy-mStartY)/mScaleFactor);
 			return x>=0 && y>=0 && x<ic->GetImageWidth() && y<ic->GetImageHeight();
 		}
 
@@ -436,12 +495,12 @@ namespace iggDialogImageComposer_Private
 	//
 	//  Image size label
 	//
-	class ImageSizeLabel : public iggWidgetTextArea
+	class ImageSizeLabel : public iggWidgetTextLabel
 	{
 
 	public:
 
-		ImageSizeLabel(iggDialogImageComposer *dialog, iggFrame *parent) : iggWidgetTextArea("%b640 x 480",parent)
+		ImageSizeLabel(iggDialogImageComposer *dialog, iggFrame *parent) : iggWidgetTextLabel("%b640 x 480",parent)
 		{
 			mDialog = dialog;
 		}
@@ -451,7 +510,7 @@ namespace iggDialogImageComposer_Private
 		virtual void UpdateWidgetBody()
 		{
 			this->SetText("%b"+iString::FromNumber(mDialog->GetImageComposer()->GetImageWidth())+" x "+iString::FromNumber(mDialog->GetImageComposer()->GetImageHeight()));
-			this->iggWidgetTextArea::UpdateWidgetBody();
+			this->iggWidgetTextLabel::UpdateWidgetBody();
 		}
 
 		iggDialogImageComposer *mDialog;
@@ -474,11 +533,15 @@ namespace iggDialogImageComposer_Private
 			this->SetBaloonHelp("Assign a visualization window to a background tile");
 		}
 
+		~WindowListComboBox()
+		{
+		}
+
 	protected:
 
 		virtual void UpdateWidgetBody()
 		{
-			int i, val = this->GetShell()->GetControlModule()->GetNumberOfViewModules();
+			int i, val = this->GetShell()->GetNumberOfViewModules();
 			if(mSubject->Count() != val+1)
 			{
 				mSubject->Clear();
@@ -488,31 +551,31 @@ namespace iggDialogImageComposer_Private
 			}
 			if(mBackground)
 			{
-				if(mDialog->GetCurrentBackgroundWindow() < 0) this->Enable(false); else
+				if(mDialog->GetActiveBackgroundWindow() < 0) this->Enable(false); else
 				{
 					this->Enable(true);
-					if(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule(mComponent) == 0)
+					if(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetActiveBackgroundWindow())->GetViewModule(mComponent) == 0)
 					{
 						mSubject->SetValue(0);
 					}
 					else
 					{
-						mSubject->SetValue(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule(mComponent)->GetWindowNumber()+1);
+						mSubject->SetValue(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetActiveBackgroundWindow())->GetViewModule(mComponent)->GetWindowNumber()+1);
 					}
 				}
 			}
 			else if(mComponent > 0)
 			{
-				if(mDialog->GetCurrentForegroundWindow() < 0) this->Enable(false); else
+				if(mDialog->GetActiveForegroundWindow() < 0) this->Enable(false); else
 				{
 					this->Enable(true);
-					if(mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->GetViewModule(mComponent) == 0)
+					if(mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow())->GetViewModule(mComponent) == 0)
 					{
 						mSubject->SetValue(0);
 					}
 					else
 					{
-						mSubject->SetValue(mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->GetViewModule(mComponent)->GetWindowNumber()+1);
+						mSubject->SetValue(mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow())->GetViewModule(mComponent)->GetWindowNumber()+1);
 					}
 				}
 			}
@@ -522,15 +585,15 @@ namespace iggDialogImageComposer_Private
 		{
 			if(mBackground)
 			{
-				if(mDialog->GetCurrentBackgroundWindow() >= 0)
+				if(mDialog->GetActiveBackgroundWindow() >= 0)
 				{
 					if(v == 0)
 					{
-						mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->SetViewModule(0,mComponent);
+						mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetActiveBackgroundWindow())->SetViewModule(0,mComponent);
 					}
 					else
 					{
-						mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->SetViewModule(this->GetShell()->GetControlModule()->GetViewModule(v-1),mComponent);
+						mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetActiveBackgroundWindow())->SetViewModule(this->GetShell()->GetViewModule(v-1),mComponent);
 					}
 				}
 			}
@@ -540,19 +603,19 @@ namespace iggDialogImageComposer_Private
 				{
 					if(v > 0)
 					{
-						mDialog->GetImageComposer()->AddForegroundWindow(this->GetShell()->GetControlModule()->GetViewModule(v-1));
-						mDialog->SetCurrentForegroundWindow(mDialog->GetImageComposer()->GetNumberOfForegroundWindows()-1);
+						mDialog->GetImageComposer()->AddForegroundWindow(this->GetShell()->GetViewModule(v-1));
+						mDialog->SetActiveForegroundWindow(mDialog->GetImageComposer()->GetNumberOfForegroundWindows()-1);
 					}
 				}
 				else
 				{
 					if(v == 0)
 					{
-						mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->SetViewModule(0,mComponent);
+						mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow())->SetViewModule(0,mComponent);
 					}
 					else
 					{
-						mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->SetViewModule(this->GetShell()->GetControlModule()->GetViewModule(v-1),mComponent);
+						mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow())->SetViewModule(this->GetShell()->GetViewModule(v-1),mComponent);
 					}
 				}
 			}
@@ -582,7 +645,7 @@ namespace iggDialogImageComposer_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			this->Enable(mDialog->GetCurrentBackgroundWindow()>=0 && mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule() == 0);
+			this->Enable(mDialog->GetActiveBackgroundWindow()>=0 && mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetActiveBackgroundWindow())->GetViewModule() == 0);
 		}
 
 		virtual void Execute()
@@ -591,9 +654,9 @@ namespace iggDialogImageComposer_Private
 			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(Environment::Base);
 			fn = this->GetMainWindow()->GetFileName("Open image file",mOldFileName,"Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)");
 
-			if(mDialog->GetCurrentBackgroundWindow()>=0 && !mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->LoadWallpaperImage(fn))
+			if(mDialog->GetActiveBackgroundWindow()>=0 && !mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetActiveBackgroundWindow())->LoadWallpaperImage(fn))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to load an image from file.",PopupWindow::Error);
+				this->GetShell()->PopupWindow(mDialog,"Failed to load an image from file.",MessageType::Error);
 			}
 		}
 
@@ -624,8 +687,8 @@ namespace iggDialogImageComposer_Private
 
 		virtual void Execute()
 		{
-			mDialog->GetImageComposer()->RemoveForegroundWindow(mDialog->GetCurrentForegroundWindow());
-			mDialog->SetCurrentForegroundWindow(mDialog->GetCurrentForegroundWindow());
+			mDialog->GetImageComposer()->RemoveForegroundWindow(mDialog->GetActiveForegroundWindow());
+			mDialog->SetActiveForegroundWindow(mDialog->GetActiveForegroundWindow());
 			if(mDialog->GetImageComposer()->GetNumberOfForegroundWindows() == 0) this->Enable(false);
 		}
 
@@ -635,12 +698,12 @@ namespace iggDialogImageComposer_Private
 	//
 	//  Scale discrete float spin box
 	//
-	class ScaleSpinBox : public iggWidgetKeyHandler<float>
+	class ScaleSpinBox : public iggWidgetPropertyControl<iType::Float>
 	{
 
 	public:
 
-		ScaleSpinBox(const iObjectKey &key, iggDialogImageComposer *dialog, iggFrame *parent) : iggWidgetKeyHandler<float>(WidgetType::Other,key,RenderMode::NoRender,parent,0,0)
+		ScaleSpinBox(const iggPropertyHandle &ph, iggDialogImageComposer *dialog, iggFrame *parent) : iggWidgetPropertyControl<iType::Float>(ph,parent,RenderMode::DoNotRender)
 		{
 			mSubject = iggSubjectFactory::CreateWidgetSpinBoxSubject(this,5,100,"",5);
 			mDialog = dialog;
@@ -661,7 +724,7 @@ namespace iggDialogImageComposer_Private
 
 		virtual void UpdateValue(float v)
 		{
-			mSubject->SetValue(round(100.0*v));
+			mSubject->SetValue(iMath::Round2Int(100.0*v));
 		}
 
 		ibgWidgetSpinBoxSubject *mSubject;
@@ -689,7 +752,7 @@ namespace iggDialogImageComposer_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			if(mDialog->GetCurrentForegroundWindow() >= 0)
+			if(mDialog->GetActiveForegroundWindow() >= 0)
 			{
 				this->Enable(true);
 				this->iggFrame::UpdateWidgetBody();
@@ -712,8 +775,8 @@ namespace iggDialogImageComposer_Private
 		{
 			mDialog = dialog;
 			mBackground = bg;
-			this->AddLine(new iggWidgetTextArea("Green channel",this),new WindowListComboBox(bg,1,"",dialog,this));
-			this->AddLine(new iggWidgetTextArea("Blue channel",this),new WindowListComboBox(bg,2,"",dialog,this));
+			this->AddLine(new iggWidgetTextLabel("Green channel",this),new WindowListComboBox(bg,1,"",dialog,this));
+			this->AddLine(new iggWidgetTextLabel("Blue channel",this),new WindowListComboBox(bg,2,"",dialog,this));
 		}
 
 	protected:
@@ -722,11 +785,11 @@ namespace iggDialogImageComposer_Private
 		{
 			if(mBackground)
 			{
-				this->Enable(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())!=0 && mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule()!=0);
+				this->Enable(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetActiveBackgroundWindow())!=0 && mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetActiveBackgroundWindow())->GetViewModule()!=0);
 			}
 			else
 			{
-				this->Enable(mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())!=0 && mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->GetViewModule()!=0);
+				this->Enable(mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow())!=0 && mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow())->GetViewModule()!=0);
 			}
 			this->iggFrame::UpdateWidgetBody();
 		}
@@ -779,7 +842,7 @@ namespace iggDialogImageComposer_Private
 				}
 			}
 
-			iImageComposerForegroundWindow *w = mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow());
+			iImageComposerForegroundWindow *w = mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow());
 			if(w==0 || w->GetZoomSource()==0)
 			{
 				mSubject->SetValue(0);
@@ -793,10 +856,10 @@ namespace iggDialogImageComposer_Private
 
 		virtual void OnInt1Body(int v)
 		{
-			iImageComposerForegroundWindow *w = mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow());
+			iImageComposerForegroundWindow *w = mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow());
 			if(w == 0)
 			{
-				IERROR_LOW("Current foreground window not set.");
+				IBUG_WARN("Current foreground window not set.");
 				return;
 			}
 
@@ -820,30 +883,6 @@ namespace iggDialogImageComposer_Private
 		iggDialogImageComposer *mDialog;
 	};
 
-	//
-	//  update zooms button
-	//
-	class UpdateZoomsButton : public iggWidgetSimpleButton
-	{
-
-	public:
-
-		UpdateZoomsButton(iggDialogImageComposer *dialog, iggFrame *parent) : iggWidgetSimpleButton("Update",parent)
-		{
-			mDialog = dialog;
-			this->SetBaloonHelp("Update zoom arrangements");
-		}
-
-	protected:
-
-		virtual void Execute()
-		{
-			mDialog->UpdateZooms();
-		}
-
-		iggDialogImageComposer *mDialog;
-	};
-
 	//
 	//  zoom widgets frame
 	//
@@ -861,12 +900,13 @@ namespace iggDialogImageComposer_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			iImageComposerForegroundWindow *win = mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow());
+			iImageComposerForegroundWindow *win = mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow());
 
 			if(win!=0 && win->GetZoomSource()!=0)
 			{
 				win->UpdateWindow();
-				this->Enable(!mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->IsAutoZoom());
+				this->Enable(!mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetActiveForegroundWindow())->IsAutoZoom());
+				this->iggFrame::UpdateWidgetBody();
 			}
 		}
 
@@ -878,30 +918,46 @@ namespace iggDialogImageComposer_Private
 using namespace iggDialogImageComposer_Private;
 
 
-iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("imcomp.png"),"Image Composer","sr.gg.di",2)
+iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialog(parent,0U,iggImageFactory::FindIcon("imcomp.png"),"Image Composer","sr.gg.dic",2)
 {
-	mCurrentBackgroundWindow = -1;
-	mCurrentForegroundWindow = -1;
+	mActiveBackgroundWindow = -1;
+	mActiveForegroundWindow = -1;
 	mArea = 0;
 
+	mSelfHandle = new ImageComposerHandle(this->GetShell()); IERROR_CHECK_MEMORY(mSelfHandle);
+
+	mBackgroundWindowHandle = new BackgroundWindowHandle(this); IERROR_CHECK_MEMORY(mBackgroundWindowHandle);
+	mForegroundWindowHandle = new ForegroundWindowHandle(this); IERROR_CHECK_MEMORY(mForegroundWindowHandle);
+
 	if(this->ImmediateConstruction()) this->CompleteConstruction();
 }
 
 
+iggDialogImageComposer::~iggDialogImageComposer()
+{
+	delete mBackgroundWindowHandle;
+	delete mForegroundWindowHandle;
+
+	delete mSelfHandle;
+}
+
+
 void iggDialogImageComposer::CompleteConstructionBody()
 {
+
 	iggFrame *tmp, *tmp2;
 
 	tmp = new iggFrame(mFrame);
 	tmp2 = new iggFrame(tmp,3);
 	mLabel = new ImageSizeLabel(this,tmp2);
-	tmp2->AddLine(new iggWidgetTextArea("Image size: ",tmp2),mLabel);
+	tmp2->AddLine(new iggWidgetTextLabel("Image size: ",tmp2),mLabel);
 	tmp2->SetColStretch(0,0);
 	tmp2->SetColStretch(1,0);
 	tmp2->SetColStretch(2,10);
 	tmp->AddLine(tmp2);
 
-	mArea = new Area(this,tmp);
+	Area *area = new Area(this,tmp);
+	mArea = area;
 	tmp->AddLine(mArea);
 	tmp->SetRowStretch(1,10);
 
@@ -917,14 +973,14 @@ void iggDialogImageComposer::CompleteConstructionBody()
 
 	iggFrame *b = new iggFrame("Number of tiles",tmp,2);
 	iggWidget *wid;
-	wid = new iggWidgetKeySpinBox(1,10,"",0,iImageComposer::KeyNumTiles(),b,0);
+	wid = new iggWidgetPropertyControlSpinBox(1,10,"",0,iggPropertyHandle("NumTiles",mSelfHandle,0),b);
 	wid->AddDependent(mArea);
 	wid->AddDependent(mLabel);
-	b->AddLine(new iggWidgetTextArea("Horizontally",b),wid);
-	wid = new iggWidgetKeySpinBox(1,10,"",0,iImageComposer::KeyNumTiles(),b,1);
+	b->AddLine(new iggWidgetTextLabel("Horizontally",b),wid);
+	wid = new iggWidgetPropertyControlSpinBox(1,10,"",0,iggPropertyHandle("NumTiles",mSelfHandle,1),b);
 	wid->AddDependent(mArea);
 	wid->AddDependent(mLabel);
-	b->AddLine(new iggWidgetTextArea("Vertically",b),wid);
+	b->AddLine(new iggWidgetTextLabel("Vertically",b),wid);
 	
 	tmp->AddLine(b,2);
 
@@ -945,19 +1001,19 @@ void iggDialogImageComposer::CompleteConstructionBody()
 	tmp->AddSpace(10);
 
 	tmp2 = new iggFrame(tmp,3);
-	wid = new iggWidgetKeySpinBox(0,100,"",0,iImageComposer::KeyBorderWidth(),tmp2);
+	wid = new iggWidgetPropertyControlSpinBox(0,100,"",0,iggPropertyHandle("BorderWidth",mSelfHandle),tmp2);
 	wid->AddDependent(mArea);
 	wid->AddDependent(mLabel);
-	tmp2->AddLine(new iggWidgetTextArea("Border width  ",tmp2),wid);
-	iggWidgetKeyColorSelection *bc = new iggWidgetKeyColorSelection(iImageComposer::KeyBorderColor(),tmp2);
+	tmp2->AddLine(new iggWidgetTextLabel("Border width  ",tmp2),wid);
+	iggWidgetPropertyControlColorSelection *bc = new iggWidgetPropertyControlColorSelection(iggPropertyHandle("BorderColor",mSelfHandle),tmp2);
 	bc->SetText("Set");
 	bc->AddDependent(mArea);
-	tmp2->AddLine(new iggWidgetTextArea("Border color  ",tmp2),bc);
-	wid = new iggWidgetKeyCheckBox("Draw border between tiles",iImageComposer::KeyInnerBorder(),tmp2);
+	tmp2->AddLine(new iggWidgetTextLabel("Border color  ",tmp2),bc);
+	wid = new iggWidgetPropertyControlCheckBox("Draw border between tiles",iggPropertyHandle("InnerBorder",mSelfHandle),tmp2);
 	wid->AddDependent(mArea);
 	wid->AddDependent(mLabel);
 	tmp2->AddLine(wid,2);
-	wid = new iggWidgetKeyCheckBox("Scale background to tile size",iImageComposer::KeyScaleBackground(),tmp2);
+	wid = new iggWidgetPropertyControlCheckBox("Scale background to tile size",iggPropertyHandle("ScaleBackground",mSelfHandle),tmp2);
 	wid->AddDependent(mArea);
 	wid->AddDependent(mLabel);
 	tmp2->AddLine(wid,2);
@@ -985,17 +1041,16 @@ void iggDialogImageComposer::CompleteConstructionBody()
 	wid = new RemoveWindowButton(this,b);
 	wid->AddDependent(mArea);
 	b->AddLine(wid);
-	mIndexHolders[0] = new ScaleSpinBox(iImageComposer::KeyForegroundWindowScale(),this,b);
-	mIndexHolders[0]->AddDependent(mArea);
-	b->AddLine(new iggWidgetTextArea("Scale",b),mIndexHolders[0]);
-	mIndexHolders[1] = new iggWidgetKeySpinBox(0,100,"",0,iImageComposer::KeyForegroundWindowBorderWidth(),b,0);
-	mIndexHolders[1]->AddDependent(mArea);
-	b->AddLine(new iggWidgetTextArea("Border width",b),mIndexHolders[1]);
-	iggWidgetKeyColorSelection *cs = new iggWidgetKeyColorSelection(iImageComposer::KeyForegroundWindowBorderColor(),b,0);
+	wid = new ScaleSpinBox(iggPropertyHandle("ForegroundWindowScale",mSelfHandle,mForegroundWindowHandle),this,b);
+	wid->AddDependent(mArea);
+	b->AddLine(new iggWidgetTextLabel("Scale",b),wid);
+	wid = new iggWidgetPropertyControlSpinBox(0,100,"",0,iggPropertyHandle("ForegroundWindowBorderWidth",mSelfHandle,mForegroundWindowHandle),b);
+	wid->AddDependent(mArea);
+	b->AddLine(new iggWidgetTextLabel("Border width",b),wid);
+	iggWidgetPropertyControlColorSelection *cs = new iggWidgetPropertyControlColorSelection(iggPropertyHandle("ForegroundWindowBorderColor",mSelfHandle,mForegroundWindowHandle),b);
 	cs->SetText("Set");
-	mIndexHolders[2] = cs;
-	mIndexHolders[2]->AddDependent(mArea);
-	b->AddLine(new iggWidgetTextArea("Border color",b),mIndexHolders[2]);
+	cs->AddDependent(mArea);
+	b->AddLine(new iggWidgetTextLabel("Border color",b),cs);
 	psb = new PseudoColorBox(false,this,b);
 	wid->AddDependent(psb);
 	mArea->AddDependent(psb);
@@ -1004,25 +1059,27 @@ void iggDialogImageComposer::CompleteConstructionBody()
 	tmp2 = new iggFrame("Show as zoom",b,2);
 	wid = new ZoomSourceListComboBox("",this,tmp2);
 	wid->AddDependent(mArea);
-	tmp2->AddLine(new iggWidgetTextArea("Source",tmp2),wid);
+	tmp2->AddLine(new iggWidgetTextLabel("Source",tmp2),wid);
 
-	iggFrame *tmp3 = new ZoomWidgetsFrame(this,tmp2);
-	mIndexHolders[3] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomX(),RenderMode::NoRender,tmp3,0);
-	mIndexHolders[3]->AddDependent(mArea);
-	tmp3->AddLine(new iggWidgetTextArea("Center X",tmp3),mIndexHolders[3]);
-	mIndexHolders[4] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomY(),RenderMode::NoRender,tmp3,0);
-	mIndexHolders[4]->AddDependent(mArea);
-	tmp3->AddLine(new iggWidgetTextArea("Center Y",tmp3),mIndexHolders[4]);
-	mIndexHolders[5] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomFactor(),RenderMode::NoRender,tmp3,0);
-	mIndexHolders[5]->AddDependent(mArea);
-	tmp3->AddLine(new iggWidgetTextArea("Factor",tmp3),mIndexHolders[5]);
-	tmp3->SetColStretch(1,10);
+	mZoomFrame = new ZoomWidgetsFrame(this,tmp2);
+	wid = new iggWidgetPropertyControlFloatSlider(0.0,1.0,20,0,3,false,false,"",iggPropertyHandle("ForegroundWindowZoomX",mSelfHandle,mForegroundWindowHandle),mZoomFrame,RenderMode::DoNotRender);
+	wid->AddDependent(mArea);
+	mZoomFrame->AddLine(new iggWidgetTextLabel("Center X",mZoomFrame),wid);
+	wid = new iggWidgetPropertyControlFloatSlider(0.0,1.0,20,0,3,false,false,"",iggPropertyHandle("ForegroundWindowZoomY",mSelfHandle,mForegroundWindowHandle),mZoomFrame,RenderMode::DoNotRender);
+	wid->AddDependent(mArea);
+	mZoomFrame->AddLine(new iggWidgetTextLabel("Center Y",mZoomFrame),wid);
+	wid = new iggWidgetPropertyControlFloatSlider(0.0,1.0,20,0,3,false,false,"",iggPropertyHandle("ForegroundWindowZoomFactor",mSelfHandle,mForegroundWindowHandle),mZoomFrame,RenderMode::DoNotRender);
+	wid->AddDependent(mArea);
+	mZoomFrame->AddLine(new iggWidgetTextLabel("Factor",mZoomFrame),wid);
+	mZoomFrame->SetColStretch(1,10);
 
-	tmp2->AddLine(tmp3,2);
+	area->AddZoomFrame(mZoomFrame);
 
-	mIndexHolders[6] = new iggWidgetKeyCheckBox("Use 4-line zoom",iImageComposer::KeyForegroundWindowZoom4Line(),tmp2,0);
-	mIndexHolders[6]->AddDependent(mArea);
-	tmp2->AddLine(mIndexHolders[6],2);
+	tmp2->AddLine(mZoomFrame,2);
+
+	wid = new iggWidgetPropertyControlCheckBox("Use 4-line zoom",iggPropertyHandle("ForegroundWindowZoom4Line",mSelfHandle,mForegroundWindowHandle),tmp2);
+	wid->AddDependent(mArea);
+	tmp2->AddLine(wid,2);
 
 	tmp2->SetColStretch(1,10);
 
@@ -1035,35 +1092,30 @@ void iggDialogImageComposer::CompleteConstructionBody()
 	mFrame->SetColStretch(0,10);
 
 	this->ResizeContents(700,500);
+
 }
 
 
-void iggDialogImageComposer::SetCurrentBackgroundWindow(int w)
+void iggDialogImageComposer::SetActiveBackgroundWindow(int w)
 {
 	if(w>=0 && w<this->GetImageComposer()->GetNumTilesX()*this->GetImageComposer()->GetNumTilesY())
 	{
-		mCurrentBackgroundWindow = w;
+		mActiveBackgroundWindow = w;
 	}
-	else mCurrentBackgroundWindow = -1;
+	else mActiveBackgroundWindow = -1;
 	mBackgroundWindowsList->UpdateWidget();
 }
 
 
-void iggDialogImageComposer::SetCurrentForegroundWindow(int w)
+void iggDialogImageComposer::SetActiveForegroundWindow(int w)
 {
-	int i;
-
 	if(w>=0 && w<this->GetImageComposer()->GetNumberOfForegroundWindows())
 	{
-		this->GetImageComposer()->MoveToBack(w);
-		mCurrentForegroundWindow = this->GetImageComposer()->GetNumberOfForegroundWindows() - 1;
-		for(i=0; i<mNumIndexHolders; i++)
-		{
-			mIndexHolders[i]->SetIndex(mCurrentForegroundWindow);
-		}
+		mActiveForegroundWindow = w;
 	}
-	else mCurrentForegroundWindow = -1;
+	else mActiveForegroundWindow = -1;
 	this->UpdateDialog();
+
 }
 
 
@@ -1078,19 +1130,6 @@ void iggDialogImageComposer::UpdateView()
 }
 
 
-void iggDialogImageComposer::UpdateZooms()
-{
-	this->GetImageComposer()->ClearCache();
-	this->GetImageComposer()->UpdateWindowList();
-//	this->UpdateDialog();
-	int i;
-	for(i=3; i<mNumIndexHolders; i++)
-	{
-		mIndexHolders[i]->UpdateWidget();
-	}
-}
-
-
 iggWidget* iggDialogImageComposer::GetArea()
 {
 	this->CompleteConstruction();
@@ -1101,7 +1140,7 @@ iggWidget* iggDialogImageComposer::GetArea()
 
 iImageComposer* iggDialogImageComposer::GetImageComposer() const
 {
-	return this->GetShell()->GetControlModule()->GetImageComposer();
+	return this->GetShell()->GetImageComposer();
 }
 
 #endif
