@@ -33,17 +33,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdialogloadfile.h"
 
 
-#include "icontrolmodule.h"
 #include "idata.h"
 #include "idatareader.h"
 #include "ierror.h"
-#include "ishell.h"
 #include "isystem.h"
 #include "iviewmodule.h"
 
 #include "iggframe.h"
+#include "igghandle.h"
 #include "iggmainwindow.h"
-#include "iggwidgetarea.h"
+#include "iggshell.h"
+#include "iggshelleventobservers.h"
+#include "iggwidgetmisc.h"
 #include "iggwidgetprogressbar.h"
 
 
@@ -89,18 +90,18 @@ iggDialogLoadFile::iggDialogLoadFile(iggMainWindow *parent) : iggDialog(parent,m
 void iggDialogLoadFile::CompleteConstructionBody()
 {
 	mProgressBar = new ProgressBar(mFrame);
-	mLabel = new iggWidgetTextArea("",mFrame);
+	mLabel = new iggWidgetTextLabel("",mFrame);
 
-	mFrame->AddLine(new iggWidgetTextArea("%bLoading file:",mFrame));
+	mFrame->AddLine(new iggWidgetTextLabel("%bLoading file:",mFrame));
 	mFrame->AddLine(mLabel,2);
 	mFrame->AddLine(mProgressBar,2);
 	if(mIsMultiThread)
 	{
-		mFrame->AddLine(new iggWidgetTextArea("You can work with other windows while file is being loaded.",mFrame),2);
+		mFrame->AddLine(new iggWidgetTextLabel("You can work with other windows while file is being loaded.",mFrame),2);
 	}
 	else
 	{
-		mFrame->AddLine(new iggWidgetTextArea("Please wait while file is being loaded.",mFrame),2);
+		mFrame->AddLine(new iggWidgetTextLabel("Please wait while file is being loaded.",mFrame),2);
 	}
 
 	mFrame->SetColStretch(1,10);
@@ -114,45 +115,35 @@ iggDialogLoadFile::~iggDialogLoadFile()
 }
 
 
-void iggDialogLoadFile::LoadData(const iDataInfo &info, const iString &filename, int mod)
+void iggDialogLoadFile::Start()
 {
-	int i;
-
-	if(this->GetShell()->GetControlModule()->GetViewModule(mod)->IsClone()) return;
-
 	if(!mCompleteConstructionCalled) this->CompleteConstruction();
 
-	mLabel->SetText(filename);
+	iRequiredCast<iggExecutionEventObserver>(INFO,this->GetShell()->GetExecutionEventObserver())->SetProgressBar(mProgressBar);
+
 	iggDialog::Show(true);
+	this->GetMainWindow()->BLOCK(true);
 
-	this->GetMainWindow()->Block(true);
-
-	for(i=0; i<info.Count(); i++)
-	{
-		this->GetShell()->GetControlModule()->GetViewModule(mod)->GetReader()->LoadFile(info.Type(i),filename);
-		if(mod==-1 || mod==this->GetShell()->GetControlModule()->GetCurrentViewModuleIndex()) this->GetMainWindow()->AfterLoadData(info.Type(i),filename);
-	}
-
-	this->GetMainWindow()->Block(false);
-	iggDialog::Show(false);
+	mLabel->SetText("...");
 }
 
 
-void iggDialogLoadFile::ReloadData(const iDataInfo &info)
+void iggDialogLoadFile::OnFileStart(const iString &fname, const iDataType &type)
 {
-	int i;
+	mLabel->SetText(fname);
+}
 
-	iggDialog::Show(true);
-	this->GetMainWindow()->Block(true);
 
-	for(i=0; i<info.Count(); i++)
-	{
-		mLabel->SetText(this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLastFileName(info.Type(i)));
-		this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->ReloadData(info.Type(i));
-		this->GetMainWindow()->AfterReloadData(info.Type(i));
-	}
-	
-	this->GetMainWindow()->Block(false);
+void iggDialogLoadFile::OnFileFinish(const iString &fname, const iDataInfo &info)
+{
+}
+
+
+void iggDialogLoadFile::Finish()
+{
+	this->GetMainWindow()->AfterDataChanged();
+
+	this->GetMainWindow()->BLOCK(false);
 	iggDialog::Show(false);
 }
 
