@@ -33,33 +33,50 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdialogpaletteeditor.h"
 
 
-#include "icontrolmodule.h"
 #include "ierror.h"
-#include "iimagefactory.h"
+#include "ihistogram.h"
 #include "ifile.h"
 #include "ipalette.h"
-#include "ipaletteset.h"
+#include "ipalettecollection.h"
 #include "ipiecewisefunction.h"
-#include "ishell.h"
-
 
 #include "iggframepaletteselectionbase.h"
 #include "iggframepiecewisefunctioncontrols.h"
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
+#include "iggshell.h"
 #include "iggwidgetarea.h"
+#include "iggwidgetmisc.h"
 #include "iggwidgetotherbutton.h"
 
 #include "ibgwidgetentrysubject.h"
 
 #include "iggsubjectfactory.h"
 
+//
+//  Templates
+//
+#include "iarray.tlh"
+
 
-using namespace iParameter;
 using namespace iParameter;
 
 
 namespace iggDialogPaletteEditor_Private
 {
+	static const iString temp("temp");
+
+	class Palette : public iPalette
+	{
+
+	public:
+
+		Palette(iShell *shell) : iPalette(0,temp,temp)
+		{
+		}
+	};
+
+
 	//
 	//  Load and save palettes to files
 	//
@@ -86,23 +103,86 @@ namespace iggDialogPaletteEditor_Private
 			iFile f(fn);
 			if(!f.Open(iFile::_Read,iFile::_Text))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to open a palette file.",PopupWindow::Error);
+				this->GetShell()->PopupWindow(mDialog,"Failed to open a palette file.",MessageType::Error);
 				return;
 			}
 
-			iString ws;
-			if(!f.ReadLine(ws) || !iPaletteSet::Default()->UnPackValuePalette(ws,mDialog->GetCurrentPalette()))
-			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Palette file is corrupted.",PopupWindow::Error);
-			}
-			else
-			{
-				mOldFileName = fn;
-				mDialog->Apply(false);
-				mDialog->UpdateDialog();
-			}
-			
+			iString line, ws;
+			while(f.ReadLine(ws)) line += ws + "\n";
 			f.Close();
+
+			if(line.Contains("/Palette/") > 0)
+			{
+				line.Replace("/Palette","");
+				line.Replace("/0,1;","\n");
+				line.Replace("/","\n");
+			}
+
+			if(line.Contains("/Red/0,1;") > 0)
+			{
+				line.Replace("/Red/0,1;","\n");
+				line.Replace("/ Green/0,1;","\n");
+				line.Replace("/ Blue/0,1;","\n");
+				line.Replace("/","\n");
+			}
+
+			ws = line.Section("\n",0,0);
+			mDialog->GetActivePalette()->SetName(ws);
+			line = line.Section("\n",1);
+
+			int j;
+			for(j=0; j<3; j++)
+			{
+				bool ok;
+				int i, n;
+				iPiecewiseFunction *fun = mDialog->GetActivePalette()->GetComponent(j);
+
+				ws = line.Section("\n",j,j);
+				n = ws.Contains(';') + 1;
+				if(n<2 || n>256)
+				{
+					this->GetShell()->PopupWindow(mDialog,"Palette file is corrupted.",MessageType::Error);
+					return;
+				}
+
+				while(fun->N() > 2) fun->RemovePoint(1);
+
+				for(i=0; i<n; i++)
+				{
+					float x, y;
+					iString s;
+
+					s = ws.Section(";",i,i);
+
+					x = s.Section(",",0,0).ToFloat(ok);
+					if(!ok)
+					{
+						this->GetShell()->PopupWindow(mDialog,"Palette file is corrupted.",MessageType::Error);
+						return;
+					}
+
+					y = s.Section(",",1).ToFloat(ok);
+					if(!ok)
+					{
+						this->GetShell()->PopupWindow(mDialog,"Palette file is corrupted.",MessageType::Error);
+						return;
+					}
+
+					if(x<1.0e-5 || x>0.99999)
+					{
+						fun->MovePoint(i,x,y);
+					}
+					else
+					{
+						fun->AddPoint(x,y);
+					}
+				}
+			}
+
+			mOldFileName = fn;
+			mDialog->SetChanged(true);
+			mDialog->GetActivePalette()->Update();
+			mDialog->GetFrame()->UpdateWidget();
 		}
 
 		iString mOldFileName;
@@ -133,15 +213,27 @@ namespace iggDialogPaletteEditor_Private
 			iFile f(fn);
 			if(!f.Open(iFile::_Write,iFile::_Text))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to create a palette file.",PopupWindow::Error);
+				this->GetShell()->PopupWindow(mDialog,"Failed to create a palette file.",MessageType::Error);
 				return;
 			}
 
 			iString ws;
-			iPaletteSet::Default()->PackValuePalette(ws,mDialog->GetCurrentPalette());
+			ws += mDialog->GetActivePalette()->GetName() + "\n";
+			int j;
+			for(j=0; j<3; j++)
+			{
+				int i;
+				iPiecewiseFunction *fun = mDialog->GetActivePalette()->GetComponent(j);
+				for(i=0; i<fun->N(); i++)
+				{
+					if(i > 0) ws += ";";
+					ws += iString::FromNumber(fun->X(i)) + "," + iString::FromNumber(fun->Y(i));
+				}
+				ws += "\n";
+			}
 			if(!f.WriteLine(ws))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to write into a palette file.",PopupWindow::Error);
+				this->GetShell()->PopupWindow(mDialog,"Unable to write into a palette file.",MessageType::Error);
 			}
 			else
 			{
@@ -162,38 +254,33 @@ namespace iggDialogPaletteEditor_Private
 
 	public:
 
-		PaletteSelection(iggDialogPaletteEditor *editor, iggFrame *parent) : iggFramePaletteSelectionBase(false,false,parent)
+		PaletteSelection(iggDialogPaletteEditor *editor, iggFrame *parent) : iggFramePaletteSelectionBase(false,false,false,parent)
 		{
 			mEditor = editor;
 		}
 
-		virtual iPalette* GetCurrentPalette() const
-		{
-			return mEditor->GetCurrentPalette();
-		}
-
 	protected:
 
 		virtual int GetPaletteId() const
 		{
-			return mEditor->GetCurrentPaletteIndex() + 1;
+			return mEditor->GetActivePaletteIndex() + 1;
 		}
 
 		virtual void SetPaletteId(int n)
 		{
-			mEditor->SetCurrentPaletteIndex(n-1);
+			mEditor->SetActivePaletteIndex(n-1);
 		}
 
 		iggDialogPaletteEditor *mEditor;
 	};
 
 
-	class PiecewiseFunctionControls : public iggFramePiecewiseFunctionControls
+	class ColorComponentControls : public iggFramePiecewiseFunctionControls
 	{
 
 	public:
 
-		PiecewiseFunctionControls(int type, iggDialogPaletteEditor *editor, iggFrame *parent): iggFramePiecewiseFunctionControls(false,false,parent)
+		ColorComponentControls(int type, iggDialogPaletteEditor *editor, iggFrame *parent): iggFramePiecewiseFunctionControls(false,false,parent)
 		{
 			mType = type;
 			mEditor = editor;
@@ -201,17 +288,17 @@ namespace iggDialogPaletteEditor_Private
 			this->SetBaloonHelp("Interactively controls palette components. Press Shift+F1 for more help.","Each of the three palette component can be represented as a piecewise function. The piecewise function can be controlled interactively by clicking on a control point and dragging it around with the mouse. Buttons below the interactive area allow you to add or remove a control point and to reset the function to the default one.");
 		}
 
-		virtual const iHistogram* GetHistogram() const
+		virtual const iHistogram& GetHistogram(int, bool) const
 		{
 			//
 			//  No background histogram
 			//
-			return 0;
+			return iHistogram::Null();
 		}
 
 		virtual iPiecewiseFunction* GetFunction()
 		{
-			return mEditor->GetCurrentPalette()->GetComponent(mType);
+			return mEditor->GetActivePalette()->GetComponent(mType);
 		}
 
 		virtual void OnRender()
@@ -224,7 +311,7 @@ namespace iggDialogPaletteEditor_Private
 		virtual void OnChange()
 		{
 			mEditor->SetChanged(true);
-			mEditor->GetCurrentPalette()->Update();
+			mEditor->GetActivePalette()->Update();
 			this->UpdateDependents();
 		}
 
@@ -241,7 +328,7 @@ namespace iggDialogPaletteEditor_Private
 
 	public:
 
-		ApplyButton(iggDialogPaletteEditor *dialog, iggFrame *parent) : iggWidgetSimpleButton("Apply",parent)
+		ApplyButton(iggDialogPaletteEditor *dialog, iggFrame *parent) : iggWidgetSimpleButton("Apply modifications",parent)
 		{
 			mDialog = dialog;
 			this->SetBaloonHelp("Apply the changes","Apply all the changes made to palettes and render all visualization scenes.");
@@ -267,7 +354,7 @@ namespace iggDialogPaletteEditor_Private
 		NameLineEdit(iggDialogPaletteEditor *dialog, iggFrame *parent) : iggWidget(parent)
 		{
 			mDialog = dialog;
-			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,"Name");
+			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,"Palette");
 			this->SetBaloonHelp("Set the name","Change the name of the current palette. The new name may contain white spaces but should not contain symbols '*'.");
 		}
 
@@ -275,19 +362,21 @@ namespace iggDialogPaletteEditor_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			mSubject->SetText(mDialog->GetCurrentPalette()->GetName());
+			mSubject->SetText(mDialog->GetActivePalette()->GetName());
 		}
 
-		virtual void OnString1Body(const iString &s)
+		virtual void OnVoid1Body()
 		{
+			iString s = mSubject->GetText();
+
 			if(s.Find("*") >= 0)
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"A palette name may not contain symbols '*'",PopupWindow::Error);
-				mSubject->SetText(mDialog->GetCurrentPalette()->GetName());
+				this->GetShell()->PopupWindow(mDialog,"A palette name may not contain symbols '*'",MessageType::Error);
+				mSubject->SetText(mDialog->GetActivePalette()->GetName());
 			}
 			else
 			{
-				mDialog->GetCurrentPalette()->SetName(s);
+				mDialog->GetActivePalette()->SetName(s);
 				mDialog->SetChanged(true);
 			}
 		}
@@ -297,6 +386,29 @@ namespace iggDialogPaletteEditor_Private
 	};
 
 
+	class NewPaletteDisplay : public iggFramePaletteViewFrame
+	{
+
+	public:
+
+		NewPaletteDisplay(iggDialogPaletteEditor *dialog, iggFrame *parent) : iggFramePaletteViewFrame("Modified palette",parent)
+		{
+			mDialog = dialog;
+			
+			this->AddLine(new NameLineEdit(dialog,this),2);
+		}
+
+		virtual iPalette* GetActivePalette() const
+		{
+			return mDialog->GetActivePalette();
+		}
+
+	private:
+
+		iggDialogPaletteEditor *mDialog;
+	};
+
+
 	class CreateNewButton : public iggWidgetSimpleButton
 	{
 
@@ -312,14 +424,14 @@ namespace iggDialogPaletteEditor_Private
 
 		virtual void Execute()
 		{
-			mDialog->Apply(true);
-			if(!iPaletteSet::Default()->AddEmptyPalette())
+			mDialog->Apply();
+			if(!iPaletteCollection::Global()->Create.CallAction())
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to create a new palette.\nPerhaps, there is not enough free memory.",PopupWindow::Error);
+				this->GetShell()->PopupWindow(mDialog,"Unable to create a new palette.\nPerhaps, there is not enough free memory.",MessageType::Error);
 			}
 			else
 			{
-				mDialog->SetCurrentPaletteIndex(iPaletteSet::Default()->GetNumberOfPalettes()-1);
+				mDialog->SetActivePaletteIndex(iPaletteCollection::Global()->GetNumber()-1);
 			}
 		}
 
@@ -331,11 +443,13 @@ namespace iggDialogPaletteEditor_Private
 using namespace iggDialogPaletteEditor_Private;
 
 
-iggDialogPaletteEditor::iggDialogPaletteEditor(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("paled.png"),"Palette Editor","sr.gg.de",2)
+iggDialogPaletteEditor::iggDialogPaletteEditor(iggMainWindow *parent) : iggDialog(parent,0U,iggImageFactory::FindIcon("paled.png"),"Palette Editor","sr.gg.dpe",2)
 {
-	mCurrentPalette = new iPalette; IERROR_ASSERT(mCurrentPalette);
-	mCurrentPalette->Copy(iPaletteSet::Default()->GetPalette(0));
-	mCurrentPaletteIndex = 0;
+	this->SetRenderTarget(ViewModuleSelection::All);
+
+	mActivePalette = new Palette(this->GetShell()); IERROR_CHECK_MEMORY(mActivePalette);
+	mActivePalette->CopyState(iPaletteCollection::Global()->GetPalette(0));
+	mActivePaletteIndex = 0;
 
 	if(this->ImmediateConstruction()) this->CompleteConstruction();
 }
@@ -343,58 +457,54 @@ iggDialogPaletteEditor::iggDialogPaletteEditor(iggMainWindow *parent) : iggDialo
 
 void iggDialogPaletteEditor::CompleteConstructionBody()
 {
-	iggFrame *cpb = new iggFrame(mFrame,2);
+	iggFrame *cpb = new iggFrame(mFrame,4);
 	PaletteSelection *ps = new PaletteSelection(this,cpb);
-	cpb->AddLine(ps);
-	cpb->SetColStretch(0,0);
+	NewPaletteDisplay *pd = new NewPaletteDisplay(this,cpb);
+	ps->AddDependent(pd);
+
+	iggFrame *po = new iggFrame("Palette operations",cpb);
+	po->AddLine(new CreateNewButton(this,po));
+	mApplyButton = new ApplyButton(this,po);
+	mApplyButton->Enable(false);
+	po->AddLine(mApplyButton);
+
+	iggFrame *fo = new iggFrame("File operations",cpb);
+	fo->AddLine(new FileLoadButton(this,fo));
+	fo->AddLine(new FileSaveButton(this,fo));
+
+	cpb->AddLine(ps,pd,po,fo);
+	cpb->SetColStretch(0,10);
 	cpb->SetColStretch(1,10);
 
-	iggFrame *f2 = new iggFrame("File operations",mFrame);
-	f2->AddLine(new FileLoadButton(this,f2));
-	f2->AddLine(new FileSaveButton(this,f2));
-
-	mFrame->AddLine(cpb,f2);
+	mFrame->AddLine(cpb);
 
 	iggFrame *spb = new iggFrame("Sculpt Palette",mFrame,3);
-	spb->AddLine(new iggWidgetTextArea("%bRed",spb),new iggWidgetTextArea("%bGreen",spb),new iggWidgetTextArea("%bBlue",spb));
+	spb->AddLine(new iggWidgetTextLabel("%bRed",spb),new iggWidgetTextLabel("%bGreen",spb),new iggWidgetTextLabel("%bBlue",spb));
 
 	iggWidget *pf1, *pf2, *pf3;
-	pf1 = new PiecewiseFunctionControls(0,this,spb);
-	ps->AddBuddy(pf1);
-	pf2 = new PiecewiseFunctionControls(1,this,spb);
-	ps->AddBuddy(pf2);
-	pf3 = new PiecewiseFunctionControls(2,this,spb);
-	ps->AddBuddy(pf3);
+	pf1 = new ColorComponentControls(0,this,spb);
+	ps->AddDependent(pf1);
+	pf1->AddDependent(pd);
+	pf2 = new ColorComponentControls(1,this,spb);
+	ps->AddDependent(pf2);
+	pf2->AddDependent(pd);
+	pf3 = new ColorComponentControls(2,this,spb);
+	ps->AddDependent(pf3);
+	pf3->AddDependent(pd);
 	spb->AddLine(pf1,pf2,pf3);
 
 	spb->SetRowStretch(0,0);
 	spb->SetRowStretch(1,10);
 
-	iggFrame *po = new iggFrame("Palette operations",mFrame);
-
-	pf1 = new NameLineEdit(this,po);
-	ps->AddDependent(pf1);
-	po->AddLine(pf1);
-	pf2 = new CreateNewButton(this,po);
-	po->AddLine(pf2);
-
-	po->AddSpace(10);
-
-	mApplyButton = new ApplyButton(this,po);
-	mApplyButton->Enable(false);
-	po->AddLine(mApplyButton);
-
-	mFrame->AddLine(spb,po);
+	mFrame->AddLine(spb);
 	mFrame->SetColStretch(0,10);
 	mFrame->SetColStretch(1,0);
-	mFrame->SetRowStretch(0,0);
-	mFrame->SetRowStretch(1,10);
 }
 
 
 iggDialogPaletteEditor::~iggDialogPaletteEditor()
 {
-	if(mCurrentPalette != 0) delete mCurrentPalette;
+	if(mActivePalette != 0) mActivePalette->Delete();
 }
 
 
@@ -412,14 +522,14 @@ void iggDialogPaletteEditor::SetChanged(bool s)
 }
 
 
-void iggDialogPaletteEditor::SetCurrentPaletteIndex(int n)
+void iggDialogPaletteEditor::SetActivePaletteIndex(int n)
 {
-	if(n>=0 && n<iPaletteSet::Default()->GetNumberOfPalettes())
+	if(n>=0 && n<iPaletteCollection::Global()->GetNumber())
 	{
 		this->CompleteConstruction();
-		if(mApplyButton->IsEnabled()) this->Apply(true);
-		mCurrentPalette->Copy(iPaletteSet::Default()->GetPalette(n));
-		mCurrentPaletteIndex = n;
+		if(mApplyButton->IsEnabled()) this->Apply();
+		mActivePalette->CopyState(iPaletteCollection::Global()->GetPalette(n));
+		mActivePaletteIndex = n;
 		this->UpdateDialog();
 	}
 }
@@ -428,19 +538,19 @@ void iggDialogPaletteEditor::SetCurrentPaletteIndex(int n)
 void iggDialogPaletteEditor::Apply(bool ask)
 {
 	this->CompleteConstruction();
-	if(mApplyButton->IsEnabled() && (!ask || this->GetMainWindow()->AskForConfirmation("Do you want to apply changes?","Apply")))
+	if(mApplyButton->IsEnabled() && (!ask || this->GetShell()->PopupWindow(this,"Do you want to apply changes?",MessageType::Information,"Apply","Cancel")==0))
 	{
-		iPaletteSet::Default()->GetPalette(mCurrentPaletteIndex)->Copy(mCurrentPalette);
+		iPaletteCollection::Global()->GetPalette(mActivePaletteIndex)->CopyState(mActivePalette);
 		iggFramePaletteSelectionBase::UpdateAll();
-		this->GetShell()->GetControlModule()->Render(RenderOption::All);
-		mApplyButton->Enable(false);
+		this->Render();
 	}
+	mApplyButton->Enable(false);
 }
 
 
 bool iggDialogPaletteEditor::CanBeClosed()
 {
-	this->Apply(true);
+	this->Apply();
 	return true;
 }
 
