@@ -34,15 +34,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ibuffer.h"
-#include "icontrolmodule.h"
 #include "ierror.h"
-#include "iimagefactory.h"
 #include "imath.h"
 #include "iparallelmanager.h"
-#include "ishell.h"
 
 #include "iggframe.h"
+#include "iggframedisplay.h"
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
+#include "iggshell.h"
 #include "iggwidgetarea.h"
 #include "iggwidgetmisc.h"
 
@@ -54,7 +54,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "ibuffertemplate.h"
+#include "ibuffer.tlh"
 
 
 namespace iggDialogParallelController_Private
@@ -77,14 +77,14 @@ namespace iggDialogParallelController_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			iParallelManager *p = this->GetShell()->GetControlModule()->GetParallelManager();
+			iParallelManager *p = this->GetShell()->GetParallelManager();
 			mSubject->SetRange(p->GetMinNumberOfProcessors(),p->GetMaxNumberOfProcessors());
 			mSubject->SetValue(p->GetNumberOfProcessors());
 		}
 
 		virtual void OnInt1Body(int n)
 		{
-			this->GetShell()->GetControlModule()->GetParallelManager()->SetNumberOfProcessors(n);
+			this->GetShell()->GetParallelManager()->SetNumberOfProcessors(n);
 		}
 
 		ibgWidgetSpinBoxSubject *mSubject;
@@ -98,7 +98,7 @@ namespace iggDialogParallelController_Private
 
 	public:
 
-		PerformanceDisplay(iggWidgetNumberDisplay *wc, iggWidgetNumberDisplay *li, iggWidgetNumberDisplay *st, iggWidgetNumberDisplay *sf, iggWidgetNumberDisplay *ft, iggWidgetNumberDisplay *ff, iggFrame *parent) : iggWidgetDrawArea(parent,false)
+		PerformanceDisplay(iggFrameNumberDisplay *wc, iggFrameNumberDisplay *li, iggFrameNumberDisplay *st, iggFrameNumberDisplay *sf, iggFrameNumberDisplay *ft, iggFrameNumberDisplay *ff, iggFrame *parent) : iggWidgetDrawArea(parent,false)
 		{
 			mWallClockTimeDisplay = wc;
 			mLoadImbalanceDisplay = li;
@@ -124,12 +124,12 @@ namespace iggDialogParallelController_Private
 			//
 			//  Cache for speed
 			//
-			iParallelManager *man = this->GetShell()->GetControlModule()->GetParallelManager();
+			iParallelManager *man = this->GetShell()->GetParallelManager();
 			n = man->GetNumberOfProcessors();
 			double tWall = man->GetWallClockExecutionTime();
 			for(i=0; i<n; i++) t[i] = man->GetProcessorExecutionTime(i);
 
-			mWallClockTimeDisplay->Display(tWall,1);
+			mWallClockTimeDisplay->Display(tWall,"%.1lg");
 
 			double tMax, tMin, imb = 0.0;
 			tMax = tMin = t[0];
@@ -142,15 +142,15 @@ namespace iggDialogParallelController_Private
 			}
 
 			if(tWall > 0.0) imb = 1.0 - imb/(n*tWall); else imb = 0.0;
-			mLoadImbalanceDisplay->Display(round(100.0*imb));
+			mLoadImbalanceDisplay->Display(iMath::Round2Int(100.0*imb));
 
 			if(iMin == iMax) iMin = iMax = -1;
 
-			mFastTimeDisplay->Display(tMin,1);
-			mFastFracDisplay->Display(round(100.0*tMin/tWall));
+			mFastTimeDisplay->Display(tMin,"%.1lg");
+			mFastFracDisplay->Display(iMath::Round2Int(100.0*tMin/tWall));
 
-			mSlowTimeDisplay->Display(tMax,1);
-			mSlowFracDisplay->Display(round(100.0*tMax/tWall));
+			mSlowTimeDisplay->Display(tMax,"%.1lg");
+			mSlowFracDisplay->Display(iMath::Round2Int(100.0*tMax/tWall));
 
 			int w = mSubject->Width();
 			int h = mSubject->Height();
@@ -159,8 +159,8 @@ namespace iggDialogParallelController_Private
 
 			for(i=0; i<n; i++)
 			{
-				k1 = round((w*(i+0.2))/n);
-				k2 = round((w*(i+0.8))/n);
+				k1 = iMath::Round2Int((w*(i+0.2))/n);
+				k2 = iMath::Round2Int((w*(i+0.8))/n);
 				if(i == iMin)
 				{
 					c = iColor(0,255,0);
@@ -173,14 +173,14 @@ namespace iggDialogParallelController_Private
 				{
 					c = iColor(0,0,255);
 				}
-				j = round(h*t[i]/tWall);
+				j = iMath::Round2Int(h*t[i]/tWall);
 				mSubject->DrawRectangle(k1,0,k2,j,c,c);
 			}
 		}
 
-		iggWidgetNumberDisplay *mWallClockTimeDisplay, *mLoadImbalanceDisplay;
-		iggWidgetNumberDisplay *mSlowTimeDisplay, *mSlowFracDisplay;
-		iggWidgetNumberDisplay *mFastTimeDisplay, *mFastFracDisplay;
+		iggFrameNumberDisplay *mWallClockTimeDisplay, *mLoadImbalanceDisplay;
+		iggFrameNumberDisplay *mSlowTimeDisplay, *mSlowFracDisplay;
+		iggFrameNumberDisplay *mFastTimeDisplay, *mFastFracDisplay;
 	};
 };
 
@@ -188,7 +188,7 @@ namespace iggDialogParallelController_Private
 using namespace iggDialogParallelController_Private;
 
 
-iggDialogParallelController::iggDialogParallelController(iggMainWindow *mw) : iggDialog(mw,0U,iImageFactory::FindIcon("parallel.png"),"Parallel Controller","sr.gg.dp",3)
+iggDialogParallelController::iggDialogParallelController(iggMainWindow *mw) : iggDialog(mw,0U,iggImageFactory::FindIcon("parallel.png"),"Parallel Controller","sr.gg.dpc",3)
 {
 	if(this->ImmediateConstruction()) this->CompleteConstruction();
 }
@@ -202,17 +202,17 @@ void iggDialogParallelController::CompleteConstructionBody()
 	q->SetColStretch(1,10);
 	
 	iggFrame *b1 = new iggFrame("",mFrame,4);
-	iggWidgetNumberDisplay *wc = new iggWidgetNumberDisplay("",b1);
-    iggWidgetNumberDisplay *ib = new iggWidgetNumberDisplay("sec;    Load imbalance",b1);
-	b1->AddLine(new iggWidgetTextArea("Wall clock time",b1),wc,ib,new iggWidgetTextArea("%",b1));
+	iggFrameNumberDisplay *wc = new iggFrameNumberDisplay("",b1);
+    iggFrameNumberDisplay *ib = new iggFrameNumberDisplay("sec;    Load imbalance",b1);
+	b1->AddLine(new iggWidgetTextLabel("Wall clock time",b1),wc,ib,new iggWidgetTextLabel("%",b1));
 
 	iggFrame *b2 = new iggFrame("",mFrame,4);
-	iggWidgetNumberDisplay *st = new iggWidgetNumberDisplay("",b2);
-	iggWidgetNumberDisplay *sf = new iggWidgetNumberDisplay("sec;   ",b2);
-	b2->AddLine(new iggWidgetTextArea("Slowest processor",b2),st,sf,new iggWidgetTextArea("% wall clock time",b2));
-	iggWidgetNumberDisplay *ft = new iggWidgetNumberDisplay("",b2);
-	iggWidgetNumberDisplay *ff = new iggWidgetNumberDisplay("sec;   ",b2);
-	b2->AddLine(new iggWidgetTextArea("Fastest processor",b2),ft,ff,new iggWidgetTextArea("% wall clock time",b2));
+	iggFrameNumberDisplay *st = new iggFrameNumberDisplay("",b2);
+	iggFrameNumberDisplay *sf = new iggFrameNumberDisplay("sec;   ",b2);
+	b2->AddLine(new iggWidgetTextLabel("Slowest processor",b2),st,sf,new iggWidgetTextLabel("% wall clock time",b2));
+	iggFrameNumberDisplay *ft = new iggFrameNumberDisplay("",b2);
+	iggFrameNumberDisplay *ff = new iggFrameNumberDisplay("sec;   ",b2);
+	b2->AddLine(new iggWidgetTextLabel("Fastest processor",b2),ft,ff,new iggWidgetTextLabel("% wall clock time",b2));
 
 	mDisplay = new PerformanceDisplay(wc,ib,st,sf,ft,ff,mFrame);
 
@@ -230,6 +230,7 @@ void iggDialogParallelController::CompleteConstructionBody()
 
 void iggDialogParallelController::UpdateDisplay()
 {
+	this->CompleteConstruction();
 	iDynamicCast<PerformanceDisplay,iggWidget>(INFO,mDisplay)->UpdateWidget();
 }
 
