@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -41,6 +41,10 @@ public:
 	iggDialogPerformanceMeter(iggMainWindow *parent);
 
 	virtual const iString& GetToolTip() const;
+
+protected:
+
+	virtual void CompleteConstructionBody();
 };
 
 #endif  //  IGGDIALOGPERFORMANCEMETER_H
