@@ -34,10 +34,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
-#include "iimagefactory.h"
 #include "imath.h"
 
 #include "iggframe.h"
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
 #include "iggrenderwindow.h"
 #include "iggwidgetarea.h"
@@ -88,7 +88,7 @@ iggDialogRenderingProgress::iggDialogRenderingProgress(iggMainWindow *parent) :
 
 	mCancelled = true;
 	mPreviousTime = 0.0;
-	mTimer = vtkTimerLog::New(); IERROR_ASSERT(mTimer);
+	mTimer = vtkTimerLog::New(); IERROR_CHECK_MEMORY(mTimer);
 
 	if(this->ImmediateConstruction()) this->CompleteConstruction();
 }
@@ -98,11 +98,11 @@ void iggDialogRenderingProgress::CompleteConstructionBody()
 {
 	iggFrame*tmp;
 
-	mFrame->AddLine(new iggWidgetTextArea("%bRendering the scene...",mFrame));
+	mFrame->AddLine(new iggWidgetTextLabel("%bRendering the scene...",mFrame));
 	
 	tmp = new iggFrame(mFrame,3);
-	mElapsedTime = new iggWidgetTextArea("0",tmp);
-	tmp->AddLine(new iggWidgetTextArea("Time elapsed: ",tmp),mElapsedTime,new iggWidgetTextArea(" seconds",tmp));
+	mElapsedTime = new iggWidgetTextLabel("0",tmp);
+	tmp->AddLine(new iggWidgetTextLabel("Time elapsed: ",tmp),mElapsedTime,new iggWidgetTextLabel(" seconds",tmp));
 	mFrame->AddLine(tmp);
 
 	tmp = new iggFrame(mFrame,3);
@@ -115,7 +115,7 @@ void iggDialogRenderingProgress::CompleteConstructionBody()
 	mFrame->AddLine(mButtonFrame);
 
 	mRemarkFrame = new iggFrame(mFrame);
-	mRemarkFrame->AddLine(new iggWidgetTextArea("Interrupting all processes...",mRemarkFrame));
+	mRemarkFrame->AddLine(new iggWidgetTextLabel("Interrupting all processes...",mRemarkFrame));
 	mFrame->AddLine(mRemarkFrame);
 }
 	
@@ -155,7 +155,7 @@ void iggDialogRenderingProgress::KeepWorking()
 	{
 		if(mBlockParent && !mIsParentBlocked)
 		{
-			mMainWindow->Block(true);
+			mMainWindow->BLOCK(true);
 			mIsParentBlocked = true;
 		}
 	}
@@ -187,7 +187,7 @@ void iggDialogRenderingProgress::Finish()
 	this->Show(false);
 	if(mBlockParent && mIsParentBlocked)
 	{
-		mMainWindow->Block(false);
+		mMainWindow->BLOCK(false);
 		mIsParentBlocked = false;
 	}
 }
