@@ -36,7 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class vtkTimerLog;
 
 class iggWidgetBase;
-class iggWidgetTextArea;
+class iggWidgetTextLabel;
 class iggWidgetLogoFlipper;
 
 
@@ -64,7 +64,7 @@ protected:
 	double mPreviousTime;
 	vtkTimerLog *mTimer;
 	iggWidgetLogoFlipper *mFlipper;
-	iggWidgetTextArea *mElapsedTime;
+	iggWidgetTextLabel *mElapsedTime;
 	iggFrame *mButtonFrame, *mRemarkFrame;
 };
 
