@@ -33,7 +33,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggelement.h"
 
 
-#include "ishell.h"
+#include "ierror.h"
+
+#include "iggshell.h"
 
 
 int iggElement::mIdCounter = 0;
@@ -42,10 +44,19 @@ int iggElement::mIdCounter = 0;
 //
 //  Main class
 //
-iggElement::iggElement(iShell *shell) : mShell(shell)
+iggElement::iggElement(iggShell *shell) : iShellComponent(shell)
 {
+	mTrueShell = shell;
+
 	mId = mIdCounter++;
-	if(mShell != 0) mShell->OnInitAtom();
+	if(this->GetShell() != 0) this->GetShell()->OnInitAtom();
+
+#ifdef I_DEBUG
+	if(mId==1128)
+	{
+		int o = 0;
+	}
+#endif
 }
 
 
