@@ -34,9 +34,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IGGELEMENT_H
 
 
-#include "ipointermacro.h"
+#include "ishellcomponent.h"
 
-class iShell;
+
+class iggShell;
 
 
 namespace iParameter
@@ -69,26 +70,28 @@ namespace iParameter
 };
 
 
-class iggElement
+class iggElement : public iShellComponent
 {
 
-	IPOINTER_AS_PART(Shell);
-
 public:
 
 	virtual ~iggElement();
 
 	int GetId() const { return mId; }
 
+	inline iggShell* GetShell() const { return mTrueShell; } // to avoid extra casting
+
 protected:
 
-	iggElement(iShell *shell);
+	iggElement(iggShell *shell);
 
 private:
 
 	int mId;
 	static int mIdCounter;
 
+	iggShell *mTrueShell;
+
 	iggElement(const iggElement&);		// Not implemented.
 	void operator=(const iggElement&);	// Not implemented.
 };
