@@ -35,11 +35,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "idata.h"
 #include "ierror.h"
-#include "iimagefactory.h"
 
 #include "iggabstractextension.h"
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
-#include "iggwidgetarea.h"
+#include "iggshell.h"
+#include "iggwidgetmisc.h"
 #include "iggwidgetotherbutton.h"
 
 #include "ibgextensionwindowsubject.h"
@@ -55,7 +56,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -104,7 +105,7 @@ private:
 
 	int mIndex;
 	ibgWindowHelper *mWindow;
-	iSearchableArray<iggWidget*> mWidgets;
+	iLookupArray<iggWidget*> mWidgets;
 };
 
 
@@ -118,7 +119,7 @@ namespace iggExtensionWindow_Private
 		RotateButton(iggExtensionWindowHelper *helper, iggFrame *parent) : iggWidgetSimpleButton("",parent,true)
 		{
 			mHelper = helper;
-			mSubject->SetIcon(*iImageFactory::FindIcon("cycle.png"));
+			mSubject->SetIcon(*iggImageFactory::FindIcon("cycle.png"));
 			this->SetBaloonHelp("Try out a different window layout");
 		}
 
@@ -163,7 +164,7 @@ namespace iggExtensionWindow_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			this->OpenPage(mPanel->GetCurrentLayer());
+			this->OpenPage(mPanel->GetActiveLayer());
 		}
 
 	private:
@@ -177,7 +178,7 @@ namespace iggExtensionWindow_Private
 
 	public:
 
-		SelectionControlButton(int index, iggWidgetTextArea *title, iggAbstractExtension *ext, iggFrameFlip *panel, iggFrame *parent) : iggWidget(parent), mIndex(index), mPanel(panel)
+		SelectionControlButton(int index, iggWidgetTextLabel *title, iggAbstractExtension *ext, iggFrameFlip *panel, iggFrame *parent) : iggWidget(parent), mIndex(index), mPanel(panel)
 		{
 			mTitle = title;
 			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::ToggleButton,"",1);
@@ -197,7 +198,7 @@ namespace iggExtensionWindow_Private
 		{
 			static const iColor c(246,144,0);
 
-			if(mIndex == mPanel->GetCurrentLayer())
+			if(mIndex == mPanel->GetActiveLayer())
 			{
 				mTitle->GetHelper()->SetBackgroundColor(c);
 				mSubject->SetDown(true);
@@ -213,7 +214,7 @@ namespace iggExtensionWindow_Private
 
 		const int mIndex;
 		iggFrameFlip *mPanel;
-		iggWidgetTextArea *mTitle;
+		iggWidgetTextLabel *mTitle;
 		ibgWidgetButtonSubject *mSubject;
 	};
 
@@ -250,7 +251,7 @@ namespace iggExtensionWindow_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			mSubject->SetValue(mPanel->GetCurrentLayer());
+			mSubject->SetValue(mPanel->GetActiveLayer());
 		}
 
 	private:
@@ -292,7 +293,7 @@ namespace iggExtensionWindow_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			mSubject->SetValue(mPanel->GetCurrentLayer());
+			mSubject->SetValue(mPanel->GetActiveLayer());
 		}
 
 	private:
@@ -317,8 +318,8 @@ namespace iggExtensionWindow_Private
 
 		void AddExtension(iggAbstractExtension *ext)
 		{
-			iggWidgetTextArea *t = new iggWidgetTextArea(" "+ext->GetTitle(),this);
-			t->AlignLeft(true);
+			iggWidgetTextLabel *t = new iggWidgetTextLabel(" "+ext->GetTitle(),this);
+			t->SetAlignment(-1);
 			this->AddLine(new SelectionControlButton(mIndex++,t,ext,mPanel,this),t);
 		}
 
@@ -336,8 +337,8 @@ namespace iggExtensionWindow_Private
 
 		LeftPanel(iggExtensionWindowHelper *helper, iggFrameFlip *panel) : iggFrame(panel->GetShell(),2)
 		{
-			mTitle = new iggWidgetTextArea("%b%+Select extension",this);
-			mTitle->AlignLeft(true);
+			mTitle = new iggWidgetTextLabel("%b%+Select extension",this);
+			mTitle->SetAlignment(-1);
 			mComboBox = new SelectionControlComboBox(panel,this);
 			mRadioBox = new SelectionControlRadioBox(panel,this);
 			mEntryBox = new SelectionControlEntryBox(panel,this);
@@ -381,7 +382,7 @@ namespace iggExtensionWindow_Private
 
 	private:
 
-		iggWidgetTextArea *mTitle;
+		iggWidgetTextLabel *mTitle;
 		iggExtensionWindowHelper *mHelper;
 		SelectionControlComboBox *mComboBox;
 		SelectionControlRadioBox *mRadioBox;
@@ -423,19 +424,20 @@ void iggExtensionWindow::AttachCreator(iggExtensionCreator *c)
 
 iggExtensionWindow::iggExtensionWindow(iggMainWindow *mw) : iggElement(mw?mw->GetShell():0)
 {
-	mMainWindow = mw; IERROR_ASSERT(mw);
+	IASSERT(mw);
+	mMainWindow = mw; 
 
 	//
 	//  Create subject
 	//
 	mSubject = iggSubjectFactory::CreateExtensionWindowSubject(this);
-	mFrames[0] = new iggFrame(this->GetShell()); IERROR_ASSERT(mFrames[0]);
+	mFrames[0] = new iggFrame(this->GetShell()); IERROR_CHECK_MEMORY(mFrames[0]);
 	mFrames[0]->SetPadding(false);
 
-	mMainPanel = new iggFrameFlip(mFrames[0]); IERROR_ASSERT(mMainPanel);
+	mMainPanel = new iggFrameFlip(mFrames[0]); IERROR_CHECK_MEMORY(mMainPanel);
 	mFrames[0]->AddLine(mMainPanel);
 
-	mHelper = new iggExtensionWindowHelper(mSubject->GetHelper()); IERROR_ASSERT(mHelper);
+	mHelper = new iggExtensionWindowHelper(mSubject->GetHelper()); IERROR_CHECK_MEMORY(mHelper);
 }
 
 
@@ -531,20 +533,6 @@ void iggExtensionWindow::SetPadding(bool s)
 }
 
 
-//
-//  Decorator methods
-//
-bool iggExtensionWindow::LogDataInfo(const iDataType &type, bool details)
-{
-	int i;
-	for(i=0; i<mExt.Size(); i++)
-	{
-		if(mExt[i]->LogDataInfo(type,details)) return true;
-	}
-	return false;
-}
-
-
 void iggExtensionWindow::OpenBookPageByIndex(int index)
 {
 	int i;
@@ -652,7 +640,7 @@ const iImage* iggExtensionWindow::GetSpecialParticleIcon(const iDataType &type)
 
 void iggExtensionWindow::OnCloseAttempt()
 {
-	this->GetMainWindow()->PopupWindow(mFrames[0],"Extension Window can not be closed. If it is on the way, it can be minimized.");
+	this->GetShell()->PopupWindow(this,"Extension Window can not be closed. If it is on the way, it can be minimized.",MessageType::Warning);
 }
 
 
