@@ -41,6 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iDataType;
 class iImage;
 class iShell;
+class iString;
 
 class iggAbstractExtension;
 class iggExtensionCreator;
@@ -68,7 +69,6 @@ public:
 	//
 	//  Broadcast to all extensions
 	//
-	bool LogDataInfo(const iDataType &type, bool details);
 	void OpenBookPageByIndex(int index);
 	void SetTabMode(int m);
 
