@@ -50,6 +50,7 @@ class ibgFrameSubject;
 class ibgFrameBookSubject;
 class ibgFrameFlipSubject;
 class ibgFrameScrollSubject;
+class ibgFrameSplitSubject;
 class ibgFrameHelper;
 
 
@@ -93,7 +94,7 @@ public:
 protected:
 
 	iggFrameBase(iggFrameBase *parent);
-	iggFrameBase(iShell *shell);
+	iggFrameBase(iggShell *shell);
 
 	virtual void UpdateWidgetBody();
 	//
@@ -107,13 +108,12 @@ protected:
 	virtual void OnVoid2Body();
 	virtual void OnVoid3Body();
 	virtual void OnBool1Body(bool);
-	virtual void OnString1Body(const iString &);
 
 	void OnChildFlipped();
 
 	bool mNeedsUpdate;
-	iPointerArray<iggWidget> mChildren;
-	iPointerArray<iggRenderWindowObserver> mRenderWindowObservers;
+	iLookupArray<iggWidget*> mChildren;
+	iLookupArray<iggRenderWindowObserver*> mRenderWindowObservers;
 
 private:
 
@@ -134,7 +134,7 @@ public:
 
 	iggFrame(const iString& title, iggFrameBase *parent, int cols = 1);
 	iggFrame(iggFrameBase *parent, int cols = 1);
-	iggFrame(iShell *shell, int cols = 1, bool withsubject = true);
+	iggFrame(iggShell *shell, int cols = 1, bool withsubject = true);
 
 	inline ibgFrameSubject* GetSubject() const { return mSubject; }
 
@@ -144,7 +144,7 @@ public:
 
 	void AddLine(iggWidget *child1, iggWidget *child2 = 0, iggWidget *child3 = 0, iggWidget *child4 = 0, iggWidget *child5 = 0, iggWidget *child6 = 0, iggWidget *child7 = 0);
 	void AddLine(iggWidget *child1, int nc1, iggWidget *child2 = 0, int nc2 = 1, iggWidget *child3 = 0, int nc3 = 1, iggWidget *child4 = 0, int nc4 = 1, iggWidget *child5 = 0, int nc5 = 1, iggWidget *child6 = 0, int nc6 = 1, iggWidget *child7 = 0, int nc7 = 1);
-	void AddSpace(int stretch);
+	void AddSpace(int space);
 
 	virtual void GetFrameGeometry(int wg[4]) const;
 
@@ -250,7 +250,7 @@ public:
 
 	int Count() const;
 
-	inline int GetCurrentLayer() const { return mCurrentLayer; }
+	inline int GetActiveLayer() const { return mActiveLayer; }
 	void ShowLayer(int i);
 	void AddLayer(iggFrame *layer);
 
@@ -260,7 +260,7 @@ public:
 
 protected:
 
-	int mCurrentLayer;
+	int mActiveLayer;
 	iArray<iggFrame*> mLayers;
 	ibgFrameFlipSubject *mSubject;
 };
@@ -286,5 +286,26 @@ protected:
 	ibgFrameScrollSubject *mSubject;
 };
 
+
+//
+//  A frame that splits into several adjustable-size segments
+//
+class iggFrameSplit : public iggFrameBase
+{
+
+public:
+
+	iggFrameSplit(iggFrameBase *parent, bool hor);
+
+	void AddSegment(iggFrame *frame);
+
+	virtual void FlipThroughAllChildren();
+
+protected:
+
+	iArray<iggFrame*> mSegments;
+	ibgFrameSplitSubject *mSubject;
+};
+
 #endif  // IGGFRAME_H
 
