@@ -36,13 +36,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "iviewmodule.h"
 
-#include "iggwidgetkeybutton.h"
-#include "iggwidgetkeylineedit.h"
+#include "igghandle.h"
+#include "iggshell.h"
+#include "iggwidgetmisc.h"
+#include "iggwidgetpropertycontrolbutton.h"
+#include "iggwidgetpropertycontrollineedit.h"
+
+#include "ibgwidgetbuttonsubject.h"
 
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -51,12 +56,12 @@ using namespace iParameter;
 namespace iggFrameBoxSize_Private
 {
 	
-	class LineEdit : public iggWidgetKeyFloatLineEdit
+	class LineEdit : public iggWidgetPropertyControlFloatLineEdit
 	{
 		
 	public:
 		
-		LineEdit(iggWidgetKeyCheckBox *cb, const iString &label, const iObjectKey &key, iggFrameBoxSize *parent) : iggWidgetKeyFloatLineEdit(label,key,RenderMode::UseGlobal,parent)
+		LineEdit(iggWidgetSimpleCheckBox *cb, const iString &label, const iggPropertyHandle &ph, iggFrameBoxSize *parent) : iggWidgetPropertyControlFloatLineEdit(label,ph,parent)
 		{
 			mRealParent = parent;
 			mCheckBox = cb;
@@ -66,62 +71,60 @@ namespace iggFrameBoxSize_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			bool val;
-			mCheckBox->QueryValue(val);
-			if(val)
+			if(mCheckBox->IsChecked())
 			{
 				this->Enable(false);
 			}
 			else
 			{
-				this->iggWidgetKeyFloatLineEdit::UpdateWidgetBody();
+				this->Enable(true);
+				this->iggWidgetPropertyControlFloatLineEdit::UpdateWidgetBody();
 			}
 		}
 
 		virtual void OnVoid1Body()
 		{
-			iggWidgetKeyFloatLineEdit::OnVoid1Body();
+			iggWidgetPropertyControlFloatLineEdit::OnVoid1Body();
 			if(mRealParent != 0)
 			{
 				mRealParent->UpdatePositions();
 			}
 		}
 
-		virtual void OnString1Body(const iString &s)
-		{
-			iggWidgetKeyFloatLineEdit::OnString1Body(s);
-			if(mRealParent!=0 && this->GetRenderMode()==RenderMode::Immediate)
-			{
-				mRealParent->UpdatePositions();
-			}
-		}
-
 	private:
 
 		iggFrameBoxSize *mRealParent;
-		iggWidgetKeyCheckBox *mCheckBox;
+		iggWidgetSimpleCheckBox *mCheckBox;
 	};
 	
 
-	class CheckBox : public iggWidgetKeyCheckBox
+	class CheckBox : public iggWidgetSimpleCheckBox
 	{
 		
 	public:
 		
-		CheckBox(const char* text, const iObjectKey &key, iggFrameBoxSize *parent) : iggWidgetKeyCheckBox(text,key,parent)
+		CheckBox(const char* text, iggFrameBoxSize *parent) : iggWidgetSimpleCheckBox(text,parent)
 		{
 			mRealParent = parent;
+
+			this->SetBaloonHelp("Specify whether to use OpenGL coordinates (box axes go from -1 to 1) or to set the size of the box (axes go from 0 to box size)");
 		}
 
 	protected:
 
-		virtual void OnVoid1Body()
+		virtual void UpdateWidgetBody()
 		{
-			iggWidgetKeyCheckBox::OnVoid1Body();
+			mSubject->SetDown(this->GetShell()->GetViewModule()->InOpenGLCoordinates());
+		}
+
+		virtual void OnChecked(bool s)
+		{
+			this->GetShell()->GetViewModule()->SetBoxSize(s?0.0:1.0);
 			if(mRealParent != 0)
 			{
 				mRealParent->UpdatePositions();
 			}
+			this->Render();
 		}
 
 	private:
@@ -136,8 +139,8 @@ using namespace iggFrameBoxSize_Private;
 
 iggFrameBoxSize::iggFrameBoxSize(iggFrame *parent) : iggFrame("Coordinates",parent,1)
 {
-	CheckBox *cb = new CheckBox("Use OpenGL coordinates",iViewModule::KeyOpenGLCoordinates(),this);
-	LineEdit *le = new LineEdit(cb,"Box size",iViewModule::KeyBoxSize(),this);
+	CheckBox *cb = new CheckBox("Use OpenGL coordinates",this);
+	LineEdit *le = new LineEdit(cb,"Box size",iggPropertyHandle("BoxSize",this->GetShell()->GetViewModuleHandle()),this);
 	cb->AddDependent(le);
 
 	this->AddLine(cb);
@@ -148,7 +151,7 @@ iggFrameBoxSize::iggFrameBoxSize(iggFrame *parent) : iggFrame("Coordinates",pare
 void iggFrameBoxSize::UpdatePositions()
 {
 	int i;
-	iPointerArray<iggWidgetKeyHandlerBase> &list = iggWidgetKeyHandlerBase::PositionList();
+	iLookupArray<iggWidgetPropertyControlBase*> &list(iggWidgetPropertyControlBase::PositionList());
 
 	for(i=0; i<list.Size(); i++)
 	{
