@@ -37,9 +37,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 class iDataInfo;
-class iObjectKey;
+class iDataType;
 
-class iggDataTypeProvider;
+class iggDataTypeHandle;
 
 
 namespace iParameter
@@ -61,30 +61,24 @@ class iggFrameDataTypeSelector : public iggFrame
 
 public:
 
-	iggFrameDataTypeSelector(iggDataTypeProvider *provider, bool withapply, const iString &title, iggFrameBase *parent, int mode = iParameter::ListDataTypes::All);
+	iggFrameDataTypeSelector(iggDataTypeHandle *handle, const iString &title, iggFrameBase *parent, int mode = iParameter::ListDataTypes::All);
 	virtual ~iggFrameDataTypeSelector();
 
 	inline int GetMode() const { return mMode; }
 	void SetMode(int m);
 
-	const iDataInfo* GetDataInfo();
-
-	bool IsModified() const;
-	void SetCurrentDataTypeIndex(int v);
-	inline int GetCurrentDataTypeIndex() const { return mCurrentDataTypeIndex; }
-
-	void Apply();
+	const iDataInfo& GetListedInfo() const;
+	iggDataTypeHandle* GetHandle() const { return mHandle; }
 
 protected:
 
-	void UpdateProvider();
 	virtual void UpdateWidgetBody();
 
-	iDataInfo *mInfoPointer;
-	bool mAutoApplying;
-	int mMode, mCurrentDataTypeIndex;
-	iggDataTypeProvider *mProvider;
+	int mMode;
+	bool mAutoPilot;
 	iggFrame *mBase;
+	iggDataTypeHandle *mHandle;
+	mutable iDataInfo *mListedInfo;
 };
 
 #endif  // IGGFRAMEDATACHANNEL_H
