@@ -33,7 +33,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframedatatypewidgetlist.h"
 
 
-#include "icontrolmodule.h"
 #include "idata.h"
 #include "idatareader.h"
 #include "idatasubject.h"
@@ -46,7 +45,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 iggFrameDataTypeWidgetList::iggFrameDataTypeWidgetList(const iString &title, iggFrame *parent) : iggFrame(title,parent)
@@ -75,7 +74,7 @@ void iggFrameDataTypeWidgetList::UpdateList()
 	//  This frame assumes that all readers have the same set of included DataType(s)
 	//
 	const iDataInfo &all(iDataInfo::Any());
-	for(i=mEntries.Size(); i<all.Count(); i++)
+	for(i=mEntries.Size(); i<all.Size(); i++)
 	{
 		mEntries.Add(this->CreateEntry(all.Type(i)));
 		mBox->GetContents()->AddLine(mEntries.Last());
@@ -89,21 +88,4 @@ void iggFrameDataTypeWidgetList::UpdateChildren()
 	iggFrame::UpdateChildren();
 }
 
-
-const iObjectKey& iggFrameDataTypeWidgetList::Translate(const iObjectKey &key, const iDataType &type) const
-{
-	if(key.Type() == iDataSubject::Type())
-	{
-		iDataSubject *subject = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetSubject(type);
-		if(subject == 0) return key;
-
-		const iObjectKey *p = iObjectKeyRegistry::FindKey(key.RetypedKey(subject->GetObjectType()));
-		if(p == 0) return key; else return *p;
-	}
-	else
-	{
-		return key;
-	}
-}
-
 #endif
