@@ -36,42 +36,43 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframe.h"
 
 
-class iDataInfo;
-class iObjectKey;
-
-class iggDataTypeProvider;
-class iggWidgetTextArea;
-class iggWidgetKeyItemizedSelectionBox;
+class iggDataTypeHandle;
+class iggObjectHandle;
+class iggPropertyHandle;
+class iggWidgetSimpleItemizedSelectionBox;
 
 
-class iggFrameDataVariableList : public iggFrame
+class iggFrameDataVariableList : public iggFrameFlip
 {
 
 public:
 
-	iggFrameDataVariableList(const iggDataTypeProvider *provider, const iString &title, const iObjectKey &key, const iObjectKey *actkey, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
-	iggFrameDataVariableList(const iDataInfo &info, const iggDataTypeProvider *provider, const iString &title, const iObjectKey &key, const iObjectKey *actkey, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
+	iggFrameDataVariableList(const iString &title, const iggObjectHandle *dsh, iggFrame *parent, const iggPropertyHandle* eh = 0);
+	iggFrameDataVariableList(const iString &title, const iggObjectHandle *dsh, const iggPropertyHandle& ph, iggFrame *parent, const iggPropertyHandle* eh = 0);
+	iggFrameDataVariableList(const iString &title, const iggDataTypeHandle *dth, const iggPropertyHandle& ph, iggFrame *parent, const iggPropertyHandle* eh = 0);
+	virtual ~iggFrameDataVariableList();
 
 	//
 	//  Decorator functions
 	//
 	virtual void InsertItem(const iString &text);
-	virtual void Complete(int extraoffset = 0);
-	void SetIndex(int i);
+	virtual void Complete();
+
+	int GetIndex() const;
 
 protected:
 
 	void UpdateList();
 	virtual void UpdateChildren();
 
-	void Define(const iggDataTypeProvider *provider);
+	void Define(const iString &title, const iggObjectHandle *dsh, const iggDataTypeHandle *dth, const iggPropertyHandle *ph, iggFrame *parent, const iggPropertyHandle* eh);
 
-	iggWidget *mWidgetCombo, *mWidgetRadio;
-	iggWidgetKeyItemizedSelectionBox *mBoxCombo, *mBoxRadio;
 	int mOffset;
-	const iObjectKey &mKey, *mActivationKey;
 	bool mCompleted;
-	const iggDataTypeProvider *mProvider;
+	const iggObjectHandle *mDataSubjectHandle;
+	const iggDataTypeHandle *mDataTypeHandle;
+	const iggPropertyHandle *mEnablingHandle;
+	iggFrame *mLayers[2];
 };
 
 #endif  // IGGFRAMEDATAVARIABLELIST_H
