@@ -33,25 +33,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframedoublebutton.h"
 
 
-#include "icontrolmodule.h"
 #include "ierror.h"
-#include "iimagefactory.h"
+#include "ihelpfactory.h"
 #include "imarker.h"
-#include "iobjecthelp.h"
-#include "ishell.h"
 #include "iviewmodule.h"
 
+#include "igghandle.h"
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
 #include "iggpage.h"
-#include "iggwidgetkeyhandler.h"
+#include "iggshell.h"
+#include "iggwidgetpropertycontrol.h"
 #include "iggwidgetotherbutton.h"
 
 #include "ibgwidgetbuttonsubject.h"
 
 #include "iggsubjectfactory.h"
 
+//
+//  Templates
+//
+#include "iarray.tlh"
+
 
-using namespace iParameter;
 using namespace iParameter;
 
 
@@ -99,11 +103,11 @@ namespace iggFrameDoubleButton_Private
 		{
 			mConcreteParent = parent;
 
-			mDelayIcon = iImageFactory::FindIcon("delay.png");
-			mReadyIcon = iImageFactory::FindIcon("ready.png");
+			mDelayIcon = iggImageFactory::FindIcon("delay.png");
+			mReadyIcon = iggImageFactory::FindIcon("ready.png");
 			if(mDelayIcon==0 || mReadyIcon==0)
 			{
-				IERROR_LOW("Icon images are not found.");
+				IBUG_WARN("Icon images are not found.");
 			}
 
 			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::ToggleButton,"",1);
@@ -156,15 +160,14 @@ namespace iggFrameDoubleButton_Private
 
 		virtual void Execute()
 		{
-			double x[3];
-			mConcreteParent->GetPosition(x);
-			if(this->GetShell()->GetControlModule()->CreateObject(iMarker::Type(),false,mConcreteParent->GetWindowNumber()))
-			{
-				iString ws;
-				this->GetShell()->GetControlModule()->PackCommand(ws,iMarker::KeyPosition(true),x,3);
-				this->GetShell()->GetControlModule()->Execute(ws,this->GetMainWindow()->IsAutoRender(),DefaultOption,mConcreteParent->GetWindowNumber());
+			iVector3D x = mConcreteParent->GetPosition();
 
+			iMarkerObject *ms = this->GetShell()->GetViewModule(mConcreteParent->GetWindowNumber())->GetMarkerObject();
+			if(ms->Create.CallAction())
+			{
+				ms->Position.SetValue(ms->GetNumber()-1,x);
 				this->GetMainWindow()->UpdateAll();
+				this->Render();
 			}
 		}
 
@@ -189,84 +192,6 @@ iggFrameDoubleButton::iggFrameDoubleButton(const iString &title, iggFrame *paren
 }
 
 
-//
-//  Create/delete button
-//
-iggFrameCreateDeleteButton::iggFrameCreateDeleteButton(iggFrame *dependent, const iObjectType &type, bool keeplast, const iString &name, iggFrame *parent) : iggFrameDoubleButton(parent,1), mType(type)
-{
-	mDependent = dependent;
-	mKeepLast = keeplast;
-	mActive = true;
-
-	this->AddLine(new Button("Create new "+name,this,1));
-	mDeleteButton = new Button("Delete current "+name,this,2);
-	this->AddLine(mDeleteButton);
-
-	this->SetBaloonHelp("Creates/Deletes an instance of the "+type.FullName()+" object. Press Shift+F1 for more help.",type.GetHelp()->GetHTML());
-}
-
-
-void iggFrameCreateDeleteButton::SetActive(bool s)
-{
-	if(s != mActive)
-	{
-		mActive = s;
-		this->UpdateWidget();
-	}
-}
-
-
-void iggFrameCreateDeleteButton::OnButton1()
-{
-	this->GetMainWindow()->Block(true);
-	if(this->GetShell()->GetControlModule()->CreateObject(mType,true))
-	{
-		if(mDependent != 0) mDependent->UpdateWidget();
-	}
-	this->GetMainWindow()->Block(false);
-}
-
-
-void iggFrameCreateDeleteButton::OnButton2()
-{
-	this->GetMainWindow()->Block(true);
-	if(this->GetShell()->GetControlModule()->DeleteObject(mType,true))
-	{
-		if(mDependent != 0) mDependent->UpdateWidget();
-	}
-	this->GetMainWindow()->Block(false);
-}
-
-
-void iggFrameCreateDeleteButton::UpdateWidgetBody()
-{
-	int i;
-	bool b;
-	const iObjectKey *key;
-
-	bool work;
-	key = iObjectKeyRegistry::FindKey(iViewSubject::KeyDataPresent().RetypedKey(mType)); IERROR_ASSERT(key);
-	if(this->GetShell()->GetControlModule()->QueryValue(*key,work))
-	{
-		work = work && mActive;
-		this->Enable(work);
-		if(!work) return;
-	}
-
-	key = iObjectKeyRegistry::FindKey(iViewModule::KeyMarkerMax().PrefixedKey().Substitute("Marker",mType.FullName())); IERROR_ASSERT(key);
-	if(this->GetShell()->GetControlModule()->QueryValue(*key,i))
-	{
-		b = false;
-		if(!mKeepLast)
-		{
-			key = iObjectKeyRegistry::FindKey(iViewSubject::KeyVisible().RetypedKey(mType)); IERROR_ASSERT(key);
-			if(!this->GetShell()->GetControlModule()->QueryValue(*key,b)) b = false;
-		}
-		mDeleteButton->Enable(i>0 || (!mKeepLast && b));
-	}
-}
-
-
 //
 //  Move the focal point to position of a given object type.
 //
@@ -300,9 +225,8 @@ void iggFrameMoveFocalPointButton::SetMoveInstantly(bool s)
 
 void iggFrameMoveFocalPointButton::OnButton1()
 {
-	double x[3];
-	this->GetPosition(x);
-	this->GetShell()->GetControlModule()->FlyTo(x,mMoveInstantly?0.0f:3.0f,this->GetWindowNumber());
+	iVector3D x = this->GetPosition();
+	this->GetShell()->GetViewModule(this->GetWindowNumber())->FlyTo(x,mMoveInstantly?1.0e-20f:3.0f);
 }
 
 
