@@ -36,43 +36,56 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 #include "iviewsubject.h"
 
-#include "iggframeattachposition.h"
 #include "iggframeposition.h"
 #include "iggframepushcontrols.h"
-#include "iggwidgetkeyslider.h"
-#include "iggwidgetkeytrackball.h"
+#include "iggwidgetpropertycontrolslider.h"
+#include "iggwidgetpropertycontroltrackball.h"
 #include "iggwidgetotherbutton.h"
 
 
 using namespace iParameter;
 
 
-iggFrameObjectControls::iggFrameObjectControls(const iString &name, const iObjectKey& poskey, const iObjectKey& dirkey, const iObjectKey& sizkey, iggFrame *parent) : iggFrame(parent,2)
+iggFrameObjectControls::iggFrameObjectControls(const iString &name, const iggPropertyHandle& posph, const iggPropertyHandle& dirph, const iggPropertyHandle& sizph, iggFrame *parent) : iggFrame(parent,2)
+{
+	this->Define(name,posph,dirph,&sizph,parent);
+}
+
+
+iggFrameObjectControls::iggFrameObjectControls(const iString &name, const iggPropertyHandle& posph, const iggPropertyHandle& dirph, iggFrame *parent) : iggFrame(parent,2)
+{
+	this->Define(name,posph,dirph,0,parent);
+}
+
+
+void iggFrameObjectControls::Define(const iString &name, const iggPropertyHandle& posph, const iggPropertyHandle& dirph, const iggPropertyHandle* sizph, iggFrame *parent)
 {
 	iString ws;
 
 	if(name.IsEmpty()) ws = "Position"; else ws = name+" position";
-	mOP = new iggFramePosition(ws,poskey,this);
+	mOP = new iggFramePosition(ws,posph,this);
 
 	if(name.IsEmpty()) ws = "Direction"; else ws = name+" direction";
 	mOD = new iggFrame(ws,this);
-	mOD->AddLine(new iggWidgetKeyTrackBall(dirkey,false,RenderMode::UseGlobal,mOD));
+	mOD->AddLine(new iggWidgetPropertyControlTrackBall(false,dirph,mOD));
 	this->AddLine(mOP,mOD);
 
-	if(name.IsEmpty()) ws = "Size"; else ws = name+" size";
-	mOS = new iggFrame(ws,this,2);
-	iggWidgetKeySizeSlider *s = new iggWidgetKeySizeSlider(1.0e-4,5,"",sizkey,RenderMode::UseGlobal,mOS);
-	mOS->AddLine(new iggWidgetAdjustSizeSliderButton(s,false,mOS),s);
-	mPO = new iggFramePushControls(mOP,"Push "+name.Lower(),dirkey,poskey,this);
+	if(sizph != 0)
+	{
+		if(name.IsEmpty()) ws = "Size"; else ws = name+" size";
+		mOS = new iggFrame(ws,this);
+		iggWidgetPropertyControlSizeSlider *s = new iggWidgetPropertyControlSizeSlider(1.0e-4,5,"",*sizph,mOS);
+		mOS->AddLine(s);
+	}
+	else
+	{
+		mOS = 0;
+	}
+
+	mPO = new iggFramePushControls(mOP,"Push "+name.Lower(),posph,dirph,this);
 	this->AddLine(mOS,mPO);
 	this->AddSpace(5);
 
-	const iObjectKey *p = iObjectKeyRegistry::FindKey(iViewSubject::KeyAttachToMarker().RetypedKey(poskey.Type()));
-	if(p != 0)
-	{
-		this->AddLine(new iggFrameAttachPosition(mOP,*p,name.Lower(),this,true));
-	}
-
 	this->SetColStretch(0,5);
 }
 
@@ -92,7 +105,7 @@ void iggFrameObjectControls::EnableDirection(bool s)
 
 void iggFrameObjectControls::EnableSize(bool s)
 {
-	mOS->Enable(s);
+	if(mOS != 0) mOS->Enable(s);
 }
 
 #endif
