@@ -41,6 +41,7 @@ class iString;
 
 class iggFramePosition;
 class iggFramePushControls;
+class iggPropertyHandle;
 
 
 class iggFrameObjectControls : public iggFrame
@@ -48,7 +49,8 @@ class iggFrameObjectControls : public iggFrame
 
 public:
 
-	iggFrameObjectControls(const iString &name, const iObjectKey &poskey, const iObjectKey &dirkey, const iObjectKey &sizkey, iggFrame *parent);
+	iggFrameObjectControls(const iString &name, const iggPropertyHandle& posph, const iggPropertyHandle& dirph, const iggPropertyHandle& sizph, iggFrame *parent);
+	iggFrameObjectControls(const iString &name, const iggPropertyHandle& posph, const iggPropertyHandle& dirph, iggFrame *parent);
 
 	void EnablePosition(bool s);
 	void EnableDirection(bool s);
@@ -56,6 +58,8 @@ public:
 
 protected:
 
+	void Define(const iString &name, const iggPropertyHandle& posph, const iggPropertyHandle& dirph, const iggPropertyHandle* sizph, iggFrame *parent);
+
 	iggFramePosition *mOP;
 	iggFrame *mOD, *mOS;
 	iggFramePushControls *mPO;
