@@ -36,9 +36,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframepaletteselectionbase.h"
 
 
-class iObjectKey;
+#include "itype.h"
 
-template<class T> class iggWidgetKeyDummy;
+class iggPropertyHandle;
+
+template<iType::TypeId id> class iggWidgetPropertyControlDummy;
 
 
 class iggFramePaletteSelection : public iggFramePaletteSelectionBase
@@ -46,17 +48,17 @@ class iggFramePaletteSelection : public iggFramePaletteSelectionBase
 
 public:
 
-	iggFramePaletteSelection(bool withbrightness, const iObjectKey &key, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
+	iggFramePaletteSelection(bool withbrightness, const iggPropertyHandle& ph, iggFrame *parent);
 	virtual ~iggFramePaletteSelection();
 
-	void SetIndex(int i);
+	//void SetIndex(int i);
 
 protected:
 
 	virtual int GetPaletteId() const;
 	virtual void SetPaletteId(int n);
 
-	iggWidgetKeyDummy<int> *mDummy;
+	iggWidgetPropertyControlDummy<iType::Int> *mDummy;
 };
 
 #endif  // IGGFRAMEPALETTESELECTION_H
