@@ -41,16 +41,33 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 class iPalette;
 
+class iggWidget;
 
-class iggFramePaletteSelectionBase : public iggFrame
+
+class iggFramePaletteViewFrame : public iggFrame
 {
 
 public:
 
-	iggFramePaletteSelectionBase(bool witheditor, bool withbrightness, iggFrame *parent);
+	iggFramePaletteViewFrame(const iString &title, iggFrame *parent);
+
+	virtual iPalette* GetActivePalette() const = 0;
+
+protected:
+
+	iggWidget *mPaletteView;
+};
+
+
+class iggFramePaletteSelectionBase : public iggFramePaletteViewFrame
+{
+
+public:
+
+	iggFramePaletteSelectionBase(bool witheditor, bool withbrightness, bool withreverse, iggFrame *parent);
 	virtual ~iggFramePaletteSelectionBase();
 
-	virtual iPalette* GetCurrentPalette() const;
+	virtual iPalette* GetActivePalette() const;
 
 	void SetReversedPalette(bool s);
 	bool GetReversedPalette() const;
@@ -58,8 +75,8 @@ public:
 	void SetBrightnessPalette(bool s);
 	bool GetBrightnessPalette() const;
 
-	void SetCurrentPaletteIndex(int n);
-	int GetCurrentPaletteIndex() const;
+	void SetActivePaletteIndex(int n);
+	int GetActivePaletteIndex() const;
 
 	static void UpdateAll();
 
@@ -71,7 +88,7 @@ protected:
 	int mOldPaletteId;
 	const bool mWithBrightness;
 
-	static iPointerArray<iggFramePaletteSelectionBase>& List();
+	static iLookupArray<iggFramePaletteSelectionBase*>& List();
 };
 
 #endif  // IGGFRAMEPALETTESELECTIONBASE_H
