@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "imath.h"
 #include "ipiecewisefunction.h"
 
-#include "iggframehistogramareaextra.h"
+#include "iggframehistogramcontrols.h"
 #include "iggwidgetarea.h"
 #include "iggwidgetotherbutton.h"
 
@@ -46,7 +46,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -69,7 +69,7 @@ namespace iggFramePiecewiseFunctionControls_Private
 
 	public:
 
-		Area(iggFramePiecewiseFunctionControls *parent) : iggWidgetHistogramArea(false,true,parent)
+		Area(iggFrameHistogramControls *controls, iggFramePiecewiseFunctionControls *parent) : iggWidgetHistogramArea(controls,parent)
 		{
 			mFrame = parent;
 
@@ -97,23 +97,21 @@ namespace iggFramePiecewiseFunctionControls_Private
 		{
 			if(mDefaultFunction == 0) 
 			{
-				mDefaultFunction = iPiecewiseFunction::New(); IERROR_ASSERT(mDefaultFunction);
+				mDefaultFunction = iPiecewiseFunction::New(); IERROR_CHECK_MEMORY(mDefaultFunction);
 				mDefaultFunction->Copy(mFrame->GetFunction());
 			}
 
-			if(mFrame->GetFunction() != 0) 
+			if(mFrame->GetFunction() == 0) this->UpdateFailed();
+
+			this->iggWidgetHistogramArea::UpdateWidgetBody();
+		}
+
+		virtual void DrawBackgroundBody()
+		{
+			if(mControls != 0)
 			{
-				const iHistogram *h = mFrame->GetHistogram();
-				if(h != 0)
-				{
-					//
-					//  Must update histogram - who knows what changed anywhere else
-					//
-					this->SetHistogram(h,0);
-				}
-				this->iggWidgetHistogramArea::UpdateWidgetBody();
+				this->DrawHistogram(mFrame->GetHistogram(mControls->GetStretchId(),mControls->GetFullResolution()));
 			}
-			else this->UpdateFailed();
 		}
 
 		virtual void DrawForegroundBody()
@@ -129,23 +127,25 @@ namespace iggFramePiecewiseFunctionControls_Private
 				ixmax = mSubject->Width() - 1;
 				iymax = mSubject->Height() - 1;
 				
+				if(mCurPoint >= fun->N()) mCurPoint = fun->N() - 1;
+
 				ixo = iyo = -1;
 				for(i=0; i<fun->N(); i++)  
 				{
-					ix = round(ixmax*fun->X(i));
-					iy = round(iymax*fun->Y(i));
+					ix = iMath::Round2Int(ixmax*fun->X(i));
+					iy = iMath::Round2Int(iymax*fun->Y(i));
 					if(ixo>=0 && iyo >=0) mSubject->DrawLine(ixo,iyo,ix,iy,regColor);
 					if(i != mCurPoint) mSubject->DrawEllipse(ix-sym/2,iy-sym/2,ix+sym/2,iy+sym/2,regColor,regColor);
 					ixo = ix; iyo = iy;
 				}
 				
-				ix = round(ixmax*fun->X(mCurPoint));
-				iy = round(iymax*fun->Y(mCurPoint));
+				ix = iMath::Round2Int(ixmax*fun->X(mCurPoint));
+				iy = iMath::Round2Int(iymax*fun->Y(mCurPoint));
 				mSubject->DrawEllipse(ix-sym/2,iy-sym/2,ix+sym/2,iy+sym/2,regColor,curColor);
 			}
 			else
 			{
-				IERROR_LOW("Unable to query PiecewiseFunctionControls.");
+				IBUG_WARN("Unable to query PiecewiseFunctionControls.");
 			}
 		}
 		
@@ -159,6 +159,7 @@ namespace iggFramePiecewiseFunctionControls_Private
 				mSubject->RequestPainting(DrawMode::Foreground);
 				mFrame->OnChange();
 			}
+			this->OnRender();
 		}
 
 		void OnRemovePoint()
@@ -171,24 +172,7 @@ namespace iggFramePiecewiseFunctionControls_Private
 				mSubject->RequestPainting(DrawMode::Foreground);
 				mFrame->OnChange();
 			}
-		}
-
-		void OnReset()
-		{
-			if(mDefaultFunction == 0)
-			{
-				this->Enable(false);
-				return;
-			}
-
-			iPiecewiseFunction *fun = mFrame->GetFunction();
-			if(fun != 0) 
-			{
-				fun->Copy(mDefaultFunction);
-				mCurPoint = 0;
-				mSubject->RequestPainting(DrawMode::Foreground);
-				mFrame->OnChange();
-			}
+			this->OnRender();
 		}
 
 		void OnRender();
@@ -254,30 +238,6 @@ namespace iggFramePiecewiseFunctionControls_Private
 		Area *mArea;
 	};
 
-	//
-	//  ResetButton
-	//
-	class ResetButton : public iggWidgetSimpleButton
-	{
-
-	public:
-
-		ResetButton(Area *area, iggFrame *parent) : iggWidgetSimpleButton("Reset",parent)
-		{
-			mArea= area;
-			this->SetBaloonHelp("Reset the function to the default shape");
-		}
-
-	protected:
-
-		virtual void Execute()
-		{
-			mArea->OnReset();
-		}
-
-		Area *mArea;
-	};
-
 	//
 	//  RenderButton
 	//
@@ -307,21 +267,22 @@ namespace iggFramePiecewiseFunctionControls_Private
 	{
 		const int sym = 16;
 		int i;
-		float xl, yl, d;
+		float d;
+		iPair p;
 
 		iPiecewiseFunction *fun = mFrame->GetFunction();
 		if(fun != 0) 
 		{
-			xl = float(x)/mSubject->Width();
-			yl = float(y)/mSubject->Height();
+			p.X = float(x)/mSubject->Width();
+			p.Y = float(y)/mSubject->Height();
 			
 			if(b==MouseButton::LeftButton || b==MouseButton::RightButton) 
 			{
-				i = fun->FindPoint(xl,yl,d);
-				if(round(d*mSubject->Width()) < 5*sym)
+				i = fun->FindPoint(p,d);
+				if(iMath::Round2Int(d*mSubject->Width()) < 5*sym)
 				{
 					mCurPoint = i;
-					fun->MovePoint(mCurPoint,xl,yl);
+					fun->MovePoint(mCurPoint,p);
 					mSubject->RequestPainting(DrawMode::Foreground);
 					if(b == MouseButton::RightButton) this->OnRender(); else if(mRenderButton!=0 && !mRenderButton->IsEnabled()) mRenderButton->Enable(true);
 					mFrame->OnChange();
@@ -332,9 +293,9 @@ namespace iggFramePiecewiseFunctionControls_Private
 
 	void Area::OnRender()
 	{
+		mFrame->Render();
 		if(mRenderButton != 0)
 		{
-			mFrame->OnRender();
 			mRenderButton->Enable(false);
 		}
 	}
@@ -344,23 +305,34 @@ namespace iggFramePiecewiseFunctionControls_Private
 using namespace iggFramePiecewiseFunctionControls_Private;
 
 
-iggFramePiecewiseFunctionControls::iggFramePiecewiseFunctionControls(bool withrender, bool withhistogram, iggFrame *parent) : iggFrame(parent,3)
+iggFramePiecewiseFunctionControls::iggFramePiecewiseFunctionControls(bool withRender, bool withHistogram, iggFrame *parent) : iggFrame(parent,3)
 {
-	Area *a = new Area(this);
-	this->AddLine(a,3);
-	if(withhistogram) this->AddLine(new iggFrameHistogramAreaExtra(a,this),3);
-	this->AddLine(new AddPointButton(a,this),new RemovePointButton(a,this));
+	Area *a;
+	if(withHistogram)
+	{
+		iggFrameHistogramControls *controls = new iggFrameHistogramControls(true,false,this);
+		a = new Area(controls,this);
+		this->AddLine(a,3);
+		this->AddLine(controls,3);
+		this->AddSpace(1);
+	}
+	else
+	{
+		a = new Area(0,this);
+		this->AddLine(a,3);
+	}
+	this->SetRowStretch(0,10);
 
 	RenderButton *rb = 0;
-	if(withrender)
+	if(withRender)
 	{
 		rb = new RenderButton(a,this);
 		a->SetRenderButton(rb);
 	}
-	this->AddLine(new ResetButton(a,this),rb);
 
-	this->SetRowStretch(0,10);
-	this->SetColStretch(2,10);
+	this->AddLine(new AddPointButton(a,this),(iggWidget*)0,rb);
+	this->AddLine(new RemovePointButton(a,this));
+	this->AddSpace(10);
 }
 
 #endif
