@@ -33,41 +33,41 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframereplicate.h"
 
 
-#include "icontrolmodule.h"
+#include "idatalimits.h"
+#include "idatasubject.h"
 #include "ierror.h"
 #include "iviewsubject.h"
 #include "ishell.h"
 
-#include "iggwidgetarea.h"
-#include "iggwidgetkeyselectionbox.h"
+#include "igghandle.h"
+#include "iggwidgetmisc.h"
+#include "iggwidgetpropertycontrolselectionbox.h"
 
 
-iggFrameReplicate::iggFrameReplicate(const iObjectType &type, iggFrame *parent) : iggFrame("Periodic extensions",parent,2), mDirKey(iObjectKeyRegistry::FindKey(iViewSubject::KeyDirectionIsPeriodic().RetypedKey(type),true))
+iggFrameReplicate::iggFrameReplicate(const iggObjectHandle *oh, iggFrame *parent) : iggFrame("Periodic extensions",parent,2), mObjectHandle(oh)
 {
-	iggWidgetKeySpinBox *box1, *box2;
-
-	const iObjectKey *key = iObjectKeyRegistry::FindKey(iViewSubject::KeyNumReplicas().RetypedKey(type)); IERROR_ASSERT(key);
+	iggWidgetPropertyControlSpinBox *box1, *box2;
 
 	iggFrame *tmp = new iggFrame(this,2);
-	tmp->AddLine(new iggWidgetTextArea("       Down",tmp),new iggWidgetTextArea("Up",tmp));
+	tmp->AddLine(new iggWidgetTextLabel("       Down",tmp),new iggWidgetTextLabel("Up",tmp));
 	this->AddLine(tmp);
 
 	mDirs[0] = new iggFrame(this,3);
-	box1 = new iggWidgetKeySpinBox(0,2,0,0,*key,mDirs[0],0);
-	box2 = new iggWidgetKeySpinBox(0,2,0,0,*key,mDirs[0],1);
-	mDirs[0]->AddLine(new iggWidgetTextArea("%b%+X",mDirs[0]),box1,box2);
+	box1 = new iggWidgetPropertyControlSpinBox(0,2,"",0,iggPropertyHandle("ReplicationFactors",oh,0),mDirs[0]);
+	box2 = new iggWidgetPropertyControlSpinBox(0,2,"",0,iggPropertyHandle("ReplicationFactors",oh,1),mDirs[0]);
+	mDirs[0]->AddLine(new iggWidgetTextLabel("%b%+X",mDirs[0]),box1,box2);
 	this->AddLine(mDirs[0]);
 
 	mDirs[1] = new iggFrame(this,3);
-	box1 = new iggWidgetKeySpinBox(0,2,0,0,*key,mDirs[1],2);
-	box2 = new iggWidgetKeySpinBox(0,2,0,0,*key,mDirs[1],3);
-	mDirs[1]->AddLine(new iggWidgetTextArea("%b%+Y",mDirs[1]),box1,box2);
+	box1 = new iggWidgetPropertyControlSpinBox(0,2,"",0,iggPropertyHandle("ReplicationFactors",oh,2),mDirs[1]);
+	box2 = new iggWidgetPropertyControlSpinBox(0,2,"",0,iggPropertyHandle("ReplicationFactors",oh,3),mDirs[1]);
+	mDirs[1]->AddLine(new iggWidgetTextLabel("%b%+Y",mDirs[1]),box1,box2);
 	this->AddLine(mDirs[1]);
 
 	mDirs[2] = new iggFrame(this,3);
-	box1 = new iggWidgetKeySpinBox(0,2,0,0,*key,mDirs[2],4);
-	box2 = new iggWidgetKeySpinBox(0,2,0,0,*key,mDirs[2],5);
-	mDirs[2]->AddLine(new iggWidgetTextArea("%b%+Z",mDirs[2]),box1,box2);
+	box1 = new iggWidgetPropertyControlSpinBox(0,2,"",0,iggPropertyHandle("ReplicationFactors",oh,4),mDirs[2]);
+	box2 = new iggWidgetPropertyControlSpinBox(0,2,"",0,iggPropertyHandle("ReplicationFactors",oh,5),mDirs[2]);
+	mDirs[2]->AddLine(new iggWidgetTextLabel("%b%+Z",mDirs[2]),box1,box2);
 	this->AddLine(mDirs[2]);
 
 	this->SetColStretch(1,10);
@@ -77,15 +77,13 @@ iggFrameReplicate::iggFrameReplicate(const iObjectType &type, iggFrame *parent)
 void iggFrameReplicate::UpdateChildren()
 {
 	this->iggFrame::UpdateChildren();
-
-	if(mDirKey != 0)
+	
+	const iViewSubject *sub = iDynamicCast<const iViewSubject>(INFO,mObjectHandle->Object());
+	
+	int i;
+	for(i=0; i<3; i++)
 	{
-		int i;
-		bool per[3];
-		if(this->GetShell()->GetControlModule()->QueryValue(*mDirKey,per,3))
-		{
-			for(i=0; i<3; i++) mDirs[i]->Enable(per[i]);
-		}
+		mDirs[i]->Enable(sub->GetSubject()->IsDirectionPeriodic(i));
 	}
 }
 
