@@ -36,8 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframe.h"
 
 
-class iObjectKey;
-class iObjectType;
+class iggObjectHandle;
 
 
 class iggFrameReplicate : public iggFrame
@@ -45,7 +44,7 @@ class iggFrameReplicate : public iggFrame
 
 public:
 
-	iggFrameReplicate(const iObjectType &type, iggFrame *parent);
+	iggFrameReplicate(const iggObjectHandle *oh, iggFrame *parent);
 
 protected:
 
@@ -54,7 +53,7 @@ protected:
 private:
 
 	iggFrame *mDirs[3];
-	const iObjectKey *mDirKey;
+	const iggObjectHandle *mObjectHandle;
 };
 
 #endif  // IGGFRAMEREPLICATE_H
