@@ -38,7 +38,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgframesubject.h"
 
 
-iggFrameTopParent::iggFrameTopParent(iShell *shell) : iggFrame(shell,1,false)
+iggFrameTopParent::iggFrameTopParent(iggShell *shell) : iggFrame(shell,1,false)
 {
 	mWasLaidOut = true;
 }
@@ -46,7 +46,8 @@ iggFrameTopParent::iggFrameTopParent(iShell *shell) : iggFrame(shell,1,false)
 
 void iggFrameTopParent::AttachSubject(ibgFrameSubject *subject)
 {
-	mSubject = subject; IERROR_ASSERT(subject);
+	IASSERT(subject);
+	mSubject = subject; 
 	iggWidget::AttachSubject(subject);
 }
 
