@@ -45,7 +45,7 @@ class iggFrameTopParent : public iggFrame
 
 public:
 
-	iggFrameTopParent(iShell *shell);
+	iggFrameTopParent(iggShell *shell);
 
 	void AttachSubject(ibgFrameSubject *subject);
 };
