@@ -41,11 +41,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 
 
-class iColor;
 class iDataInfo;
-class iDataType;
-class iFileLoader;
 class iImage;
+class iViewModule;
 
 class iggDialog;
 class iggDialogAbout;
@@ -61,17 +59,16 @@ class iggDialogPaletteEditor;
 class iggDialogParallelController;
 class iggDialogPickerWindow;
 class iggDialogRenderingProgress;
-class iggDialogScriptDebugger;
 class iggExtensionWindow;
 class iggFrame;
 class iggFrameBook;
 class iggFrameFlip;
-class iggFrameTopParent;
 class iggPageData;
 class iggPageObject;
 class iggPageParticles;
 class iggPageView;
 class iggRenderWindow;
+class iggScriptWindow;
 class iggWidget;
 class iggWidgetProgressBar;
 class iggWidgetTextBrowser;
@@ -80,20 +77,6 @@ class ibgMainWindowSubject;
 class ibgWindowSubject;
 
 
-namespace iParameter
-{
-	//
-	//  Popup types
-	//
-	namespace PopupWindow
-	{
-		const int Message =		0;
-		const int Warning =		1;
-		const int Error =		2;
-	};
-};
-
-
 class iggMainWindow : public iObject, public iggMenuWindow
 {
 
@@ -102,7 +85,6 @@ class iggMainWindow : public iObject, public iggMenuWindow
 public:
 
 	vtkTypeMacro(iggMainWindow,iObject);
-	static const iObjectType& Type();
 
 	//
 	//  Register dependent windows
@@ -121,8 +103,8 @@ public:
 
 	inline iggExtensionWindow* GetExtensionWindow() const { return mExtensionWindow; }
 
-	iggWidgetProgressBar* GetProgressBar() const;
-	iggFrameFlip* GetDataTypeFrame() const { return mDataTypeFrame; }
+	inline iggWidgetProgressBar* GetProgressBar() const { return mProgressBar; }
+	inline iggFrameFlip* GetDataTypeFrame() const { return mDataTypeFrame; }
 
 	inline iggDialog* GetDialogDataExplorer() const { return mDialogDataExplorer; }
 	inline iggDialog* GetDialogPaletteEditor() const { return mDialogPaletteEditor; };
@@ -131,27 +113,23 @@ public:
 	inline iggDialogAnimatingProgress* GetDialogAnimatingProgress() const { return mDialogAnimatingProgress; };
 	inline iggDialogHelp* GetDialogHelp() const { return mDialogHelp; };
 	inline iggDialogImageComposer* GetDialogImageComposer() const { return mDialogImageComposer; };
+	inline iggDialogLoadFile* GetDialogLoadFile() const { return mDialogLoadFile; }
 	inline iggDialogParallelController* GetDialogParallelController() const { return mDialogParallelController; };
 	inline iggDialogPickerWindow* GetDialogPickerWindow() const { return mDialogPickerWindow; };
 	inline iggDialogRenderingProgress* GetDialogRenderingProgress() const { return mDialogRenderingProgress; };
-	inline iggDialogScriptDebugger* GetDialogScriptDebugger() const { return mDialogScriptDebugger; };
+	inline iggScriptWindow* GetScriptWindow() const { return mScriptWindow; };
 
 	inline iggPageObject* GetPage(int n) const { if(n>0 && n<7) return mPages[n-1]; else return 0; }
 
-	//
-	//  User notification
-	//
-	int PopupWindow(const iString &text, int type = iParameter::PopupWindow::Message, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
-	int PopupWindow(const iggFrame *parent, const iString &text, int type = iParameter::PopupWindow::Message, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
-	int PopupWindow(const iggRenderWindow *parent, const iString &text, int type = iParameter::PopupWindow::Message, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
-
 	void WriteToLog(const iString &prefix, const iString &message, const iColor &c = iColor(0,0,0));
 	void WriteToLog(const iString &message);
+#ifdef I_DEBUG
+	void WriteToDebugLog(const iString &message);
+#endif
 	void ClearLog();
 	void ShowLog(bool s);
 	bool IsLogVisible() const;
 
-	inline bool IsIdiosyncratic() const { return mIdiosyncratic; }
 	bool AskForConfirmation(const iString &message, const char *action);
 
 	void ProcessEvents(bool sync = false) const;
@@ -160,28 +138,7 @@ public:
 	//
 	//  Data handling
 	//
-	void LoadData(const iDataType &type, const iString &filename, int mod = -1);
-	void AfterLoadData(const iDataType &type, const iString &filename);
-
-	void ReloadData();
-	void AfterReloadData(const iDataType &type);
-	inline const iDataInfo& GetReloadDataInfo() const { return *mReloadDataInfo; }
-	void AddReloadDataType(const iDataType &type);
-	void RequestReloadData(const iDataInfo &info);
-
-	void EraseData();
-	void AfterEraseData(const iDataType &type);
-	inline const iDataInfo& GetEraseDataInfo() const { return *mEraseDataInfo; }
-	void AddEraseDataType(const iDataType &type);
-	void RemoveEraseDataType(const iDataType &type);
-
-	void LogDataInfo(const iFileLoader *loader, bool details);
-
-	//
-	//  Multiple window settings
-	//
-	inline void SetWindowUnderFocusCurrent(bool s){ mWindowUnderFocusCurrent = s; }
-	inline bool GetWindowUnderFocusCurrent() const { return mWindowUnderFocusCurrent; }
+	void AfterDataChanged(); // data can change not just from loading a file - for example, is some are erased
 
 	//
 	//  Update components
@@ -191,14 +148,19 @@ public:
 	void UpdateParticleWidgets(const iImage *icon = 0);
 
 	void ShowAll(bool s);
-	void Block(bool s);
 	void Exit();
+#ifndef I_NO_CHECK
+	void Block(bool s, int line, const char *file);
+#define BLOCK(s) Block(s,__LINE__,__FILE__)
+#else
+	void Block(bool s);
+#define BLOCK(s) Block(s)
+#endif
 
 	//
 	//  Main book manipulation
 	//
 	void OpenBookPage(int n);
-	void SetTabMode(int m);
 
 	//
 	//  Render window events
@@ -217,22 +179,18 @@ public:
 	void DisplayWindowsAsWindows();
 	void MoveWindows(int pos[2]);
 
-	inline bool IsDocked() const { return mDocked; }
-	inline bool IsAutoRender() const { return mAutoRender; }
-	
 	void ShowInteractorHelp(bool s, iViewModule *vm = 0);
 
 private:
 
-	iggMainWindow(iShell *shell);
+	iggMainWindow(iggShell *shell);
 	virtual ~iggMainWindow();
 
 	void StartInitialization();
 	void PreShowInitialization();
 	void PostShowInitialization();
 
-	virtual void PackStateBody(iString &s) const;
-	virtual void UnPackStateBody(const iString &s);
+	void StartTimer();
 
 	virtual void UpdateContents();
 
@@ -241,16 +199,13 @@ private:
 	//
 	virtual void OnMenuBody(int id, bool on);
 	void BuildMenus();
+	const iString ListBlockRegistry();
 
 	//
 	//  Misc functions
 	//
-	void ShowToolTips(bool s);
 	void DockWindows(bool s, bool show);
 	bool IsExitAllowed();
-	void SetTheme(int n);
-
-	void LogDataInfo(const iDataType &type, bool details);
 
 	//
 	//  Subject
@@ -267,7 +222,6 @@ private:
 	//
 	iggDialog *mDialogAbout;
 	iggDialog *mDialogAxesLabels;
-	iggDialog *mDialogCommandLine;
 	iggDialog *mDialogDataExplorer;
 	iggDialog *mDialogDocking;
 	iggDialog *mDialogFileSetExplorer;
@@ -281,9 +235,9 @@ private:
 	iggDialogParallelController *mDialogParallelController;
 	iggDialogPickerWindow *mDialogPickerWindow;
 	iggDialogRenderingProgress *mDialogRenderingProgress;
-	iggDialogScriptDebugger *mDialogScriptDebugger;
+	iggScriptWindow *mScriptWindow;
 
-	iSearchableArray<iggDialogAuto*> mAutoDialogList;
+	iLookupArray<iggDialogAuto*> mAutoDialogList;
 
 #if defined(I_DEBUG)
 	iggDialog *mDialogDebugHelper;
@@ -293,7 +247,7 @@ private:
 	//
 	iggFrameTopParent *mBusyIndicatorFrame, *mVisitedFileListFrame;
 	iggFrameFlip *mBaseFrame, *mDataTypeFrame;
-	iggWidget *mBusyIndicator, *mVisitedFileList, *mRenderButton;
+	iggWidget *mBusyIndicator, *mVisitedFileList, *mRenderButton, *mRenderAllButton;
 	iggFrameBook *mBook;
 	iggPageView *mViewPage;
 	iggPageParticles *mParticlesPage;
@@ -306,39 +260,39 @@ private:
 	//  Helper variables
 	//
 	iArray<iString> mThemeList;
-	int mCurrentTheme, mBlockLevel;
-	iPointerArray<ibgWindowSubject> mWindowList;
+	int mBlockLevel;
+	iLookupArray<ibgWindowSubject*> mWindowList;
 	iggWidgetProgressBar *mProgressBar;
-	bool mDocked, mInteractorHelp, mToolTips, mOptionsAreGlobal, mWindowUnderFocusCurrent, mDetailLoadedDataInfo, mAutoRender, mMoveTogether;
-	bool mIdiosyncratic, mDoNotOfferToReload, mInitialized, mInMove, mTwoSubjectsAreTheSame, mAllowPrePopulateToolBar;
-	iDataInfo *mReloadDataInfo, *mEraseDataInfo;
-	iString mStateFileName;
-	int mInitialGeometry[4], mPrevPos[2], mNextPos[2], mProgressBarMode;
+	bool mMoveTogether;
+	bool mInitialized, mInMove, mTwoSubjectsAreTheSame;
+	iString mStateFileName, mExportFileName;
+	int mInitialGeometry[4], mPrevPos[2], mNextPos[2];
 
 	iggMainWindow(const iggMainWindow&); // Not implemented.
 	void operator=(const iggMainWindow&);  // Not implemented.
 
-	static const iObjectKey& KeyGeometry();
-	static const iObjectKey& KeyExtensionGeometry();
-	static const iObjectKey& KeyDocked();
-	static const iObjectKey& KeyInteractorHelp();
-	static const iObjectKey& KeyToolTips();
-	static const iObjectKey& KeyOptionsAreGlobal();
-	static const iObjectKey& KeyWindowUnderFocusCurrent();
-	static const iObjectKey& KeyIsIdiosyncratic();
-	static const iObjectKey& KeyTabMode();
-	static const iObjectKey& KeyBookOrientation();
-	static const iObjectKey& KeyTheme();
-	static const iObjectKey& KeySlidersAreEditable();
-	static const iObjectKey& KeyAllowPrePopulateToolBar();
+	iObjectPropertyMacro2V(Geometry,Int);
+	iObjectPropertyMacro2V(ExtensionGeometry,Int);
+
+	iObjectPropertyMacro1S(TabMode,Int);
+	iObjectPropertyMacro1S(Theme,String);
+	iObjectPropertyMacro1S(BookOrientation,Int);
+
+	iObjectPropertyMacro1S(Docked,Bool);
+	iObjectPropertyMacro1S(ToolTips,Bool);
+	iObjectPropertyMacro1S(InteractorHelp,Bool);
+	iObjectPropertyMacro1S(IsIdiosyncratic,Bool);
+	iObjectPropertyMacro1S(OptionsAreGlobal,Bool);
+	iObjectPropertyMacro1S(AllowPrePopulateToolBar,Bool);
+	iObjectPropertyMacro1S(WindowUnderFocusActive,Bool);
 };
 
 //
 //  Useful Macros
 //
 #define FOR_EVERY_RENDER_WINDOW(window) \
-vtkRenderWindowCollection *c_; iggRenderWindow *window; int k_, n_ = this->GetShell()->GetControlModule()->GetNumberOfViewModules(); \
-for(k_=0;  k_<n_ && (c_=this->GetShell()->GetControlModule()->GetViewModule(k_)->GetRenderWindowCollection(true))!=0; k_++) while((window=iRequiredCast<iggRenderWindow>(INFO,c_->GetNextItem())) != 0)
+vtkRenderWindowCollection *c_; iggRenderWindow *window; int k_, n_ = this->GetShell()->GetNumberOfViewModules(); \
+for(k_=0;  k_<n_ && (c_=this->GetShell()->GetViewModule(k_)->GetRenderWindowCollection(true))!=0; k_++) while((window=iRequiredCast<iggRenderWindow>(INFO,c_->GetNextItem())) != 0)
 
 #endif  // IGGMAINWINDOW_H
 
