@@ -33,7 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IGGMENUWINDOW_H
 
 
-#include "iggelement.h"
+#include "iggrenderingelement.h"
 
 
 #include "istring.h"
@@ -44,7 +44,7 @@ class iggMainWindow;
 class ibgMenuWindowSubject;
 
 
-class iggMenuWindow : public iggElement
+class iggMenuWindow : public iggRenderingElement
 {
 
 	friend class iggSubjectFactory;
@@ -60,11 +60,13 @@ public:
 	iString GetFileName(const iString &header, const iString &file, const iString &selection, bool reading = true);
 
 	inline const iggFrameTopParent* GetGlobalFrame() const { return mGlobalFrame; }
+	virtual bool CanBeClosed();
 
 	//
 	//  Update components
 	//
 	void UpdateAll();
+	void UpdateMenus();
 
 	//
 	//  Do all menu work here
@@ -73,7 +75,7 @@ public:
 
 protected:
 
-	iggMenuWindow(iShell *shell);
+	iggMenuWindow(iggShell *shell);
 	iggMenuWindow(iggMainWindow *mainWindow);
 
 	void AttachSubject(ibgMenuWindowSubject *subject, int cols);
