@@ -35,13 +35,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ierror.h"
 
+#include "iggwidgetarea.h"
 
-iggPage::iggPage(iggFrameBase *parent, bool withbook, bool feedback) : iggFrame(parent)
+
+iggPage::iggPage(iggFrameBase *parent, int flags) : iggFrame(parent)
 {
-	if(withbook)
+	if((flags&WithBook) != 0)
 	{
-		mBook = new iggFrameBook(this,feedback); IERROR_ASSERT(mBook);
+		mBook = new iggFrameBook(this,(flags&WithFeedback)!=0); IERROR_CHECK_MEMORY(mBook);
 		this->AddLine(mBook);
+		this->SetRowStretch(1,10);
 	}
 	else mBook = 0;
 }
