@@ -43,6 +43,9 @@ class iggPage : public iggFrame
 
 public:
 
+	const static int WithBook     = 1;
+	const static int WithFeedback = 2;
+
 	virtual ~iggPage();
 
 	void ShowPage(int n);
@@ -50,7 +53,7 @@ public:
 
 protected:
 
-	iggPage(iggFrameBase *parent, bool withbook = true, bool feedback = false);
+	iggPage(iggFrameBase *parent, int flags);
 
 	iggFrameBook *mBook;
 };
