@@ -33,10 +33,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggpagemain.h"
 
 
+#include "ierror.h"
+
 #include "iggmainwindow.h"
+#include "iggshell.h"
+
+//
+//  Templates (needed for some compilers)
+//
+#include "iarray.tlh"
 
 
-iggPageMain::iggPageMain(iggFrameBase *parent, bool withbook, bool feedback) : iggPage(parent,withbook,feedback)
+iggPageMain::iggPageMain(iggFrameBase *parent, int flags) : iggPage(parent,flags)
 {
 	mFlipFrame = 0;
 	mFlipIndex = -1;
@@ -71,4 +79,43 @@ void iggPageMain::UpdateChildren()
 	if(this->IsVisible()) this->GetMainWindow()->GetDataTypeFrame()->ShowLayer(mFlipIndex);
 }
 
+
+//
+//  Helper class for window-dependent indicies (like active instances and data types)
+//
+iggIndex::iggIndex(iggShell *s)
+{
+	IASSERT(s);
+	mShell = s;
+}
+
+
+iggIndex::RegistryItem& iggIndex::Item() const
+{
+	int i,n = mShell->GetActiveViewModuleIndex();
+	iViewModule *vm;
+
+	for(i = 0; i <= n; i++)
+	{
+		vm = mShell->GetViewModule(i);
+
+		//
+		//  Update the registry, but only up to the window we need
+		//
+		while(i < this->mRegistry.Size() && this->mRegistry[i].vm != vm)
+		{
+			this->mRegistry.Remove(i);
+		}
+		if(i == this->mRegistry.Size())
+		{
+			RegistryItem w;
+			w.vm = vm;
+			w.idx = 0;
+			this->mRegistry.Add(w);
+		}
+	}
+
+	return this->mRegistry[n];
+}
+
 #endif
