@@ -46,14 +46,52 @@ public:
 
 protected:
 
-	iggPageMain(iggFrameBase *parent, bool withbook = true, bool feedback = false);
+	iggPageMain(iggFrameBase *parent, int flags);
 
 	virtual void UpdateChildren();
-	virtual iggFrame* CreateFlipFrame(iggFrameBase *parent) const = 0;
+	virtual iggFrame* CreateFlipFrame(iggFrameBase *parent) = 0;
 
 	iggFrame *mFlipFrame;
 	int mFlipIndex;
 };
 
+
+//
+//  Helper class for window-dependent indicies (like active instances and data types)
+//
+class iViewModule;
+
+class iggIndex
+{
+
+public:
+
+	iggIndex(iggShell *s);
+
+	inline void operator=(int v)
+	{
+		this->Item().idx = v;
+	}
+
+	inline operator int() const
+	{
+		return this->Item().idx;
+	}
+
+private:
+
+	struct RegistryItem
+	{
+		iViewModule *vm;
+		int idx;
+	};
+
+	RegistryItem& Item() const;
+
+	mutable iArray<RegistryItem> mRegistry;
+	iggShell *mShell;
+};
+
+
 #endif  // IGGPAGEMAIN_H
 
