@@ -35,33 +35,100 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "idata.h"
 #include "ierror.h"
+#include "iviewobject.h"
+#include "iviewsubject.h"
 
-#include "iggdatatypeprovider.h"
+#include "igghandle.h"
 #include "iggmainwindow.h"
+#include "iggshell.h"
 #include "iggpageobject.h"
 
 
-iggPageObjectExtension::iggPageObjectExtension(iggFrameBase *parent, int pageId, const iDataInfo &info, bool withbook , bool feedback) : iggPage(parent,withbook,feedback), mPageId(pageId), mInfo(new iDataInfo(info))
+namespace iggPageObjectExtension_Private
 {
-	IERROR_ASSERT(mInfo);
+	//
+	//  Returns the current VS
+	//
+	class ViewSubjectHandle : public iggObjectHandle
+	{
+
+	public:
+
+		ViewSubjectHandle(iggPageObjectExtension *owner) : iggObjectHandle(owner)
+		{
+			mOwner = owner; IASSERT(mOwner);
+		}
+
+		virtual const iObject* Object(int mod = -1) const
+		{
+			return mOwner->GetViewSubject(mod);
+		}
+
+	private:
+
+		iggPageObjectExtension *mOwner;
+	};
+};
+
+
+using namespace iggPageObjectExtension_Private;
+
+
+iggPageObjectExtension::iggPageObjectExtension(iggFrameBase *parent, int pageId, const iDataType &type, int flags) : iggPage(parent,flags), mPageId(pageId), mDataType(type)
+{
+	mOwner = this->GetMainWindow()->GetPage(mPageId); IASSERT(mOwner);
+
+	mSubjectHandle = new ViewSubjectHandle(this);
 }
 
 
 iggPageObjectExtension::~iggPageObjectExtension()
 {
-	delete mInfo;
+	delete mSubjectHandle;
+}
+
+
+const iggPropertyHandle iggPageObjectExtension::CreatePropertyHandle(const iString &name) const
+{
+	return iggPropertyHandle(name,mSubjectHandle,mOwner->GetInstanceHandle());
+}
+
+
+iViewSubject* iggPageObjectExtension::GetViewSubject(int mod) const
+{
+	iViewSubject *sub = mOwner->GetViewSubject(mod);
+
+	if(mDataType == sub->GetDataType())
+	{
+		return sub;
+	}
+	else
+	{
+		return mOwner->GetViewObject(mod)->GetSubject(mDataType);
+	}
+}
+
+
+int iggPageObjectExtension::GetActiveInstance() const
+{
+	return mOwner->GetActiveInstance();
+}
+
+
+const iImage* iggPageObjectExtension::Icon() const
+{
+	return mOwner->Icon();
 }
 
 
 void iggPageObjectExtension::UpdateWidgetBody()
 {
-	if(this->GetMainWindow()->GetPage(mPageId)!=0 && mInfo->Count()>0)
+	if(this->GetViewSubject(-1) == mOwner->GetViewSubject(-1))
 	{
-		this->Enable(mInfo->Includes(this->GetMainWindow()->GetPage(mPageId)->GetProvider()->GetActiveDataType()));
+		this->Enable(true);
+		this->iggPage::UpdateWidgetBody();
 	}
-	else this->Enable(true);
-
-	this->iggPage::UpdateWidgetBody();
+	else this->Enable(false);
 }
 
 #endif
