@@ -52,7 +52,7 @@ public:
 
 protected:
 
-	virtual iggFrame* CreateFlipFrame(iggFrameBase *parent) const;
+	virtual iggFrame* CreateFlipFrame(iggFrameBase *parent);
 
 	iggDialog *mWindowSizeDialog, *mWindowListDialog;
 };
