@@ -37,26 +37,22 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkOpenGLRenderWindow.h>
+#include "iviewmodulecomponent.h"
 
 
-#include "ipointermacro.h"
-
-class iViewModule;
-
 class iggMainWindow;
+class iggShell;
 
 class ibgRenderWindowSubject;
 
 
-class iggRenderWindow : public vtkOpenGLRenderWindow
+class iggRenderWindow : public vtkOpenGLRenderWindow, public iViewModuleComponent
 {
 
-	friend class iShellFactory;
+	friend class iggShell;
 	friend class iggMainWindow;
 	friend class ibgRenderWindowSubject;
 
-	IPOINTER_AS_PART(ViewModule);
-
 public:
 
 	vtkTypeMacro(iggRenderWindow,vtkOpenGLRenderWindow);
@@ -101,6 +97,12 @@ public:
 	//
 	virtual void SetStereoCapableWindow(int capable);
 
+	//
+	//  Shell-specific
+	//
+	void UpdateActiveStatus(bool last);
+	bool IsActiveWindow() const;
+
 protected:
 
 	iggRenderWindow(iViewModule *vm);
@@ -109,6 +111,7 @@ protected:
 	void AttachToMainWindow(iggMainWindow *mw);
 
 	void Initialize();
+	void Finalize();
 
 	//
 	//  These functions are helpers for image creation
@@ -127,6 +130,8 @@ protected:
 
 	ibgRenderWindowSubject *mSubject;
 
+	iggShell *mTrueShell;
+
 private:
 	//
 	//  Unused pure virtual overwrites
@@ -140,7 +145,6 @@ private:
 	virtual void SetWindowInfo(char *);
 	virtual void SetParentInfo(char *);
 
-	virtual void Finalize();
 	virtual void HideCursor();
 	virtual void ShowCursor();
 	virtual void WindowRemap();
