@@ -34,22 +34,19 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkRenderWindowInteractor.h>
+#include "iviewmodulecomponent.h"
 
 
 #include "ipointermacro.h"
 #include "ivtk.h"
 
-class iShell;
 
-
-class iggRenderWindowInteractor : public vtkRenderWindowInteractor
+class iggRenderWindowInteractor : public vtkRenderWindowInteractor, public iViewModuleComponent
 {
 
-	friend class iShellFactory;
+	friend class iggShell;
 	friend class ibgRenderWindowSubject;
 
-	IPOINTER_AS_PART(Shell);
-
 public:
 
 	vtkTypeMacro(iggRenderWindowInteractor,vtkRenderWindowInteractor);
@@ -82,20 +79,9 @@ public:
 	//virtual void StartPickCallback();
 	//virtual void EndPickCallback();
 
-	// Description:
-	// Timer methods must be overridden by platform dependent subclasses.
-	// flag is passed to indicate if this is first timer set or an update
-	// as Win32 uses repeating timers, whereas X uses One shot more timer
-	// if flag==VTKXI_TIMER_FIRST Win32 and X should createtimer
-	// otherwise Win32 should exit and X should perform AddTimeOut()
-#ifdef IVTK_PRE52
-	virtual int CreateTimer(int duration){ return this->InternalCreateTimer(1,1,duration); }
-	virtual int DestroyTimer(){ return this->InternalDestroyTimer(1); }
-#endif
-
 protected:
 
-	iggRenderWindowInteractor(iShell *shell);
+	iggRenderWindowInteractor(iViewModule *vm);
 	virtual ~iggRenderWindowInteractor();
 
 	virtual int InternalCreateTimer(int timerId, int timerType, unsigned long duration);
