@@ -33,12 +33,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggrenderwindowobserver.h"
 
 
-#include "icontrolmodule.h"
 #include "ierror.h"
-#include "ishell.h"
 #include "iviewmodule.h"
 
 #include "iggframe.h"
+#include "iggshell.h"
 
 #include <vtkRenderWindow.h>
 
@@ -48,7 +47,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 iggRenderWindowObserver::iggRenderWindowObserver(iggFrame *parent, bool disabled)
 {
-	IERROR_ASSERT(parent);
+	IASSERT(parent);
 	mParent = parent;
 
 	mParent->RegisterRenderWindowObserver(this);
@@ -59,7 +58,7 @@ iggRenderWindowObserver::iggRenderWindowObserver(iggFrame *parent, bool disabled
 	}
 	else
 	{
-		mHelper = new iggRenderWindowObserverHelper(this,parent); IERROR_ASSERT(mHelper);
+		mHelper = new iggRenderWindowObserverHelper(this,parent); IERROR_CHECK_MEMORY(mHelper);
 	}
 }
 
@@ -84,10 +83,10 @@ void iggRenderWindowObserver::UpdateConnection()
 //
 //  Helper class
 //
-iggRenderWindowObserverHelper::iggRenderWindowObserverHelper(iggRenderWindowObserver *owner, iggFrame *frame) : iEventObserver(frame?frame->GetShell():0)
+iggRenderWindowObserverHelper::iggRenderWindowObserverHelper(iggRenderWindowObserver *owner, iggFrame *frame) : iEventObserver()
 {
-	IERROR_ASSERT(frame);
-	IERROR_ASSERT(owner);
+	IASSERT(frame);
+	IASSERT(owner);
 
 	mFrame = frame;
 	mOwner = owner;
@@ -109,7 +108,7 @@ void iggRenderWindowObserverHelper::Detach()
 
 void iggRenderWindowObserverHelper::UpdateConnection()
 {
-	vtkRenderWindow *win = mFrame->GetShell()->GetControlModule()->GetViewModule()->GetRenderWindow();
+	vtkRenderWindow *win = mFrame->GetShell()->GetViewModule()->GetRenderWindow();
 	if(win!=0 && win!=mWindow)
 	{
 		this->Detach();
@@ -122,10 +121,10 @@ void iggRenderWindowObserverHelper::UpdateConnection()
 
 void iggRenderWindowObserverHelper::ExecuteBody(vtkObject *caller, unsigned long event, void *)
 {
-#ifdef I_CHECK1
+#ifndef I_NO_CHECK
 	if(caller != mWindow)
 	{
-		IERROR_REPORT_BUG;
+		IBUG_WARN("Internal check failed.");
 	}
 #endif
 	if(caller == mWindow)
