@@ -28,7 +28,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  A base class for all generic (toolkit-independent) widgets.
 //
-//  The GUI hierarchy tree is bulid in the following manner. All igg... classes are
+//  The GUI hierarchy tree is build in the following manner. All igg... classes are
 //  completely toolkit-independent and comprise their own independent hierarchy. They all
 //  derive from this class. Those of igg... classes that need toolkit-dependent capabilities
 //  have subject ibg...Subject (the same name) classes as members, and decorate them. The ibg... 
@@ -48,7 +48,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IGGWIDGET_H
 
 
-#include "iggelement.h"
+#include "iggrenderingelement.h"
 
 
 #include "iarray.h"
@@ -66,20 +66,6 @@ class ibgWidgetSubject;
 
 namespace iParameter
 {
-	namespace WidgetType
-	{
-		const int Other = 0;
-		const int Entry = 1;
-	};
-
-	namespace RenderMode
-	{
-		const int UseGlobal = 0;
-		const int Immediate = 1;
-		const int Delayed = 2;
-		const int NoRender = 3;
-	};
-
 	namespace ButtonType
 	{
 		const int PushButton = 0;
@@ -91,7 +77,7 @@ namespace iParameter
 };
 
 
-class iggWidget : public iggElement
+class iggWidget : public iggRenderingElement
 {
 
 	friend class iggFrame;
@@ -120,18 +106,13 @@ public:
 	virtual void Show(bool s);
 	bool IsVisible() const;
 
-	void Enable(bool s);
+	virtual void Enable(bool s);
 	bool IsEnabled() const;
 
 	void Emphasize(bool s, bool random = false);
 
 	void UpdateWidget();
 	
-	int GetExecuteFlags() const;
-	void SetExecuteFlags(int f);
-	static void SetGlobalExecuteFlags(int f);
-//	static inline int GetGlobalExecuteFlags(){ return mGlobalExecuteFlags; }
-
 #ifdef I_DEBUG
 	static void EmphasizeLayouts(bool s);
 #endif
@@ -139,7 +120,7 @@ public:
 protected:
 
 	iggWidget(iggFrameBase *parent);
-	iggWidget(iShell *shell);
+	iggWidget(iggShell *shell);
 
 	virtual void UpdateWidgetBody() = 0;
 	//
@@ -161,31 +142,27 @@ protected:
 	virtual void OnVoid3Body(){}
 ///	virtual void OnVoid4Body(){}
 	virtual void OnBool1Body(bool){}
-	virtual void OnString1Body(const iString &){}
 
 	iggFrameBase *mParent;
-	iPointerArray<iggWidget> mBuddies;
-	iPointerArray<iggWidget> mDependents;
-	bool mNeedsBaloonHelp, mWasLaidOut, mSubjectOwner, mInitialized, mHelpIsSet, mInUpdate;
+	iLookupArray<iggWidget*> mBuddies;
+	iLookupArray<iggWidget*> mDependents;
+	bool mNeedsBaloonHelp, mWasLaidOut, mSubjectOwner, mInitialized, mHelpIsSet, mInUpdate, mDisableDepedentUpdate;
 	iggMainWindow *mMainWindow;
 	ibgWidgetHelper *mWidgetHelper;
 	ibgWidgetSubject *mWidgetSubject;
 
 private:
 
-	static int mGlobalExecuteFlags;
-	int mExecuteFlags; // ExecureFlags should be accessed via GetExecuteFlags always
-
 	void Define();
 
 	//
 	//  Registry
 	//
-	static iPointerArray<iggWidget>& List();
+	static iLookupArray<iggWidget*>& List();
 
 	iggWidget(const iggWidget&); // Not implemented.
 	void operator=(const iggWidget&);  // Not implemented.
 };
 
-#endif  // IGGWIDGETBASE_H
+#endif  // IGGWIDGET_H
 
