@@ -33,11 +33,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggwidgetarea.h"
 
 
+#include "ierror.h"
 #include "ihistogram.h"
-#include "ihistogrammaker.h"
-#include "imath.h"
+#include "istretch.h"
 
-#include "iggframehistogramareaextra.h"
+#include "iggframehistogramcontrols.h"
 #include "iggmainwindow.h"
 
 #include "ibgwidgetareasubject.h"
@@ -47,38 +47,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
-
-
-//
-//  TextArea widget
-//
-iggWidgetTextArea::iggWidgetTextArea(const iString &text, iggFrame *parent) : iggWidget(parent)
-{
-	mSubject = iggSubjectFactory::CreateWidgetDisplayAreaSubject(this,text);
-
-	mNeedsBaloonHelp = false;
-}
-
-
-void iggWidgetTextArea::SetText(const iString &text)
-{
-	mSubject->SetText(text);
-}
-
-
-void iggWidgetTextArea::AlignLeft(bool s)
-{
-	mSubject->AlignLeft(s);
-}
-
-
-void iggWidgetTextArea::UpdateWidgetBody()
-{
-	//
-	//  Nothing to do here
-	//
-}
+#include "iarray.tlh"
 
 
 //
@@ -154,146 +123,95 @@ void iggWidgetImageArea::SetFixedSize(int w, int h)
 //
 //  HistogramArea widget (with a histogram as a background)
 //
-iggWidgetHistogramArea::iggWidgetHistogramArea(bool inlog, bool withticks, iggFrame *parent) : iggWidgetDrawArea(parent,true)
+iggWidgetHistogramArea::iggWidgetHistogramArea(iggFrameHistogramControls *controls, iggFrame *parent) : iggWidgetDrawArea(parent,true)
 {
-	mInLog = inlog;
-	mWithTicks = withticks;
-	mHistogram = 0;
-	mRange = 0;
-	mExtra = 0;
+	mControls = controls;  // controls can be 0
+
+	if(mControls != 0)
+	{
+		mControls->Attach(this);
+	}
 }
 
 
-void iggWidgetHistogramArea::SetHistogram(const iHistogram *h, float *range)
+void iggWidgetHistogramArea::DrawHistogram(const iHistogram &h, const iColor &color)
 {
-	mHistogram = h;
-	mRange = range;
-}
-	
+	float range[2] = { 0, 1 };
 
-void iggWidgetHistogramArea::DrawHistogram(const iColor &drawColor)
+	this->DrawHistogram(h,range,color);
+}
+
+
+void iggWidgetHistogramArea::DrawHistogram(const iHistogram &h, float range[2], const iColor &color)
 {
 	static float topOffset = 0.95f;
 	static const iColor tickColor = iColor(60,60,60);    // tick mark color
 	static int tickWidth = 3;
-	int i, ixmax, iymax, ix1, ix2, iy1, iytick;
-	float x1, x2, dx, yoffset;
 
-	if(mHistogram == 0)	return;
-	
-	float ys, ymax, ymin;
-	ymax = ymin = mHistogram->Y(1);
-	for(i=2; i<mHistogram->N()-1; i++)
+	if(h.NumBins() < 1)
 	{
-		if(ymax < mHistogram->Y(i)) ymax = mHistogram->Y(i);
-		if(ymin > mHistogram->Y(i)) ymin = mHistogram->Y(i);
+		return;
 	}
 
-	if(ymax < 1) return;
-
-	float ynorm = float(1.0/log(2*ymax));
-
-	ixmax = mSubject->Width() - 1;
-	iymax = mSubject->Height() - 1;
-	
-	yoffset = topOffset*iymax;
-	iytick = round(0.05*iymax);
-	
-	dx = float(1.0+(float)ixmax)/(mHistogram->N()-2);
-	x2 = 0.0;
-	if(mRange != 0)
+	int i;
+	float ymax = h.Value(0);
+	for(i=1; i<h.NumBins(); i++)
 	{
-		dx *= (mRange[1]-mRange[0]);
-		x2 += mRange[0]*(1.0f+ixmax);
+		if(ymax < h.Value(i)) ymax = h.Value(i);
 	}
-	ix2 = round(x2);
+	if(ymax < 1.0e-35) return;
 
-	int n = mHistogram->N()-1;
-	for(i=1; i<n; i++)  
+	bool inlog = false;
+	if(mControls != 0)
+	{
+		inlog = mControls->GetYLogScale();
+		mControls->DisplayRange(h.GetMin(),h.GetMax());
+	}
+	float xmin = iStretch::Apply(h.GetMin(),h.StretchId(),false);
+	float xmax = iStretch::Apply(h.GetMax(),h.StretchId(),true);
+	if(xmax-xmin < 1.0e-35) return;
+
+	int ixmin = iMath::Round2Int(range[0]*(mSubject->Width()-1));
+	int iymin = 0;
+	int ixmax = iMath::Round2Int(range[1]*(mSubject->Width()-1));
+	int iymax = mSubject->Height() - 1;
+
+	float xnorm = float(ixmax-ixmin);
+	float ynorm = float(1.0/log(1+ymax));
+	float ys,yoffset = topOffset*iymax;
+	int iytick = iMath::Round2Int(0.05*iymax);
+
+	int iy1,ix1,ix2 = ixmin;
+	for(i=0; i<h.NumBins(); i++)
 	{
-		x1 = x2;
 		ix1 = ix2;
-		x2 += dx;
-		ix2 = round(x2);
+		ix2 = ixmin + iMath::Round2Int(xnorm*(iStretch::Apply(h.GetBinMax(i),h.StretchId(),true)-xmin)/(xmax-xmin));
 		if(ix2 > ix1)
 		{
-			if(mInLog)
+			if(inlog)
 			{
-				ys = ynorm*float(log(1.0e-30f+2*mHistogram->Y(i)));
+				ys = ynorm*float(log(1+h.Value(i)));
 				if(ys < 0.0) ys = 0.0;
 			}
 			else
 			{
-				ys = mHistogram->Y(i)/ymax;
+				ys = h.Value(i)/ymax;
 			}
-			iy1 = round(yoffset*ys);
+			iy1 = iMath::Round2Int(yoffset*ys);
 			if(ix2 > ix1+1)
 			{
-				mSubject->DrawRectangle(ix1,0,ix2-1,iy1,drawColor,drawColor);
+				mSubject->DrawRectangle(ix1,0,ix2-1,iy1,color,color);
 			}
 			else
 			{
-				mSubject->DrawLine(ix1,0,ix1,iy1,drawColor);
+				mSubject->DrawLine(ix1,0,ix1,iy1,color);
 			}
-			if(mWithTicks && mHistogram->N()<20) 
+			if(h.NumBins() < 20)
 			{
 				mSubject->DrawLine((ix1+ix2)/2,0,(ix1+ix2)/2,iytick,tickColor,tickWidth);
 			}
 		}
 	}
-
-	if(mExtra != 0) mExtra->UpdateWidget();
-}
-
-
-void iggWidgetHistogramArea::DrawBackgroundBody()
-{
-	this->DrawHistogram();
-}
-
-
-void iggWidgetHistogramArea::SetLogScale(bool s)
-{
-	mInLog = s;
-	this->UpdateWidget();
-}
-
-
-void iggWidgetHistogramArea::GetHistogramRange(float &min, float &max) const
-{
-	if(mHistogram == 0) return;
-	min = mHistogram->GetMinValue();
-	max = mHistogram->GetMaxValue();
-}
-
-
-void iggWidgetHistogramArea::SetFullResolution(bool s)
-{
-	if(mHistogram!=0 && mHistogram->GetMaker()!=0 && s!=mHistogram->GetMaker()->GetFullResolution())
-	{
-		mHistogram->GetMaker()->SetFullResolution(s);
-		if(s) this->GetMainWindow()->Block(true);
-		mHistogram->GetMaker()->Update();
-		if(s) this->GetMainWindow()->Block(false);
-	}
-}
-
-
-bool iggWidgetHistogramArea::GetFullResolution() const
-{
-	if(mHistogram!=0 && mHistogram->GetMaker()!=0) return mHistogram->GetMaker()->GetFullResolution(); else return false;
-}
-
-
-bool iggWidgetHistogramArea::SupportsFullResolution() const
-{
-	if(mHistogram!=0 && mHistogram->GetMaker()!=0) return mHistogram->GetMaker()->SupportsFullResolution(); else return false;
-}
-
-
-void iggWidgetHistogramArea::AddExtra(iggFrameHistogramAreaExtra *extra)
-{
-	mExtra = extra;
 }
 
 #endif
