@@ -38,29 +38,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 class iHistogram;
 
-class iggFrameHistogramAreaExtra;
+class iggFrameHistogramControls;
 
 class ibgWidgetDrawAreaSubject;
-class ibgWidgetInteractiveDrawAreaSubject;
-class ibgWidgetDisplayAreaSubject;
-
-
-class iggWidgetTextArea : public iggWidget
-{
-
-public:
-
-	iggWidgetTextArea(const iString &text, iggFrame *parent);
-
-	void SetText(const iString &text);
-	void AlignLeft(bool s);
-
-protected:
-
-	virtual void UpdateWidgetBody();
-
-	ibgWidgetDisplayAreaSubject *mSubject;
-};
 
 
 class iggWidgetDrawArea : public iggWidget
@@ -119,30 +99,14 @@ class iggWidgetHistogramArea : public iggWidgetDrawArea
 
 public:
 
-	iggWidgetHistogramArea(bool inlog, bool withticks, iggFrame *parent);
-
-	void SetHistogram(const iHistogram *h, float *range);
-	void DrawHistogram(const iColor &drawcolor = iColor(160,160,160));
-
-	virtual void GetHistogramRange(float &min, float &max) const;
-	inline bool GetLogScale() const { return mInLog; }
-	void SetLogScale(bool s);
-
-	void SetFullResolution(bool s);
-	bool GetFullResolution() const;
-	bool SupportsFullResolution() const;
-
-	void AddExtra(iggFrameHistogramAreaExtra *extra);
+	iggWidgetHistogramArea(iggFrameHistogramControls *controls, iggFrame *parent);
 
 protected:
 
-	virtual void DrawBackgroundBody();
-	virtual void DrawForegroundBody(){}
+	void DrawHistogram(const iHistogram& h, const iColor &color = iColor(160,160,160));
+	void DrawHistogram(const iHistogram& h, float range[2], const iColor &color = iColor(160,160,160));
 
-	bool mInLog, mWithTicks;
-	float *mRange;
-	const iHistogram *mHistogram;
-	iggFrameHistogramAreaExtra *mExtra;
+	iggFrameHistogramControls *mControls;
 };
 
 #endif  // IGGWIDGETAREA_H
