@@ -33,10 +33,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggwidgetmisc.h"
 
 
-#include "iimagefactory.h"
 #include "imath.h"
 
 #include "iggframe.h"
+#include "iggimagefactory.h"
 
 #include "ibgwidgetareasubject.h"
 #include "ibgwidgetbuttonsubject.h"
@@ -98,80 +98,104 @@ void iggWidgetImageFlipper::UpdateWidgetBody()
 //
 iggWidgetLogoFlipper::iggWidgetLogoFlipper(iggFrame *parent) : iggWidgetImageFlipper(parent)
 {
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_000.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_001.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_002.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_003.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_004.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_005.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_006.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_007.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_008.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_009.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_010.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_011.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_012.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_013.png"),false);
-	mSubject->AddImage(*iImageFactory::FindIcon("genie1_frame_014.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_000.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_001.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_002.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_003.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_004.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_005.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_006.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_007.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_008.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_009.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_010.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_011.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_012.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_013.png"),false);
+	mSubject->AddImage(*iggImageFactory::FindIcon("genie1_frame_014.png"),false);
 
 	mNeedsBaloonHelp = false;
 }
 
 
 //
-//  iggWidgetNumberDisplay class
+//  NumberLabel widget
 //
-iggWidgetNumberDisplay::iggWidgetNumberDisplay(const iString &title, iggFrame *parent) : iggWidget(parent)
+iggWidgetNumberLabel::iggWidgetNumberLabel(iggFrame *parent, int alignment) : iggWidget(parent)
 {
-	mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,6,title);
-	mSubject->SetEditable(false);
+	mSubject = iggSubjectFactory::CreateWidgetDisplayAreaSubject(this,"");
+	this->SetAlignment(alignment);
 
 	mNeedsBaloonHelp = false;
-
-	this->Display(0);
 }
 
 
-void iggWidgetNumberDisplay::Display(double v, int prec)
+void iggWidgetNumberLabel::SetNumber(double v, const char *format)
 {
-	if(v != mSubject->GetValue())
-	{
-		if(prec>=0 && prec<20)
-		{
-			double f = pow10((float)prec);
-			v = round(f*v)/f;
-		}
-		mSubject->SetValue(0,v);
-	}
+	mSubject->SetText(iString::FromNumber(v,format));
 }
 
 
-void iggWidgetNumberDisplay::UpdateWidgetBody()
+void iggWidgetNumberLabel::SetNumber(int v, const char *format)
 {
+	mSubject->SetText(iString::FromNumber(v,format));
+}
+
+
+void iggWidgetNumberLabel::SetAlignment(int s)
+{
+	mSubject->SetAlignment(s);
+}
+
+
+void iggWidgetNumberLabel::UpdateWidgetBody()
+{
+	//
+	//  Nothing to do here
+	//
 }
 
 
 //
-//  iggWidgetTextDisplay class
+//  TextLabel widget
 //
-iggWidgetTextDisplay::iggWidgetTextDisplay(const iString &title, iggFrame *parent) : iggWidget(parent)
+iggWidgetTextLabel::iggWidgetTextLabel(const iString &text, iggFrame *parent, int alignment) : iggWidget(parent)
 {
-	mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,title);
-	mSubject->SetEditable(false);
+	mSubject = iggSubjectFactory::CreateWidgetDisplayAreaSubject(this,text);
+	this->SetAlignment(alignment);
 
 	mNeedsBaloonHelp = false;
-
-	this->Display("");
 }
 
 
-void iggWidgetTextDisplay::Display(const iString &text)
+void iggWidgetTextLabel::SetText(const iString &text)
 {
-	if(text != mSubject->GetText()) mSubject->SetText(text);
+	mSubject->SetText(text);
 }
 
 
-void iggWidgetTextDisplay::UpdateWidgetBody()
+void iggWidgetTextLabel::SetAlignment(int s)
+{
+	mSubject->SetAlignment(s);
+}
+
+
+void iggWidgetTextLabel::UpdateWidgetBody()
+{
+	//
+	//  Nothing to do here
+	//
+}
+
+
+//
+//******************************************
+//
+//  ItemizedSelectionBox
+//
+//******************************************
+//
+iggWidgetSimpleItemizedSelectionBox::iggWidgetSimpleItemizedSelectionBox(iggFrame *parent) : iggWidget(parent)
 {
 }
 
@@ -179,7 +203,7 @@ void iggWidgetTextDisplay::UpdateWidgetBody()
 //
 //  iggWidgetSimpleRadioBox class
 //
-iggWidgetSimpleRadioBox::iggWidgetSimpleRadioBox(int cols, const iString &text, iggFrame *parent) : iggWidget(parent)
+iggWidgetSimpleRadioBox::iggWidgetSimpleRadioBox(int cols, const iString &text, iggFrame *parent) : iggWidgetSimpleItemizedSelectionBox(parent)
 {
 	mSubject = iggSubjectFactory::CreateWidgetRadioBoxSubject(this,cols,text);
 }
@@ -208,6 +232,71 @@ void iggWidgetSimpleRadioBox::InsertItem(const iString &text, int index)
 	mSubject->SetValue(index>=0?index:0);
 }
 
+void iggWidgetSimpleRadioBox::SetItem(const iString &text, int index, bool vis)
+{
+	mSubject->SetItem(text,index,vis);
+}
+
+
+void iggWidgetSimpleRadioBox::RemoveItem(int index)
+{
+	if(index>=0 && index<this->Count())	mSubject->RemoveItem(index);
+}
+
+int iggWidgetSimpleRadioBox::Count() const
+{
+	return mSubject->Count();
+}
+
+
+//
+//  iggWidgetSimpleComboBox class
+//
+iggWidgetSimpleComboBox::iggWidgetSimpleComboBox(const iString &text, iggFrame *parent) : iggWidgetSimpleItemizedSelectionBox(parent)
+{
+	mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,text);
+}
+
+
+void iggWidgetSimpleComboBox::UpdateWidgetBody()
+{
+}
+
+
+int iggWidgetSimpleComboBox::GetValue() const
+{
+	return mSubject->GetValue();
+}
+
+
+void iggWidgetSimpleComboBox::SetValue(int v)
+{
+	mSubject->SetValue(v);
+}
+
+
+void iggWidgetSimpleComboBox::InsertItem(const iString &text, int index)
+{
+	mSubject->InsertItem(text,index);
+	mSubject->SetValue(index>=0?index:0);
+}
+
+void iggWidgetSimpleComboBox::SetItem(const iString &text, int index, bool vis)
+{
+	mSubject->SetItem(text,index,vis);
+}
+
+
+void iggWidgetSimpleComboBox::RemoveItem(int index)
+{
+	if(index>=0 && index<this->Count())	mSubject->RemoveItem(index);
+}
+
+int iggWidgetSimpleComboBox::Count() const
+{
+	return mSubject->Count();
+}
+
 
 //
 //  iggWidgetSimpleSpinBox class
@@ -235,6 +324,23 @@ int iggWidgetSimpleSpinBox::GetValue() const
 }
 
 
+void iggWidgetSimpleSpinBox::SetRange(int min,int max)
+{
+	mSubject->SetRange(min,max);
+}
+
+void iggWidgetSimpleSpinBox::SetStep(int step)
+{
+	mSubject->SetStep(step);
+}
+
+
+int iggWidgetSimpleSpinBox::Count()
+{
+	return mSubject->Count();
+}
+
+
 //
 //  iggWidgetSimpleCheckBox class
 //
