@@ -33,18 +33,19 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggwidgetotherbutton.h"
 
 
-#include "icontrolmodule.h"
 #include "ierror.h"
-#include "iimagefactory.h"
-#include "iobjecthelp.h"
+#include "ihelpfactory.h"
 #include "ishell.h"
 #include "iviewsubject.h"
 
 #include "iggdialog.h"
 #include "iggframe.h"
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
-#include "iggwidgetkeyhandler.h"
-#include "iggwidgetkeyslider.h"
+#include "igghandle.h"
+#include "iggpageobject.h"
+#include "iggwidgetpropertycontrol.h"
+#include "iggwidgetpropertycontrolslider.h"
 
 #include "ibgwidgetbuttonsubject.h"
 
@@ -53,29 +54,33 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates (needed for some compilers)
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
+#include "iggwidgetpropertycontrol.tlh"
+#include "iggwidgetpropertycontrolslider.tlh"
 
 
-using namespace iParameter;
 using namespace iParameter;
 
 
 //
 //  Show button
 //
-iggWidgetShowButton::iggWidgetShowButton(const iObjectType &type, iggFrame *parent) : iggWidget(parent), mType(type)
+iggWidgetShowButton::iggWidgetShowButton(iggPageObject *page, iggFrame *parent) : iggWidget(parent)
 {
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Show",1);
+	IASSERT(page);
+	mPage = page;
 
-	iString tt = "Shows/hides the "+type.FullName()+" object. Press Shift+F1 for more help.";
-	this->SetBaloonHelp(tt,type.GetHelp()->GetHTML());
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Show",1,25);
+
+	iString tt = "Shows/hides the "+mPage->GetObjectHandle()->Object()->LongName()+" object. Press Shift+F1 for more help.";
+	const iHelpDataBuffer &buf = iHelpFactory::FindData("or.-vo.vis",iHelpFactory::_ObjectReference);
+	this->SetBaloonHelp(tt,buf.GetHTML());
 }
 
 
 void iggWidgetShowButton::OnVoid1Body()
 {
-	this->GetShell()->GetControlModule()->Show(mType,mSubject->IsDown(),true);
-	this->GetMainWindow()->UpdateAll();
+	mPage->Show(mSubject->IsDown());
 }
 
 
@@ -84,21 +89,10 @@ void iggWidgetShowButton::OnVoid1Body()
 //
 void iggWidgetShowButton::UpdateWidgetBody()
 {
-	const iObjectKey *key;
+	const iViewSubject *sub = iDynamicCast<const iViewSubject>(INFO,mPage->GetSubjectHandle()->Object());
 
-	bool ready;
-	key = iObjectKeyRegistry::FindKey(iViewSubject::KeyReady().RetypedKey(mType)); IERROR_ASSERT(key);
-	if(this->GetShell()->GetControlModule()->QueryValue(*key,ready))
-	{
-		this->Enable(ready);
-	}
-
-	bool visible;
-	key = iObjectKeyRegistry::FindKey(iViewSubject::KeyVisible().RetypedKey(mType)); IERROR_ASSERT(key);
-	if(this->GetShell()->GetControlModule()->QueryValue(*key,visible))
-	{
-		mSubject->SetDown(visible);
-	}
+	this->Enable(sub->IsThereData());
+	mSubject->SetDown(sub->Visible.GetValue(0));
 }
 
 
@@ -180,20 +174,20 @@ void iggWidgetAllInstancesCheckBox::OnVoid1Body()
 {
 	int i, ef;
 
-	ef = DefaultOption;
+	ef = ExecuteFlag::Default;
 	if(mSubject->IsDown())
 	{
 		//
-		//  Unset the object mode flag
+		//  Unset the index flag
 		//
-		ef &= (~ObjectOption::Mask);
-		ef |= ObjectOption::All;
+		ef &= (~ExecuteFlag::Index::Mask);
+		ef |= ExecuteFlag::Index::All;
 	}
 
-	iggWidgetKeyHandlerBase *kh;
+	iggWidgetPropertyControlBase *kh;
 	for(i=0; i<mDependents.Size(); i++)
 	{
-		kh = dynamic_cast<iggWidgetKeyHandlerBase*>(mDependents[i]);
+		kh = dynamic_cast<iggWidgetPropertyControlBase*>(mDependents[i]);
 		if(kh != 0) kh->SetExecuteFlags(ef);
 	}
 }
@@ -202,10 +196,10 @@ void iggWidgetAllInstancesCheckBox::OnVoid1Body()
 //
 //  iggWidgetSimpleButton class
 //
-iggWidgetSimpleButton::iggWidgetSimpleButton(const iString &text, iggFrame *parent, bool tool) : iggWidget(parent)
+iggWidgetSimpleButton::iggWidgetSimpleButton(const iString &text, iggFrame *parent, bool tool, int minsize) : iggWidget(parent)
 {
 	int type = tool ? ButtonType::ToolButton : ButtonType::PushButton;
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,type,text,1);
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,type,text,1,minsize);
 }
 
 
@@ -236,25 +230,4 @@ void iggWidgetDialogCloseButton::Execute()
 	if(mDialog != 0) mDialog->Close();
 }
 
-
-//
-//  iggWidgetAdjustSizeSliderButton class
-//
-iggWidgetAdjustSizeSliderButton::iggWidgetAdjustSizeSliderButton(iggWidgetKeySizeSlider *s, bool shrink, iggFrame *parent) : iggWidgetSimpleButton("",parent,true)
-{
-	mSlider = s;
-	mShrink = shrink;
-
-	if(shrink) mSubject->SetIcon(*iImageFactory::FindIcon("moveright.png")); else mSubject->SetIcon(*iImageFactory::FindIcon("moveleft.png"));
-
-	this->SetBaloonHelp("Adjust the lower limit of the size slider");
-}
-
-
-void iggWidgetAdjustSizeSliderButton::Execute()
-{
-	mSlider->AdjustLowerLimit(mShrink);
-	mSlider->UpdateWidget();
-}
-
 #endif
