@@ -36,13 +36,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarray.h"
 
 class iImage;
-class iObjectType;
 
 class iggDialog;
 class iggMenuWindow;
+class iggObjectHandle;
 class iggPage;
-class iggWidgetKeyHandlerBase;
-class iggWidgetKeySizeSlider;
+class iggPageObject;
+class iggWidgetPropertyControlBase;
+class iggWidgetPropertyControlSizeSlider;
 
 class ibgWidgetButtonSubject;
 
@@ -52,7 +53,7 @@ class iggWidgetShowButton : public iggWidget
 
 public:
 
-	iggWidgetShowButton(const iObjectType &type, iggFrame *parent);
+	iggWidgetShowButton(iggPageObject *page, iggFrame *parent);
 
 protected:
 
@@ -60,7 +61,7 @@ protected:
 	virtual void OnVoid1Body();
 
 	ibgWidgetButtonSubject *mSubject;
-	const iObjectType &mType;
+	iggPageObject *mPage;
 };
 
 
@@ -108,7 +109,7 @@ class iggWidgetSimpleButton : public iggWidget
 
 public:
 
-	iggWidgetSimpleButton(const iString &text, iggFrame *parent, bool tool = false);
+	iggWidgetSimpleButton(const iString &text, iggFrame *parent, bool tool = false, int minsize = 0);
 
 protected:
 
@@ -134,21 +135,5 @@ protected:
 	iggDialog *mDialog;
 };
 
-
-class iggWidgetAdjustSizeSliderButton : public iggWidgetSimpleButton
-{
-
-public:
-
-	iggWidgetAdjustSizeSliderButton(iggWidgetKeySizeSlider *s, bool shrink, iggFrame *parent);
-
-protected:
-
-	virtual void Execute();
-
-	bool mShrink;
-	iggWidgetKeySizeSlider *mSlider;
-};
-
 #endif  // IGGWIDGETOTHERBUTTON_H
 
