@@ -51,7 +51,7 @@ public:
 	void Reset();
 
 	void Abort();
-	inline bool IsAborted() const { return mAborted; }
+	bool IsAborted() const;
 
 	inline ibgWidgetProgressBarSubject* GetSubject() const { return mSubject; } // needed for re-parenting
 
