@@ -33,14 +33,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggwidgetrendermodebutton.h"
 
 
-#include "icontrolmodule.h"
-#include "iimagefactory.h"
 #include "imarker.h"
-#include "iobjecthelp.h"
 #include "ishell.h"
 #include "iviewmodule.h"
 
-#include "iggwidgetkeyhandler.h"
+#include "iggimagefactory.h"
+#include "iggwidgetpropertycontrol.h"
 
 #include "ibgwidgetbuttonsubject.h"
 
@@ -49,7 +47,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Template
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -58,15 +56,15 @@ using namespace iParameter;
 //
 //  RenderMode button
 //
-iggWidgetRenderModeButton::iggWidgetRenderModeButton(iggWidgetKeyHandlerBase *parent, bool registered) : iggWidget(parent->GetParent())
+iggWidgetRenderModeButton::iggWidgetRenderModeButton(iggWidgetPropertyControlBase *parent, bool registered) : iggWidget(parent==0?0:parent->GetParent())
 {
-	mKeyHandler = parent;
+	mParent = parent; IASSERT(mParent)
 
-	mDelayIcon = iImageFactory::FindIcon("delay.png");
-	mReadyIcon = iImageFactory::FindIcon("ready.png");
+	mDelayIcon = iggImageFactory::FindIcon("delay.png");
+	mReadyIcon = iggImageFactory::FindIcon("ready.png");
 	if(mDelayIcon==0 || mReadyIcon==0)
 	{
-		IERROR_LOW("Icon images are not found.");
+		IBUG_WARN("Icon images are not found.");
 	}
 	if(registered) List().AddUnique(this);
 
@@ -91,7 +89,7 @@ iggWidgetRenderModeButton::~iggWidgetRenderModeButton()
 
 void iggWidgetRenderModeButton::UpdateWidgetBody()
 {
-	switch(mKeyHandler->GetRenderMode())
+	switch(mParent->GetRenderMode())
 	{
 	case RenderMode::Delayed:
 		{
@@ -105,7 +103,7 @@ void iggWidgetRenderModeButton::UpdateWidgetBody()
 		}
 	default:
 		{
-			IERROR_LOW("iggWidgetRenderModeButton should only be used with rendering widgets.");
+			IBUG_WARN("iggWidgetRenderModeButton should only be used with rendering widgets.");
 		}
 	}
 }
@@ -113,50 +111,31 @@ void iggWidgetRenderModeButton::UpdateWidgetBody()
 
 void iggWidgetRenderModeButton::OnVoid1Body()
 {
-	switch(mKeyHandler->GetRenderMode())
+	switch(mParent->GetRenderMode())
 	{
 	case RenderMode::Delayed:
 		{
-			mKeyHandler->SetRenderMode(RenderMode::Immediate);
+			mParent->SetRenderMode(RenderMode::Immediate);
 			break;
 		}
 	case RenderMode::Immediate:
 		{
-			mKeyHandler->SetRenderMode(RenderMode::Delayed);
+			mParent->SetRenderMode(RenderMode::Delayed);
 			break;
 		}
 	default:
 		{
-			IERROR_LOW("iggWidgetRenderModeButton should only be used with rendering widgets.");
+			IBUG_WARN("iggWidgetRenderModeButton should only be used with rendering widgets.");
 		}
 	}
 	this->UpdateWidget();
 }
 
 
-void iggWidgetRenderModeButton::ResetToGlobal()
-{
-	mKeyHandler->SetRenderMode(RenderMode::UseGlobal);
-	this->UpdateWidget();
-}
-
-
-void iggWidgetRenderModeButton::ResetAllToGlobal()
-{
-	int i;
-	iPointerArray<iggWidgetRenderModeButton> &list = List();
-
-	for(i=0; i<list.Size(); i++)
-	{
-		list[i]->ResetToGlobal();
-	}
-}
-
-
 void iggWidgetRenderModeButton::ShowAll(bool s)
 {
 	int i;
-	iPointerArray<iggWidgetRenderModeButton> &list = List();
+	iLookupArray<iggWidgetRenderModeButton*> &list(List());
 
 	for(i=0; i<list.Size(); i++)
 	{
@@ -168,7 +147,7 @@ void iggWidgetRenderModeButton::ShowAll(bool s)
 void iggWidgetRenderModeButton::UpdateAll()
 {
 	int i;
-	iPointerArray<iggWidgetRenderModeButton> &list = List();
+	iLookupArray<iggWidgetRenderModeButton*> &list(List());
 
 	for(i=0; i<list.Size(); i++)
 	{
@@ -177,9 +156,9 @@ void iggWidgetRenderModeButton::UpdateAll()
 }
 
 
-iPointerArray<iggWidgetRenderModeButton>& iggWidgetRenderModeButton::List()
+iLookupArray<iggWidgetRenderModeButton*>& iggWidgetRenderModeButton::List()
 {
-	static iPointerArray<iggWidgetRenderModeButton> list(100);
+	static iLookupArray<iggWidgetRenderModeButton*> list(100);
 	return list;
 }
 
