@@ -34,9 +34,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 class iImage;
-template<class T> class iPointerArray;
+template<class T> class iLookupArray;
 
-class iggWidgetKeyHandlerBase;
+class iggWidgetPropertyControlBase;
 
 class ibgWidgetButtonSubject;
 class ibgWidgetEntrySubject;
@@ -48,15 +48,12 @@ class iggWidgetRenderModeButton : public iggWidget
 
 public:
 
-	iggWidgetRenderModeButton(iggWidgetKeyHandlerBase *parent, bool registered = true);
+	iggWidgetRenderModeButton(iggWidgetPropertyControlBase *parent, bool registered = true);
 	virtual ~iggWidgetRenderModeButton();
 
-	static void ResetAllToGlobal();
 	static void ShowAll(bool s);
 	static void UpdateAll();
 
-	void ResetToGlobal();
-
 	ibgWidgetButtonSubject* GetSubject() const { return mSubject; }
 
 	//
@@ -71,12 +68,12 @@ protected:
 	virtual void OnVoid1Body();
 
 	ibgWidgetButtonSubject *mSubject;
-	iggWidgetKeyHandlerBase *mKeyHandler;
+	iggWidgetPropertyControlBase *mParent;
 	const iImage *mDelayIcon, *mReadyIcon;
 	//
 	//  Registry functionality
 	//
-	static iPointerArray<iggWidgetRenderModeButton> &List();
+	static iLookupArray<iggWidgetRenderModeButton*> &List();
 };
 
 #endif  // IQTWIDGETRENDERMODEBUTTON_H
