@@ -35,11 +35,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ierror.h"
 #include "ihelpfactory.h"
-#include "iimagefactory.h"
 #include "iobject.h"
 #include "istring.h"
 
 #include "iggframe.h"
+#include "iggimagefactory.h"
+#include "iggshell.h"
 
 #include "ibgwidgethelpbrowsersubject.h"
 #include "ibgwidgettexteditorsubject.h"
@@ -49,7 +50,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -128,6 +129,12 @@ void iggWidgetTextEditor::RemoveLine(int n)
 }
 
 
+void iggWidgetTextEditor::AdjustFontSize(int val)
+{
+	mSubject->AdjustFontSize(val);
+}
+
+
 //
 //  Selection
 //
@@ -155,7 +162,7 @@ void iggWidgetTextEditor::UseEditingFunction(int type)
 //
 //  iggWidgetTextBrowser class
 //
-iggWidgetTextBrowser::iggWidgetTextBrowser(bool wrapping, bool blockselection, iggFrame *parent) : iggWidgetTextEditor(TextEditorFlag::ReadOnly|TextEditorFlag::WithHTML|(wrapping?TextEditorFlag::Wrapping:0U),parent)
+iggWidgetTextBrowser::iggWidgetTextBrowser(bool wrapping, bool blockselection, iggFrame *parent, bool withHTML) : iggWidgetTextEditor(TextEditorFlag::ReadOnly|(withHTML?TextEditorFlag::WithHTML:0)|(wrapping?TextEditorFlag::Wrapping:0U),parent)
 {
 	mBlockSelection = blockselection;
 	mNeedsBaloonHelp = false;
@@ -165,13 +172,12 @@ iggWidgetTextBrowser::iggWidgetTextBrowser(bool wrapping, bool blockselection, i
 void iggWidgetTextBrowser::AppendTextLine(const iString &text, const iColor &textcolor)
 {
 	static const iString none;
-	static const iColor black(0,0,0);
 
-	this->AppendTextLine(none,text,black,textcolor);
+	this->AppendTextLine(none,text,textcolor);
 }
 
 
-void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &text, const iColor &prefixcolor, const iColor &color, bool prefixbold)
+void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &text, const iColor &textcolor, const iColor &prefixcolor, bool prefixbold)
 {
 	if(mSubject->SupportsHTML())
 	{
@@ -183,15 +189,15 @@ void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &
 			if(prefixbold) ws += "<b>";
 			ws += prefix + ": ";
 			if(prefixbold) ws += "</b>";
-			if(prefixcolor != color)
+			if(prefixcolor != textcolor)
 			{
-				ws += "</font><font color=\"#" + iString::FromNumber(color.Red(),"%02X") + iString::FromNumber(color.Green(),"%02X") + iString::FromNumber(color.Blue(),"%02X") + "\">";
+				ws += "</font><font color=\"#" + iString::FromNumber(textcolor.Red(),"%02X") + iString::FromNumber(textcolor.Green(),"%02X") + iString::FromNumber(textcolor.Blue(),"%02X") + "\">";
 			}
 		}
 		else
 		{
 			if(prefix == "\t") ws += "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"; 
-			ws += "<font color=\"#" + iString::FromNumber(color.Red(),"%02X") + iString::FromNumber(color.Green(),"%02X") + iString::FromNumber(color.Blue(),"%02X") + "\">";
+			ws += "<font color=\"#" + iString::FromNumber(textcolor.Red(),"%02X") + iString::FromNumber(textcolor.Green(),"%02X") + iString::FromNumber(textcolor.Blue(),"%02X") + "\">";
 		}
 		ws += text + "</font>";
 		mSubject->AppendText(ws);
@@ -203,7 +209,7 @@ void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &
 			iString ws;
 			if(prefix == "\t") ws += "        ";
 			ws += text;
-			mSubject->SetTextColor(color);
+			mSubject->SetTextColor(textcolor);
 			if(mSubject->AppendBreaksLine())
 			{
 				mSubject->AppendText(ws);
@@ -217,7 +223,7 @@ void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &
 		{
 			if(mSubject->AppendBreaksLine())
 			{
-				mSubject->SetTextColor(color);
+				mSubject->SetTextColor(textcolor);
 				mSubject->AppendText(prefix+": "+text);
 			}
 			else
@@ -226,7 +232,7 @@ void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &
 				mSubject->SetBoldText(prefixbold);
 				mSubject->AppendText(prefix+": ");
 				mSubject->SetBoldText(false);
-				mSubject->SetTextColor(color);
+				mSubject->SetTextColor(textcolor);
 				mSubject->AppendText(text+"\n");
 			}
 		}
@@ -368,19 +374,22 @@ void iggWidgetHelpBrowser::SetContentsText(const iString &text)
 		{
 			tmp = tmp.Part(i+1);
 			name = tmp.Section("\"",0,0);
-			im = iImageFactory::FindHelpChart(name.Part(8));
+			im = iggImageFactory::FindHelpChart(name.Part(8));
 			if(im != 0) 
 			{
 				mHTMLSubject->AddImage(name,*im);
 			}
 			else
 			{
-				IERROR_LOW(("Missing image "+name).ToCharPointer());
+				IBUG_WARN(("Missing image "+name).ToCharPointer());
 			}
 			i = tmp.Find("\"images::");
 		}
 		
-		mHTMLSubject->SetText(text);
+		tmp = text;
+		tmp.RemoveFormatting("<pdfonly>","</pdfonly>");
+
+		mHTMLSubject->SetText(tmp);
 	}
 	else
 	{
@@ -396,13 +405,11 @@ void iggWidgetHelpBrowser::SetContentsText(const iString &text)
 
 void iggWidgetHelpBrowser::SetContents(const char *tag, bool resetHistory)
 {
-	iHelpDataBuffer *buf = iHelpFactory::FindData(tag,iHelpFactory::_All,true);
+	const iHelpDataBuffer &buf = iHelpFactory::FindData(tag,iHelpFactory::_All,true);
 
-	if(buf == 0) return; // avoid recursion
-
-	if(!buf->IsNull())
+	if(!buf.IsNull())
 	{
-		iString text = buf->GetHTML();
+		iString text = buf.GetHTML();
 
 		this->ModifyText(tag,text);
 		this->SetContentsText(text);
@@ -417,8 +424,6 @@ void iggWidgetHelpBrowser::SetContents(const char *tag, bool resetHistory)
 		this->UpdateDependents();
 	}
 	else this->OnNullHelpBuffer();
-
-	delete buf;
 }
 
 
@@ -482,36 +487,23 @@ void iggWidgetHelpBrowser::ModifyText(const char *tag, iString &text)
 		iString tmp = (tag+3);
 		if(tmp.Contains('.') == 0)
 		{
-			text += "<p><b>Available properties:</b><ul>";
-
-			const iObjectType *type = iObjectTypeRegistry::FindType(tmp);
-			if(type != 0)
+			text = iHelpFactory::FormObjectDescription(tmp,false);
+#ifndef I_NO_CHECK
+			if(text.IsEmpty())
 			{
-				const iObjectKey *key;
-				iObjectKeyRegistry::InitTraversal(type);
-				while((key=iObjectKeyRegistry::GetNextKey(false)) != 0)
-				{
-					text += iHelpFactory::FormKeyReference(*key,true);
-				}
+				IBUG_ERROR("Undefined reference tag: "+iString(tmp));
 			}
-			text += "</ul>";
+#endif
 		}
 		else
 		{
-			//
-			//  Is this a key reference?
-			//
-			iString name = tmp.Section(".",0,1);
-			name.Replace(".",iObjectKey::PrefixSeparator());
-			const iObjectKey *key = iObjectKeyRegistry::FindKey(name,true);
-
-			if(key != 0)
+			text = iHelpFactory::FormPropertyDescription(tmp,false,true);
+#ifndef I_NO_CHECK
+			if(text.IsEmpty())
 			{
-				//
-				//  Yes, it is a key reference
-				//
-				text = iHelpFactory::FormKeyDescription(*key,text,false);
+				IBUG_ERROR("Undefined reference tag: "+iString(tmp));
 			}
+#endif
 		}
 	}
 
