@@ -51,10 +51,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qtooltip.h>
 #else
 #include <QtGui/QCloseEvent>
+#ifdef IQT_4
 #include <QtGui/QDialog>
 #include <QtGui/QGridLayout>
 #include <QtGui/QPushButton>
 #include <QtGui/QToolTip>
+#else
+#include <QtWidgets/QDialog>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QToolTip>
+#endif
 #endif
 
 
@@ -72,7 +79,7 @@ iqtDialogSubject::iqtDialogSubject(iggDialog *owner, const ibgWindowSubject *bas
 #endif
 	ibgDialogSubject(owner,base,mode,icon,title)
 {
-	mWindowHelper = new iqtWindowHelper(this,icon,title); IERROR_ASSERT(mWindowHelper);
+	mWindowHelper = new iqtWindowHelper(this,icon,title); IERROR_CHECK_MEMORY(mWindowHelper);
 
 	mMode = mode;
 	QGridLayout *layout = iqtHelper::NewLayout(this,1);
