@@ -43,7 +43,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifdef IQT_3
 #include <qlayout.h>
 #else
+#ifdef IQT_4
 #include <QtGui/QGridLayout>
+#else
+#include <QtWidgets/QGridLayout>
+#endif
 #endif
 
 
@@ -54,12 +58,12 @@ iqtExplicitFrameSubject::iqtExplicitFrameSubject(QWidget *qparent, iggFrame *own
 {
 	if(cols < 1)
 	{
-		IERROR_LOW("Incorrect number of columns.");
+		IBUG_WARN("Incorrect number of columns.");
 		cols = 1;
 	}
 	if(cols > 7)
 	{
-		IERROR_LOW("Current implementation does not support more than 7 columns.");
+		IBUG_WARN("Current implementation does not support more than 7 columns.");
 		cols = 7;
 	}
 
@@ -84,7 +88,7 @@ iqtExplicitFrameSubject::iqtExplicitFrameSubject(QWidget *qparent, iggFrame *own
 		mLayout = iqtHelper::NewLayout(this->layout(),cols);
 	}
 
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 }
 
 
@@ -147,7 +151,7 @@ void iqtExplicitFrameSubject::SetColStretch(int col, int s)
 #ifdef IQT_3
 	if(mLayout->numCols() != mNumCols)
 	{
-		IERROR_LOW("Corrupted layout.");
+		IBUG_WARN("Corrupted layout.");
 	}
 	if(col>=0 && col<mNumCols) mLayout->setColStretch(col,s);
 #else
@@ -161,7 +165,7 @@ void iqtExplicitFrameSubject::SetRowStretch(int row, int s)
 #ifdef IQT_3
 	if(mLayout->numRows() != mNumRows)
 	{
-		IERROR_LOW("Corrupted layout.");
+		IBUG_WARN("Corrupted layout.");
 	}
 	if(row>=0 && row<mNumRows) mLayout->setRowStretch(row,s);
 #else
@@ -199,7 +203,7 @@ void iqtExplicitFrameSubject::PlaceWidget(int col, int row, ibgWidgetSubject *ch
 	}
 	else
 	{
-		IERROR_LOW("Invalid layout cell.");
+		IBUG_WARN("Invalid layout cell.");
 	}
 }
 
