@@ -37,8 +37,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #ifdef IQT_3
 #include <qgroupbox.h>
-#else
+#elif defined(IQT_4)
 #include <QtGui/QGroupBox>
+#else
+#include <QtWidgets/QGroupBox>
 #endif
 #include "ibgframesubject.h"
 
