@@ -34,11 +34,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
-#include "iimagefactory.h"
 #include "istring.h"
 
 #include "iggabstractextension.h"
 #include "iggextensionwindow.h"
+#include "iggimagefactory.h"
 
 #include "iqthelper.h"
 #include "iqtwindowhelper.h"
@@ -49,8 +49,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qlayout.h>
 #include <qstyle.h>
 #else
-#include <QtGui/QGridLayout>
 #include <QtGui/QMouseEvent>
+#ifdef IQT_4
+#include <QtGui/QGridLayout>
+#else
+#include <QtWidgets/QGridLayout>
+#endif
 #endif
 
 
@@ -68,7 +72,7 @@ iqtExtensionWindowSubject::iqtExtensionWindowSubject(iggExtensionWindow *ew) :
 #endif
 	ibgExtensionWindowSubject(ew)
 {
-	mWindowHelper = new iqtWindowHelper(this,iImageFactory::FindIcon("genie1ext.png"),"IFrIT - Extension Window",true); IERROR_ASSERT(mWindowHelper);
+	mWindowHelper = new iqtWindowHelper(this,iggImageFactory::FindIcon("genie1ext.png"),"IFrIT - Extension Window",true); IERROR_CHECK_MEMORY(mWindowHelper);
 }
 
 
