@@ -48,9 +48,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #else
 #include <QtCore/QEvent>
 #include <QtGui/QImage>
+#ifdef IQT_4
 #include <QtGui/QLayout>
 #include <QtGui/QScrollBar>
 #include <QtGui/QTabBar>
+#else
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QScrollBar>
+#include <QtWidgets/QTabBar>
+#endif
 #endif
 
 
@@ -75,7 +81,7 @@ iqtFrameSubject::~iqtFrameSubject()
 //
 iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback) : QTabWidget(iqtHelper::Convert(owner->GetParent())), ibgFrameBookSubject(owner,withFeedback)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
 
@@ -88,9 +94,9 @@ iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback)
 	if(withFeedback)
 	{
 #ifdef IQT_3
-		if(!this->connect(this,SIGNAL(currentChanged(QWidget * )),this,SLOT(OnCurrentChanged(QWidget * )))) IERROR_LOW("Missed connection.");
+		if(!this->connect(this,SIGNAL(currentChanged(QWidget * )),this,SLOT(OnCurrentChanged(QWidget * )))) IBUG_WARN("Missed connection.");
 #else
-		if(!this->connect(this,SIGNAL(currentChanged(int)),this,SLOT(OnCurrentChanged(int)))) IERROR_LOW("Missed connection.");
+		if(!this->connect(this,SIGNAL(currentChanged(int)),this,SLOT(OnCurrentChanged(int)))) IBUG_WARN("Missed connection.");
 #endif
 	}
 }
@@ -138,7 +144,8 @@ void iqtFrameBookSubject::OpenPage(int i)
 
 void iqtFrameBookSubject::AddPage(const iString &title, const iImage *image, iggFrame *frame)
 {
-	QWidget *w = iqtHelper::Convert(frame); IERROR_ASSERT(w);
+	QWidget *w = iqtHelper::Convert(frame); 
+	IASSERT(w);
 #ifndef IQT_3
 	iqtHelper::SetParent(w,0);
 #endif
@@ -265,7 +272,7 @@ int iqtFrameBookSubject::GetOrientation()
 //
 iqtFrameFlipSubject::iqtFrameFlipSubject(iggFrameFlip *owner, bool expanding) : QStackedWidget(iqtHelper::Convert(owner->GetParent())), ibgFrameFlipSubject(owner,expanding)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,expanding?QSizePolicy::Expanding:QSizePolicy::Minimum));
 }
@@ -315,7 +322,7 @@ void iqtFrameFlipSubject::AddLayerBody(iggFrame *page)
 //
 iqtFrameScrollSubject::iqtFrameScrollSubject(iggFrameScroll *owner, bool withHor, bool withVer) : QScrollArea(iqtHelper::Convert(owner->GetParent())), ibgFrameScrollSubject(owner,withHor)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 
 #ifdef IQT_3
 	this->setVScrollBarMode(withVer?QScrollView::Auto:QScrollView::AlwaysOff);
@@ -328,7 +335,7 @@ iqtFrameScrollSubject::iqtFrameScrollSubject(iggFrameScroll *owner, bool withHor
 #endif
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
-};
+}
 
 
 void iqtFrameScrollSubject::AttachContents(iggFrame *frame)
@@ -396,4 +403,21 @@ QSize iqtFrameScrollSubject::sizeHint() const
 }
 #endif
 
+
+//
+//  FrameSplit class
+//
+iqtFrameSplitSubject::iqtFrameSplitSubject(iggFrameSplit *owner, bool hor) : QSplitter(hor?Qt::Horizontal:Qt::Vertical ,iqtHelper::Convert(owner->GetParent())), ibgFrameSplitSubject(owner,hor)
+{
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
+}
+
+
+void iqtFrameSplitSubject::AddSegment(iggFrame *frame)
+{
+	//
+	//  This is automatic
+	//
+}
+
 #endif
