@@ -35,6 +35,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iqt.h"
 
+
 #ifdef IQT_3
 #include <qnamespace.h>
 #else
@@ -50,7 +51,6 @@ class iggFrameBase;
 class QColor;
 class QFont;
 class QGridLayout;
-class QIcon;
 class QImage;
 class QLayout;
 class QPaintEvent;
@@ -112,7 +112,7 @@ public:
 	//  Image conversion
 	//
 	static iImage Convert(const QImage &i);
-	static QImage Convert(const iImage &i);
+	static QImage Convert(const iImage &i, float scale = 1.0f);
 	static QPixmap ConvertToPixmap(const iImage &i, bool withMask = true);
 	static QIcon ConvertToIcon(const iImage &i);
 
