@@ -33,18 +33,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iqtmainwindowsubject.h"
 
 
-#include "icontrolmodule.h"
 #include "ierror.h"
-#include "iimagefactory.h"
-#include "ishell.h"
 #include "iviewmodule.h"
 
 #include "iggdialog.h"
 #include "iggextensionwindow.h"
 #include "iggframe.h"
 #include "iggframetopparent.h"
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
 #include "iggrenderwindow.h"
+#include "iggshell.h"
 
 #include "ibgwindowhelper.h"
 
@@ -61,28 +60,39 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qcursor.h>
 #include <qlayout.h>
 #include <qmenubar.h>
-#include <qmessagebox.h>
 #include <qstatusbar.h>
 #include <qstylefactory.h>
 #include <qtoolbutton.h>
 #include <qtooltip.h>
 #include <qworkspace.h>
 #else
+#include <QtGui/QWindowStateChangeEvent>
+#ifdef IQT_4
 #include <QtGui/QApplication>
 #include <QtGui/QLayout>
 #include <QtGui/QMenuBar>
-#include <QtGui/QMessageBox>
 #include <QtGui/QStatusBar>
 #include <QtGui/QStyleFactory>
 #include <QtGui/QToolButton>
-#include <QtGui/QWindowStateChangeEvent>
-#include <QtGui/QWorkspace>
+#include <QtGui/QMdiArea>
+#else
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QMenuBar>
+#include <QtWidgets/QStatusBar>
+#include <QtWidgets/QStyleFactory>
+#include <QtWidgets/QToolButton>
+#include <QtWidgets/QMdiArea>
+#endif
+#define addWindow	addSubWindow
+#define windowList	subWindowList
+#define cascade		cascadeSubWindows
 #endif
 
 //
 //  templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -97,7 +107,9 @@ namespace iqtMainWindowSubject_Private
 
 		Workspace(QWidget *parent) : QWorkspace(parent)
 		{
+#ifdef IQT_3
 			this->setScrollBarsEnabled(true);
+#endif
 		}
 
 		void AddWindow(iqtRenderWindowSubject *rw)
@@ -137,10 +149,11 @@ using namespace iqtMainWindowSubject_Private;
 //
 //  Main class
 //
-iqtMainWindowSubject::iqtMainWindowSubject(iggMainWindow *owner) : iqtMenuWindowSubject(owner,iImageFactory::FindIcon("genie1gui.png"),"Ionization Front Interactive Tool"), ibgMainWindowSubject(owner)
+iqtMainWindowSubject::iqtMainWindowSubject(iggMainWindow *owner) : iqtMenuWindowSubject(owner,iggImageFactory::FindIcon("genie1gui.png"),"Ionization Front Interactive Tool"), ibgMainWindowSubject(owner)
 {
 	int i;
 
+	mTimerId = -1;
 	mMainFrame = 0;
 	mDockingWorkspace = 0;
 
@@ -154,6 +167,7 @@ iqtMainWindowSubject::iqtMainWindowSubject(iggMainWindow *owner) : iqtMenuWindow
 
 iqtMainWindowSubject::~iqtMainWindowSubject()
 {
+	if(mTimerId > -1) this->killTimer(mTimerId);
 }
 
 
@@ -181,57 +195,6 @@ void iqtMainWindowSubject::PopulateStatusBar(iggFrame *busyIndicatorFrame, ibgWi
 }
 
 
-int iqtMainWindowSubject::PopupWindow(const iggFrame *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2)
-{
-	QWidget *w;
-	if(parent != 0)
-	{
-		w = iqtHelper::Convert(parent);
-	}
-	else
-	{
-		w = this;
-	}
-	
-	return PopupWindowBody(w,text,type,b0,b1,b2);
-}
-
-
-int iqtMainWindowSubject::PopupWindow(const iggRenderWindow *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2)
-{
-	if(parent != 0)
-	{
-		return PopupWindowBody(iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,parent->GetSubject()),text,type,b0,b1,b2);
-	}
-	else return -1;
-}
-
-
-int iqtMainWindowSubject::PopupWindowBody(QWidget *w, const iString &text, int type, const char *b0, const char *b1, const char *b2)
-{
-	switch(type)
-	{
-	case PopupWindow::Message:
-		{
-			return QMessageBox::information(w,"IFrIT",iqtHelper::Convert(text),b0,b1,b2);
-		}
-	case PopupWindow::Warning:
-		{
-			return QMessageBox::warning(w,"IFrIT",iqtHelper::Convert(text),b0,b1,b2);
-		}
-	case PopupWindow::Error:
-		{
-			return QMessageBox::critical(w,"IFrIT",iqtHelper::Convert(text),b0,b1,b2);
-		}
-	default:
-		{
-			IERROR_LOW("Incorrect type for pop-up window.");
-		}
-	}
-	return -1;
-}
-
-
 void iqtMainWindowSubject::ShowToolTips(bool s)
 {
 #ifdef IQT_3
@@ -246,6 +209,12 @@ void iqtMainWindowSubject::SetTheme(const iString &name)
 }
 
 
+void iqtMainWindowSubject::StartTimer()
+{
+	mTimerId = this->startTimer(10);
+}
+
+
 //
 //  Docking helpers
 //
@@ -253,7 +222,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 {
 	if(mMainFrame != 0)
 	{
-		IERROR_FATAL("Invalid call to iqtMainWindowSubject::PlaceWindowsInDockedPositions.");
+		IBUG_FATAL("Invalid call to iqtMainWindowSubject::PlaceWindowsInDockedPositions.");
 	}
 
 	QSize s = this->size();
@@ -263,7 +232,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 	mMainFrame = this->centralWidget();
 
 	QWidget *base = new QWidget(this);
-	QGridLayout *l = iqtHelper::NewLayout(base,2); IERROR_ASSERT(l);
+	QGridLayout *l = iqtHelper::NewLayout(base,2); IERROR_CHECK_MEMORY(l);
 #ifdef IQT_3
 	l->expand(2,2);
 	l->setColStretch(0,10);
@@ -281,7 +250,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 
 	QGridLayout *fl = iqtHelper::NewLayout(fw,1);
 
-    Workspace *ws = new Workspace(fw); IERROR_ASSERT(ws);
+    Workspace *ws = new Workspace(fw); IERROR_CHECK_MEMORY(ws);
 	fl->addWidget(ws,0,0);
 
 	l->addWidget(fw,0,0);
@@ -325,7 +294,7 @@ void iqtMainWindowSubject::RestoreWindowsFromDockedPositions()
 {
 	if(mMainFrame == 0)
 	{
-		IERROR_FATAL("Invalid call to iqtMainWindowSubject::RestoreWindowsFromDockedPositions.");
+		IBUG_FATAL("Invalid call to iqtMainWindowSubject::RestoreWindowsFromDockedPositions.");
 	}
 
 	this->hide();
@@ -340,9 +309,9 @@ void iqtMainWindowSubject::RestoreWindowsFromDockedPositions()
 		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->showNormal();
 		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->AttachToParent(0);
 #ifdef IQT_3
-		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->setIcon(iqtHelper::ConvertToPixmap(*iImageFactory::FindIcon("genie1vtk.png")));
+		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->setIcon(iqtHelper::ConvertToPixmap(*iggImageFactory::FindIcon("genie1vtk.png")));
 #else
-		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->setWindowIcon(iqtHelper::ConvertToPixmap(*iImageFactory::FindIcon("genie1vtk.png")));
+		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->setWindowIcon(iqtHelper::ConvertToPixmap(*iggImageFactory::FindIcon("genie1vtk.png")));
 #endif
 	}
 
@@ -381,7 +350,7 @@ void iqtMainWindowSubject::AttachRenderWindow(iggRenderWindow *rw)
 	iqtRenderWindowSubject *s = iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,rw->GetSubject());
 	Workspace *ws = iDynamicCast<Workspace,QWorkspace>(INFO,mDockingWorkspace);
 
-	if(mMainWindow->IsDocked())
+	if(mMainWindow->GetDocked())
 	{
 		s->GetHelper()->SaveWindowGeometry();
 		ws->AddWindow(s);
@@ -440,13 +409,14 @@ void iqtMainWindowSubject::closeEvent(QCloseEvent *e)
 }
 
 
+void iqtMainWindowSubject::timerEvent(QTimerEvent *e)
+{
+	this->GetShell()->OnTimerEvent();
+}
+
+
 void iqtMainWindowSubject::resizeEvent(QResizeEvent *e)
 {
-	static const iString tmp("New size");
-
-#ifdef I_DEBUG
-	mMainWindow->WriteToLog(tmp,iString::FromNumber(e->size().width())+"x"+iString::FromNumber(e->size().height()));
-#endif
 	QMainWindow::resizeEvent(e);
 }
 
