@@ -37,7 +37,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgmainwindowsubject.h"
 
 
+#ifdef IQT_3
 class QWorkspace;
+#else
+class QMdiArea;
+#define QWorkspace	QMdiArea
+#endif
 
 
 class iqtMainWindowSubject : public iqtMenuWindowSubject, public ibgMainWindowSubject
@@ -59,10 +64,9 @@ protected:
 	//
 	//  General members
 	//
-	virtual int PopupWindow(const iggFrame *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2);
-	virtual int PopupWindow(const iggRenderWindow *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2);
 	virtual void ShowToolTips(bool s);
 	virtual void SetTheme(const iString &name);
+	virtual void StartTimer();
 
 	//
 	//  Construction helpers
@@ -82,7 +86,8 @@ protected:
 	virtual bool event(QEvent *e);
 	virtual void moveEvent(QMoveEvent *e);
 	virtual void closeEvent(QCloseEvent *e);
-	virtual void resizeEvent(QResizeEvent *e); 
+	virtual void timerEvent(QTimerEvent *e);
+	virtual void resizeEvent(QResizeEvent *e);
 //	virtual void keyPressEvent(QKeyEvent *e); 
 //	virtual void keyReleaseEvent(QKeyEvent *e); 
 //	virtual void focusInEvent(QFocusEvent *e);
@@ -90,8 +95,7 @@ protected:
 
 private:
 
-	int PopupWindowBody(QWidget *w, const iString &text, int type, const char *b0, const char *b1, const char *b2);
-
+	int mTimerId;
 	QWidget *mMainFrame;
 	QWorkspace *mDockingWorkspace;
 
