@@ -40,18 +40,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qmainwindow.h>
 #include <qpopupmenu.h>
 #define QMenu QPopupMenu
-#else
+#elif defined(IQT_4)
 #include <QtGui/QAction>
 #include <QtGui/QMainWindow>
 #include <QtGui/QMenu>
+#else
+#include <QtWidgets/QAction>
+#include <QtWidgets/QMainWindow>
+#include <QtWidgets/QMenu>
 #endif
 #include "ibgmenuwindowsubject.h"
 
 
 #include "iarray.h"
 
-class iObjectKey;
-
 class iqtMenu;
 class iqtMenuWindowSubject;
 
@@ -69,7 +71,8 @@ class iqtMenuItem : public QAction
 
 public:
 
-	iqtMenuItem(int id, iqtMenuWindowSubject *subject, const iObjectKey *ekey, bool reverse, const iObjectKey *vkey, int val);
+	iqtMenuItem(int id, iqtMenuWindowSubject *subject, const iggMenuHelperBase *enabler, const iggMenuHelperBase *checker);
+	~iqtMenuItem();
 
 	void Update();
 	inline int GetId() const { return mId; }
@@ -86,9 +89,8 @@ protected slots:
 
 protected:
 
-	int mId, mValue;
-	bool mReverse;
-	const iObjectKey *mEnableKey, *mValueKey;
+	int mId;
+	iggMenuHelperBase *mEnabler, *mChecker;
 	iqtMenuWindowSubject *mSubject;
 };
 
@@ -138,9 +140,9 @@ public:
 
 	virtual void BeginMenu(const iString &text, bool exclusive);
 	virtual void EndMenu();
-	virtual void AddMenuItem(int id, const iString &text, const iImage *icon, const iString &accel, bool toggle, bool on, const iObjectKey *ekey = 0, bool reverse = false, const iObjectKey *vkey = 0, int val = iMath::_IntMax);
+	virtual void AddMenuItem(int id, const iString &text, const iImage *icon, const iString &accel, bool toggle, bool on, const iggMenuHelperBase *enabler = 0, const iggMenuHelperBase *checker = 0);
 	virtual void AddMenuSeparator();
-	virtual void AddToolBarButton(int id, const iString &tooltip, const iImage *icon = 0, bool toggle = false, const iObjectKey *ekey = 0, bool reverse = false, const iObjectKey *vkey = 0, int val = iMath::_IntMax);
+	virtual void AddToolBarButton(int id, const iString &tooltip, const iImage *icon, bool toggle, const iggMenuHelperBase *enabler = 0, const iggMenuHelperBase *checker = 0);
 	virtual void AddToolBarSeparator();
 	virtual void CompleteMenu();
 
@@ -166,6 +168,7 @@ protected:
 	//  Qt-specific
 	//
 	virtual bool event(QEvent *e);
+	virtual void closeEvent(QCloseEvent *e);
 
 protected slots:
 
