@@ -36,12 +36,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iqtrenderwindowsubject.h"
 
 
-#include "icontrolmodule.h"
 #include "ierror.h"
-#include "iimagefactory.h"
 #include "iviewmodule.h"
 #include "ivtk.h"
 
+#include "iggimagefactory.h"
 #include "iggmainwindow.h"
 #include "iggrenderwindow.h"
 #include "iggshell.h"
@@ -59,17 +58,25 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qtimer.h>
 #else
 #include <QtCore/QTimer>
-#include <QtGui/QApplication>
 #include <QtGui/QImage> 
-#include <QtGui/QLayout>
 #include <QtGui/QMouseEvent>
+#ifdef IQT_4
+#include <QtGui/QApplication>
+#include <QtGui/QLayout>
+#else
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QLayout>
+#include <QtGui/QWindow>
+#endif
+#ifdef Q_WS_X11
 #include <QtGui/QX11Info>
 #endif
+#endif
 
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
@@ -83,7 +90,7 @@ iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget*
 #endif
 	ibgRenderWindowSubject(owner)
 {
-	mWindowHelper = new iqtWindowHelper(this,iImageFactory::FindIcon("genie1vtk.png"),"",true); IERROR_ASSERT(mWindowHelper);
+	mWindowHelper = new iqtWindowHelper(this,iggImageFactory::FindIcon("genie1vtk.png"),"",true); IERROR_CHECK_MEMORY(mWindowHelper);
 
 	this->setFocusPolicy(QFocus::StrongFocus);
 
@@ -92,7 +99,7 @@ iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget*
 	//
 	if(!this->doubleBuffer())
 	{
-		IERROR_FATAL("IFrIT only works in double buffering mode.");
+		IBUG_FATAL("IFrIT only works in double buffering mode.");
 	}
 	this->setMinimumWidth(120);
 	this->setMinimumHeight(120);
@@ -136,7 +143,7 @@ void iqtRenderWindowSubject::AttachToParent(QWidget *parent, bool border)
 #ifdef I_DEBUG
 	if(!this->context()->isValid())
 	{
-		IERROR_FATAL("Invalid context in iqtRenderWindowSubject.");
+		IBUG_FATAL("Invalid context in iqtRenderWindowSubject.");
 	}
 #endif
 }
@@ -162,12 +169,91 @@ void iqtRenderWindowSubject::Initialize(bool show)
 }
 
 
+//
+// Finalize the window before deletion
+//
+void iqtRenderWindowSubject::Finalize() 
+{
+	// I don't yet know what should go here
+	//this->doneCurrent();
+	this->hide();
+}
+
+
+//
+//  Mark active/inactive window
+//
+void iqtRenderWindowSubject::UpdateActiveStatus(bool last)
+{
+	if(mOwner->IsActiveWindow() || last)
+	{
+		static const iImage *icon = iggImageFactory::FindIcon("genie1vtk.png");
+		if(icon != 0)
+		{
+#ifdef IQT_3
+			this->setIcon(iqtHelper::ConvertToPixmap(*icon));
+#else
+			this->setWindowIcon(iqtHelper::ConvertToIcon(*icon));
+#endif
+		}
+	}
+	else
+	{
+		static const iImage *icon = iggImageFactory::FindIcon("genie1vtk2.png");
+		if(icon != 0)
+		{
+#ifdef IQT_3
+			this->setIcon(iqtHelper::ConvertToPixmap(*icon));
+#else
+			this->setWindowIcon(iqtHelper::ConvertToIcon(*icon));
+#endif
+		}
+	}
+
+#ifdef IQT_3
+	QString s = this->caption();
+#else
+	QString s = this->windowTitle();
+#endif
+	if(mOwner->IsActiveWindow() && !last)
+	{
+		if(s.left(4) != "*** ")
+		{
+			s = "*** " + s;
+#ifdef IQT_3
+			this->setCaption(s);
+#else
+			this->setWindowTitle(s);
+#endif
+		}
+	}
+	else
+	{
+		if(s.left(4) == "*** ")
+		{
+			s = s.mid(4);
+#ifdef IQT_3
+			this->setCaption(s);
+#else
+			this->setWindowTitle(s);
+#endif
+		}
+	}
+}
+
+
 //
 // End the rendering process and display the image. 
 //
 void iqtRenderWindowSubject::SwapBuffers() 
 {
-	this->swapBuffers();
+	if(this->isVisible())
+	{
+#ifndef IQT_PRE5		
+		if(this->windowHandle()!=0 && this->windowHandle()->isExposed())
+#endif
+			this->swapBuffers();
+	}
 }
 
 
@@ -248,7 +334,7 @@ bool iqtRenderWindowSubject::IsReadyForDumpingImage()
 		this->showNormal();
 		if(this->isMinimized()) 
 		{
-			iRequiredCast<iggShell>(INFO,this->GetShell())->GetMainWindow()->PopupWindow("The visualization window must be visible.\n Please, restore the visualization window before creating an image.");
+			this->GetShell()->PopupWindow("The visualization window must be visible.\n Please, restore the visualization window before creating an image.",MessageType::Warning);
 			return false;
 		}
 	}
@@ -268,18 +354,14 @@ bool iqtRenderWindowSubject::IsReadyForDumpingImage()
 //
 int iqtRenderWindowSubject::InternalCreateTimer(int /*timerId*/, int timerType, unsigned long duration)
 {
-	QTimer *timer = new QTimer(this); IERROR_ASSERT(timer);
-	if(!connect(timer,SIGNAL(timeout()),this,SLOT(OnTimer()))) IERROR_FATAL("Missed connection.");
+	QTimer *timer = new QTimer(this); IERROR_CHECK_MEMORY(timer);
+	if(!connect(timer,SIGNAL(timeout()),this,SLOT(OnTimer()))) IBUG_FATAL("Missed connection.");
 
 	mTimers.Add(timer);
 	//
 	// Start a one-shot timer for 10ms. 
 	//
-#ifdef IVTK_PRE52
-	bool ss = true;
-#else
 	bool ss = (timerType==vtkRenderWindowInteractor::OneShotTimer);
-#endif
 #ifdef IQT_3
 	timer->start(duration,ss);
 #else
@@ -326,7 +408,7 @@ void iqtRenderWindowSubject::paintGL()
 	//
 	if(this->autoBufferSwap())
 	{
-		IERROR_LOW("iqtRenderWindowSubject only works with AutoBufferSwap turned off.");
+		IBUG_WARN("iqtRenderWindowSubject only works with AutoBufferSwap turned off.");
 		return;
 	}
 
@@ -406,8 +488,14 @@ bool iqtRenderWindowSubject::IsCurrent() const
 void iqtRenderWindowSubject::RequestStereo(bool s)
 {
 	QGLFormat f = this->format();
-	f.setStereo(s);
-	this->setFormat(f);
+	//
+	//  This misbehaves non-fatally under Qt 4.8, so be conservative
+	//
+	if(f.stereo() != s)
+	{
+		f.setStereo(s);
+		//this->setFormat(f);
+	}
 }
 
 
