@@ -38,7 +38,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggshell.h"
 
+#include "ibgwindowsubject.h"
+
 #include "iqt.h"
+#include "iqthelper.h"
+#include "iqtwindowhelper.h"
 
 #include <vtkIOStream.h>
 
@@ -47,20 +51,51 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qmessagebox.h>
 #include <qgl.h>
 #else
+#include <QtOpenGL/QGLFormat>
+#ifdef IQT_4
 #include <QtGui/QApplication>
 #include <QtGui/QDesktopWidget>
 #include <QtGui/QMessageBox>
+#else
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDesktopWidget>
+#include <QtWidgets/QMessageBox>
+#endif
 #ifdef Q_WS_X11
 #include <QtGui/QX11Info>
 #endif
-#include <QtOpenGL/QGLFormat>
 #endif
 
 
-iqtShellSubject::iqtShellSubject(iggShell *owner, int argc, char **argv) : ibgShellSubject(owner,argc,argv)
+using namespace iParameter;
+
+
+iqtShellSubject::iqtShellSubject(iggShell *owner) : ibgShellSubject(owner)
 {
-	qtargc = argc;
-	qtargv = argv;
+	//
+	//  Workaround for that weird Qt bug
+	//
+#ifdef IQT_PRE5
+	static int qtargc = 1;
+	static char* qtargv[1];
+	qtargv[0] = (char *)"IFrIT";
+#else
+	static int qtargc = 3;
+	static char* qtargv[3];
+	qtargv[0] = (char *)"IFrIT";
+	qtargv[1] = (char *)"-platformpluginpath";
+	qtargv[2] = (char *)".";
+#endif
+
+#ifndef IQT_3
+	static bool first = true;
+	if(!first)
+	{
+		IBUG_FATAL("Due to a bug in Qt4, IFrIT can only be started once.");
+	}
+	first = false;
+	//QCoreApplicationPrivate::theMainThread = 0;
+#endif
 	new QApplication(qtargc,qtargv);
 
 	//
@@ -69,23 +104,32 @@ iqtShellSubject::iqtShellSubject(iggShell *owner, int argc, char **argv) : ibgSh
 	QWidget *pp = new QMessageBox();
 	if(pp == 0)
 	{
-		IERROR_FATAL("There is not enough memory to run IFrIT.");
-		exit(0);
+		IBUG_FATAL("There is not enough memory to run IFrIT.");
 	}
 	QMessageBox *ps = dynamic_cast<QMessageBox*>(pp);
 	if(ps == 0)
 	{
-		IERROR_FATAL("Qt has not been compiled with the RTTI (Run-Time Type Information) support.\nIFrIT needs all components to be compiled with the RTTI support.\nPlease re-compile Qt with the RTTI support enabled.");
-		delete qApp;
-		exit(0);
+		IBUG_FATAL("Qt has not been compiled with the RTTI (Run-Time Type Information) support.\nIFrIT needs all components to be compiled with the RTTI support.\nPlease re-compile Qt with the RTTI support enabled.");
 	}
 	delete ps;
+
+	//
+	//  Do OpenGL stuff
+	//
+	QGLFormat f;
+    f.setAlpha(true);
+#ifdef I_NO_STEREO
+	f.setStereo(false);
+#else
+	f.setStereo(true);
+#endif
+    QGLFormat::setDefaultFormat( f );
 }
 
 
 iqtShellSubject::~iqtShellSubject()
 {
-	delete qApp;
+	if(qApp != 0) delete qApp;
 }
 
 
@@ -105,7 +149,6 @@ void iqtShellSubject::GetDesktopDimensions(int &w, int &h) const
 void iqtShellSubject::ProcessEvents(bool sync)
 {
 	qApp->flush();
-	if(sync) qApp->syncX();
 	qApp->sendPostedEvents();
 	qApp->processEvents();
 }
@@ -125,42 +168,37 @@ void iqtShellSubject::EnterEventLoop()
 	qApp->exec();
 }
 
-//
-//  Shell capabilities
-//
-bool iqtShellSubject::CanRecognize8BitDisplay(bool check) const
+
+int iqtShellSubject::PopupWindow(ibgWindowSubject *parent, const iString &text, int type, const char *button0, const char *button1, const char *button2) const
 {
-#ifdef Q_WS_X11
-	if(!check) return true;
-	//
-	//  Check for the 8-bit display
-	//
-#ifdef IQT_3
-	return (QPaintDevice::x11AppDepth() < 16);
-#else
-	return (QX11Info::appDepth() < 16);
-#endif
-#else
-	return false;
-#endif
-}
+	QWidget *w = 0;
 
+	if(parent != 0)
+	{
+		iqtWindowHelper *h = dynamic_cast<iqtWindowHelper*>(parent->GetHelper());
+		if(h != 0) w = h->GetWidget();
+	}
 
-bool iqtShellSubject::CanDockWindows() const
-{
-	return true;
-}
-
-
-bool iqtShellSubject::CanChangeFontSize() const
-{
-	return true;
-}
-
-
-bool iqtShellSubject::CheckCondition(int /* flag */) const
-{
-	return false;  // seems not possible to discover from Qt?
+	switch(type)
+	{
+	case MessageType::Information:
+		{
+			return QMessageBox::information(w,"IFrIT",iqtHelper::Convert(text),button0,button1,button2);
+		}
+	case MessageType::Warning:
+		{
+			return QMessageBox::warning(w,"IFrIT",iqtHelper::Convert(text),button0,button1,button2);
+		}
+	case MessageType::Error:
+		{
+			return QMessageBox::critical(w,"IFrIT",iqtHelper::Convert(text),button0,button1,button2);
+		}
+	default:
+		{
+			IBUG_WARN("Incorrect type for pop-up window.");
+		}
+	}
+	return -1;
 }
 
 #endif
