@@ -50,17 +50,25 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qlayout.h>
 #include <qpushbutton.h>
 #else
+#ifdef IQT_4
 #include <QtGui/QColorDialog>
 #include <QtGui/QFrame>
 #include <QtGui/QGridLayout>
 #include <QtGui/QLabel>
 #include <QtGui/QPushButton>
+#else
+#include <QtWidgets/QColorDialog>
+#include <QtWidgets/QFrame>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QPushButton>
+#endif
 #endif
 
 
 iqtWidgetColorSelectionSubject::iqtWidgetColorSelectionSubject(iggWidget *owner) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetColorSelectionSubject(owner), mSize(16)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 
 	//
 	//  Create a layout
@@ -74,7 +82,7 @@ iqtWidgetColorSelectionSubject::iqtWidgetColorSelectionSubject(iggWidget *owner)
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 
-	if(!this->connect(mButton,SIGNAL(clicked()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid1()))) IERROR_LOW("Missed connection.");
+	if(!this->connect(mButton,SIGNAL(clicked()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid1()))) IBUG_WARN("Missed connection.");
 }
 
 
@@ -106,8 +114,12 @@ void iqtWidgetColorSelectionSubject::SetColor(const iColor &v)
 #include <qdrawutil.h>
 #include <qpainter.h>
 #else
-//#include <qdrawutil.h>
 #include <QtGui/QPainter>
+#ifdef IQT_4
+#include <QtGui/qdrawutil.h>
+#else
+#include <QtWidgets/qdrawutil.h>
+#endif
 #endif
 
 
