@@ -36,15 +36,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #ifdef IQT_3
 #include <qwidget.h>
-#else
+#elif defined(IQT_4)
 #include <QtGui/QWidget>
+#else
+#include <QtWidgets/QWidget>
 #endif
 #include "ibgwidgetentrysubject.h"
 
 
-class iqtCallbackHelper;
-
-class QLCDNumber;
 class QLineEdit;
 class QMouseEvent;
 class QSlider;
@@ -61,7 +60,6 @@ public:
 
 	virtual void AddButton(ibgWidgetButtonSubject* button);
 	virtual void SetEditable(bool s);
-	virtual void SetDelayedEdit(bool s);
 
 	//
 	//  Decorator functions
@@ -88,14 +86,9 @@ protected:
 
 	iqtWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label);
 
-	void SetDoubleValue(int v, double dv, bool withEdit);
-
-	iqtCallbackHelper *mCallbackHelper;
-
 	int mNumButtons;
 
-	QLCDNumber *mView;
-	QLineEdit *mEdit;
+	QLineEdit *mDisplay;
 	QSlider *mSlider;
 };
 
