@@ -45,12 +45,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qwhatsthis.h>
 #include <qwidget.h>
 #else
+#include <QtGui/QWhatsThisClickedEvent>
+#ifdef IQT_4
 #include <QtGui/QAbstractButton>
 #include <QtGui/QButtonGroup>
 #include <QtGui/QToolTip>
 #include <QtGui/QWhatsThis>
-#include <QtGui/QWhatsThisClickedEvent>
 #include <QtGui/QWidget>
+#else
+#include <QtWidgets/QAbstractButton>
+#include <QtWidgets/QButtonGroup>
+#include <QtWidgets/QToolTip>
+#include <QtWidgets/QWhatsThis>
+#include <QtWidgets/QWidget>
+#endif
 using namespace Qt;
 #endif
 
@@ -120,7 +128,7 @@ protected:
 //
 iqtWidgetHelper::iqtWidgetHelper(QWidget *widget, iggWidget *owner) : ibgWidgetHelper(owner)
 {
-	IERROR_ASSERT(widget);
+	IASSERT(widget);
 	mWidget = widget;
 	mBaloonHelp = 0;
 
@@ -285,15 +293,6 @@ void iqtWidgetHelper::OnBool1(bool v)
 }
 
 
-void iqtWidgetHelper::OnString1(const QString &v)
-{
-	if(!mWidget->signalsBlocked())
-	{
-		this->OnString1Body(iqtHelper::Convert(v));
-	}
-}
-
-
 void iqtWidgetHelper::OnButtonClicked(QAbstractButton *b)
 {
 #ifndef IQT_3
