@@ -47,13 +47,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifdef IQT_3
 #include <qapplication.h>
 #else
+#ifdef IQT_4
 #include <QtGui/QApplication>
+#else
+#include <QtWidgets/QApplication>
+#endif
 #endif
 
 
 iqtWidgetProgressBarSubject::iqtWidgetProgressBarSubject(iggWidget *owner) : QProgressBar(iqtHelper::Convert(owner->GetParent())), ibgWidgetProgressBarSubject(owner)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 
 #ifdef IQT_3
 	this->setTotalSteps(100);
