@@ -51,6 +51,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qradiobutton.h>
 #include <qspinbox.h>
 #else
+#include <QtGui/QStandardItem>
+#include <QtGui/QStandardItemModel>
+#ifdef IQT_4
 #include <QtGui/QAbstractItemView>
 #include <QtGui/QButtonGroup>
 #include <QtGui/QComboBox>
@@ -58,8 +61,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QtGui/QLabel>
 #include <QtGui/QRadioButton>
 #include <QtGui/QSpinBox>
-#include <QtGui/QStandardItem>
-#include <QtGui/QStandardItemModel>
+#else
+#include <QtWidgets/QAbstractItemView>
+#include <QtWidgets/QButtonGroup>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QSpinBox>
+#endif
 #endif
 
 
@@ -72,7 +82,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 iqtWidgetSpinBoxSubject::iqtWidgetSpinBoxSubject(iggWidget *owner, int min, int max, const iString &title, int step) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetSpinBoxSubject(owner,min,max,title,step)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 	//
 	//  Create a layout
 	//
@@ -96,10 +106,11 @@ iqtWidgetSpinBoxSubject::iqtWidgetSpinBoxSubject(iggWidget *owner, int min, int
 	l->addWidget(mBox,0,1);
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
+	this->setMinimumHeight(25);
 
 	iqtWidgetHelper *h = iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper);
 	if(h != 0) h->SetDisabling(true);
-	if(!this->connect(mBox,SIGNAL(valueChanged(int)),h,SLOT(OnInt1(int)))) IERROR_LOW("Missed connection.");
+	if(!this->connect(mBox,SIGNAL(valueChanged(int)),h,SLOT(OnInt1(int)))) IBUG_WARN("Missed connection.");
 }
 
 
@@ -175,7 +186,7 @@ int iqtWidgetSpinBoxSubject::Count()
 //
 iqtWidgetComboBoxSubject::iqtWidgetComboBoxSubject(iggWidget *owner, const iString &title, bool bold) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetComboBoxSubject(owner,title,bold)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 	//
 	//  Create a layout
 	//
@@ -199,8 +210,8 @@ iqtWidgetComboBoxSubject::iqtWidgetComboBoxSubject(iggWidget *owner, const iStri
 	}
 //	mBox->listBox()->setAutoBottomScrollBar(true); 
 
-	if(!this->connect(mBox,SIGNAL(activated(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt1(int)))) IERROR_LOW("Missed connection.");
-//	if(!this->connect(mBox,SIGNAL(highlighted(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt2(int)))) IERROR_LOW("Missed connection.");
+	if(!this->connect(mBox,SIGNAL(activated(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt1(int)))) IBUG_WARN("Missed connection.");
+//	if(!this->connect(mBox,SIGNAL(highlighted(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt2(int)))) IBUG_WARN("Missed connection.");
 }
 
 
@@ -391,7 +402,7 @@ void iqtWidgetComboBoxSubject::Clear()
 //
 iqtWidgetRadioBoxSubject::iqtWidgetRadioBoxSubject(iggWidget *owner, int cols, const iString &title) : QRadioBox(iqtHelper::Convert(owner->GetParent())), ibgWidgetRadioBoxSubject(owner,cols,title)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 	//
 	//  Create a layout
 	//
@@ -400,7 +411,7 @@ iqtWidgetRadioBoxSubject::iqtWidgetRadioBoxSubject(iggWidget *owner, int cols, c
 
 	if(cols < 0)
 	{
-		IERROR_LOW("Incorrect number of columns.");
+		IBUG_WARN("Incorrect number of columns.");
 		cols = 1;
 	}
 
@@ -416,9 +427,9 @@ iqtWidgetRadioBoxSubject::iqtWidgetRadioBoxSubject(iggWidget *owner, int cols, c
 	this->setTitle(iqtHelper::ConvertWithModifiers(this,title));
 
 #ifdef IQT_3
-	if(!this->connect(this,SIGNAL(clicked(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt1(int)))) IERROR_LOW("Missed connection.");
+	if(!this->connect(this,SIGNAL(clicked(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt1(int)))) IBUG_WARN("Missed connection.");
 #else
-	if(!this->connect(mGroup,SIGNAL(buttonClicked(QAbstractButton * )),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnButtonClicked(QAbstractButton * )))) IERROR_LOW("Missed connection.");
+	if(!this->connect(mGroup,SIGNAL(buttonClicked(QAbstractButton * )),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnButtonClicked(QAbstractButton * )))) IBUG_WARN("Missed connection.");
 #endif
 }
 
@@ -452,10 +463,6 @@ void iqtWidgetRadioBoxSubject::SetValue(int v)
 		b->setChecked(true);
 		b->blockSignals(false);
 	}
-	else
-	{
-		IERROR_LOW("Invalid button index.");
-	}
 #endif
 }
 
@@ -514,6 +521,7 @@ void iqtWidgetRadioBoxSubject::SetItem(const iString &text, int index, bool vis)
 		mGroup->addButton(b);
 		this->layout()->addWidget(b);
 #endif
+		b->setText("unavailable");
 		this->layout()->invalidate(); // Qt bug!!! 
 	}
 	QString s = iqtHelper::ConvertWithModifiers(b,text);
