@@ -38,16 +38,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qbuttongroup.h>
 #include <qwidget.h>
 #define QRadioBox QButtonGroup
-#else
+#elif defined(IQT_4)
 #include <QtGui/QGroupBox>
 #include <QtGui/QWidget>
 #define QRadioBox QGroupBox
+#else
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QWidget>
+#define QRadioBox QGroupBox
 #endif
 #include "ibgwidgetselectionboxsubject.h"
 
-class iqtCallbackHelper;
-
-class QAbstractButton;
 class QButtonGroup;
 class QComboBox;
 class QLabel;
@@ -82,8 +83,6 @@ protected:
 
 	iqtWidgetSpinBoxSubject(iggWidget *owner, int min, int max, const iString &title, int step);
 
-	iqtCallbackHelper *mCallbackHelper;
-
 	QSpinBox *mBox;
 	QLabel *mTitle;
 };
@@ -122,8 +121,6 @@ protected:
 
 	iqtWidgetComboBoxSubject(iggWidget *owner, const iString &title, bool bold);
 
-	iqtCallbackHelper *mCallbackHelper;
-
 	QComboBox *mBox;
 	QLabel *mTitle;
 };
@@ -158,7 +155,6 @@ protected:
 
 	QAbstractButton* FindButton(int index); // porting helper
 
-	iqtCallbackHelper *mCallbackHelper;
 #ifndef IQT_3
 	QButtonGroup *mGroup;
 #endif
