@@ -44,30 +44,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 using namespace iParameter;
 
 
-#ifdef IQT_3
-//
-//  Temporary fix: people complained that syntax highliting code does not
-//  compile under Qt4.
-//
-#include <private/qrichtext_p.h>
-
-#if (QT_VERSION < 0x030005)
-#define QTextParagraph QTextParag
-#endif
-
-#else
+#ifndef IQT_3
 
 #include <QtGui/QMouseEvent>
 #include <QtGui/QTextBlock>
 
-#define QTextPreProcessor QObject
-
 //
 // Helper class
 //
@@ -106,194 +93,12 @@ private:
 #endif
 
 
-class iqtWidgetTextEditorSubject::SyntaxHighlighter : public QTextPreProcessor
-{
-
-public:
-
-	SyntaxHighlighter() : QTextPreProcessor(), mLastFormat(0), mLastFormatId(-1)
-	{
-		mActive = false;
-
-		mCommentString = "";
-		mHighlightComments = mHighlightStrings = false;
-
-		mDefaultFont = QFont("courier",10,QFont::Normal);
-
-#ifdef IQT_3
-		this->AddFormat(0,new QTextFormat(mDefaultFont,Qt::black));
-		this->AddFormat(1,new QTextFormat(mDefaultFont,Qt::darkGreen));
-		this->AddFormat(2,new QTextFormat(mDefaultFont,Qt::darkRed));
-#endif
-
-		mFirstFormat = 3;
-	}
-
-	virtual ~SyntaxHighlighter()
-	{
-		while(mKeywords.Size() > 0) delete mKeywords.RemoveLast();
-	}
-
-	void SetPointSize(int s)
-	{
-#ifdef IQT_3
-		unsigned int i;
-		for(i=0; i<mFormats.count(); i++)
-		{
-			this->format(i)->setPointSize(s);
-			this->format(i)->setBold((s > 13));
-		}
-#endif
-		mDefaultFont = QFont(mDefaultFont.family(),s,(s>13)?QFont::Bold:QFont::Normal);
-	}
-
-#ifdef IQT_3
-	void process(QTextDocument*, QTextParagraph *string, int, bool)
-	{
-		int i, j, len, index, index2, indexMax = -1;
-		static QString line;
-		static QString alphabeth = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ-_";
-		static QString mathChars = "xXeE";
-		static QString numbers = "0123456789";
-
-		line = string->string()->toString();
-		line = line.left(line.length()-1);
-		if(line.isEmpty() || !mActive) return;
-		//
-		//  Highlight comments first
-		//
-		if(mHighlightComments)
-		{
-			indexMax = line.find(mCommentString,0);
-			if(indexMax == -1) 
-			{
-				indexMax = line.length(); 
-			}
-			else
-			{
-				string->setFormat(indexMax,line.length()-indexMax,this->format(1),false);
-			}
-
-			if(indexMax == 0) return; // whole line is a comment
-		}
-
-		string->setFormat(0,indexMax,this->format(0),false);
-		//
-		//  Highlight reserved words
-		//
-		for(j=0; j<mKeywords.Size(); j++)
-		{
-			QStringList &list = *mKeywords[j];
-			for(i=0; i<(int)list.count(); i++)
-			{
-				len = list[i].length();
-				index = 0;
-				while((index=line.find(list[i],index))!=-1 && index<indexMax && (index==0 || alphabeth.find(line.at(index-1),0)==-1) && alphabeth.find(line.at(index+len),0)==-1)
-				{
-					string->setFormat(index,len,this->format(mFirstFormat+j),false);
-					index += len;
-				}
-			}
-		}
-
-		//
-		//  Highlight strings
-		//
-		if(mHighlightStrings)
-		{
-			index2 = -1;
-			while((index=line.find('"',index2+1)) != -1)
-			{
-				index2 = line.find('"',index+1);
-				if(index2 == -1) index2 = indexMax - 1; 
-				string->setFormat(index,index2-index+1,this->format(2),false);
-			}
-		}
-	}
-
-	QTextFormat* format(int id)
-	{
-		if(mLastFormatId==id && mLastFormat) return mLastFormat;
-
-		QTextFormat *f = mFormats[id];
-		mLastFormat = f ? f : mFormats[ 0 ];
-		mLastFormatId = id;
-		return mLastFormat;
-	}
-#endif
-
-	void Activate(bool s)
-	{
-		mActive = s;
-	}
-
-	void AddKeyword(const QString &s, int category)
-	{
-		if(category>=0 && category<mKeywords.Size())
-		{
-			mKeywords[category]->append(s);
-		}
-	}
-
-	void AddCategory(const QColor &c)
-	{
-#ifdef IQT_3
-		this->AddFormat(mFirstFormat+mKeywords.Size(),new QTextFormat(mDefaultFont,c));
-#endif
-		mKeywords.Add(new QStringList);
-	}
-
-	void SetHighlightComments(const QString &s, const QColor &c)
-	{
-		mHighlightComments = !s.isEmpty();
-		if(mHighlightComments)
-		{
-			mCommentString = s;
-#ifdef IQT_3
-			this->format(1)->setColor(c);
-#endif
-		}
-	}
-
-	void SetHighlightStrings(const QColor &c)
-	{
-		mHighlightStrings = true;
-		if(mHighlightStrings)
-		{
-#ifdef IQT_3
-			this->format(2)->setColor(c);
-#endif
-		}
-	}
-
-private:
-
-#ifdef IQT_3
-	void AddFormat(int id, QTextFormat *f)
-	{
-		mFormats.insert(id,f);
-	}
-
-	QIntDict<QTextFormat> mFormats;
-#endif
-
-	QTextFormat *mLastFormat;
-
-	int mLastFormatId;
-	iArray<QStringList*> mKeywords;
-	QString mCommentString;
-	bool mActive, mHighlightComments, mHighlightStrings;
-	QFont mDefaultFont;
-	int mFirstFormat;
-};
-
-
 //
 // Constructs an editor and connects a syntax highlighter
 //
 iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owner, unsigned int mode) : QTextEdit(iqtHelper::Convert(owner->GetParent())), ibgWidgetTextEditorSubject(owner,mode), mMode(mode)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
 	this->setFocusPolicy(QFocus::StrongFocus);
@@ -326,30 +131,20 @@ iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owne
 	if(mode & TextEditorFlag::WithHTML) this->setTextFormat(Qt::RichText); else this->setTextFormat(Qt::PlainText);
 #endif
 
-	mSyntaxHighlighter = new SyntaxHighlighter; IERROR_ASSERT(mSyntaxHighlighter);
+	if(!connect(this,SIGNAL(textChanged()),this,SLOT(OnTextChanged()))) IBUG_WARN("Missed connection.");
+	if(!connect(this,SIGNAL(selectionChanged()),this,SLOT(OnSelectionChanged()))) IBUG_WARN("Missed connection.");
 #ifdef IQT_3
-	this->document()->setPreProcessor(mSyntaxHighlighter);
-#endif
-
-	if(!connect(this,SIGNAL(textChanged()),this,SLOT(OnTextChanged()))) IERROR_LOW("Missed connection.");
-	if(!connect(this,SIGNAL(selectionChanged()),this,SLOT(OnSelectionChanged()))) IERROR_LOW("Missed connection.");
-#ifdef IQT_3
-	if(!connect(this,SIGNAL(returnPressed()),this,SLOT(OnReturnPressed()))) IERROR_LOW("Missed connection.");
-	if(!connect(this,SIGNAL(cursorPositionChanged(int,int)),this,SLOT(OnCursorPositionChanged(int,int)))) IERROR_LOW("Missed connection.");
+	if(!connect(this,SIGNAL(returnPressed()),this,SLOT(OnReturnPressed()))) IBUG_WARN("Missed connection.");
+	if(!connect(this,SIGNAL(cursorPositionChanged(int,int)),this,SLOT(OnCursorPositionChanged(int,int)))) IBUG_WARN("Missed connection.");
 #else
-	if(!connect(this,SIGNAL(returnPressed2()),this,SLOT(OnReturnPressed()))) IERROR_LOW("Missed connection.");
-	if(!connect(this,SIGNAL(cursorPositionChanged()),this,SLOT(OnCursorPositionChanged()))) IERROR_LOW("Missed connection.");
+	if(!connect(this,SIGNAL(returnPressed2()),this,SLOT(OnReturnPressed()))) IBUG_WARN("Missed connection.");
+	if(!connect(this,SIGNAL(cursorPositionChanged()),this,SLOT(OnCursorPositionChanged()))) IBUG_WARN("Missed connection.");
 #endif
 }
 
 
 iqtWidgetTextEditorSubject::~iqtWidgetTextEditorSubject()
 {
-#ifdef IQT_3
-	this->document()->setPreProcessor(0);
-#endif
-
-	delete mSyntaxHighlighter;
 }
 
 
@@ -496,17 +291,12 @@ iString iqtWidgetTextEditorSubject::GetLine(int n) const
 //
 //  Text attribute manipulations
 //
-void iqtWidgetTextEditorSubject::SetPointSize(int s)
+void iqtWidgetTextEditorSubject::AdjustFontSize(int s)
 {
 	if(!this->SupportsHTML())
 	{
-		mSyntaxHighlighter->SetPointSize(s);
 		this->blockSignals(true);
-#ifdef IQT_3
-		this->setPointSize(s);
-#else
-		this->setFontPointSize(s);
-#endif
+		if(s > 0) this->zoomIn(s); else if(s < 0) this->zoomOut(-s);
 		this->blockSignals(false);
 	}
 }
@@ -586,6 +376,12 @@ iColor iqtWidgetTextEditorSubject::GetLineColor(int line) const
 }
 
 
+void iqtWidgetTextEditorSubject::SetReadOnly(bool s)
+{
+	this->setReadOnly(s);
+}
+
+
 //
 //  Selection
 //
@@ -768,39 +564,6 @@ bool iqtWidgetTextEditorSubject::Find(const iString &text, bool cs, bool wo, boo
 }
 
 
-//
-//  Syntax highlighting
-//
-void iqtWidgetTextEditorSubject::HighlightSyntax(bool s)
-{
-	mSyntaxHighlighter->Activate(s);
-}
-
-
-void iqtWidgetTextEditorSubject::AddKeyword(const iString &word, int category)
-{
-	mSyntaxHighlighter->AddKeyword(iqtHelper::Convert(word),category);
-}
-
-
-void iqtWidgetTextEditorSubject::AddCategory(const iColor &color)
-{
-	mSyntaxHighlighter->AddCategory(iqtHelper::Convert(color));
-}
-
-
-void iqtWidgetTextEditorSubject::HighlightComments(const iString &comment, const iColor &color)
-{
-	mSyntaxHighlighter->SetHighlightComments(iqtHelper::Convert(comment),iqtHelper::Convert(color));
-}
-
-
-void iqtWidgetTextEditorSubject::HighlightStrings(const iColor &color)
-{
-	mSyntaxHighlighter->SetHighlightStrings(iqtHelper::Convert(color));
-}
-
-
 void iqtWidgetTextEditorSubject::enterEvent(QEvent * )
 {
 	//
