@@ -33,13 +33,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iqtwidgettrackballsubject.h"
 
 
-#include "icontrolmodule.h"
 #include "ierror.h"
 #include "imath.h"
-#include "ishell.h"
 #include "itransform.h"
 #include "iviewmodule.h"
 
+#include "iggimagefactory.h"
+#include "iggshell.h"
 #include "iggwidget.h"
 #include "iggwidgetrendermodebutton.h"
 
@@ -56,24 +56,32 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qpainter.h>
+#include <qtoolbutton.h>
 #else
 #include <QtGui/QBitmap>
-#include <QtGui/QGridLayout>
-#include <QtGui/QLabel>
 #include <QtGui/QMouseEvent>
 #include <QtGui/QPainter>
+#ifdef IQT_4
+#include <QtGui/QGridLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QToolButton>
+#else
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QToolButton>
+#endif
 #endif
 
 //
 //  Templates
 //
-#include "iarraytemplate.h"
+#include "iarray.tlh"
 
 
 namespace iqtWidgetTrackBall_Private
 {
-	const float PI = 3.1415927535f;
-	const float TWOPI = 2*PI;
+	const double PI = 3.1415926535897932384626433;
+	const double TWOPI = 2*PI;
 };
 
 
@@ -88,7 +96,7 @@ iqtWidgetTrackBallSubject::iqtWidgetTrackBallSubject(iggWidget *owner, bool foll
 #endif
 																																	), ibgWidgetTrackBallSubject(owner,followCamera)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_CHECK_MEMORY(mWidgetHelper);
 	//
 	//  Create a layout
 	//
@@ -103,6 +111,33 @@ iqtWidgetTrackBallSubject::iqtWidgetTrackBallSubject(iggWidget *owner, bool foll
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
 	this->setMinimumSize(mFixedSize,mFixedSize);
 
+#ifdef IQT_3
+	l->expand(2,3);
+#endif
+	
+	QToolButton *db = new QToolButton(this);
+#ifdef IQT_3
+	db->setPixmap(iqtHelper::ConvertToPixmap(*iggImageFactory::FindIcon("data.png")));
+#else
+	const iImage &icon(*iggImageFactory::FindIcon("data.png"));
+	QIcon ic = iqtHelper::ConvertToIcon(icon);
+	db->setIcon(ic);
+	if(db->minimumSize() == db->maximumSize())
+	{
+		db->setIconSize(QSize(icon.Width(),icon.Height()));
+	}
+#endif
+	//db->setAutoRaise(true);
+	if(!this->connect(db,SIGNAL(clicked()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid1()))) IBUG_WARN("Missed connection.");
+
+	l->addWidget(db,0,0);
+#ifdef IQT_3
+	l->setColStretch(1,10);
+#else
+	l->setColumnStretch(1,10);
+#endif
+	l->setRowStretch(1,10);
+
 	mInUpdate = false;
 }
 
@@ -131,18 +166,9 @@ void iqtWidgetTrackBallSubject::AddButton(ibgWidgetButtonSubject* button)
 	if(button != 0)
 	{
 		QGridLayout *l = iDynamicCast<QGridLayout,QLayout>(INFO,this->layout());
-#ifdef IQT_3
-		l->expand(2,2);
-#endif
 		iqtWidgetButtonSubject *bs = iDynamicCast<iqtWidgetButtonSubject,ibgWidgetButtonSubject>(INFO,button);
 		iqtHelper::SetParent(bs,this);
-		l->addWidget(bs,0,1);
-#ifdef IQT_3
-		l->setColStretch(0,10);
-#else
-		l->setColumnStretch(0,10);
-#endif
-		l->setRowStretch(1,10);
+		l->addWidget(bs,0,2);
 	}
 }
 
@@ -172,7 +198,7 @@ void iqtWidgetTrackBallSubject::mousePressEvent(QMouseEvent *e)
 			this->erase();
 #endif
 		}
-		iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnVoid1();
+		//iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnVoid1();
 	}
 
 	if(e!=0 && e->button()==Qt::RightButton)
@@ -189,7 +215,7 @@ void iqtWidgetTrackBallSubject::mouseReleaseEvent(QMouseEvent *e)
 	if(e!=0 && (e->button()==Qt::LeftButton || e->button()==Qt::RightButton))
 	{
 		iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnBool1(true);
-		iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnVoid2();
+		//iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnVoid2();
 		if(e->button() == Qt::RightButton)
 		{
 			while(mTimerIds.Size() > 0) this->killTimer(mTimerIds.RemoveLast());
@@ -240,7 +266,7 @@ void iqtWidgetTrackBallSubject::paintEvent(QPaintEvent * )
 
 	if(!mFollowCamera)
 	{
-		ct = mOwner->GetShell()->GetControlModule()->GetViewModule()->GetRenderer()->GetActiveCamera()->GetViewTransformObject()->GetLinearInverse();
+		ct = mOwner->GetShell()->GetViewModule()->GetRenderer()->GetActiveCamera()->GetViewTransformObject()->GetLinearInverse();
 	}
 
 	//
@@ -303,13 +329,13 @@ void iqtWidgetTrackBallSubject::paintEvent(QPaintEvent * )
 	}
 
 	QColor c;
-	float r2, lon, lat, dimFactor, n0[3], n[3];
+	double r2, lon, lat, dimFactor, n0[3], n[3];
 	for(i=-rad; i<=rad; i++)
 	{
-		n0[0] = float(i)/rad;
+		n0[0] = double(i)/rad;
 		for(j=-rad; j<=rad; j++)
 		{
-			n0[1] = float(j)/rad;
+			n0[1] = double(j)/rad;
 			r2 = n0[0]*n0[0] + n0[1]*n0[1];
 			if(r2 <= 1.0)
 			{
@@ -337,8 +363,8 @@ void iqtWidgetTrackBallSubject::paintEvent(QPaintEvent * )
 				//  Light calculation
 				//
 				dimFactor = vtkMath::Dot(mLightDirection,n0);
-				if(dimFactor < 0.1) dimFactor = (float)0.1;
-				c.setRgb(round(c.red()*dimFactor),round(c.green()*dimFactor),round(c.blue()*dimFactor));
+				if(dimFactor < 0.1) dimFactor = (double)0.1;
+				c.setRgb(iMath::Round2Int(c.red()*dimFactor),iMath::Round2Int(c.green()*dimFactor),iMath::Round2Int(c.blue()*dimFactor));
 				
 				//
 				//  Draw the scene
