@@ -36,8 +36,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #ifdef IQT_3
 #include <qwidget.h>
-#else
+#elif defined(IQT_4)
 #include <QtGui/QWidget>
+#else
+#include <QtWidgets/QWidget>
 #endif
 #include "ibgwidgettrackballsubject.h"
 
