@@ -46,13 +46,19 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qwidget.h>
 #include <qgl.h>  //  needed for diabling close button under windows
 #else
-#include <QtGui/QApplication>
 #include <QtGui/QIcon>
-#include <QtGui/QLayout>
 #include <QtGui/QPixmap>
 #include <QtGui/QResizeEvent>
+#include <QtOpenGL/QGLWidget>  //  needed for disabling close button under windows
+#ifdef IQT_4
+#include <QtGui/QApplication>
+#include <QtGui/QLayout>
 #include <QtGui/QWidget>
-#include <QtOpenGL/QGLWidget>  //  needed for diabling close button under windows
+#else
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QWidget>
+#endif
 #endif
 
 
@@ -61,7 +67,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 iqtWindowHelper::iqtWindowHelper(QWidget *widget, const iImage *icon, const iString &title, bool disableClose) : ibgWindowHelper(icon,title,disableClose)
 {
-	mWidget = widget; IERROR_ASSERT(widget);
+	IASSERT(widget);
+	mWidget = widget; 
 
 #ifndef IQT_40
 	iqtHelper::SetBackground(mWidget,1); // messes things on Unix under Qt 4.0
@@ -97,7 +104,7 @@ void iqtWindowHelper::RestoreDecoration()
 #ifdef _WIN32
 	if(mDisableClose)
 	{
-		HMENU hmenu = GetSystemMenu(mWidget->winId(),false);
+		HMENU hmenu = GetSystemMenu((HWND)mWidget->winId(),false);
 //		DeleteMenu(hmenu,SC_CLOSE,MF_BYCOMMAND);  //ok actually remove the close button
 		EnableMenuItem(hmenu,SC_CLOSE,MF_BYCOMMAND|MF_GRAYED);  //ok actually remove the close button
 	}
